#
# Copyright (c) 2014-2017 National Technology and Engineering
# Solutions of Sandia, LLC. Under the terms of Contract DE-NA0003525
# with National Technology and Engineering Solutions of Sandia, LLC,
# the U.S. Government retains certain rights in this software.
#
# Redistribution and use in source and binary forms, with or without
# modification, are permitted provided that the following conditions
# are met:
#
# 1. Redistributions of source code must retain the above copyright
# notice, this list of conditions and the following disclaimer.
#
# 2. Redistributions in binary form must reproduce the above copyright
# notice, this list of conditions and the following disclaimer in the
# documentation and/or other materials provided with the distribution.
#
# THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS
# "AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT
# LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS
# FOR A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE
# COPYRIGHT HOLDER OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT,
# INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING,
# BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES;
# LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER
# CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT
# LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN
# ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE
# POSSIBILITY OF SUCH DAMAGE.

# -*- encoding: utf-8; -*-

"""
city_table.py - Position and population data for lots of cities
"""

#
# This code is derived from a list of cities provided by MaxMind at
# http://www.maxmind.com/en/worldcities.  Here is the license under
# which we use the data:
#
# OPEN DATA LICENSE for MaxMind WorldCities and Postal Code Databases
#
# Copyright (c) 2008 MaxMind Inc.  All Rights Reserved.
#
# The database uses toponymic information, based on the Geographic
# Names Data Base, containing official standard names approved by the
# United States Board on Geographic Names and maintained by the
# National Geospatial-Intelligence Agency. More information is
# available at the Maps and Geodata link at www.nga.mil. The National
# Geospatial-Intelligence Agency name, initials, and seal are
# protected by 10 United States Code Section 445.
#
# It also uses free population data from Stefan Helders www.world-gazetteer.com.
# Visit his website to download the free population data.  Our database
# combines Stefan's population data with the list of all cities in the world.
#
# All advertising materials and documentation mentioning features or
# use of this database must display the following acknowledgment:
# "This product includes data created by MaxMind, available from
# http://www.maxmind.com/"
#
# Redistribution and use with or without modification, are permitted provided
# that the following conditions are met:
#
# 1. Redistributions must retain the above copyright notice, this list of
# conditions and the following disclaimer in the documentation and/or other
# materials provided with the distribution.
#
# 2. All advertising materials and documentation mentioning features or use of
# this database must display the following acknowledgement:
# "This product includes data created by MaxMind, available from
# http://www.maxmind.com/"
#
# 3. "MaxMind" may not be used to endorse or promote products derived from this
# database without specific prior written permission.
#
# THIS DATABASE IS PROVIDED BY MAXMIND.COM ``AS IS'' AND ANY EXPRESS
# OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED
# WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
# ARE DISCLAIMED. IN NO EVENT SHALL MAXMIND.COM BE LIABLE FOR ANY
# DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL
# DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE
# GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS
# INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER
# IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR
# OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS DATABASE, EVEN
# IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.

table_headings = [ u"Country",u"AccentCity",'Population','Latitude','Longitude' ]
city_table = [
    [ u"ad",u"Andorra la Vella",20430,42.5,1.5166667 ],
    [ u"ad",u"Canillo",3292,42.5666667,1.6 ],
    [ u"ad",u"Encamp",11224,42.5333333,1.5833333 ],
    [ u"ad",u"La Massana",7211,42.55,1.5166667 ],
    [ u"ad",u"Les Escaldes",15854,42.5,1.5333333 ],
    [ u"ad",u"Ordino",2553,42.55,1.5333333 ],
    [ u"ad",u"Sant Julià de Lòria",8020,42.4666667,1.5 ],
    [ u"ae",u"Abu Dhabi",603687,24.466667,54.366667 ],
    [ u"ae",u"Dubai",1137376,25.258172,55.304717 ],
    [ u"ae",u"Sharjah",543942,25.35731,55.403304 ],
    [ u"af",u"Acin",15098,34.082481,70.668152 ],
    [ u"af",u"Anar Darreh",10023,32.758698,61.653969 ],
    [ u"af",u"Andarab",27034,35.633484,69.260195 ],
    [ u"af",u"Asadabad",48400,34.873113,71.14697 ],
    [ u"af",u"Asmar",15708,35.033328,71.358087 ],
    [ u"af",u"Aybak",47877,36.26468,68.015512 ],
    [ u"af",u"Azrow",12526,34.173553,69.645728 ],
    [ u"af",u"Baglan",108481,36.130684,68.708286 ],
    [ u"af",u"Bagrami",30256,34.493761,69.274274 ],
    [ u"af",u"Baraki Barak",22305,33.9675,68.948611 ],
    [ u"af",u"Cah Ab",23424,37.397734,69.814644 ],
    [ u"af",u"Carikar",53693,35.016585,69.174011 ],
    [ u"af",u"Ciras",12778,35.416737,65.982341 ],
    [ u"af",u"Dawlatabad",13603,36.432589,64.920713 ],
    [ u"af",u"Dawlatabad",17674,36.98782,66.82066 ],
    [ u"af",u"Deh Rawud",25683,32.624131,65.459659 ],
    [ u"af",u"Eskasem",12120,36.706932,71.570658 ],
    [ u"af",u"Farah",43574,32.374508,62.116383 ],
    [ u"af",u"Gardan Diwal",6815,34.508977,68.260739 ],
    [ u"af",u"Gardez",103732,33.597439,69.225922 ],
    [ u"af",u"Gazni",143049,33.550833,68.4225 ],
    [ u"af",u"Geresk",43638,31.820894,64.570048 ],
    [ u"af",u"Herat",272880,34.348167,62.199673 ],
    [ u"af",u"Jalalabad",200389,34.426468,70.45153 ],
    [ u"af",u"Jurm",12121,36.864768,70.834207 ],
    [ u"af",u"Kabul",3043589,34.516667,69.183333 ],
    [ u"af",u"Kholm",64954,36.697362,67.698255 ],
    [ u"af",u"Khowst",96246,33.339512,69.92041 ],
    [ u"af",u"Kuhestan",12087,34.653889,61.197778 ],
    [ u"af",u"Kusk",16952,33.29565,61.952206 ],
    [ u"af",u"Lar Gerd",11635,35.489361,66.664088 ],
    [ u"af",u"Mehtar Lam",17350,34.671389,70.209444 ],
    [ u"af",u"Mirabad",14160,30.436244,61.838304 ],
    [ u"af",u"Nahrin",22389,36.064904,69.13343 ],
    [ u"af",u"Nuristan",17072,34.95,70.4 ],
    [ u"af",u"Orgun",10665,32.901111,69.152798 ],
    [ u"af",u"Pagman",49173,34.5875,68.953333 ],
    [ u"af",u"Panjab",13471,34.387949,67.023273 ],
    [ u"af",u"Qandahar",391230,31.613323,65.710126 ],
    [ u"af",u"Qarchi Gak",8942,37.039988,66.788912 ],
    [ u"af",u"Qarqin",15023,37.404464,66.074375 ],
    [ u"af",u"Qunduz",161943,36.728955,68.857001 ],
    [ u"af",u"Rostaq",25644,37.126035,69.83045 ],
    [ u"af",u"Rudbar",11034,30.15,62.6 ],
    [ u"af",u"Sahrak",15967,34.107375,64.305199 ],
    [ u"af",u"Sangin",13579,32.072752,64.835903 ],
    [ u"af",u"Sar-e Pul",52138,36.215443,65.932487 ],
    [ u"af",u"Sharan",7368,33.146667,68.791667 ],
    [ u"af",u"Shibarghan",55658,36.667567,65.752904 ],
    [ u"af",u"Sindand",29273,33.302944,62.1474 ],
    [ u"af",u"Tagab",6400,34.855007,69.64917 ],
    [ u"af",u"Taloqan",64275,36.734133,69.533559 ],
    [ u"af",u"Taywarah",14398,33.521176,64.421156 ],
    [ u"af",u"Tir Pol",6979,34.594307,61.268951 ],
    [ u"af",u"Tokzar",12021,35.948308,66.42132 ],
    [ u"af",u"Uruzgan",13400,32.927751,66.632534 ],
    [ u"af",u"Zaranj",33894,30.966667,61.883333 ],
    [ u"ag",u"All Saints",2526,17.05,-61.8 ],
    [ u"ag",u"Carlisle",831,17.1333333,-61.8 ],
    [ u"ag",u"Codrington",682,17.6333333,-61.8333333 ],
    [ u"ag",u"Freetown",623,17.05,-61.7 ],
    [ u"ag",u"Liberta",1668,17.0333333,-61.7833333 ],
    [ u"ag",u"Old Road",623,17.0166667,-61.8333333 ],
    [ u"ag",u"Parham",969,17.0833333,-61.7666667 ],
    [ u"ag",u"Swetes",727,17.05,-61.8 ],
    [ u"ai",u"The Valley",1379,18.2166667,-63.05 ],
    [ u"al",u"Bajram Curri",7967,42.3572222,20.0730556 ],
    [ u"al",u"Ballsh",10361,40.5988889,19.7347222 ],
    [ u"al",u"Berat",47606,40.7058333,19.9522222 ],
    [ u"al",u"Bilisht",7114,40.6275,20.99 ],
    [ u"al",u"Bulqizë",11212,41.4916667,20.2219444 ],
    [ u"al",u"Burrel",15539,41.6102778,20.0088889 ],
    [ u"al",u"Cërrik",14269,41.0316667,19.9758333 ],
    [ u"al",u"Çorovodë",14046,40.5041667,20.2272222 ],
    [ u"al",u"Delvinë",3916,39.9511111,20.0977778 ],
    [ u"al",u"Durrës",122034,41.3230556,19.4413889 ],
    [ u"al",u"Elbasan",100903,41.1125,20.0822222 ],
    [ u"al",u"Ersekë",7890,40.3377778,20.6788889 ],
    [ u"al",u"Fier",59719,40.7238889,19.5561111 ],
    [ u"al",u"Fierzë",742,42.2647222,20.0269444 ],
    [ u"al",u"Fierzë",742,42.2605556,20.0169444 ],
    [ u"al",u"Fushë-Arrëz",2438,42.0622222,20.0166667 ],
    [ u"al",u"Fushë-Krujë",10458,41.4783333,19.7177778 ],
    [ u"al",u"Gjirokastër",23437,40.0758333,20.1388889 ],
    [ u"al",u"Gramsh",11556,40.8697222,20.1844444 ],
    [ u"al",u"Himarë",4596,40.1016667,19.7447222 ],
    [ u"al",u"Kamzë",11026,41.3816667,19.7602778 ],
    [ u"al",u"Kavajë",29354,41.1855556,19.5569444 ],
    [ u"al",u"Këlcyrë",2486,40.3130556,20.1894444 ],
    [ u"al",u"Kërrabë",1177,41.2155556,19.9713889 ],
    [ u"al",u"Klos",683,41.4844444,20.1080556 ],
    [ u"al",u"Konispol",1349,39.6588889,20.1813889 ],
    [ u"al",u"Koplik",4078,42.2136111,19.4363889 ],
    [ u"al",u"Korçë",58259,40.6186111,20.7808333 ],
    [ u"al",u"Krastë",1168,41.4225,20.205 ],
    [ u"al",u"Krujë",21286,41.5091667,19.7927778 ],
    [ u"al",u"Kuçovë",18166,40.8002778,19.9166667 ],
    [ u"al",u"Kukës",17972,42.0769444,20.4219444 ],
    [ u"al",u"Kurbnesh",1429,41.7797222,20.0836111 ],
    [ u"al",u"Laç",24825,41.6355556,19.7130556 ],
    [ u"al",u"Leskovik",2655,40.1513889,20.5972222 ],
    [ u"al",u"Lezhë",18695,41.7836111,19.6436111 ],
    [ u"al",u"Libohovë",3651,40.0311111,20.2630556 ],
    [ u"al",u"Librazhd",12691,41.1794444,20.315 ],
    [ u"al",u"Lushnjë",41423,40.9419444,19.705 ],
    [ u"al",u"Maliq",3735,40.7058333,20.6997222 ],
    [ u"al",u"Mamurras",8282,41.5775,19.6922222 ],
    [ u"al",u"Memaliaj",4951,40.3458333,19.9791667 ],
    [ u"al",u"Milot",2157,41.6802778,19.7244444 ],
    [ u"al",u"Orikum",2604,40.3252778,19.4713889 ],
    [ u"al",u"Patos",22679,40.6833333,19.6194444 ],
    [ u"al",u"Peqin",7513,41.0461111,19.7511111 ],
    [ u"al",u"Përmet",10686,40.2336111,20.3516667 ],
    [ u"al",u"Përrenjas",4015,41.0730556,20.5488889 ],
    [ u"al",u"Peshkopi",15261,41.685,20.4288889 ],
    [ u"al",u"Pogradec",25758,40.9025,20.6525 ],
    [ u"al",u"Poliçan",10663,40.6122222,20.0980556 ],
    [ u"al",u"Pukë",6495,42.0444444,19.8997222 ],
    [ u"al",u"Roskovec",6657,40.7375,19.7022222 ],
    [ u"al",u"Rrëshen",10064,41.7675,19.8755556 ],
    [ u"al",u"Rrogozhinë",5620,41.0763889,19.6652778 ],
    [ u"al",u"Rubik",2332,41.7744444,19.7861111 ],
    [ u"al",u"Sarandë",15147,39.8755556,20.0052778 ],
    [ u"al",u"Selenicë",6912,40.5305556,19.6358333 ],
    [ u"al",u"Shëngjin",2698,41.8136111,19.5938889 ],
    [ u"al",u"Shijak",14138,41.3455556,19.5672222 ],
    [ u"al",u"Shkodër",89102,42.0675,19.5130556 ],
    [ u"al",u"Tepelenë",11955,40.2958333,20.0191667 ],
    [ u"al",u"Tirana",374801,41.3275,19.8188889 ],
    [ u"al",u"Ulzë",600,41.6827778,19.8933333 ],
    [ u"al",u"Vlorë",89528,40.4666667,19.4897222 ],
    [ u"al",u"Vorë",4973,41.3908333,19.655 ],
    [ u"am",u"Abovyan",1379,40.0488889,44.5475 ],
    [ u"am",u"Abovyan",35677,40.2691667,44.6244444 ],
    [ u"am",u"Agarakadzor",1195,39.7363889,45.3455556 ],
    [ u"am",u"Agarak",1575,40.3077778,44.2847222 ],
    [ u"am",u"Agarak",1278,41.0105556,44.4675 ],
    [ u"am",u"Agarak",4707,39.2038889,46.5472222 ],
    [ u"am",u"Aghavnadzor",1252,40.5841667,44.6913889 ],
    [ u"am",u"Aghavnadzor",1925,39.7836111,45.2280556 ],
    [ u"am",u"Aghavnatun",2913,40.2336111,44.2513889 ],
    [ u"am",u"Akhuryan",7672,40.7813889,43.8963889 ],
    [ u"am",u"Aknalich",2654,40.1430556,44.1483333 ],
    [ u"am",u"Aknashen",1362,40.0958333,44.2861111 ],
    [ u"am",u"Alaverdi",13186,41.1305556,44.6519444 ],
    [ u"am",u"Amasia",1675,40.9466667,43.7813889 ],
    [ u"am",u"Amberd",1267,40.2416667,44.2727778 ],
    [ u"am",u"Anushavan",1532,40.6419444,43.9822222 ],
    [ u"am",u"Apaga",1634,40.0961111,44.2511111 ],
    [ u"am",u"Aparan",5670,40.5961111,44.3536111 ],
    [ u"am",u"Aragats",2952,40.3330556,43.6580556 ],
    [ u"am",u"Aragats",5092,40.2183333,44.2327778 ],
    [ u"am",u"Aragyukh",999,40.4025,44.5436111 ],
    [ u"am",u"Aramus",3214,40.2511111,44.6630556 ],
    [ u"am",u"Arapi",1738,40.7797222,43.8005556 ],
    [ u"am",u"Ararat",6554,39.8094444,44.7144444 ],
    [ u"am",u"Arazap",1373,40.0427778,44.1458333 ],
    [ u"am",u"Archis",1235,41.1641667,44.8725 ],
    [ u"am",u"Areni",1718,39.7208333,45.1838889 ],
    [ u"am",u"Arevabuyr",1041,40.0361111,44.4688889 ],
    [ u"am",u"Arevashat",1403,40.1416667,44.3708333 ],
    [ u"am",u"Arevashogh",2435,40.8613889,44.2727778 ],
    [ u"am",u"Arevik",2455,40.1005556,44.0969444 ],
    [ u"am",u"Arevik",1522,40.7361111,43.8927778 ],
    [ u"am",u"Arevshat",2089,40.0391667,44.5416667 ],
    [ u"am",u"Arevshat",1623,40.6486111,44.0444444 ],
    [ u"am",u"Argavand",1703,40.1580556,44.44 ],
    [ u"am",u"Argavand",2047,40.0608333,44.0952778 ],
    [ u"am",u"Argel",2528,40.3794444,44.5994444 ],
    [ u"am",u"Armash",2434,39.7666667,44.8083333 ],
    [ u"am",u"Armavir",2752,40.0897222,44.0483333 ],
    [ u"am",u"Arshaluys",3808,40.1688889,44.2141667 ],
    [ u"am",u"Artashat",20562,39.9538889,44.5505556 ],
    [ u"am",u"Arteni",3086,40.2983333,43.7541667 ],
    [ u"am",u"Artimet",1501,40.1513889,44.2663889 ],
    [ u"am",u"Artsvaberd",3193,40.8336111,45.4711111 ],
    [ u"am",u"Artsvanist",2819,40.1544444,45.5022222 ],
    [ u"am",u"Arzakan",2660,40.4494444,44.6063889 ],
    [ u"am",u"Arzni",2244,40.2963889,44.5958333 ],
    [ u"am",u"Ashnak",1131,40.3275,43.9166667 ],
    [ u"am",u"Ashtarak",18779,40.3016667,44.3591667 ],
    [ u"am",u"Astghadzor",3520,40.1238889,45.3566667 ],
    [ u"am",u"Avshar",4215,39.8405556,44.6836111 ],
    [ u"am",u"Aygavan",3758,39.8647222,44.6702778 ],
    [ u"am",u"Aygedzor",2535,39.4627778,46.4152778 ],
    [ u"am",u"Aygehovit",2888,40.9744444,45.2519444 ],
    [ u"am",u"Aygek",1095,40.1886111,44.3833333 ],
    [ u"am",u"Aygepat",1349,39.95,44.6 ],
    [ u"am",u"Aygeshat",1358,40.2355556,44.2866667 ],
    [ u"am",u"Aygeshat",1606,40.0666667,44.0666667 ],
    [ u"am",u"Aygestan",2431,40.0030556,44.5575 ],
    [ u"am",u"Aygezard",3192,39.9458333,44.6088889 ],
    [ u"am",u"Aygut",997,40.6841667,45.1730556 ],
    [ u"am",u"Ayrum",2174,41.195,44.8925 ],
    [ u"am",u"Ayrum",2174,41.1716667,44.8191667 ],
    [ u"am",u"Azatamut",1850,40.9758333,45.1980556 ],
    [ u"am",u"Azatan",4448,40.7238889,43.8205556 ],
    [ u"am",u"Azatavan",2886,39.9833333,44.5 ],
    [ u"am",u"Azatavan",2886,40.1333333,44.0666667 ],
    [ u"am",u"Baghramyan",1690,40.1908333,43.8494444 ],
    [ u"am",u"Bagratashen",3024,41.2458333,44.8211111 ],
    [ u"am",u"Balahovit",2982,40.2536111,44.6038889 ],
    [ u"am",u"Bambakashat",3089,40.1144444,44.0122222 ],
    [ u"am",u"Bardzrashen",1273,40.0852778,44.5786111 ],
    [ u"am",u"Bazum",1114,40.8680556,44.4455556 ],
    [ u"am",u"Berdavan",3150,41.2027778,45.0033333 ],
    [ u"am",u"Berd",8374,40.8808333,45.3916667 ],
    [ u"am",u"Brnakot",1912,39.4969444,45.9730556 ],
    [ u"am",u"Brun",1028,39.5338889,46.3030556 ],
    [ u"am",u"Buzhakan",1678,40.4552778,44.5205556 ],
    [ u"am",u"Byurakan",3902,40.3413889,44.2736111 ],
    [ u"am",u"Byuravan",1228,40.0161111,44.5186111 ],
    [ u"am",u"Byureghavan",6972,40.3147222,44.5936111 ],
    [ u"am",u"Chambarak",6153,40.5952778,45.3475 ],
    [ u"am",u"Chochkan",1740,41.1861111,44.8313889 ],
    [ u"am",u"Dalar",2504,39.9669444,44.5363889 ],
    [ u"am",u"Dalarik",3080,40.2183333,43.8602778 ],
    [ u"am",u"Darakert",2325,40.1058333,44.4138889 ],
    [ u"am",u"Darpas",1785,40.8380556,44.4233333 ],
    [ u"am",u"Dashtavan",1762,40.1016667,44.3905556 ],
    [ u"am",u"Ddmashen",2157,40.5719444,44.8122222 ],
    [ u"am",u"Dilijan",13480,40.7408333,44.8630556 ],
    [ u"am",u"Dimitrov",1212,40.0080556,44.4880556 ],
    [ u"am",u"Doghs",1186,40.2227778,44.2716667 ],
    [ u"am",u"Drakhtik",1016,40.5688889,45.2319444 ],
    [ u"am",u"Dsegh",2484,40.9633333,44.6516667 ],
    [ u"am",u"Dvin",2795,40.02,44.5852778 ],
    [ u"am",u"Dzitankov",1162,40.5155556,43.8133333 ],
    [ u"am",u"Dzoraghbyur",2011,40.205,44.6430556 ],
    [ u"am",u"Dzoragyukh",3570,40.1752778,45.175 ],
    [ u"am",u"Fantan",1019,40.3941667,44.685 ],
    [ u"am",u"Fioletovo",1264,40.7247222,44.7138889 ],
    [ u"am",u"Gagarin",1305,40.5369444,44.8577778 ],
    [ u"am",u"Gandzak",3841,40.3147222,45.1113889 ],
    [ u"am",u"Garni",6827,40.1194444,44.7230556 ],
    [ u"am",u"Gavar",21681,40.3588889,45.1266667 ],
    [ u"am",u"Gay",3309,40.0838889,44.3055556 ],
    [ u"am",u"Geghamasar",1060,40.3116667,45.68 ],
    [ u"am",u"Geghamavan",1597,40.5619444,44.8827778 ],
    [ u"am",u"Geghanist",2409,40.1497222,44.4344444 ],
    [ u"am",u"Getahovit",2005,40.8958333,45.1313889 ],
    [ u"am",u"Getashen",2114,40.0433333,43.9447222 ],
    [ u"am",u"Getazat",1947,40.0380556,44.5638889 ],
    [ u"am",u"Ghukasavan",2113,40.1261111,44.4177778 ],
    [ u"am",u"Gladzor",2080,39.7783333,45.3477778 ],
    [ u"am",u"Gogaran",1088,40.8955556,44.1991667 ],
    [ u"am",u"Goris",20379,39.5077778,46.3386111 ],
    [ u"am",u"Gosh",994,40.7225,45.0033333 ],
    [ u"am",u"Griboyedov",1879,40.1130556,44.2716667 ],
    [ u"am",u"Gyulagarak",2109,40.9697222,44.4713889 ],
    [ u"am",u"Gyumri",148383,40.7894444,43.8475 ],
    [ u"am",u"Haghartsin",3370,40.7780556,44.9625 ],
    [ u"am",u"Hayanist",2031,40.1197222,44.3775 ],
    [ u"am",u"Haykashen",1140,40.0727778,44.3069444 ],
    [ u"am",u"Haykavan",1201,40.7558333,43.77 ],
    [ u"am",u"Hnaberd",1817,40.6427778,44.1444444 ],
    [ u"am",u"Hoktember",5348,40.1361111,44.0138889 ],
    [ u"am",u"Horom",1893,40.6541667,43.8822222 ],
    [ u"am",u"Hovtashat",3472,40.1019444,44.3427778 ],
    [ u"am",u"Hovtashen",1134,40.0244444,44.45 ],
    [ u"am",u"Hrazdan",40796,40.5016667,44.7547222 ],
    [ u"am",u"Ijevan",14737,40.8755556,45.1491667 ],
    [ u"am",u"Janfida",2986,40.0455556,44.0208333 ],
    [ u"am",u"Jermuk",4582,39.8416667,45.6722222 ],
    [ u"am",u"Jrahovit",1032,40.0452778,44.4736111 ],
    [ u"am",u"Jrashen",3078,40.7875,44.1972222 ],
    [ u"am",u"Jrashen",1696,40.0547222,44.5133333 ],
    [ u"am",u"Kamaris",2064,40.2358333,44.6938889 ],
    [ u"am",u"Kamo",1340,40.8280556,43.9483333 ],
    [ u"am",u"Kanakeravan",2950,40.2472222,44.5366667 ],
    [ u"am",u"Kapan",33161,39.2011111,46.415 ],
    [ u"am",u"Kaputan",1252,40.3244444,44.6938889 ],
    [ u"am",u"Karbi",3521,40.3338889,44.3777778 ],
    [ u"am",u"Karchaghbyur",2274,40.1638889,45.5722222 ],
    [ u"am",u"Kasakh",4247,40.5333333,44.4166667 ],
    [ u"am",u"Khashtarak",1728,40.9386111,45.1797222 ],
    [ u"am",u"Khndzoresk",1940,39.5122222,46.4336111 ],
    [ u"am",u"Kosh",2581,40.3072222,44.16 ],
    [ u"am",u"Lanjaghbyur",2097,40.2730556,45.1444444 ],
    [ u"am",u"Lchashen",4182,40.5202778,44.9308333 ],
    [ u"am",u"Lenughi",1499,40.1238889,43.9652778 ],
    [ u"am",u"Lernakert",1306,40.5669444,43.9361111 ],
    [ u"am",u"Lernanist",2511,40.4675,44.7980556 ],
    [ u"am",u"Lernantsk",1192,40.7955556,44.2783333 ],
    [ u"am",u"Lernapat",1710,40.82,44.3972222 ],
    [ u"am",u"Lernavan",1517,40.7883333,44.1844444 ],
    [ u"am",u"Lorut",1101,40.9388889,44.7725 ],
    [ u"am",u"Lukashin",2197,40.1758333,44.0186111 ],
    [ u"am",u"Madina",1024,40.0802778,45.2511111 ],
    [ u"am",u"Maisyan",1521,40.8530556,43.8294444 ],
    [ u"am",u"Malishka",4174,39.7369444,45.3875 ],
    [ u"am",u"Maralik",4959,40.5722222,43.8669444 ],
    [ u"am",u"Margahovit",3308,40.7380556,44.6875 ],
    [ u"am",u"Margara",1360,40.0336111,44.1738889 ],
    [ u"am",u"Marmarashen",2946,40.0575,44.4711111 ],
    [ u"am",u"Marmashen",1644,40.8375,43.7719444 ],
    [ u"am",u"Martuni",11037,40.1447222,45.3063889 ],
    [ u"am",u"Masis",18911,40.0138889,44.4858333 ],
    [ u"am",u"Mayakovski",1727,40.2522222,44.6383333 ],
    [ u"am",u"Meghradzor",2659,40.6147222,44.6522222 ],
    [ u"am",u"Meghrashen",1107,40.6758333,43.9486111 ],
    [ u"am",u"Meghri",4540,38.9022222,46.2383333 ],
    [ u"am",u"Merdzavan",2702,40.1816667,44.3991667 ],
    [ u"am",u"Metsamor",8789,40.0713889,44.2891667 ],
    [ u"am",u"Metsavan",4767,41.2016667,44.2288889 ],
    [ u"am",u"Mets Masrik",2570,40.2186111,45.7694444 ],
    [ u"am",u"Mets Parni",1934,40.8372222,44.1091667 ],
    [ u"am",u"Mosesgegh",1964,40.9063889,45.4913889 ],
    [ u"am",u"Mrganush",1032,40.0286111,44.5586111 ],
    [ u"am",u"Mrgashat",4961,40.1297222,44.0705556 ],
    [ u"am",u"Mrgashen",1623,40.285,44.5422222 ],
    [ u"am",u"Mrgavan",1713,39.9661111,44.5333333 ],
    [ u"am",u"Mrgavet",2131,40.0283333,44.4827778 ],
    [ u"am",u"Musaler",2323,40.1544444,44.3777778 ],
    [ u"am",u"Musayelyan",1499,40.7652778,43.9908333 ],
    [ u"am",u"Myasnikyan",3458,40.1775,43.9063889 ],
    [ u"am",u"Nalbandyan",4019,40.0677778,43.9855556 ],
    [ u"am",u"Navur",1227,40.8613889,45.3175 ],
    [ u"am",u"Nizami",1060,40.0913889,44.4041667 ],
    [ u"am",u"Norakert",2485,40.1922222,44.3466667 ],
    [ u"am",u"Noramarg",1811,40.0236111,44.4244444 ],
    [ u"am",u"Nor Armavir",1597,40.0866667,43.99 ],
    [ u"am",u"Norashen",3049,40.0041667,44.5947222 ],
    [ u"am",u"Norashen",1386,41.1880556,44.3272222 ],
    [ u"am",u"Noratus",5426,40.3822222,45.1783333 ],
    [ u"am",u"Nor Geghi",4896,40.3211111,44.5797222 ],
    [ u"am",u"Nor Gyukh",1462,40.2666667,44.6563889 ],
    [ u"am",u"Nor Yerznka",1459,40.3133333,44.4047222 ],
    [ u"am",u"Noyakert",1751,39.8166667,44.6669444 ],
    [ u"am",u"Noyemberyan",5119,41.1725,44.9936111 ],
    [ u"am",u"Nshavan",1916,40.0263889,44.5252778 ],
    [ u"am",u"Odzun",4524,41.0538889,44.6113889 ],
    [ u"am",u"Oshakan",4768,40.2705556,44.2691667 ],
    [ u"am",u"Paravakar",1637,40.9805556,45.3991667 ],
    [ u"am",u"Pemzashen",2436,40.5933333,43.94 ],
    [ u"am",u"Pokr Mantash",1838,40.65,44.05 ],
    [ u"am",u"Proshyan",4333,40.2480556,44.415 ],
    [ u"am",u"Pshatavan",2159,40.0405556,44.0675 ],
    [ u"am",u"Ptghni",1231,40.2566667,44.585 ],
    [ u"am",u"Ranchpar",989,40.0252778,44.3702778 ],
    [ u"am",u"Rind",1368,39.7597222,45.18 ],
    [ u"am",u"Samaghar",2343,40.1852778,44.2422222 ],
    [ u"am",u"Saramech",1111,40.7725,44.2191667 ],
    [ u"am",u"Saratak",1115,40.67,43.8663889 ],
    [ u"am",u"Sarigyukh",1096,41.0563889,45.1458333 ],
    [ u"am",u"Sarukhan",6173,40.2891667,45.1341667 ],
    [ u"am",u"Sasunik",1959,40.2472222,44.3380556 ],
    [ u"am",u"Sevan",17083,40.555,44.9536111 ],
    [ u"am",u"Shaghat",1011,39.5616667,45.9122222 ],
    [ u"am",u"Shahumyan",3905,39.9308333,44.5783333 ],
    [ u"am",u"Shahumyan",1843,40.7883333,44.5316667 ],
    [ u"am",u"Shatin",1671,39.8333333,45.3016667 ],
    [ u"am",u"Shenavan",1587,40.4861111,44.3825 ],
    [ u"am",u"Shenavan",1757,40.05,43.9333333 ],
    [ u"am",u"Shinuhayr",2206,39.4341667,46.3155556 ],
    [ u"am",u"Shirakamut",2008,40.8605556,44.1527778 ],
    [ u"am",u"Shirak",1007,40.8480556,43.9213889 ],
    [ u"am",u"Shnogh",2872,41.1477778,44.8377778 ],
    [ u"am",u"Sisavan",1793,39.9,44.6666667 ],
    [ u"am",u"Sisian",15208,39.4627778,45.9730556 ],
    [ u"am",u"Sis",1135,40.0586111,44.3863889 ],
    [ u"am",u"Solak",2295,40.4636111,44.7086111 ],
    [ u"am",u"Sovetakan",1613,40.1133333,44.0552778 ],
    [ u"am",u"Spandaryan",1226,40.665,44.0188889 ],
    [ u"am",u"Spitak",15063,40.7955556,44.2783333 ],
    [ u"am",u"Surenavan",2241,39.75,44.8 ],
    [ u"am",u"Talin",4945,40.3369444,43.8588889 ],
    [ u"am",u"Tandzut",1816,40.0772222,44.0886111 ],
    [ u"am",u"Taronik",1874,40.1330556,44.1991667 ],
    [ u"am",u"Tashir",7318,41.1244444,44.2819444 ],
    [ u"am",u"Tazagyukh",2248,40.1416667,45.1913889 ],
    [ u"am",u"Tegh",2120,39.5547222,46.4758333 ],
    [ u"am",u"Tsaghkaber",1207,40.7986111,44.1072222 ],
    [ u"am",u"Tsaghkadzor",1408,40.5386111,44.7113889 ],
    [ u"am",u"Tsaghkahovit",1551,40.6361111,44.2230556 ],
    [ u"am",u"Tsiatsan",1050,40.1869444,44.2666667 ],
    [ u"am",u"Tsovagyugh",3857,40.6330556,44.9522222 ],
    [ u"am",u"Tsovak",2531,40.1819444,45.635 ],
    [ u"am",u"Tsovazard",1949,40.4769444,45.0375 ],
    [ u"am",u"Tsovinar",3968,40.1608333,45.4538889 ],
    [ u"am",u"Tumanyan",1693,40.9633333,44.6516667 ],
    [ u"am",u"Urut",1102,41.0711111,44.3969444 ],
    [ u"am",u"Ushi",1276,40.3536111,44.3686111 ],
    [ u"am",u"Vagharshapat",49514,40.1727778,44.2925 ],
    [ u"am",u"Vaghashen",3235,40.1377778,45.3291667 ],
    [ u"am",u"Vahagni",1184,40.9080556,44.6069444 ],
    [ u"am",u"Vahan",1153,40.57,45.3955556 ],
    [ u"am",u"Vanadzor",101099,40.8127778,44.4883333 ],
    [ u"am",u"Vardablur",1297,40.95,44.4666667 ],
    [ u"am",u"Vardadzor",2095,40.1916667,45.1875 ],
    [ u"am",u"Vardenik",7709,40.135,45.4363889 ],
    [ u"am",u"Vardenis",11382,40.1805556,45.7283333 ],
    [ u"am",u"Varser",1614,40.5561111,44.9111111 ],
    [ u"am",u"Vedi",12192,39.9105556,44.7277778 ],
    [ u"am",u"Verin Artashat",3931,40.0005556,44.585 ],
    [ u"am",u"Verin Dvin",1853,40.0252778,44.5908333 ],
    [ u"am",u"Verin Getashen",4173,40.1327778,45.2486111 ],
    [ u"am",u"Verishen",2114,39.5358333,46.3119444 ],
    [ u"am",u"Vernashen",1162,39.7938889,45.3633333 ],
    [ u"am",u"Voskehask",1803,40.7383333,43.7758333 ],
    [ u"am",u"Voskehat",2181,40.1413889,44.3291667 ],
    [ u"am",u"Voskevan",1287,41.1191667,45.0652778 ],
    [ u"am",u"Voskevaz",3789,40.2797222,44.295 ],
    [ u"am",u"Vostan",2925,39.9588889,44.5591667 ],
    [ u"am",u"Yeghegnavan",1221,39.8277778,44.6372222 ],
    [ u"am",u"Yeghegnut",1746,40.0902778,44.1625 ],
    [ u"am",u"Yeghegnut",1154,40.9041667,44.6325 ],
    [ u"am",u"Yeghvard",10705,40.3216667,44.4813889 ],
    [ u"am",u"Yeraskhahun",1346,40.0722222,44.2158333 ],
    [ u"am",u"Yerazgavors",1285,40.7,43.75 ],
    [ u"am",u"Yerevan",1093499,40.1811111,44.5136111 ],
    [ u"am",u"Zangakatun",1130,39.8094444,45.0511111 ],
    [ u"am",u"Zaritap",1323,39.6372222,45.5086111 ],
    [ u"am",u"Zar",1340,40.2611111,44.7361111 ],
    [ u"am",u"Zhdanov",1512,40.1616667,44.0883333 ],
    [ u"am",u"Zorak",1390,40.0925,44.3919444 ],
    [ u"am",u"Zoravan",1167,40.3569444,44.5230556 ],
    [ u"am",u"Zovaber",1470,40.5736111,44.7863889 ],
    [ u"am",u"Zovuni",4484,40.5108333,44.4288889 ],
    [ u"an",u"Barber",2424,12.2833333,-69.0666667 ],
    [ u"an",u"Golden Rock",823,17.4833333,-62.9833333 ],
    [ u"an",u"Hato",13,12.1833333,-68.2833333 ],
    [ u"an",u"Kralendijk",3081,12.15,-68.2666667 ],
    [ u"an",u"Lagún",289,12.3166667,-69.1666667 ],
    [ u"an",u"Nieuwpoort",1937,12.05,-68.8166667 ],
    [ u"an",u"Oranjestad",1097,17.4666667,-62.9833333 ],
    [ u"an",u"Rincón",1496,12.2333333,-68.3333333 ],
    [ u"an",u"Sint Michiel",5138,12.1333333,-68.9833333 ],
    [ u"an",u"Soto",1987,12.2666667,-69.1 ],
    [ u"an",u"The Bottom",488,17.6333333,-63.25 ],
    [ u"an",u"Westpunt",783,12.3666667,-69.1666667 ],
    [ u"an",u"Willemstad",97590,12.1,-68.9166667 ],
    [ u"an",u"Windward Side",442,17.6333333,-63.2333333 ],
    [ u"ao",u"Benguela",151235,-12.578333,13.407222 ],
    [ u"ao",u"Caála",21205,-12.8525,15.560556 ],
    [ u"ao",u"Cabinda",66020,-5.55,12.2 ],
    [ u"ao",u"Caconda",10551,-13.733333,15.066667 ],
    [ u"ao",u"Caluquembe",30305,-13.783333,14.683333 ],
    [ u"ao",u"Camabatela",12839,-8.18812,15.37495 ],
    [ u"ao",u"Camacupa",19150,-12.016667,17.483333 ],
    [ u"ao",u"Catabola",18858,-12.15,17.283333 ],
    [ u"ao",u"Catumbela",16980,-12.431389,13.547222 ],
    [ u"ao",u"Caxito",28229,-8.58,13.664167 ],
    [ u"ao",u"Cazaje",4764,-11.067147,20.701483 ],
    [ u"ao",u"Chissamba",7677,-12.166667,17.333333 ],
    [ u"ao",u"Huambo",226177,-12.776111,15.739167 ],
    [ u"ao",u"Kibala",8915,-10.73366,14.979949 ],
    [ u"ao",u"Kuito",113624,-12.383333,16.933333 ],
    [ u"ao",u"Leúa",5168,-11.65,20.45 ],
    [ u"ao",u"Lobito",207957,-12.319722,13.599722 ],
    [ u"ao",u"Longonjo",24350,-12.906667,15.253333 ],
    [ u"ao",u"Luanda",2776125,-8.836804,13.233174 ],
    [ u"ao",u"Luau",18465,-10.707273,22.22466 ],
    [ u"ao",u"Lubango",102541,-14.916667,13.5 ],
    [ u"ao",u"Lucapa",20115,-8.419151,20.744655 ],
    [ u"ao",u"Luena",21115,-11.783333,19.916667 ],
    [ u"ao",u"Lumeje",4972,-11.55,20.783333 ],
    [ u"ao",u"Malanje",87047,-9.544722,16.345278 ],
    [ u"ao",u"Menongue",19141,-14.661639,17.688224 ],
    [ u"ao",u"Namibe",80150,-15.196111,12.152222 ],
    [ u"ao",u"Ondjiva",10169,-17.066667,15.733333 ],
    [ u"ao",u"Saurimo",40498,-9.66078,20.391553 ],
    [ u"ao",u"Soyo",67553,-6.134903,12.368935 ],
    [ u"ao",u"Sumbe",33278,-11.206048,13.843713 ],
    [ u"ao",u"Uíge",60008,-7.613282,15.056621 ],
    [ u"ar",u"Alta Gracia",40385,-31.652925,-64.428259 ],
    [ u"ar",u"Azul",52333,-36.776976,-59.858539 ],
    [ u"ar",u"Bahia Blanca",282950,-38.719595,-62.272432 ],
    [ u"ar",u"Bell Ville",35106,-32.625906,-62.68873 ],
    [ u"ar",u"Campana",83175,-34.168742,-58.95914 ],
    [ u"ar",u"Catamarca",213601,-28.469574,-65.785239 ],
    [ u"ar",u"Chacabuco",34587,-34.641667,-60.473889 ],
    [ u"ar",u"Chivilcoy",52307,-34.895661,-60.016667 ],
    [ u"ar",u"Comodoro Rivadavia",142597,-45.864135,-67.496558 ],
    [ u"ar",u"Concepcion del Uruguay",72904,-32.482493,-58.237217 ],
    [ u"ar",u"Concordia",155686,-31.392959,-58.02089 ],
    [ u"ar",u"Cordoba",1441007,-31.413496,-64.181052 ],
    [ u"ar",u"Corrientes",390481,-27.480596,-58.834099 ],
    [ u"ar",u"Dolores",25190,-36.313215,-57.679185 ],
    [ u"ar",u"Eldorado",62823,-26.404841,-54.624784 ],
    [ u"ar",u"Formosa",248756,-26.177534,-58.178139 ],
    [ u"ar",u"General Pico",55900,-35.656622,-63.756815 ],
    [ u"ar",u"General Roca",76066,-39.02797,-67.573711 ],
    [ u"ar",u"Goya",70340,-29.14003,-59.262564 ],
    [ u"ar",u"Gualeguaychu",88218,-33.009375,-58.51722 ],
    [ u"ar",u"Gualeguay",33120,-33.141559,-59.309657 ],
    [ u"ar",u"Jujuy",277150,-24.194565,-65.297116 ],
    [ u"ar",u"Junin",76369,-34.583816,-60.943318 ],
    [ u"ar",u"La Plata",684318,-34.921454,-57.954533 ],
    [ u"ar",u"La Rioja",178497,-29.411048,-66.850668 ],
    [ u"ar",u"Libertador General San Martin",49273,-23.806443,-64.787574 ],
    [ u"ar",u"Lincoln",24798,-34.866494,-61.530197 ],
    [ u"ar",u"Lujan",74823,-34.570278,-59.105 ],
    [ u"ar",u"Lujan",77625,-33.035471,-68.877823 ],
    [ u"ar",u"Mar del Plata",645771,-38.002278,-57.557539 ],
    [ u"ar",u"Mendoza",973047,-32.890845,-68.827171 ],
    [ u"ar",u"Mercedes",49067,-34.651455,-59.430676 ],
    [ u"ar",u"Mercedes",30649,-29.181858,-58.078951 ],
    [ u"ar",u"Mercedes",126559,-33.674359,-65.461405 ],
    [ u"ar",u"Necochea",84969,-38.547259,-58.736753 ],
    [ u"ar",u"Neuquen",359037,-38.951606,-68.059102 ],
    [ u"ar",u"Nueve de Julio",34717,-35.444374,-60.883131 ],
    [ u"ar",u"Obera",58939,-27.487059,-55.11994 ],
    [ u"ar",u"Olavarria",80005,-36.892715,-60.32254 ],
    [ u"ar",u"Parana",299257,-31.731967,-60.523802 ],
    [ u"ar",u"Pergamino",86708,-33.889949,-60.573568 ],
    [ u"ar",u"Posadas",313438,-27.367077,-55.896078 ],
    [ u"ar",u"Presidencia Roque Saenz Pena",89584,-26.785221,-60.438761 ],
    [ u"ar",u"Puerto Madryn",95547,-42.769201,-65.038513 ],
    [ u"ar",u"Punta Alta",53117,-38.875875,-62.073589 ],
    [ u"ar",u"Rafaela",84025,-31.250332,-61.486696 ],
    [ u"ar",u"Rawson",26341,-43.300158,-65.10228 ],
    [ u"ar",u"Reconquista",95979,-29.15,-59.65 ],
    [ u"ar",u"Resistencia",406967,-27.46056,-58.983886 ],
    [ u"ar",u"Rio Cuarto",174058,-33.130671,-64.349918 ],
    [ u"ar",u"Rio Gallegos",93234,-51.622613,-69.218127 ],
    [ u"ar",u"Rio Tercero",53396,-32.173008,-64.114055 ],
    [ u"ar",u"Rivadavia",65641,-33.190509,-68.46081 ],
    [ u"ar",u"Rosario",1218497,-32.946818,-60.639317 ],
    [ u"ar",u"Salta",548288,-24.785896,-65.411664 ],
    [ u"ar",u"San Carlos de Bariloche",110044,-41.140293,-71.301369 ],
    [ u"ar",u"San Francisco",71444,-31.427971,-62.082656 ],
    [ u"ar",u"San Juan",469958,-31.5375,-68.536389 ],
    [ u"ar",u"San Lorenzo",47627,-28.133061,-58.767331 ],
    [ u"ar",u"San Luis",184869,-33.295012,-66.335627 ],
    [ u"ar",u"San Martin",107554,-33.081031,-68.468138 ],
    [ u"ar",u"San Nicolas",130705,-33.335784,-60.225233 ],
    [ u"ar",u"San Pedro",67514,-33.679127,-59.666635 ],
    [ u"ar",u"San Pedro",43124,-24.231266,-64.866141 ],
    [ u"ar",u"San Rafael",125033,-34.617717,-68.330066 ],
    [ u"ar",u"San Ramon de la Nueva Oran",84504,-23.13398,-64.324645 ],
    [ u"ar",u"Santa Fe",456044,-31.629484,-60.701036 ],
    [ u"ar",u"Santa Rosa",89478,-36.616667,-64.283333 ],
    [ u"ar",u"Santiago del Estero",407636,-27.795112,-64.261489 ],
    [ u"ar",u"San Vicente",84333,-34.982645,-58.376169 ],
    [ u"ar",u"Tandil",100127,-37.321674,-59.133164 ],
    [ u"ar",u"Tartagal",63600,-22.516365,-63.801314 ],
    [ u"ar",u"Trelew",107883,-43.250075,-65.313295 ],
    [ u"ar",u"Tres Arroyos",47143,-38.373939,-60.279781 ],
    [ u"ar",u"Tucuman",828402,-26.824144,-65.2226 ],
    [ u"ar",u"Ushuaia",58045,-54.8,-68.3 ],
    [ u"ar",u"Veinticinco de Mayo",24668,-35.432303,-60.172707 ],
    [ u"ar",u"Venado Tuerto",71794,-33.745564,-61.968845 ],
    [ u"ar",u"Victoria",25139,-32.619888,-60.153907 ],
    [ u"ar",u"Viedma",76553,-40.813452,-62.996676 ],
    [ u"ar",u"Villa Carlos Paz",61095,-31.424138,-64.497778 ],
    [ u"ar",u"Villa Constitucion",44278,-33.227778,-60.329699 ],
    [ u"ar",u"Villa Maria",92337,-32.407514,-63.240161 ],
    [ u"ar",u"Zarate",88222,-34.098142,-59.028585 ],
    [ u"at",u"Absam",6594,47.3,11.5 ],
    [ u"at",u"Abtenau",5829,47.55,13.35 ],
    [ u"at",u"Altach",6040,47.35,9.65 ],
    [ u"at",u"Althofen",4833,47.15,14.233333 ],
    [ u"at",u"Altmunster",9652,47.9,13.75 ],
    [ u"at",u"Amstetten",22832,48.116667,14.866667 ],
    [ u"at",u"Anif",4154,47.75,13.066667 ],
    [ u"at",u"Ansfelden",14936,48.2,14.283333 ],
    [ u"at",u"Arnoldstein",6923,46.546111,13.71 ],
    [ u"at",u"Asten",6517,48.216667,14.4 ],
    [ u"at",u"Axams",5560,47.233333,11.3 ],
    [ u"at",u"Bad Aussee",5210,47.6,13.783333 ],
    [ u"at",u"Baden",24893,48.016667,16.233333 ],
    [ u"at",u"Bad Goisern",7869,47.633333,13.616667 ],
    [ u"at",u"Bad Hall",4935,48.033333,14.2 ],
    [ u"at",u"Bad Hofgastein",7002,47.166667,13.1 ],
    [ u"at",u"Bad Ischl",14267,47.716667,13.616667 ],
    [ u"at",u"Bad Sankt Leonhard",4775,46.962778,14.791667 ],
    [ u"at",u"Bad Voslau",11013,47.966667,16.2 ],
    [ u"at",u"Barnbach",4850,46.983333,16.05 ],
    [ u"at",u"Bergheim",5031,47.833333,13.033333 ],
    [ u"at",u"Berndorf",8796,47.95,16.1 ],
    [ u"at",u"Bischofshofen",10145,47.416667,13.216667 ],
    [ u"at",u"Bludenz",13904,47.149722,9.816667 ],
    [ u"at",u"Braunau",16403,48.266667,13.033333 ],
    [ u"at",u"Bregenz",26928,47.5,9.766667 ],
    [ u"at",u"Bruck an der Leitha",7339,48.016667,16.766667 ],
    [ u"at",u"Bruck an der Mur",13254,47.416667,15.283333 ],
    [ u"at",u"Deutschlandsberg",8049,46.815278,15.222222 ],
    [ u"at",u"Deutsch-Wagram",7153,48.299722,16.566667 ],
    [ u"at",u"Dornbirn",43013,47.416667,9.733056 ],
    [ u"at",u"Ebbs",5088,47.633333,12.216667 ],
    [ u"at",u"Ebensee",8376,47.8,13.766667 ],
    [ u"at",u"Ebenthal",7809,46.608056,14.364167 ],
    [ u"at",u"Eberndorf",6089,46.591389,14.643611 ],
    [ u"at",u"Ebreichsdorf",9509,47.95,16.4 ],
    [ u"at",u"Eisenerz",5987,47.533333,14.883333 ],
    [ u"at",u"Eisenstadt",11767,47.85,16.516667 ],
    [ u"at",u"Engerwitzdorf",8510,48.35,14.45 ],
    [ u"at",u"Enns",10816,48.2,14.466667 ],
    [ u"at",u"Feldbach",4877,46.953056,15.888333 ],
    [ u"at",u"Feldkirchen an der Donau",5286,48.35,14.05 ],
    [ u"at",u"Feldkirchen",14440,46.716667,14.1 ],
    [ u"at",u"Feldkirch",29446,47.233056,9.6 ],
    [ u"at",u"Ferlach",7661,46.526944,14.301944 ],
    [ u"at",u"Finkenstein",8406,46.565556,13.865278 ],
    [ u"at",u"Fohnsdorf",8203,47.2,14.683333 ],
    [ u"at",u"Frankenburg",5162,48.066667,13.483333 ],
    [ u"at",u"Freistadt",7574,48.5,14.5 ],
    [ u"at",u"Friesach",5369,46.955278,14.405833 ],
    [ u"at",u"Frohnleiten",6629,47.266667,15.316667 ],
    [ u"at",u"Fugen",3734,47.35,11.85 ],
    [ u"at",u"Furstenfeld",5962,47.05,16.083333 ],
    [ u"at",u"Gallneukirchen",6282,48.35,14.416667 ],
    [ u"at",u"Ganserndorf",8588,48.35,16.733333 ],
    [ u"at",u"Garsten",6657,48.016667,14.4 ],
    [ u"at",u"Gleisdorf",5245,47.1,15.716667 ],
    [ u"at",u"Gloggnitz",6213,47.666667,15.933333 ],
    [ u"at",u"Gmunden",13287,47.916667,13.8 ],
    [ u"at",u"Gmund",5811,48.766667,14.983333 ],
    [ u"at",u"Gotzis",10342,47.333056,9.633056 ],
    [ u"at",u"Gratkorn",6806,47.133333,15.35 ],
    [ u"at",u"Graz",222326,47.066667,15.45 ],
    [ u"at",u"Grieskirchen",4766,48.233333,13.833333 ],
    [ u"at",u"Grodig",6918,47.733333,13.033333 ],
    [ u"at",u"Guntramsdorf",9071,48.033333,16.3 ],
    [ u"at",u"Haag",5164,48.15,15.5 ],
    [ u"at",u"Hainburg",5622,48.15,16.933333 ],
    [ u"at",u"Hallein",18980,47.683333,13.1 ],
    [ u"at",u"Hall",11197,47.6,14.45 ],
    [ u"at",u"Hard",11766,47.483056,9.683056 ],
    [ u"at",u"Heidenreichstein",4472,48.866667,15.116667 ],
    [ u"at",u"Hermagor",7242,46.627222,13.367222 ],
    [ u"at",u"Herzogenburg",7866,48.266667,15.683333 ],
    [ u"at",u"Himberg",5534,48.083333,16.433333 ],
    [ u"at",u"Hochst",7207,47.466667,9.633056 ],
    [ u"at",u"Hohenems",14072,47.366667,9.683056 ],
    [ u"at",u"Hollabrunn",10966,48.55,16.083333 ],
    [ u"at",u"Hopfgarten",5314,47.45,12.166667 ],
    [ u"at",u"Horbranz",6414,47.55,9.75 ],
    [ u"at",u"Horn",6485,48.65,15.65 ],
    [ u"at",u"Horsching",5312,48.233333,14.183333 ],
    [ u"at",u"Imst",9225,47.233333,10.733333 ],
    [ u"at",u"Innsbruck",112467,47.266667,11.4 ],
    [ u"at",u"Jenbach",6806,47.4,11.783333 ],
    [ u"at",u"Jennersdorf",4319,46.939167,16.146667 ],
    [ u"at",u"Judenburg",9992,47.166667,14.666667 ],
    [ u"at",u"Kapfenberg",21819,47.433333,15.3 ],
    [ u"at",u"Kindberg",5790,47.5,15.45 ],
    [ u"at",u"Kirchbichl",5115,47.516667,12.083333 ],
    [ u"at",u"Kitzbuhel",8818,47.45,12.383333 ],
    [ u"at",u"Klagenfurt",90610,46.624722,14.305278 ],
    [ u"at",u"Klosterneuburg",24843,48.3,16.316667 ],
    [ u"at",u"Knittelfeld",12704,47.216667,14.816667 ],
    [ u"at",u"Koflach",10447,47.066667,15.083333 ],
    [ u"at",u"Korneuburg",11498,48.35,16.333333 ],
    [ u"at",u"Kottingbrunn",7184,47.95,16.216667 ],
    [ u"at",u"Krems",24092,48.416667,15.6 ],
    [ u"at",u"Kremsmunster",6626,48.05,14.133333 ],
    [ u"at",u"Krieglach",5236,47.533333,15.55 ],
    [ u"at",u"Kuchl",6668,47.616667,13.15 ],
    [ u"at",u"Kufstein",16116,47.583333,12.166667 ],
    [ u"at",u"Laakirchen",9569,47.966667,13.816667 ],
    [ u"at",u"Laa",6084,48.716667,16.383333 ],
    [ u"at",u"Landeck",7351,47.133333,10.566667 ],
    [ u"at",u"Langenlois",7081,48.466667,15.666667 ],
    [ u"at",u"Langenzersdorf",7733,48.3,16.35 ],
    [ u"at",u"Lauterach",9212,47.483056,9.733056 ],
    [ u"at",u"Leibnitz",7029,46.781667,15.541667 ],
    [ u"at",u"Lenzing",5044,47.966667,13.616667 ],
    [ u"at",u"Leoben",24809,47.383333,15.1 ],
    [ u"at",u"Leonding",22736,48.266667,14.25 ],
    [ u"at",u"Lienz",12270,46.831111,12.759722 ],
    [ u"at",u"Liezen",6903,47.566667,14.233333 ],
    [ u"at",u"Linz",181163,48.3,14.3 ],
    [ u"at",u"Lochau",5209,47.533333,9.75 ],
    [ u"at",u"Lustenau",20218,47.433056,9.65 ],
    [ u"at",u"Marchtrenk",11666,48.183333,14.116667 ],
    [ u"at",u"Maria Enzersdorf",8085,48.1,16.283333 ],
    [ u"at",u"Matrei",5076,47,12.533333 ],
    [ u"at",u"Mattersburg",6448,47.733333,16.4 ],
    [ u"at",u"Melk",5272,48.216667,15.316667 ],
    [ u"at",u"Micheldorf",5902,47.85,14.133333 ],
    [ u"at",u"Mistelbach",10820,48.57,16.576667 ],
    [ u"at",u"Mittelberg",4627,47.2,9.65 ],
    [ u"at",u"Mittersill",5680,47.266667,12.483333 ],
    [ u"at",u"Modling",20710,48.083333,16.283333 ],
    [ u"at",u"Moosburg",4602,46.6575,14.174722 ],
    [ u"at",u"Murzzuschlag",9410,47.6,15.683333 ],
    [ u"at",u"Nenzing",5856,47.183056,9.7 ],
    [ u"at",u"Neudorfl",4183,47.783333,16.283333 ],
    [ u"at",u"Neulengbach",7521,48.2,15.9 ],
    [ u"at",u"Neunkirchen",11313,47.716667,16.083333 ],
    [ u"at",u"Neusiedl am See",5949,47.933333,16.833333 ],
    [ u"at",u"Nuziders",4628,47.166667,9.8 ],
    [ u"at",u"Oberndorf",5738,48.25,13.333333 ],
    [ u"at",u"Oberwart",6879,47.283333,16.2 ],
    [ u"at",u"Pasching",6143,48.25,14.2 ],
    [ u"at",u"Paternion",6301,46.714167,13.636111 ],
    [ u"at",u"Perchtoldsdorf",14041,48.116667,16.266667 ],
    [ u"at",u"Perg",7644,48.25,14.633333 ],
    [ u"at",u"Pinkafeld",5257,47.366667,16.116667 ],
    [ u"at",u"Pottendorf",6105,47.9,16.383333 ],
    [ u"at",u"Poysdorf",5653,48.666667,16.633333 ],
    [ u"at",u"Pressbaum",6083,48.183333,16.083333 ],
    [ u"at",u"Purgstall",5247,48.05,15.133333 ],
    [ u"at",u"Purkersdorf",8327,48.2,16.166667 ],
    [ u"at",u"Radstadt",4926,47.383333,13.45 ],
    [ u"at",u"Rankweil",11455,47.283056,9.65 ],
    [ u"at",u"Reichenau",2673,47.7,15.833333 ],
    [ u"at",u"Retz",4139,48.75,15.95 ],
    [ u"at",u"Reutte",5851,47.483333,10.716667 ],
    [ u"at",u"Ried",11511,48.216667,13.5 ],
    [ u"at",u"Rottenmann",5561,47.516667,14.35 ],
    [ u"at",u"Rum",8498,47.283333,11.45 ],
    [ u"at",u"Rust",1726,47.8,16.666667 ],
    [ u"at",u"Saalfelden",16119,47.416667,12.85 ],
    [ u"at",u"Salzburg",145310,47.8,13.033333 ],
    [ u"at",u"Sankt Andra",10825,46.766111,14.823611 ],
    [ u"at",u"Sankt Florian",5760,48.166667,13.133333 ],
    [ u"at",u"Sankt Georgen",4180,47.933333,13.483333 ],
    [ u"at",u"Sankt Jakob",4481,46.547778,14.057222 ],
    [ u"at",u"Sankt Johann im Pongau",10887,47.35,13.2 ],
    [ u"at",u"Sankt Polten",49000,48.2,15.633333 ],
    [ u"at",u"Sankt Valentin",9063,48.166667,14.516667 ],
    [ u"at",u"Sankt Veit",13116,46.768056,14.360278 ],
    [ u"at",u"Scharding",4919,48.45,13.433333 ],
    [ u"at",u"Scharnstein",4631,47.9,13.95 ],
    [ u"at",u"Schladming",4659,47.383333,13.683333 ],
    [ u"at",u"Schrems",5811,48.783333,15.066667 ],
    [ u"at",u"Schruns",3506,47.066667,9.916667 ],
    [ u"at",u"Schwaz",12507,47.333333,11.7 ],
    [ u"at",u"Schwechat",15711,48.133333,16.466667 ],
    [ u"at",u"Seeboden",6221,46.821944,13.495 ],
    [ u"at",u"Seekirchen",9865,47.9,13.133333 ],
    [ u"at",u"Seewalchen",4959,47.95,13.583333 ],
    [ u"at",u"Sieghartskirchen",7062,48.25,16 ],
    [ u"at",u"Sierning",8722,48.033333,14.3 ],
    [ u"at",u"Spittal",16363,46.8,13.5 ],
    [ u"at",u"Steyregg",4856,48.283333,14.366667 ],
    [ u"at",u"Steyr",39567,48.05,14.416667 ],
    [ u"at",u"Stockerau",14831,48.383333,16.216667 ],
    [ u"at",u"Strasshof",7637,48.316667,16.666667 ],
    [ u"at",u"Tamsweg",6126,47.133333,13.8 ],
    [ u"at",u"Telfs",14028,47.3,11.066667 ],
    [ u"at",u"Ternitz",15153,47.716667,16.033333 ],
    [ u"at",u"Thalgau",5501,47.833333,13.25 ],
    [ u"at",u"Timelkam",5855,48,13.6 ],
    [ u"at",u"Traiskirchen",16212,48.016667,16.283333 ],
    [ u"at",u"Traismauer",5815,48.35,15.733333 ],
    [ u"at",u"Traun",23959,48.216667,14.233333 ],
    [ u"at",u"Trofaiach",8313,47.416667,15 ],
    [ u"at",u"Tulln",14201,48.333333,16.05 ],
    [ u"at",u"Velden am Worthersee",8817,46.616111,14.045833 ],
    [ u"at",u"Vienna",1569315,48.2,16.366667 ],
    [ u"at",u"Villach",58882,46.610278,13.855833 ],
    [ u"at",u"Vocklabruck",11887,48.016667,13.65 ],
    [ u"at",u"Vocklamarkt",4869,48,13.483333 ],
    [ u"at",u"Voitsberg",9980,47.033333,15.15 ],
    [ u"at",u"Volkermarkt",11543,46.662222,14.634444 ],
    [ u"at",u"Vols",6573,47.25,11.333333 ],
    [ u"at",u"Vomp",4628,47.333333,11.683333 ],
    [ u"at",u"Vorchdorf",7456,48,13.916667 ],
    [ u"at",u"Waidhofen",11774,47.966667,14.766667 ],
    [ u"at",u"Wattens",7517,47.283333,11.6 ],
    [ u"at",u"Weiz",9128,47.216667,15.616667 ],
    [ u"at",u"Wels",57947,48.166667,14.033333 ],
    [ u"at",u"Wernberg",5070,46.616667,13.933333 ],
    [ u"at",u"Wiener Neudorf",8530,48.066667,16.316667 ],
    [ u"at",u"Wiener Neustadt",38481,47.8,16.25 ],
    [ u"at",u"Wilhelmsburg",6718,48.1,15.6 ],
    [ u"at",u"Wolfsberg",25610,46.840556,14.844167 ],
    [ u"at",u"Wolfurt",8110,47.466667,9.75 ],
    [ u"at",u"Wolkersdorf",6416,48.383333,16.516667 ],
    [ u"at",u"Worgl",11265,47.483333,12.066667 ],
    [ u"at",u"Ybbs",5676,48.166667,15.083333 ],
    [ u"at",u"Zell am See",10046,47.316667,12.783333 ],
    [ u"at",u"Zeltweg",7726,47.183333,14.75 ],
    [ u"at",u"Zirl",6567,47.283333,11.233333 ],
    [ u"at",u"Zistersdorf",5661,48.533333,16.75 ],
    [ u"at",u"Zwettl",11718,48.616667,15.166667 ],
    [ u"au",u"Adelaide",1074168,-34.928661,138.598633 ],
    [ u"au",u"Albany",23913,-35.003101,117.865952 ],
    [ u"au",u"Albury",104261,-36.07494,146.923935 ],
    [ u"au",u"Alice Springs",26188,-23.697479,133.883621 ],
    [ u"au",u"Alyangula",1289,-13.85413,136.421295 ],
    [ u"au",u"Ararat",6111,-37.285419,142.927277 ],
    [ u"au",u"Armidale",22673,-30.50828,151.671234 ],
    [ u"au",u"Atherton",6959,-17.268641,145.47522 ],
    [ u"au",u"Australind",6621,-33.279202,115.715042 ],
    [ u"au",u"Ayr",9079,-19.573931,147.406662 ],
    [ u"au",u"Bairnsdale",11006,-37.822891,147.610413 ],
    [ u"au",u"Ballarat",85110,-37.56266,143.862579 ],
    [ u"au",u"Ballina",14248,-28.86414,153.565414 ],
    [ u"au",u"Batemans Bay",10557,-35.706581,150.175415 ],
    [ u"au",u"Benalla",9020,-36.551128,145.984253 ],
    [ u"au",u"Bendigo",81658,-36.758179,144.280243 ],
    [ u"au",u"Biloela",6309,-24.416667,150.5 ],
    [ u"au",u"Blackwater",7250,-23.583509,148.87912 ],
    [ u"au",u"Bongaree",13649,-27.08367,153.159424 ],
    [ u"au",u"Bowen",10983,-20.01367,148.247543 ],
    [ u"au",u"Bowral",9605,-34.477501,150.420395 ],
    [ u"au",u"Brisbane",1843459,-27.47101,153.024292 ],
    [ u"au",u"Broken Hill",17395,-31.961729,141.459976 ],
    [ u"au",u"Broome",13218,-17.955379,122.23922 ],
    [ u"au",u"Buderim",15228,-26.684429,153.057053 ],
    [ u"au",u"Bunbury",26370,-33.32711,115.641373 ],
    [ u"au",u"Bundaberg",52478,-24.866211,152.3479 ],
    [ u"au",u"Burnie",19976,-41.05584,145.903748 ],
    [ u"au",u"Burpengary",8280,-27.161131,152.959442 ],
    [ u"au",u"Busselton",12374,-33.652489,115.345497 ],
    [ u"au",u"Byron Bay",6764,-28.64201,153.611938 ],
    [ u"au",u"Caboolture",21478,-27.08465,152.951096 ],
    [ u"au",u"Cairns",154318,-16.92304,145.766251 ],
    [ u"au",u"Caloundra",38714,-26.797091,153.137711 ],
    [ u"au",u"Canberra",324025,-35.27603,149.13435 ],
    [ u"au",u"Carnarvon",7392,-24.88073,113.659401 ],
    [ u"au",u"Casino",9539,-28.858191,153.047485 ],
    [ u"au",u"Castlemaine",6604,-37.067089,144.216843 ],
    [ u"au",u"Cessnock",16394,-32.832111,151.356232 ],
    [ u"au",u"Charters Towers",9574,-20.07671,146.263535 ],
    [ u"au",u"Clifton Springs",7413,-38.1567,144.555099 ],
    [ u"au",u"Coffs Harbour",62978,-30.296261,153.11351 ],
    [ u"au",u"Colac",9089,-38.339001,143.584885 ],
    [ u"au",u"Collie",6337,-33.362061,116.156174 ],
    [ u"au",u"Coolum Beach",8555,-26.533331,153.091232 ],
    [ u"au",u"Cooma",6520,-36.234692,149.125977 ],
    [ u"au",u"Cootamundra",4934,-34.640949,148.028381 ],
    [ u"au",u"Corowa",5179,-35.999619,146.385803 ],
    [ u"au",u"Cowra",6799,-33.835541,148.696625 ],
    [ u"au",u"Craigieburn",19728,-37.6,144.95 ],
    [ u"au",u"Cranbourne",39420,-38.113419,145.283264 ],
    [ u"au",u"Crib Point",6908,-38.35,145.2 ],
    [ u"au",u"Dalby",9848,-27.18169,151.262054 ],
    [ u"au",u"Darwin",93081,-12.45722,130.836639 ],
    [ u"au",u"Deception Bay",16090,-27.193541,153.026306 ],
    [ u"au",u"Deniliquin",8024,-35.527409,144.959579 ],
    [ u"au",u"Devonport",19318,-41.176949,146.351517 ],
    [ u"au",u"Dubbo",29362,-32.24295,148.604843 ],
    [ u"au",u"Emerald",9399,-23.522961,148.157837 ],
    [ u"au",u"Esperance",7889,-33.86013,121.882591 ],
    [ u"au",u"Flinders",15000,-32.79924,134.211594 ],
    [ u"au",u"Forbes",4838,-33.384361,148.007599 ],
    [ u"au",u"Galiwinku",1347,-12.02811,135.564865 ],
    [ u"au",u"Gatton",6513,-27.558729,152.276184 ],
    [ u"au",u"Gawler",16362,-34.602509,138.749023 ],
    [ u"au",u"Geelong",150438,-38.153461,144.358093 ],
    [ u"au",u"Geraldton",27259,-28.778971,114.614594 ],
    [ u"au",u"Gladstone",30493,-23.84761,151.256348 ],
    [ u"au",u"Gold Coast",501175,-28.00029,153.430878 ],
    [ u"au",u"Goulburn",20941,-34.751549,149.720856 ],
    [ u"au",u"Grafton",16399,-29.690121,152.933365 ],
    [ u"au",u"Griffith",15456,-34.288528,146.050934 ],
    [ u"au",u"Gunnedah",7148,-30.98065,150.258377 ],
    [ u"au",u"Gympie",11029,-26.189159,152.658188 ],
    [ u"au",u"Hamilton",8869,-37.74334,142.028915 ],
    [ u"au",u"Hastings",6583,-38.3,145.183333 ],
    [ u"au",u"Healesville",7098,-37.65395,145.517181 ],
    [ u"au",u"Hervey Bay",47561,-25.285,152.873 ],
    [ u"au",u"Hobart",204863,-42.883209,147.331665 ],
    [ u"au",u"Horsham",12830,-36.711311,142.199814 ],
    [ u"au",u"Howard Springs",3359,-12.49576,131.044464 ],
    [ u"au",u"Ingham",6127,-18.645519,146.162476 ],
    [ u"au",u"Innisfail",10144,-17.522091,146.031021 ],
    [ u"au",u"Inverell",8561,-29.774031,151.111664 ],
    [ u"au",u"Jabiru",1892,-12.67558,132.831406 ],
    [ u"au",u"Karratha",11694,-20.73649,116.84638 ],
    [ u"au",u"Katherine",10142,-14.46517,132.263474 ],
    [ u"au",u"Kawana Waters",19881,-26.705999,153.131577 ],
    [ u"au",u"Kempsey",9522,-31.078979,152.830933 ],
    [ u"au",u"Kiama",10380,-34.668282,150.852188 ],
    [ u"au",u"Kingaroy",8573,-26.53994,151.837296 ],
    [ u"au",u"Kununurra",5679,-15.77813,128.744141 ],
    [ u"au",u"Kurri Kurri",10991,-32.819328,151.47908 ],
    [ u"au",u"Kwinana",20087,-32.230129,115.781281 ],
    [ u"au",u"Kyabram",6396,-36.313351,145.050354 ],
    [ u"au",u"Lakes Entrance",5849,-37.878941,147.995132 ],
    [ u"au",u"Lara",8179,-38.02388,144.406174 ],
    [ u"au",u"Launceston",72462,-41.438759,147.134674 ],
    [ u"au",u"Leeton",7299,-34.551048,146.404831 ],
    [ u"au",u"Lemon Tree Passage",5865,-32.731579,152.037186 ],
    [ u"au",u"Leopold",6120,-38.19001,144.468246 ],
    [ u"au",u"Lismore",31433,-28.81328,153.275803 ],
    [ u"au",u"Lithgow",11129,-33.482471,150.136307 ],
    [ u"au",u"Mackay",75924,-21.15345,149.165543 ],
    [ u"au",u"Mandurah",73369,-32.526901,115.721703 ],
    [ u"au",u"Maningrida",1391,-12.05111,134.22258 ],
    [ u"au",u"Mareeba",8403,-16.995001,145.423233 ],
    [ u"au",u"Maryborough",20680,-25.54073,152.704926 ],
    [ u"au",u"Maryborough",7046,-37.04562,143.739227 ],
    [ u"au",u"Medowie",5841,-32.741501,151.867599 ],
    [ u"au",u"Melbourne",3730212,-37.813938,144.963425 ],
    [ u"au",u"Melton",32369,-37.683392,144.585434 ],
    [ u"au",u"Mildura",47867,-34.185509,142.162506 ],
    [ u"au",u"Milingimbi",986,-12.10188,134.919006 ],
    [ u"au",u"Mittagong",6717,-34.45002,150.445724 ],
    [ u"au",u"Moranbah",7955,-21.99828,148.034836 ],
    [ u"au",u"Morayfield",10261,-27.108761,152.949066 ],
    [ u"au",u"Moree",8205,-29.46278,149.841568 ],
    [ u"au",u"Morwell",11585,-38.23476,146.394989 ],
    [ u"au",u"Moss Vale",6739,-34.553741,150.371155 ],
    [ u"au",u"Mount Barker",8357,-35.066667,138.866667 ],
    [ u"au",u"Mount Gambier",23210,-37.831799,140.77919 ],
    [ u"au",u"Mount Isa",22564,-20.725229,139.497269 ],
    [ u"au",u"Mudgee",9042,-32.433333,149.583333 ],
    [ u"au",u"Murray Bridge",11356,-35.119862,139.273453 ],
    [ u"au",u"Murwillumbah",6868,-28.32732,153.393387 ],
    [ u"au",u"Muswellbrook",11630,-32.261181,150.890091 ],
    [ u"au",u"Nambour",14919,-26.626129,152.959412 ],
    [ u"au",u"Nambucca Heads",6899,-30.643181,153.008835 ],
    [ u"au",u"Narrabri",7082,-30.32612,149.783707 ],
    [ u"au",u"Nelson Bay",7725,-32.720428,152.143982 ],
    [ u"au",u"Nerang",17684,-27.98941,153.336334 ],
    [ u"au",u"Newcastle",497961,-32.927792,151.784485 ],
    [ u"au",u"New Norfolk",5526,-42.78075,147.059387 ],
    [ u"au",u"Nguiu",1250,-11.75911,130.638153 ],
    [ u"au",u"Ngukurr",947,-14.73081,134.731018 ],
    [ u"au",u"Nhulunbuy",3202,-12.18652,136.782013 ],
    [ u"au",u"Northam",5858,-31.649321,116.674232 ],
    [ u"au",u"Orange",30402,-33.283089,149.100006 ],
    [ u"au",u"Pakenham",10602,-38.070179,145.474106 ],
    [ u"au",u"Palmerston",31075,-12.45722,130.836639 ],
    [ u"au",u"Parkes",11137,-33.137199,148.175903 ],
    [ u"au",u"Perth",1446715,-31.95224,115.861397 ],
    [ u"au",u"Port Augusta",12133,-32.495972,137.772812 ],
    [ u"au",u"Port Hedland",14289,-20.312149,118.610588 ],
    [ u"au",u"Port Keats",1351,-14.24029,129.52092 ],
    [ u"au",u"Portland",8842,-38.352612,141.605743 ],
    [ u"au",u"Port Lincoln",11247,-34.72625,135.87442 ],
    [ u"au",u"Port Macquarie",48553,-31.43084,152.908936 ],
    [ u"au",u"Port Pirie",12328,-33.191761,138.017456 ],
    [ u"au",u"Queanbeyan",32249,-35.354931,149.231995 ],
    [ u"au",u"Raymond Terrace",13606,-32.75,151.75 ],
    [ u"au",u"Rockhampton",65851,-23.38032,150.505951 ],
    [ u"au",u"Roebourne",19264,-20.772289,117.146477 ],
    [ u"au",u"Roma",5497,-26.56741,148.787506 ],
    [ u"au",u"Sale",12917,-38.11095,147.068024 ],
    [ u"au",u"Sawtell",14608,-30.36459,153.10141 ],
    [ u"au",u"Singleton",13813,-32.567421,151.166031 ],
    [ u"au",u"Somerville",7015,-38.216667,145.166667 ],
    [ u"au",u"Stawell",6991,-37.05632,142.780884 ],
    [ u"au",u"Sunbury",29926,-37.577419,144.726074 ],
    [ u"au",u"Swan Hill",9276,-35.3386,143.559525 ],
    [ u"au",u"Sydney",4394585,-33.861481,151.205475 ],
    [ u"au",u"Tamworth",38552,-31.090481,150.929047 ],
    [ u"au",u"Taree",44183,-31.91099,152.453873 ],
    [ u"au",u"Toowoomba",92802,-27.56056,151.953857 ],
    [ u"au",u"Torquay",6670,-25.283333,152.866667 ],
    [ u"au",u"Townsville",138959,-19.26639,146.805695 ],
    [ u"au",u"Traralgon",18226,-38.195278,146.541504 ],
    [ u"au",u"Tumut",6526,-35.300159,148.225052 ],
    [ u"au",u"Ulladulla",9250,-35.359058,150.472473 ],
    [ u"au",u"Ulverstone",9605,-41.160259,146.182419 ],
    [ u"au",u"Victor Harbor",7760,-35.550419,138.621536 ],
    [ u"au",u"Victoria Point",11930,-27.58329,153.311722 ],
    [ u"au",u"Wagga Wagga",55382,-35.125771,147.353745 ],
    [ u"au",u"Wangaratta",14023,-36.358459,146.320557 ],
    [ u"au",u"Warragul",9128,-38.159119,145.931183 ],
    [ u"au",u"Warrnambool",29928,-38.38176,142.487991 ],
    [ u"au",u"Warwick",12347,-28.219009,152.034378 ],
    [ u"au",u"Wellington",5428,-32.555882,148.945084 ],
    [ u"au",u"Whyalla",19646,-33.032681,137.564835 ],
    [ u"au",u"Wodonga",31518,-36.121792,146.888092 ],
    [ u"au",u"Wollongong",260918,-34.424,150.893448 ],
    [ u"au",u"Wonthaggi",5985,-38.605862,145.593552 ],
    [ u"au",u"Yeppoon",10769,-23.126829,150.744064 ],
    [ u"au",u"Young",7501,-34.313499,148.301071 ],
    [ u"au",u"Yulara",3903,-25.245291,130.980545 ],
    [ u"aw",u"Oranjestad",29998,12.5166667,-70.0333333 ],
    [ u"az",u"Agdam",39451,39.99096,46.927356 ],
    [ u"az",u"Agdas",23528,40.65,47.476111 ],
    [ u"az",u"Agstafa",12542,41.118889,45.453889 ],
    [ u"az",u"Agsu",17209,40.569167,48.396476 ],
    [ u"az",u"Alunitdag",857,40.521667,46.080556 ],
    [ u"az",u"Aran",6724,40.625278,46.975556 ],
    [ u"az",u"Artyom",13435,40.472255,50.333041 ],
    [ u"az",u"Astara",15190,38.455977,48.87498 ],
    [ u"az",u"Badamdar",11398,40.339444,49.803889 ],
    [ u"az",u"Baku",1116513,40.395278,49.882222 ],
    [ u"az",u"Basqal",1234,40.7552,48.391044 ],
    [ u"az",u"Buzovna",24795,40.517888,50.113901 ],
    [ u"az",u"Ceyranbatan",5684,40.540833,49.659722 ],
    [ u"az",u"Corat",8624,40.5725,49.706389 ],
    [ u"az",u"Culfa",10820,38.9558,45.6308 ],
    [ u"az",u"Gilazi",3277,40.903896,49.335522 ],
    [ u"az",u"Gilazi",3277,40.870977,49.342333 ],
    [ u"az",u"Goranboy",7334,40.610278,46.789722 ],
    [ u"az",u"Göyçay",35348,40.653056,47.740556 ],
    [ u"az",u"Gürgan",712,40.397462,50.336733 ],
    [ u"az",u"Guzdak",2462,40.374444,49.681944 ],
    [ u"az",u"Hadrut",2523,39.520018,47.0318 ],
    [ u"az",u"Haftoni",2003,38.763253,48.762231 ],
    [ u"az",u"Hasanabad",4308,39.336672,49.214143 ],
    [ u"az",u"Horadiz",2714,39.448771,47.335313 ],
    [ u"az",u"Hövsan",36293,40.374444,50.085278 ],
    [ u"az",u"Imisli",31381,39.871307,48.064094 ],
    [ u"az",u"Istisu",929,39.947532,45.962121 ],
    [ u"az",u"Kesla",17913,40.397778,49.898611 ],
    [ u"az",u"Kijäba",4567,38.532778,48.816667 ],
    [ u"az",u"Kirovskiy",34488,40.433333,49.85 ],
    [ u"az",u"Korgöz",2036,40.303056,49.62 ],
    [ u"az",u"Lerik",7094,38.772633,48.412788 ],
    [ u"az",u"Lökbatan",30694,40.323718,49.728038 ],
    [ u"az",u"Masalli",9603,39.027781,48.670276 ],
    [ u"az",u"Mastaga",40092,40.532778,50.003889 ],
    [ u"az",u"Mincivan",6353,39.029348,46.718471 ],
    [ u"az",u"Mugan",4410,40.095182,48.821136 ],
    [ u"az",u"Naftalan",7045,40.506667,46.825 ],
    [ u"az",u"Nardaran",7700,40.556111,50.005556 ],
    [ u"az",u"Neftçala",18661,39.37417,49.247224 ],
    [ u"az",u"Ordubad",9781,38.905954,46.023411 ],
    [ u"az",u"Pirsagi",5102,40.564032,49.8913 ],
    [ u"az",u"Pushkino",18182,39.458333,48.545 ],
    [ u"az",u"Puta",1018,40.296667,49.660278 ],
    [ u"az",u"Qabaqçöl",1293,41.72,46.264722 ],
    [ u"az",u"Qala",2709,40.44182,50.168121 ],
    [ u"az",u"Qaraçala",4211,39.813178,48.952303 ],
    [ u"az",u"Qaraçuxur",72989,40.396667,49.973611 ],
    [ u"az",u"Qarayeri",5565,40.78862,46.306589 ],
    [ u"az",u"Qax",11993,41.4225,46.924167 ],
    [ u"az",u"Qazanbulaq",980,40.618611,46.645278 ],
    [ u"az",u"Qazax",18904,41.093333,45.366111 ],
    [ u"az",u"Qobu",7377,40.404722,49.713056 ],
    [ u"az",u"Qobustan",13398,40.08238,49.412048 ],
    [ u"az",u"Qovlar",12819,40.942137,45.732171 ],
    [ u"az",u"Quba",22405,41.362587,48.515186 ],
    [ u"az",u"Qusar",16022,41.427284,48.42893 ],
    [ u"az",u"Quscu",408,40.555556,46.091944 ],
    [ u"az",u"Ramana",8855,40.442222,49.980556 ],
    [ u"az",u"Sabirabad",28076,40.009458,48.475154 ],
    [ u"az",u"Sabunçu",20996,40.4425,49.948056 ],
    [ u"az",u"Sahbuz",2674,39.407222,45.573889 ],
    [ u"az",u"Salyan",36555,39.593615,48.980552 ],
    [ u"az",u"Samur",1760,41.632544,48.430248 ],
    [ u"az",u"Saray",10173,40.532222,49.716389 ],
    [ u"az",u"Sollar",205,41.639727,48.664408 ],
    [ u"az",u"Sonqar",730,40.322099,49.601085 ],
    [ u"az",u"Suraabad",1945,40.819244,49.468745 ],
    [ u"az",u"Susa",18663,39.758934,46.749187 ],
    [ u"az",u"Tovuz",12626,40.992222,45.628889 ],
    [ u"az",u"Türkan",9699,40.363889,50.215 ],
    [ u"az",u"Türyançay",307,40.7088,47.54326 ],
    [ u"az",u"Ucar",15741,40.518333,47.654167 ],
    [ u"az",u"Vurgun",2635,41.094229,45.471616 ],
    [ u"az",u"Xaçmaz",37175,41.463489,48.80605 ],
    [ u"az",u"Xanlar",17816,40.586944,46.315833 ],
    [ u"az",u"Xocali",5810,39.9,46.866667 ],
    [ u"az",u"Xocali",5810,39.912973,46.790284 ],
    [ u"az",u"Xocasan",5089,40.413484,49.772088 ],
    [ u"az",u"Xudat",13625,41.630965,48.681 ],
    [ u"az",u"Yevlax",53715,40.612732,47.142329 ],
    [ u"az",u"Zabrat",21396,40.476104,49.941582 ],
    [ u"az",u"Zaqatala",18277,41.633611,46.643333 ],
    [ u"az",u"Zig",6001,40.343889,49.969167 ],
    [ u"ba",u"Banja Luka",221100,44.7758333,17.1855556 ],
    [ u"ba",u"Banovici",7211,44.4041667,18.4475 ],
    [ u"ba",u"Barice",3697,44.5405556,18.4811111 ],
    [ u"ba",u"Batkovici",4923,44.8536111,19.1963889 ],
    [ u"ba",u"Bihac",75641,44.8169444,15.8708333 ],
    [ u"ba",u"Bijela",3484,43.6086111,17.9519444 ],
    [ u"ba",u"Bijeljina",37691,44.7569444,19.2161111 ],
    [ u"ba",u"Bila",4397,43.7825,16.9252778 ],
    [ u"ba",u"Bileca",13256,42.8719444,18.4297222 ],
    [ u"ba",u"Blagaj",4715,43.2575,17.8886111 ],
    [ u"ba",u"Blatnica",5675,44.3530556,17.5894444 ],
    [ u"ba",u"Bosanska Dubica",9959,45.1766667,16.8094444 ],
    [ u"ba",u"Bosanska Gradiska",13345,45.1411111,17.25 ],
    [ u"ba",u"Bosanska Kostajnica",4739,45.2197222,16.5358333 ],
    [ u"ba",u"Bosanska Krupa",15193,44.8825,16.1513889 ],
    [ u"ba",u"Bosanski Brod",9249,45.1375,17.9897222 ],
    [ u"ba",u"Bosanski Novi",8920,45.0458333,16.3802778 ],
    [ u"ba",u"Bosanski Samac",3599,45.0591667,18.4669444 ],
    [ u"ba",u"Bosansko Grahovo",5642,44.1794444,16.3638889 ],
    [ u"ba",u"Bratunac",4717,44.1875,19.3394444 ],
    [ u"ba",u"Brcko",38478,44.8727778,18.8083333 ],
    [ u"ba",u"Breza",3732,44.0161111,18.2588889 ],
    [ u"ba",u"Bronzani Majdan",3945,44.7869444,16.9311111 ],
    [ u"ba",u"Bugojno",41378,44.0572222,17.4508333 ],
    [ u"ba",u"Busovaca",4775,44.0975,17.8788889 ],
    [ u"ba",u"Buzim",7229,45.0547222,16.0319444 ],
    [ u"ba",u"Cajnice",3908,43.5575,19.0711111 ],
    [ u"ba",u"Capljina",7923,43.1138889,17.7036111 ],
    [ u"ba",u"Careva Cuprija",3954,44.2658333,18.4291667 ],
    [ u"ba",u"Cazin",21741,44.9669444,15.9430556 ],
    [ u"ba",u"Cecava",3847,44.6866667,17.7705556 ],
    [ u"ba",u"Celinac",6670,44.7227778,17.3277778 ],
    [ u"ba",u"Cim",3966,43.3527778,17.7772222 ],
    [ u"ba",u"Citluk",5718,43.2286111,17.7008333 ],
    [ u"ba",u"Coralici",5223,44.9830556,15.9041667 ],
    [ u"ba",u"Crnici",5789,43.1288889,17.8666667 ],
    [ u"ba",u"Derventa",9772,44.9772222,17.9102778 ],
    [ u"ba",u"Divicani",7250,44.3666667,17.3261111 ],
    [ u"ba",u"Doboj",27234,44.7347222,18.0877778 ],
    [ u"ba",u"Dobrinje",3987,44.0497222,18.1194444 ],
    [ u"ba",u"Dobrljin",3581,45.1469444,16.5033333 ],
    [ u"ba",u"Donja Dubica",3489,45.075,18.4113889 ],
    [ u"ba",u"Donja Mahala",5565,45.0469444,18.6663889 ],
    [ u"ba",u"Donja Medjidja",3782,44.8025,18.4033333 ],
    [ u"ba",u"Donja Orahovica",5612,44.6530556,18.3702778 ],
    [ u"ba",u"Donje Dubrave",3811,44.4811111,18.6961111 ],
    [ u"ba",u"Donje Vukovije",3535,44.4636111,18.7538889 ],
    [ u"ba",u"Donji Vakuf",7955,44.1436111,17.4 ],
    [ u"ba",u"Dreznica",3908,43.5288889,17.2819444 ],
    [ u"ba",u"Drinovci",3791,43.355,17.3538889 ],
    [ u"ba",u"Dubravica",3868,44.4419444,18.1180556 ],
    [ u"ba",u"Foca",14614,43.505,18.7786111 ],
    [ u"ba",u"Fojnica",8244,43.9625,17.8983333 ],
    [ u"ba",u"Gacko",3417,43.1672222,18.5352778 ],
    [ u"ba",u"Glamoc",4015,44.0458333,16.8486111 ],
    [ u"ba",u"Gnojnica",3985,44.6205556,18.4466667 ],
    [ u"ba",u"Gorazde",17649,43.6669444,18.9763889 ],
    [ u"ba",u"Gornja Koprivna",4600,45.0119444,15.9572222 ],
    [ u"ba",u"Gornja Tuzla",4864,44.5561111,18.7613889 ],
    [ u"ba",u"Gornje Dubrave",4821,44.4713889,18.7297222 ],
    [ u"ba",u"Gornje Zivinice",4661,44.4286111,18.6169444 ],
    [ u"ba",u"Gornji Vakuf",7014,43.9380556,17.5883333 ],
    [ u"ba",u"Gostovici",5802,44.415,18.1583333 ],
    [ u"ba",u"Gracanica",15758,44.7033333,18.3097222 ],
    [ u"ba",u"Gradacac",15659,44.8808333,18.4269444 ],
    [ u"ba",u"Gromiljak",6457,43.9666667,18.0530556 ],
    [ u"ba",u"Grude",4627,43.3641667,17.4205556 ],
    [ u"ba",u"Hadzici",7173,43.8222222,18.2066667 ],
    [ u"ba",u"Hotonj",4013,43.8947222,18.3727778 ],
    [ u"ba",u"Ilici",3688,43.3472222,17.7680556 ],
    [ u"ba",u"Ilijas",5854,43.9508333,18.2708333 ],
    [ u"ba",u"Izacic",4089,44.875,15.7819444 ],
    [ u"ba",u"Jablanica",6209,43.6602778,17.7616667 ],
    [ u"ba",u"Jajce",9762,44.3422222,17.2655556 ],
    [ u"ba",u"Janja",5543,44.6652778,19.2477778 ],
    [ u"ba",u"Jelah",5291,44.6541667,17.9580556 ],
    [ u"ba",u"Jezerski",4361,44.9808333,16.0841667 ],
    [ u"ba",u"Kacuni",5042,44.065,17.9386111 ],
    [ u"ba",u"Kakanj",12405,44.1272222,18.1180556 ],
    [ u"ba",u"Karadaglije",3700,44.5716667,18.0183333 ],
    [ u"ba",u"Kiseljak",3447,44.4888889,18.5688889 ],
    [ u"ba",u"Kladanj",6783,44.2263889,18.6913889 ],
    [ u"ba",u"Kljuc",7244,44.535,16.7722222 ],
    [ u"ba",u"Knezica",4792,45.1027778,16.6775 ],
    [ u"ba",u"Kobilja Glava",3666,43.8819444,18.3891667 ],
    [ u"ba",u"Kocerin",3516,43.3897222,17.485 ],
    [ u"ba",u"Konjic",15950,43.6519444,17.9613889 ],
    [ u"ba",u"Koran",3394,43.8102778,18.5688889 ],
    [ u"ba",u"Laktasi",6464,44.9080556,17.3008333 ],
    [ u"ba",u"Lamovita",4582,44.9255556,16.9072222 ],
    [ u"ba",u"Lijesnica",3559,44.4941667,18.0741667 ],
    [ u"ba",u"Listica",9370,43.3833333,17.5927778 ],
    [ u"ba",u"Livno",11748,43.8269444,17.0077778 ],
    [ u"ba",u"Ljubinje",4235,42.9508333,18.0886111 ],
    [ u"ba",u"Ljubuski",9987,43.1969444,17.545 ],
    [ u"ba",u"Lokvine",3928,44.2047222,17.8563889 ],
    [ u"ba",u"Lopare",3614,44.6377778,18.8427778 ],
    [ u"ba",u"Lukavac",12607,44.5419444,18.5258333 ],
    [ u"ba",u"Lukavica",4084,44.7627778,18.1688889 ],
    [ u"ba",u"Maglajani",4221,44.9486111,17.3494444 ],
    [ u"ba",u"Maglaj",7398,44.5491667,18.0966667 ],
    [ u"ba",u"Mala Kladusa",6033,45.1341667,15.8586111 ],
    [ u"ba",u"Malesici",3764,44.7380556,18.2738889 ],
    [ u"ba",u"Maricka",3707,44.8588889,16.8522222 ],
    [ u"ba",u"Maslovare",4899,44.5655556,17.5336111 ],
    [ u"ba",u"Milici",8210,44.1316667,19.0316667 ],
    [ u"ba",u"Mionica",8701,44.8672222,18.4630556 ],
    [ u"ba",u"Modrica",5135,44.9544444,18.3036111 ],
    [ u"ba",u"Mostar",104517,43.3433333,17.8080556 ],
    [ u"ba",u"Mostre",4009,44.025,18.1413889 ],
    [ u"ba",u"Mramor",3918,44.5916667,18.5644444 ],
    [ u"ba",u"Mrkonjic Grad",14737,44.4158333,17.0861111 ],
    [ u"ba",u"Nevesinje",7312,43.2586111,18.1133333 ],
    [ u"ba",u"Novi Seher",4416,44.5102778,18.0258333 ],
    [ u"ba",u"Novi Travnik",10006,44.1711111,17.6575 ],
    [ u"ba",u"Obudovac",2171,44.965,18.6122222 ],
    [ u"ba",u"Odzak",11621,45.0111111,18.3266667 ],
    [ u"ba",u"Olovo",3305,44.13,18.5827778 ],
    [ u"ba",u"Omarska",6466,44.89,16.8991667 ],
    [ u"ba",u"Orasac",3856,44.6288889,16.0711111 ],
    [ u"ba",u"Orasje",3613,45.0355556,18.6933333 ],
    [ u"ba",u"Orguz",4371,43.7738889,16.8638889 ],
    [ u"ba",u"Ostra Luka",3923,45.0,18.5883333 ],
    [ u"ba",u"Ostrozac",5456,44.9086111,15.9402778 ],
    [ u"ba",u"Otoka",6595,44.96,16.1791667 ],
    [ u"ba",u"Pajic Polje",4026,43.9758333,17.5275 ],
    [ u"ba",u"Pale",7458,43.8161111,18.5694444 ],
    [ u"ba",u"Pazaric",4787,43.7886111,18.1608333 ],
    [ u"ba",u"Pecigrad",6514,45.0544444,15.8969444 ],
    [ u"ba",u"Peci",3650,44.6272222,16.7861111 ],
    [ u"ba",u"Petkovci",2211,44.4530556,19.0761111 ],
    [ u"ba",u"Piskavica",3797,44.8341667,16.9888889 ],
    [ u"ba",u"Pjanici",3537,44.9836111,15.8227778 ],
    [ u"ba",u"Podbrdo",4028,44.4408333,17.0138889 ],
    [ u"ba",u"Podhum",5801,43.7230556,17.0011111 ],
    [ u"ba",u"Podzvizd",6665,45.1741667,15.8736111 ],
    [ u"ba",u"Polje",3799,43.8805556,18.0744444 ],
    [ u"ba",u"Posusje",5114,43.4722222,17.3266667 ],
    [ u"ba",u"Potoci",8311,43.4086111,17.8786111 ],
    [ u"ba",u"Pribinic",3558,44.6105556,17.6905556 ],
    [ u"ba",u"Priboj",4351,44.6027778,18.9313889 ],
    [ u"ba",u"Prijedor",36346,44.9813889,16.7130556 ],
    [ u"ba",u"Prnjavor",7098,44.8702778,17.6627778 ],
    [ u"ba",u"Prozor",10349,43.8222222,17.6091667 ],
    [ u"ba",u"Puracic",3461,44.5469444,18.4766667 ],
    [ u"ba",u"Radisici",4071,43.2219444,17.5430556 ],
    [ u"ba",u"Rodoc",5159,43.3088889,17.8069444 ],
    [ u"ba",u"Rogatica",4946,43.8008333,19.0025 ],
    [ u"ba",u"Rumboci",3854,43.8322222,17.5011111 ],
    [ u"ba",u"Sanica",5666,44.6141667,16.6411111 ],
    [ u"ba",u"Sanski Most",13550,44.7652778,16.6655556 ],
    [ u"ba",u"Sarajevo",696726,43.85,18.3833333 ],
    [ u"ba",u"Sekovici",6315,44.2986111,18.8527778 ],
    [ u"ba",u"Serici",3663,44.4652778,18.5580556 ],
    [ u"ba",u"Sipovo",10737,44.2813889,17.0838889 ],
    [ u"ba",u"Skender Vakuf",6866,44.4908333,17.3775 ],
    [ u"ba",u"Skokovi",3553,45.0313889,15.9144444 ],
    [ u"ba",u"Sladna",4304,44.7294444,18.4241667 ],
    [ u"ba",u"Sokolac",8842,43.9397222,18.8016667 ],
    [ u"ba",u"Solina",4780,44.5602778,18.6947222 ],
    [ u"ba",u"Srbac",7380,45.0977778,17.525 ],
    [ u"ba",u"Srebrenica",2861,44.1063889,19.2969444 ],
    [ u"ba",u"Srebrenik",6723,44.7077778,18.4880556 ],
    [ u"ba",u"Stanari",3590,44.7472222,17.8294444 ],
    [ u"ba",u"Stijena",10844,44.9352778,16.0172222 ],
    [ u"ba",u"Stolac",7733,43.0844444,17.9575 ],
    [ u"ba",u"Stupari",4424,44.3147222,18.6841667 ],
    [ u"ba",u"Sturlic",5013,45.0638889,15.7780556 ],
    [ u"ba",u"Sumatac",4987,45.0988889,15.8575 ],
    [ u"ba",u"Svodna",4387,45.0372222,16.5383333 ],
    [ u"ba",u"Svojat",3515,44.3947222,18.7391667 ],
    [ u"ba",u"Tesanjka",5666,44.6730556,18.0127778 ],
    [ u"ba",u"Tesanj",7549,44.6116667,17.9872222 ],
    [ u"ba",u"Teslic",6404,44.6063889,17.8597222 ],
    [ u"ba",u"Todorovo",9560,45.0883333,15.9308333 ],
    [ u"ba",u"Tojsici",6587,44.4813889,18.7869444 ],
    [ u"ba",u"Tolisa",4282,45.0430556,18.6427778 ],
    [ u"ba",u"Tomislavgrad",7737,43.7180556,17.2266667 ],
    [ u"ba",u"Travnik",31127,44.2266667,17.6705556 ],
    [ u"ba",u"Trebinje",33177,42.7119444,18.3441667 ],
    [ u"ba",u"Trn",7553,44.8597222,17.2363889 ],
    [ u"ba",u"Trzacka Rastela",6617,44.9733333,15.7902778 ],
    [ u"ba",u"Turbe",4766,44.2436111,17.5713889 ],
    [ u"ba",u"Tuzla",142484,44.5427778,18.6694444 ],
    [ u"ba",u"Ugljevik",3452,44.6636111,19.0202778 ],
    [ u"ba",u"Ustikolina",4446,43.5836111,18.79 ],
    [ u"ba",u"Vares",7193,44.1644444,18.3283333 ],
    [ u"ba",u"Varoska Rijeka",6573,45.0847222,16.0141667 ],
    [ u"ba",u"Velagici",4972,44.5572222,16.7316667 ],
    [ u"ba",u"Velika Kladusa",19330,45.1894444,15.8116667 ],
    [ u"ba",u"Velika Obarska",5142,44.8052778,19.1641667 ],
    [ u"ba",u"Vidosi",3905,43.7713889,17.0283333 ],
    [ u"ba",u"Visegrad",6086,43.7847222,19.2991667 ],
    [ u"ba",u"Visoko",17890,43.9888889,18.1780556 ],
    [ u"ba",u"Vitez",8140,44.1544444,17.7902778 ],
    [ u"ba",u"Vitina",4384,43.2375,17.4838889 ],
    [ u"ba",u"Vlasenica",4508,44.1819444,18.9405556 ],
    [ u"ba",u"Vogosca",8179,43.9019444,18.3480556 ],
    [ u"ba",u"Voljevac",3764,43.8786111,17.6591667 ],
    [ u"ba",u"Vozuca",3209,44.3613889,18.3577778 ],
    [ u"ba",u"Vrnograc",6859,45.1636111,15.9536111 ],
    [ u"ba",u"Zabrisce",4261,43.7925,16.9422222 ],
    [ u"ba",u"Zavidovici",14380,44.4458333,18.1497222 ],
    [ u"ba",u"Zboriste",4922,45.1458333,16.0177778 ],
    [ u"ba",u"Zeljezno Polje",5783,44.4083333,17.9319444 ],
    [ u"ba",u"Zenica",164422,44.2013889,17.9063889 ],
    [ u"ba",u"Zepce",8502,44.4266667,18.0377778 ],
    [ u"ba",u"Zivinice",13640,44.4494444,18.6497222 ],
    [ u"ba",u"Zivinice",3718,44.5472222,17.375 ],
    [ u"ba",u"Zvornik",8024,44.3869444,19.1013889 ],
    [ u"bb",u"Bathsheba",1765,13.2166667,-59.5166667 ],
    [ u"bb",u"Blackmans",623,13.1833333,-59.5333333 ],
    [ u"bb",u"Bridgetown",98511,13.1,-59.6166667 ],
    [ u"bb",u"Crab Hill",727,13.3166667,-59.6333333 ],
    [ u"bb",u"Greenland",623,13.25,-59.5666667 ],
    [ u"bb",u"Hillaby",519,13.2166667,-59.5833333 ],
    [ u"bb",u"Holetown",1350,13.1833333,-59.65 ],
    [ u"bb",u"Oistins",2285,13.0666667,-59.5333333 ],
    [ u"bb",u"Speightstown",3634,13.25,-59.65 ],
    [ u"bd",u"Abhaynagar",42658,23.0166667,89.4666667 ],
    [ u"bd",u"Badarganj",32604,25.6666667,89.05 ],
    [ u"bd",u"Bajitpur",34564,24.2166667,90.95 ],
    [ u"bd",u"Bandarban",32526,22.2,92.2166667 ],
    [ u"bd",u"Baniachang",37812,24.5166667,91.3666667 ],
    [ u"bd",u"Barisal",280437,22.7,90.3666667 ],
    [ u"bd",u"Bera",39608,24.0833333,89.6166667 ],
    [ u"bd",u"Bhairab Bazar",105470,24.0666667,90.9666667 ],
    [ u"bd",u"Bhandaria",30222,22.4833333,90.0666667 ],
    [ u"bd",u"Bheramara",38164,24.0333333,88.9666667 ],
    [ u"bd",u"Bhola",99090,22.6833333,90.65 ],
    [ u"bd",u"Chandpur",120183,23.15,90.7166667 ],
    [ u"bd",u"Char Bhadrasan",34427,23.3166667,90.2166667 ],
    [ u"bd",u"Chhagalnaiya",39339,23.03,91.5069444 ],
    [ u"bd",u"Chhatak",39223,25.0333333,91.6666667 ],
    [ u"bd",u"Chilmari",49742,25.55,89.7166667 ],
    [ u"bd",u"Dhaka",6493177,23.7230556,90.4086111 ],
    [ u"bd",u"Dhamrai",38003,23.9122222,90.2683333 ],
    [ u"bd",u"Dinajpur",206251,25.6333333,88.6333333 ],
    [ u"bd",u"Dohar",45549,23.5883333,90.1469444 ],
    [ u"bd",u"Faridpur",112200,23.6,89.8333333 ],
    [ u"bd",u"Fatikchhari",39974,22.725,91.7675 ],
    [ u"bd",u"Feni",84038,23.0186111,91.41 ],
    [ u"bd",u"Gafargaon",34181,24.4333333,90.5666667 ],
    [ u"bd",u"Gaurnadi",40524,22.9666667,90.2333333 ],
    [ u"bd",u"Gazipur",132249,23.8,90.65 ],
    [ u"bd",u"Habiganj",88770,24.3833333,91.4166667 ],
    [ u"bd",u"Hajiganj",44349,23.2511111,90.8591667 ],
    [ u"bd",u"Ishurdi",82005,24.1333333,89.0833333 ],
    [ u"bd",u"Jaipur Hat",73076,25.1,89.0166667 ],
    [ u"bd",u"Jamalpur",167914,24.9166667,89.9333333 ],
    [ u"bd",u"Jhikargachha",41962,23.1166667,89.1166667 ],
    [ u"bd",u"Kalia",40497,23.05,89.6333333 ],
    [ u"bd",u"Kaliganj",45636,23.4166667,89.1333333 ],
    [ u"bd",u"Keshabpur",30930,22.9166667,89.2166667 ],
    [ u"bd",u"Khagrachari",50364,23.1,91.9666667 ],
    [ u"bd",u"Khulna",1342429,22.8,89.55 ],
    [ u"bd",u"Kishorganj",90700,24.4333333,90.7666667 ],
    [ u"bd",u"Laksham",82299,23.2472222,91.1425 ],
    [ u"bd",u"Lakshmipur",61710,22.95,90.8333333 ],
    [ u"bd",u"Lalmanir Hat",65135,25.9,89.45 ],
    [ u"bd",u"Lalmohan",42225,22.3166667,90.7166667 ],
    [ u"bd",u"Madaripur",84799,23.1752778,90.2072222 ],
    [ u"bd",u"Manikchhari",24836,22.8386111,91.8455556 ],
    [ u"bd",u"Manikganj",85800,23.8552778,90.0125 ],
    [ u"bd",u"Mathbaria",29764,22.3,89.95 ],
    [ u"bd",u"Maulvi Bazar",57448,24.4833333,91.7833333 ],
    [ u"bd",u"Mehendiganj",39429,22.8166667,90.5333333 ],
    [ u"bd",u"Mirzapur",41142,24.1,90.1 ],
    [ u"bd",u"Morrelganj",31651,22.4666667,89.85 ],
    [ u"bd",u"Muktagachha",24687,24.7666667,90.2333333 ],
    [ u"bd",u"Nabinagar",31675,23.8916667,90.9733333 ],
    [ u"bd",u"Nageshwari",49431,25.9666667,89.7166667 ],
    [ u"bd",u"Nalchiti",38708,22.6333333,90.2833333 ],
    [ u"bd",u"Naral",55118,23.1666667,89.5 ],
    [ u"bd",u"Narayanganj",223773,23.6233333,90.5011111 ],
    [ u"bd",u"Narsingdi",281110,23.9208333,90.7180556 ],
    [ u"bd",u"Nawabganj",142373,24.6,88.2833333 ],
    [ u"bd",u"Netrakona",79025,24.8833333,90.7166667 ],
    [ u"bd",u"Pabna",137904,24.0,89.25 ],
    [ u"bd",u"Palang",67659,23.2166667,90.35 ],
    [ u"bd",u"Panchagarh",48536,26.3333333,88.5666667 ],
    [ u"bd",u"Parbatipur",48026,25.65,88.9166667 ],
    [ u"bd",u"Patiya",51367,22.3030556,91.9783333 ],
    [ u"bd",u"Phultala",37990,22.7,89.5166667 ],
    [ u"bd",u"Pirganj",34610,25.8666667,88.3666667 ],
    [ u"bd",u"Pirojpur",54424,22.5666667,89.9833333 ],
    [ u"bd",u"Rajshahi",700206,24.3666667,88.6 ],
    [ u"bd",u"Ramganj",55247,23.1,90.85 ],
    [ u"bd",u"Ramgarh",28017,22.9702778,91.7966667 ],
    [ u"bd",u"Rangpur",285586,25.75,89.25 ],
    [ u"bd",u"Raozan",25711,22.5661111,91.9325 ],
    [ u"bd",u"Raypur",64659,23.05,90.7666667 ],
    [ u"bd",u"Sakhipur",40874,24.3,90.1833333 ],
    [ u"bd",u"Sarankhola",36475,22.3,89.7833333 ],
    [ u"bd",u"Sarishabari",81334,24.7333333,89.8333333 ],
    [ u"bd",u"Satkhira",128933,22.7166667,89.1 ],
    [ u"bd",u"Sherpur",107431,25.0166667,90.0166667 ],
    [ u"bd",u"Shibganj",35965,24.6833333,88.1666667 ],
    [ u"bd",u"Sirajganj",167501,24.45,89.7166667 ],
    [ u"bd",u"Sunamganj",76491,25.0666667,91.4 ],
    [ u"bd",u"Teknaf",40562,20.8666667,92.3 ],
    [ u"bd",u"Thakurgaon",71104,26.0333333,88.4666667 ],
    [ u"bd",u"Tungi",337620,23.89,90.4058333 ],
    [ u"be",u"Aalst",77534,50.933333,4.033333 ],
    [ u"be",u"Aalter",18802,51.083333,3.45 ],
    [ u"be",u"Aarschot",27656,50.983333,4.833333 ],
    [ u"be",u"Aartselaar",14193,51.133333,4.383333 ],
    [ u"be",u"Alken",10933,50.866667,5.3 ],
    [ u"be",u"Alveringem",4910,51.016667,2.716667 ],
    [ u"be",u"Amay",13307,50.55,5.316667 ],
    [ u"be",u"Amel",5221,50.35,6.15 ],
    [ u"be",u"Andenne",24055,50.483333,5.1 ],
    [ u"be",u"Anderlues",11597,50.4,4.266667 ],
    [ u"be",u"Anhée",7125,50.316667,4.883333 ],
    [ u"be",u"Ans",27297,50.65,5.533333 ],
    [ u"be",u"Anthisnes",4116,50.483333,5.516667 ],
    [ u"be",u"Antoing",7507,50.566667,3.45 ],
    [ u"be",u"Antwerp",459805,51.216667,4.416667 ],
    [ u"be",u"Anzegem",13920,50.833333,3.466667 ],
    [ u"be",u"Ardooie",9161,50.983333,3.2 ],
    [ u"be",u"Arendonk",12247,51.316667,5.083333 ],
    [ u"be",u"Arlon",26179,49.683333,5.816667 ],
    [ u"be",u"As",7250,51.016667,5.583333 ],
    [ u"be",u"Asse",28985,50.916667,4.2 ],
    [ u"be",u"Assenede",13495,51.233333,3.75 ],
    [ u"be",u"Assesse",6279,50.366667,5.016667 ],
    [ u"be",u"Ath",26681,50.633333,3.783333 ],
    [ u"be",u"Attert",4491,49.766667,5.783333 ],
    [ u"be",u"Aubange",14932,49.583333,5.8 ],
    [ u"be",u"Aubel",4119,50.7,5.85 ],
    [ u"be",u"Avelgem",9106,50.766667,3.433333 ],
    [ u"be",u"Awans",8612,50.666667,5.466667 ],
    [ u"be",u"Aywaille",10636,50.466667,5.666667 ],
    [ u"be",u"Baarle-Hertog",2305,51.45,4.933333 ],
    [ u"be",u"Baelen",3928,50.633333,5.966667 ],
    [ u"be",u"Balen",19978,51.166667,5.15 ],
    [ u"be",u"Bassenge",8151,50.766667,5.6 ],
    [ u"be",u"Bastogne",14395,50,5.716667 ],
    [ u"be",u"Beaumont",6645,50.233333,4.233333 ],
    [ u"be",u"Beauraing",8242,50.116667,4.966667 ],
    [ u"be",u"Beauvechain",6334,50.783333,4.766667 ],
    [ u"be",u"Beernem",14512,51.15,3.333333 ],
    [ u"be",u"Beerse",16208,51.316667,4.866667 ],
    [ u"be",u"Beersel",23228,50.766667,4.3 ],
    [ u"be",u"Begijnendijk",9178,51.016667,4.766667 ],
    [ u"be",u"Bekkevoort",5714,50.95,4.966667 ],
    [ u"be",u"Beloeil",13405,50.55,3.716667 ],
    [ u"be",u"Beringen",40930,51.05,5.216667 ],
    [ u"be",u"Berlaar",10370,51.116667,4.65 ],
    [ u"be",u"Berlare",13853,51.033333,4 ],
    [ u"be",u"Berloz",2770,50.7,5.216667 ],
    [ u"be",u"Bernissart",11588,50.466667,3.633333 ],
    [ u"be",u"Bertem",9215,50.866667,4.633333 ],
    [ u"be",u"Bertogne",2852,50.083333,5.666667 ],
    [ u"be",u"Bertrix",8063,49.85,5.25 ],
    [ u"be",u"Bever",1932,50.916667,4.316667 ],
    [ u"be",u"Beveren",45179,51.216667,4.25 ],
    [ u"be",u"Beyne-Heusay",11608,50.616667,5.65 ],
    [ u"be",u"Bierbeek",8994,50.833333,4.766667 ],
    [ u"be",u"Bièvre",3207,49.933333,5.016667 ],
    [ u"be",u"Bilzen",29622,50.866667,5.516667 ],
    [ u"be",u"Binche",32030,50.4,4.166667 ],
    [ u"be",u"Blankenberge",18230,51.316667,3.133333 ],
    [ u"be",u"Blegny",12745,50.666667,5.733333 ],
    [ u"be",u"Bocholt",12346,51.166667,5.583333 ],
    [ u"be",u"Boechout",12145,51.166667,4.5 ],
    [ u"be",u"Bonheiden",14260,51.033333,4.533333 ],
    [ u"be",u"Boom",15810,51.083333,4.366667 ],
    [ u"be",u"Boortmeerbeek",11570,50.983333,4.566667 ],
    [ u"be",u"Borgloon",9955,50.8,5.333333 ],
    [ u"be",u"Bornem",19997,51.1,4.233333 ],
    [ u"be",u"Borsbeek",10334,51.2,4.483333 ],
    [ u"be",u"Bouillon",5347,49.8,5.066667 ],
    [ u"be",u"Boussu",20058,50.433333,3.8 ],
    [ u"be",u"Boutersem",7702,50.85,4.833333 ],
    [ u"be",u"Braine-le-Château",9627,50.683333,4.266667 ],
    [ u"be",u"Braine-le-Comte",20133,50.6,4.133333 ],
    [ u"be",u"Braives",5672,50.633333,5.15 ],
    [ u"be",u"Brasschaat",37040,51.283333,4.45 ],
    [ u"be",u"Brecht",25908,51.35,4.633333 ],
    [ u"be",u"Bredene",14862,51.233333,2.966667 ],
    [ u"be",u"Bree",14363,51.133333,5.6 ],
    [ u"be",u"Brugelette",3358,50.6,3.85 ],
    [ u"be",u"Brugge",116709,51.216667,3.233333 ],
    [ u"be",u"Brunehaut",7592,50.5,4.416667 ],
    [ u"be",u"Brussels",1019022,50.833333,4.333333 ],
    [ u"be",u"Buggenhout",13510,51.016667,4.2 ],
    [ u"be",u"Bullingen",5340,50.416667,6.266667 ],
    [ u"be",u"Burdinne",2799,50.583333,5.066667 ],
    [ u"be",u"Butgenbach",5516,50.433333,6.2 ],
    [ u"be",u"Celles",5471,50.716667,3.45 ],
    [ u"be",u"Cerfontaine",4500,50.166667,4.416667 ],
    [ u"be",u"Chapelle-lez-Herlaimont",14353,50.466667,4.283333 ],
    [ u"be",u"Charleroi",200132,50.416667,4.433333 ],
    [ u"be",u"Chastre",6243,50.6,4.633333 ],
    [ u"be",u"Châtelet",35238,50.4,4.516667 ],
    [ u"be",u"Chaudfontaine",20960,50.583333,5.633333 ],
    [ u"be",u"Chaumont-Gistoux",10943,50.683333,4.733333 ],
    [ u"be",u"Chièvres",6045,50.583333,3.8 ],
    [ u"be",u"Chimay",9720,50.05,4.316667 ],
    [ u"be",u"Chiny",4897,49.733333,5.333333 ],
    [ u"be",u"Ciney",14830,50.3,5.1 ],
    [ u"be",u"Clavier",4092,50.416667,5.366667 ],
    [ u"be",u"Colfontaine",19964,50.383333,3.866667 ],
    [ u"be",u"Comblain-au-Pont",5308,50.466667,5.583333 ],
    [ u"be",u"Courcelles",29473,50.466667,4.366667 ],
    [ u"be",u"Court-Saint-Étienne",9353,50.65,4.566667 ],
    [ u"be",u"Couvin",13518,50.05,4.483333 ],
    [ u"be",u"Crisnée",2587,50.716667,5.4 ],
    [ u"be",u"Dalhem",6391,50.716667,5.716667 ],
    [ u"be",u"Damme",10924,51.25,3.283333 ],
    [ u"be",u"Daverdisse",1299,50.016667,5.116667 ],
    [ u"be",u"Deerlijk",11292,50.85,3.35 ],
    [ u"be",u"De Haan",11766,51.266667,3.033333 ],
    [ u"be",u"Deinze",27777,50.983333,3.533333 ],
    [ u"be",u"Denderleeuw",16969,50.883333,4.066667 ],
    [ u"be",u"Dendermonde",43055,51.033333,4.116667 ],
    [ u"be",u"Dentergem",8038,50.966667,3.416667 ],
    [ u"be",u"De Panne",9799,51.1,2.583333 ],
    [ u"be",u"De Pinte",10020,51,3.65 ],
    [ u"be",u"Dessel",8707,51.233333,5.116667 ],
    [ u"be",u"Destelbergen",16853,51.05,3.8 ],
    [ u"be",u"Diepenbeek",17699,50.9,5.4 ],
    [ u"be",u"Diest",22516,50.983333,5.05 ],
    [ u"be",u"Diksmuide",15515,51.033333,2.866667 ],
    [ u"be",u"Dilbeek",39482,50.85,4.266667 ],
    [ u"be",u"Dinant",12875,50.266667,4.916667 ],
    [ u"be",u"Dison",13642,50.616667,5.85 ],
    [ u"be",u"Doische",2739,50.133333,4.75 ],
    [ u"be",u"Donceel",2712,50.65,5.316667 ],
    [ u"be",u"Dour",16861,50.4,3.783333 ],
    [ u"be",u"Drogenbos",4843,50.783333,4.316667 ],
    [ u"be",u"Duffel",16011,51.1,4.516667 ],
    [ u"be",u"Durbuy",10251,50.35,5.466667 ],
    [ u"be",u"Edegem",21839,51.15,4.45 ],
    [ u"be",u"Eeklo",19116,51.183333,3.566667 ],
    [ u"be",u"Éghezée",14352,50.6,4.9 ],
    [ u"be",u"Ellezelles",5566,50.733333,3.683333 ],
    [ u"be",u"Enghien",11367,50.7,4.033333 ],
    [ u"be",u"Engis",5737,50.583333,5.416667 ],
    [ u"be",u"Érezée",2930,50.3,5.55 ],
    [ u"be",u"Erquelinnes",9396,50.3,4.116667 ],
    [ u"be",u"Esneux",13497,50.533333,5.566667 ],
    [ u"be",u"Essen",16754,51.466667,4.466667 ],
    [ u"be",u"Estaimpuis",9340,50.7,3.25 ],
    [ u"be",u"Étalle",5228,49.683333,5.6 ],
    [ u"be",u"Eupen",18029,50.633333,6.033333 ],
    [ u"be",u"Evergem",31615,51.116667,3.7 ],
    [ u"be",u"Faimes",3349,50.666667,5.266667 ],
    [ u"be",u"Farciennes",11488,50.433333,4.55 ],
    [ u"be",u"Fauvillers",1952,49.85,5.666667 ],
    [ u"be",u"Ferrières",4434,50.4,5.6 ],
    [ u"be",u"Fexhe-le-Haut-Clocher",3082,50.666667,5.4 ],
    [ u"be",u"Fléron",15994,50.616667,5.683333 ],
    [ u"be",u"Fleurus",22080,50.483333,4.533333 ],
    [ u"be",u"Flobecq",3142,50.733333,3.733333 ],
    [ u"be",u"Floreffe",7480,50.433333,4.783333 ],
    [ u"be",u"Florennes",10723,50.25,4.616667 ],
    [ u"be",u"Florenville",5464,49.7,5.3 ],
    [ u"be",u"Frameries",20598,50.4,3.9 ],
    [ u"be",u"Galmaarden",7939,50.75,3.966667 ],
    [ u"be",u"Gavere",11888,50.933333,3.666667 ],
    [ u"be",u"Gedinne",4416,49.983333,4.933333 ],
    [ u"be",u"Geel",34697,51.166667,5 ],
    [ u"be",u"Geer",2682,50.666667,5.166667 ],
    [ u"be",u"Geetbets",5813,50.883333,5.116667 ],
    [ u"be",u"Gembloux",21676,50.566667,4.683333 ],
    [ u"be",u"Genappe",14266,50.6,4.45 ],
    [ u"be",u"Genk",63666,50.966667,5.5 ],
    [ u"be",u"Gent",231493,51.05,3.716667 ],
    [ u"be",u"Geraardsbergen",30807,50.766667,3.866667 ],
    [ u"be",u"Gerpinnes",11977,50.333333,4.516667 ],
    [ u"be",u"Gesves",6150,50.4,5.066667 ],
    [ u"be",u"Gingelom",7930,50.75,5.116667 ],
    [ u"be",u"Gistel",11084,51.166667,2.95 ],
    [ u"be",u"Glabbeek",5070,50.866667,4.95 ],
    [ u"be",u"Gooik",8957,50.8,4.116667 ],
    [ u"be",u"Gouvy",4706,50.185,5.941111 ],
    [ u"be",u"Grez-Doiceau",12367,50.733333,4.7 ],
    [ u"be",u"Grimbergen",33561,50.933333,4.383333 ],
    [ u"be",u"Grobbendonk",10724,51.2,4.716667 ],
    [ u"be",u"Haacht",13541,50.983333,4.633333 ],
    [ u"be",u"Haaltert",17129,50.9,4 ],
    [ u"be",u"Habay",7704,49.733333,5.616667 ],
    [ u"be",u"Halen",8548,50.95,5.1 ],
    [ u"be",u"Halle",34479,50.733333,4.233333 ],
    [ u"be",u"Hamme",22891,51.1,4.133333 ],
    [ u"be",u"Hamoir",3500,50.433333,5.533333 ],
    [ u"be",u"Hamois",6662,50.333333,5.133333 ],
    [ u"be",u"Hannut",14129,50.666667,5.083333 ],
    [ u"be",u"Harelbeke",25978,50.85,3.3 ],
    [ u"be",u"Hasselt",69222,50.933333,5.333333 ],
    [ u"be",u"Hastière",5147,50.216667,4.833333 ],
    [ u"be",u"Havelange",4790,50.383333,5.233333 ],
    [ u"be",u"Heers",6689,50.75,5.283333 ],
    [ u"be",u"Heist-op-den-Berg",37873,51.083333,4.716667 ],
    [ u"be",u"Hemiksem",9504,51.15,4.35 ],
    [ u"be",u"Hensies",6390,50.433333,3.666667 ],
    [ u"be",u"Herbeumont",1612,49.783333,5.233333 ],
    [ u"be",u"Herentals",25912,51.183333,4.833333 ],
    [ u"be",u"Herent",19218,50.9,4.666667 ],
    [ u"be",u"Herenthout",8379,51.15,4.766667 ],
    [ u"be",u"Herk-de-Stad",11566,50.933333,5.166667 ],
    [ u"be",u"Herne",6459,50.716667,4.033333 ],
    [ u"be",u"Héron",4305,50.55,5.083333 ],
    [ u"be",u"Herselt",13493,51.05,4.883333 ],
    [ u"be",u"Herstal",36503,50.666667,5.633333 ],
    [ u"be",u"Herstappe",93,50.733333,5.416667 ],
    [ u"be",u"Herve",16544,50.633333,5.8 ],
    [ u"be",u"Herzele",16523,50.883333,3.883333 ],
    [ u"be",u"Hoegaarden",6110,50.783333,4.9 ],
    [ u"be",u"Hoeilaart",10272,50.766667,4.466667 ],
    [ u"be",u"Hoeselt",9265,50.85,5.483333 ],
    [ u"be",u"Holsbeek",9094,50.916667,4.75 ],
    [ u"be",u"Hooglede",9900,50.983333,3.083333 ],
    [ u"be",u"Hoogstraten",18524,51.4,4.766667 ],
    [ u"be",u"Hotton",4969,50.266667,5.45 ],
    [ u"be",u"Houffalize",4614,50.133333,5.783333 ],
    [ u"be",u"Houthulst",8951,50.983333,2.95 ],
    [ u"be",u"Houyet",4505,50.183333,5.016667 ],
    [ u"be",u"Hove",7968,51.15,4.466667 ],
    [ u"be",u"Huldenberg",9137,50.783333,4.583333 ],
    [ u"be",u"Hulshout",9198,51.083333,4.783333 ],
    [ u"be",u"Huy",19973,50.516667,5.233333 ],
    [ u"be",u"Ichtegem",13582,51.1,3 ],
    [ u"be",u"Ieper",35089,50.85,2.883333 ],
    [ u"be",u"Incourt",4395,50.7,4.783333 ],
    [ u"be",u"Ingelmunster",10603,50.916667,3.25 ],
    [ u"be",u"Ittre",6014,50.65,4.266667 ],
    [ u"be",u"Izegem",26382,50.916667,3.2 ],
    [ u"be",u"Jabbeke",13488,51.183333,3.083333 ],
    [ u"be",u"Jalhay",7688,50.566667,5.966667 ],
    [ u"be",u"Jodoigne",11930,50.716667,4.866667 ],
    [ u"be",u"Juprelle",8354,50.716667,5.533333 ],
    [ u"be",u"Jurbise",9483,50.533333,3.933333 ],
    [ u"be",u"Kalmthout",17485,51.383333,4.466667 ],
    [ u"be",u"Kampenhout",10784,50.95,4.55 ],
    [ u"be",u"Kapellen",26410,51.316667,4.433333 ],
    [ u"be",u"Kapelle-op-den-Bos",8859,51.016667,4.366667 ],
    [ u"be",u"Kaprijke",6114,51.216667,3.6 ],
    [ u"be",u"Kasterlee",17765,51.25,4.95 ],
    [ u"be",u"Keerbergen",12363,51,4.616667 ],
    [ u"be",u"Kinrooi",11946,51.15,5.75 ],
    [ u"be",u"Knesselare",7889,51.133333,3.416667 ],
    [ u"be",u"Knokke-Heist",33781,51.35,3.266667 ],
    [ u"be",u"Koekelare",8317,51.083333,2.966667 ],
    [ u"be",u"Koksijde",21027,51.1,2.65 ],
    [ u"be",u"Kontich",20290,51.133333,4.45 ],
    [ u"be",u"Kortemark",11937,51.033333,3.033333 ],
    [ u"be",u"Kortenaken",7374,50.916667,5.066667 ],
    [ u"be",u"Kortenberg",17774,50.883333,4.533333 ],
    [ u"be",u"Kortessem",8042,50.866667,5.366667 ],
    [ u"be",u"Kortrijk",73879,50.833333,3.266667 ],
    [ u"be",u"Kraainem",12815,50.866667,4.466667 ],
    [ u"be",u"Kruibeke",14815,51.166667,4.316667 ],
    [ u"be",u"Kruishoutem",8179,50.9,3.516667 ],
    [ u"be",u"Kuurne",12638,50.85,3.283333 ],
    [ u"be",u"Laarne",11600,51.033333,3.85 ],
    [ u"be",u"La Bruyère",8194,50.283333,4.583333 ],
    [ u"be",u"La Hulpe",7415,50.733333,4.483333 ],
    [ u"be",u"La Louvière",76668,50.466667,4.183333 ],
    [ u"be",u"Lanaken",24771,50.883333,5.65 ],
    [ u"be",u"Landen",14458,50.75,5.083333 ],
    [ u"be",u"La Roche-en-Ardenne",4200,50.183333,5.583333 ],
    [ u"be",u"Lebbeke",17372,51,4.133333 ],
    [ u"be",u"Ledegem",9102,50.85,3.116667 ],
    [ u"be",u"Lede",16813,50.966667,3.983333 ],
    [ u"be",u"Léglise",3865,49.8,5.533333 ],
    [ u"be",u"Lendelede",5393,50.883333,3.233333 ],
    [ u"be",u"Lennik",8818,50.8,4.15 ],
    [ u"be",u"Lens",3902,50.55,3.9 ],
    [ u"be",u"Leopoldsburg",14149,51.116667,5.25 ],
    [ u"be",u"Lessines",17687,50.716667,3.833333 ],
    [ u"be",u"Leuven",92892,50.883333,4.7 ],
    [ u"be",u"Libin",4609,49.983333,5.25 ],
    [ u"be",u"Lichtervelde",8169,51.033333,3.15 ],
    [ u"be",u"Liedekerke",11980,50.866667,4.083333 ],
    [ u"be",u"Liège",182597,50.633333,5.566667 ],
    [ u"be",u"Lierneux",3332,50.283333,5.8 ],
    [ u"be",u"Lille",15466,51.233333,4.833333 ],
    [ u"be",u"Limbourg",5612,50.616667,5.933333 ],
    [ u"be",u"Lincent",2884,50.716667,5.033333 ],
    [ u"be",u"Linkebeek",4823,50.766667,4.333333 ],
    [ u"be",u"Lint",7982,51.133333,4.5 ],
    [ u"be",u"Lobbes",5467,50.35,4.25 ],
    [ u"be",u"Lochristi",19696,51.1,3.833333 ],
    [ u"be",u"Lokeren",37567,51.1,3.983333 ],
    [ u"be",u"Lommel",31993,51.233333,5.3 ],
    [ u"be",u"Londerzeel",17274,51,4.3 ],
    [ u"be",u"Lontzen",4862,50.683333,6 ],
    [ u"be",u"Lovendegem",9272,51.1,3.6 ],
    [ u"be",u"Lubbeek",13574,50.883333,4.833333 ],
    [ u"be",u"Lummen",13689,50.983333,5.2 ],
    [ u"be",u"Maaseik",23684,51.1,5.8 ],
    [ u"be",u"Maasmechelen",36251,50.816667,5.666667 ],
    [ u"be",u"Machelen",12252,50.916667,4.433333 ],
    [ u"be",u"Maldegem",22092,51.216667,3.45 ],
    [ u"be",u"Malmédy",11514,50.416667,6.033333 ],
    [ u"be",u"Manage",22196,50.5,4.216667 ],
    [ u"be",u"Manhay",3128,50.3,5.666667 ],
    [ u"be",u"Marche-en-Famenne",16856,50.2,5.333333 ],
    [ u"be",u"Marchin",5063,50.466667,5.233333 ],
    [ u"be",u"Martelange",1440,49.833333,5.733333 ],
    [ u"be",u"Mechelen",77531,51.033333,4.466667 ],
    [ u"be",u"Meerhout",9346,51.133333,5.083333 ],
    [ u"be",u"Meise",18497,50.933333,4.333333 ],
    [ u"be",u"Meix-devant-Virton",2637,49.6,5.483333 ],
    [ u"be",u"Melle",10687,51,3.8 ],
    [ u"be",u"Menen",31916,50.8,3.116667 ],
    [ u"be",u"Merbes-le-Château",3999,50.316667,4.15 ],
    [ u"be",u"Merchtem",14660,50.966667,4.233333 ],
    [ u"be",u"Merelbeke",22047,51,3.75 ],
    [ u"be",u"Merksplas",7963,51.366667,4.866667 ],
    [ u"be",u"Mesen",975,50.766667,2.9 ],
    [ u"be",u"Messancy",7144,49.6,5.816667 ],
    [ u"be",u"Mettet",12014,50.316667,4.666667 ],
    [ u"be",u"Meulebeke",10948,50.95,3.283333 ],
    [ u"be",u"Middelkerke",17789,51.183333,2.816667 ],
    [ u"be",u"Modave",3825,50.45,5.3 ],
    [ u"be",u"Moerbeke",5855,51.166667,3.933333 ],
    [ u"be",u"Mol",32659,51.183333,5.1 ],
    [ u"be",u"Momignies",5183,50.033333,4.166667 ],
    [ u"be",u"Mons",91277,50.45,3.933333 ],
    [ u"be",u"Mont-Saint-Guibert",6557,50.633333,4.616667 ],
    [ u"be",u"Moorslede",10720,50.883333,3.066667 ],
    [ u"be",u"Morlanwelz",18233,50.45,4.233333 ],
    [ u"be",u"Mortsel",24525,51.166667,4.466667 ],
    [ u"be",u"Mouscron",52069,50.733333,3.216667 ],
    [ u"be",u"Musson",4225,49.566667,5.7 ],
    [ u"be",u"Namur",106284,50.466667,4.866667 ],
    [ u"be",u"Nandrin",5480,50.5,5.416667 ],
    [ u"be",u"Nassogne",5081,50.133333,5.35 ],
    [ u"be",u"Nazareth",10890,50.966667,3.6 ],
    [ u"be",u"Neerpelt",16122,51.216667,5.416667 ],
    [ u"be",u"Neufchâteau",6416,49.833333,5.433333 ],
    [ u"be",u"Nevele",11153,51.033333,3.55 ],
    [ u"be",u"Niel",8656,51.116667,4.333333 ],
    [ u"be",u"Nieuwerkerken",6466,50.866667,5.183333 ],
    [ u"be",u"Nieuwpoort",10845,51.133333,2.75 ],
    [ u"be",u"Nijlen",20792,51.166667,4.65 ],
    [ u"be",u"Ninove",34795,50.833333,4.016667 ],
    [ u"be",u"Nivelles",24149,50.6,4.333333 ],
    [ u"be",u"Ohey",4324,50.433333,5.133333 ],
    [ u"be",u"Olen",11070,51.15,4.85 ],
    [ u"be",u"Olne",3836,50.583333,5.75 ],
    [ u"be",u"Onhaye",3014,50.25,4.833333 ],
    [ u"be",u"Oosterzele",13151,50.95,3.8 ],
    [ u"be",u"Oostkamp",21489,51.15,3.233333 ],
    [ u"be",u"Oostrozebeke",7489,50.916667,3.333333 ],
    [ u"be",u"Opglabbeek",9452,51.05,5.583333 ],
    [ u"be",u"Opwijk",12045,50.966667,4.183333 ],
    [ u"be",u"Oreye",3373,50.733333,5.366667 ],
    [ u"be",u"Ostend",69011,51.216667,2.916667 ],
    [ u"be",u"Oudenaarde",27935,50.85,3.6 ],
    [ u"be",u"Oudenburg",8752,51.183333,3 ],
    [ u"be",u"Oud-Heverlee",10533,50.833333,4.666667 ],
    [ u"be",u"Oud-Turnhout",12354,51.316667,4.983333 ],
    [ u"be",u"Ouffet",2477,50.433333,5.466667 ],
    [ u"be",u"Oupeye",23594,50.7,5.65 ],
    [ u"be",u"Overijse",23486,50.766667,4.533333 ],
    [ u"be",u"Overpelt",13344,51.216667,5.416667 ],
    [ u"be",u"Paliseul",5037,49.9,5.133333 ],
    [ u"be",u"Pecq",5302,50.683333,3.333333 ],
    [ u"be",u"Peer",15551,51.133333,5.466667 ],
    [ u"be",u"Pepingen",4261,50.75,4.15 ],
    [ u"be",u"Pepinster",9530,50.566667,5.816667 ],
    [ u"be",u"Péruwelz",16647,50.516667,3.583333 ],
    [ u"be",u"Perwez",7340,50.616667,4.816667 ],
    [ u"be",u"Philippeville",8051,50.2,4.533333 ],
    [ u"be",u"Pittem",6589,51,3.266667 ],
    [ u"be",u"Plombières",9596,50.733333,5.95 ],
    [ u"be",u"Pont-à-Celles",15909,50.5,4.35 ],
    [ u"be",u"Poperinge",19537,50.85,2.716667 ],
    [ u"be",u"Profondeville",11401,50.383333,4.866667 ],
    [ u"be",u"Putte",15276,51.066667,4.633333 ],
    [ u"be",u"Puurs",15944,51.083333,4.283333 ],
    [ u"be",u"Quaregnon",18491,50.433333,3.85 ],
    [ u"be",u"Quiévrain",6560,50.4,3.683333 ],
    [ u"be",u"Raeren",9925,50.683333,6.116667 ],
    [ u"be",u"Ranst",17405,51.2,4.55 ],
    [ u"be",u"Ravels",13560,51.366667,5 ],
    [ u"be",u"Remicourt",5050,50.683333,5.333333 ],
    [ u"be",u"Rendeux",2320,50.233333,5.5 ],
    [ u"be",u"Retie",10069,51.266667,5.066667 ],
    [ u"be",u"Riemst",15809,50.8,5.6 ],
    [ u"be",u"Rijkevorsel",10606,51.35,4.766667 ],
    [ u"be",u"Rixensart",21616,50.716667,4.533333 ],
    [ u"be",u"Rochefort",11978,50.166667,5.216667 ],
    [ u"be",u"Roeselare",56016,50.95,3.133333 ],
    [ u"be",u"Ronse",24204,50.75,3.6 ],
    [ u"be",u"Rotselaar",15007,50.95,4.716667 ],
    [ u"be",u"Rouvroy",1946,49.533333,5.5 ],
    [ u"be",u"Ruiselede",5129,51.05,3.4 ],
    [ u"be",u"Rumes",4918,50.55,3.3 ],
    [ u"be",u"Rumst",14521,51.083333,4.416667 ],
    [ u"be",u"Sainte-Ode",2310,50.083333,5.533333 ],
    [ u"be",u"Saint-Ghislain",22500,50.45,3.816667 ],
    [ u"be",u"Saint-Hubert",5538,50.016667,5.383333 ],
    [ u"be",u"Saint-Léger",3092,49.616667,5.65 ],
    [ u"be",u"Saint-Nicolas",22586,50.633333,5.533333 ],
    [ u"be",u"Schelle",7675,51.133333,4.333333 ],
    [ u"be",u"Schilde",20373,51.233333,4.566667 ],
    [ u"be",u"Schoten",33622,51.25,4.5 ],
    [ u"be",u"Seneffe",11025,50.516667,4.25 ],
    [ u"be",u"Seraing",60737,50.6,5.483333 ],
    [ u"be",u"Silly",7887,50.65,3.916667 ],
    [ u"be",u"Sint-Amands",7653,51.05,4.2 ],
    [ u"be",u"Sint-Genesius-Rode",17990,50.75,4.35 ],
    [ u"be",u"Sint-Gillis-Waas",17658,51.216667,4.133333 ],
    [ u"be",u"Sint-Katelijne-Waver",19487,51.066667,4.533333 ],
    [ u"be",u"Sint-Laureins",6657,51.25,3.516667 ],
    [ u"be",u"Sint-Lievens-Houtem",9146,50.916667,3.85 ],
    [ u"be",u"Sint-Martens-Latem",8303,51.016667,3.633333 ],
    [ u"be",u"Sint-Niklaas",69010,51.166667,4.133333 ],
    [ u"be",u"Sint-Pieters-Leeuw",30446,50.783333,4.233333 ],
    [ u"be",u"Sint-Truiden",37859,50.8,5.2 ],
    [ u"be",u"Soignies",24869,50.583333,4.066667 ],
    [ u"be",u"Sombreffe",7452,50.516667,4.6 ],
    [ u"be",u"Somme-Leuze",4532,50.333333,5.366667 ],
    [ u"be",u"Soumagne",15237,50.616667,5.75 ],
    [ u"be",u"Spa",10756,50.5,5.866667 ],
    [ u"be",u"Sprimont",12945,50.5,5.666667 ],
    [ u"be",u"Stabroek",17294,51.333333,4.366667 ],
    [ u"be",u"Staden",10786,50.983333,3.016667 ],
    [ u"be",u"Stavelot",6646,50.383333,5.933333 ],
    [ u"be",u"Steenokkerzeel",10566,50.916667,4.516667 ],
    [ u"be",u"Stekene",16989,51.2,4.033333 ],
    [ u"be",u"Stoumont",2970,50.416667,5.8 ],
    [ u"be",u"Tellin",2353,50.083333,5.216667 ],
    [ u"be",u"Temse",26054,51.133333,4.216667 ],
    [ u"be",u"Tenneville",2510,50.1,5.533333 ],
    [ u"be",u"Ternat",14569,50.866667,4.183333 ],
    [ u"be",u"Tervuren",20623,50.816667,4.516667 ],
    [ u"be",u"Tessenderlo",16574,51.066667,5.083333 ],
    [ u"be",u"Theux",11587,50.533333,5.816667 ],
    [ u"be",u"Thuin",14682,50.333333,4.283333 ],
    [ u"be",u"Tielt",19299,51,3.316667 ],
    [ u"be",u"Tienen",31743,50.8,4.95 ],
    [ u"be",u"Tinlot",2236,50.483333,5.366667 ],
    [ u"be",u"Tintigny",3538,49.683333,5.516667 ],
    [ u"be",u"Tongeren",29816,50.783333,5.466667 ],
    [ u"be",u"Torhout",18933,51.066667,3.1 ],
    [ u"be",u"Tournai",67720,50.6,3.383333 ],
    [ u"be",u"Tremelo",13721,50.983333,4.7 ],
    [ u"be",u"Trooz",7559,50.566667,5.683333 ],
    [ u"be",u"Tubize",21859,50.683333,4.2 ],
    [ u"be",u"Turnhout",39654,51.316667,4.95 ],
    [ u"be",u"Vaux-sur-Sûre",4581,49.916667,5.583333 ],
    [ u"be",u"Verlaine",3600,50.6,5.316667 ],
    [ u"be",u"Verviers",52824,50.583333,5.866667 ],
    [ u"be",u"Veurne",11983,51.066667,2.666667 ],
    [ u"be",u"Vielsalm",7291,50.284722,5.918611 ],
    [ u"be",u"Villers-la-Ville",9592,50.583333,4.533333 ],
    [ u"be",u"Villers-le-Bouillet",6059,50.583333,5.266667 ],
    [ u"be",u"Vilvoorde",36955,50.933333,4.433333 ],
    [ u"be",u"Virton",11259,49.566667,5.533333 ],
    [ u"be",u"Visé",17054,50.733333,5.7 ],
    [ u"be",u"Vorselaar",7238,51.2,4.766667 ],
    [ u"be",u"Vosselaar",10317,51.316667,4.883333 ],
    [ u"be",u"Waarschoot",7762,51.15,3.6 ],
    [ u"be",u"Waasmunster",10460,51.1,4.083333 ],
    [ u"be",u"Wachtebeke",6911,51.166667,3.866667 ],
    [ u"be",u"Waimes",6661,50.416667,6.116667 ],
    [ u"be",u"Walcourt",17501,50.25,4.416667 ],
    [ u"be",u"Walhain",5992,50.616667,4.7 ],
    [ u"be",u"Wanze",12918,50.533333,5.216667 ],
    [ u"be",u"Waregem",35896,50.883333,3.416667 ],
    [ u"be",u"Waremme",13737,50.683333,5.25 ],
    [ u"be",u"Wasseiges",2471,50.616667,5 ],
    [ u"be",u"Waterloo",28910,50.716667,4.383333 ],
    [ u"be",u"Wavre",32112,50.716667,4.616667 ],
    [ u"be",u"Welkenraedt",9006,50.65,5.966667 ],
    [ u"be",u"Wellen",6804,50.85,5.316667 ],
    [ u"be",u"Wellin",2937,50.083333,5.116667 ],
    [ u"be",u"Wemmel",14406,50.916667,4.3 ],
    [ u"be",u"Wervik",17340,50.783333,3.033333 ],
    [ u"be",u"Westerlo",22579,51.083333,4.916667 ],
    [ u"be",u"Wetteren",22930,51,3.883333 ],
    [ u"be",u"Wevelgem",30954,50.8,3.166667 ],
    [ u"be",u"Wezembeek-Oppem",13245,50.85,4.483333 ],
    [ u"be",u"Wichelen",11014,51,3.983333 ],
    [ u"be",u"Wielsbeke",8828,50.9,3.366667 ],
    [ u"be",u"Wijnegem",8932,51.233333,4.533333 ],
    [ u"be",u"Willebroek",22808,51.066667,4.366667 ],
    [ u"be",u"Wingene",12887,51.066667,3.266667 ],
    [ u"be",u"Wommelgem",11917,51.2,4.516667 ],
    [ u"be",u"Wuustwezel",18117,51.383333,4.6 ],
    [ u"be",u"Yvoir",8169,50.333333,4.883333 ],
    [ u"be",u"Zandhoven",12306,51.216667,4.65 ],
    [ u"be",u"Zaventem",28188,50.883333,4.466667 ],
    [ u"be",u"Zedelgem",21968,51.15,3.133333 ],
    [ u"be",u"Zele",20236,51.066667,4.033333 ],
    [ u"be",u"Zelzate",11901,51.2,3.816667 ],
    [ u"be",u"Zemst",21096,50.983333,4.466667 ],
    [ u"be",u"Zingem",6588,50.9,3.65 ],
    [ u"be",u"Zoersel",20642,51.266667,4.7 ],
    [ u"be",u"Zomergem",8158,51.116667,3.55 ],
    [ u"be",u"Zonhoven",19922,50.983333,5.35 ],
    [ u"be",u"Zonnebeke",11581,50.866667,2.983333 ],
    [ u"be",u"Zottegem",24434,50.866667,3.8 ],
    [ u"be",u"Zoutleeuw",7897,50.833333,5.1 ],
    [ u"be",u"Zuienkerke",2736,51.266667,3.166667 ],
    [ u"be",u"Zulte",14670,50.916667,3.433333 ],
    [ u"be",u"Zutendaal",6962,50.933333,5.566667 ],
    [ u"be",u"Zwevegem",23358,50.8,3.333333 ],
    [ u"be",u"Zwijndrecht",18249,51.216667,4.333333 ],
    [ u"bf",u"Banfora",63883,10.6333333,-4.7666667 ],
    [ u"bf",u"Batié",6525,9.8833333,-2.9166667 ],
    [ u"bf",u"Bobo Dioulasso",370809,11.2,-4.3 ],
    [ u"bf",u"Bogandé",9916,12.9713889,-0.1436111 ],
    [ u"bf",u"Boromo",13240,11.75,-2.9333333 ],
    [ u"bf",u"Boulsa",17623,12.6675,-0.5758333 ],
    [ u"bf",u"Boussé",11093,13.1,-3.3833333 ],
    [ u"bf",u"Dano",11224,11.15,-3.0666667 ],
    [ u"bf",u"Dédougou",47235,12.4666667,-3.4666667 ],
    [ u"bf",u"Diapaga",24302,12.0708333,1.7888889 ],
    [ u"bf",u"Diébougou",12814,10.9666667,-3.25 ],
    [ u"bf",u"Djibo",22821,14.1022222,-1.6305556 ],
    [ u"bf",u"Dori",27554,14.0333333,-0.0333333 ],
    [ u"bf",u"Gaoua",7300,10.2991667,-3.2508333 ],
    [ u"bf",u"Garango",29076,11.8,-0.5505556 ],
    [ u"bf",u"Gayéri",2004,12.6497222,0.4930556 ],
    [ u"bf",u"Gorom-Gorom",6743,14.4438889,-0.2361111 ],
    [ u"bf",u"Goulouré",6719,12.2305556,-1.9288889 ],
    [ u"bf",u"Gourcy",17982,13.2166667,-2.35 ],
    [ u"bf",u"Houndé",23617,11.5,-3.5166667 ],
    [ u"bf",u"Kaya",39130,13.0916667,-1.0844444 ],
    [ u"bf",u"Kokologo",25958,12.1897222,-1.8855556 ],
    [ u"bf",u"Kombissiri",19180,12.0655556,-1.3375 ],
    [ u"bf",u"Kongoussi",26338,13.3258333,-1.5347222 ],
    [ u"bf",u"Koudougou",86965,12.25,-2.3666667 ],
    [ u"bf",u"Koupéla",19850,12.1794444,-0.3516667 ],
    [ u"bf",u"Léo",21151,11.1,-2.1 ],
    [ u"bf",u"Manga",15269,11.6636111,-1.0730556 ],
    [ u"bf",u"Nouna",21144,12.7333333,-3.8666667 ],
    [ u"bf",u"Orodara",18635,10.9491667,-4.9341667 ],
    [ u"bf",u"Ouagadougou",1031330,12.3702778,-1.5247222 ],
    [ u"bf",u"Ouahigouya",61439,13.5833333,-2.4166667 ],
    [ u"bf",u"Ouargaye",30726,11.5033333,0.0572222 ],
    [ u"bf",u"Pitmoaga",8041,12.2397222,-1.8766667 ],
    [ u"bf",u"Pô",21003,11.1697222,-1.145 ],
    [ u"bf",u"Réo",24616,12.3166667,-2.4666667 ],
    [ u"bf",u"Sapouy",3862,11.5544444,-1.7736111 ],
    [ u"bf",u"Sindou",3942,10.6666667,-5.1666667 ],
    [ u"bf",u"Solenzo",10451,12.1833333,-4.0833333 ],
    [ u"bf",u"Tenkodogo",37123,11.78,-0.3697222 ],
    [ u"bf",u"Toma",9926,12.65,-4.4166667 ],
    [ u"bf",u"Tougan",17702,13.0666667,-3.0666667 ],
    [ u"bf",u"Yako",23080,12.9666667,-2.2666667 ],
    [ u"bf",u"Ziniaré",12783,12.5822222,-1.2983333 ],
    [ u"bf",u"Zorgo",19789,12.2488889,-0.6158333 ],
    [ u"bg",u"Ahtopol",857,42.1,27.95 ],
    [ u"bg",u"Ajtos",21177,42.7,27.25 ],
    [ u"bg",u"Alfatar",1941,43.95,27.2833333 ],
    [ u"bg",u"Antonovo",1950,43.15,26.1666667 ],
    [ u"bg",u"Ardino",3497,41.5833333,25.1333333 ],
    [ u"bg",u"Asenovgrad",50735,42.0166667,24.8666667 ],
    [ u"bg",u"Balgarovo",2344,42.6166667,27.3 ],
    [ u"bg",u"Bankja",8104,42.7,23.1333333 ],
    [ u"bg",u"Bansko",8412,41.8394444,23.5 ],
    [ u"bg",u"Batak",4103,41.95,24.2166667 ],
    [ u"bg",u"Batanovci",2532,42.5997222,22.9505556 ],
    [ u"bg",u"Belene",10401,43.65,25.1166667 ],
    [ u"bg",u"Belica",3334,41.9569444,23.5725 ],
    [ u"bg",u"Belogradcik",4865,43.6272222,22.6836111 ],
    [ u"bg",u"Beloslav",7817,43.1833333,27.7 ],
    [ u"bg",u"Belovo",4533,42.2166667,24.0166667 ],
    [ u"bg",u"Berkovica",13574,43.2361111,23.1258333 ],
    [ u"bg",u"Bjala",1753,43.45,25.7333333 ],
    [ u"bg",u"Bjala",10284,42.8833333,27.8833333 ],
    [ u"bg",u"Blagoevgrad",69547,42.0166667,23.1 ],
    [ u"bg",u"Bobosevo",1528,42.1597222,23.0163889 ],
    [ u"bg",u"Bobovdol",7222,42.3697222,23.0172222 ],
    [ u"bg",u"Boljarovo",1474,42.15,26.8166667 ],
    [ u"bg",u"Borovo",2520,43.5,25.8 ],
    [ u"bg",u"Botevgrad",20497,42.9,23.7833333 ],
    [ u"bg",u"Bracigovo",4600,42.0166667,24.3666667 ],
    [ u"bg",u"Bregovo",2629,44.1516667,22.6425 ],
    [ u"bg",u"Breznik",4150,42.7413889,22.8980556 ],
    [ u"bg",u"Brezovo",1920,42.35,25.0833333 ],
    [ u"bg",u"Buhovo",3069,42.7666667,23.5666667 ],
    [ u"bg",u"Burgas",188554,42.5,27.4666667 ],
    [ u"bg",u"Carevo",5023,42.1666667,27.85 ],
    [ u"bg",u"Cepelare",5342,41.7333333,24.6833333 ],
    [ u"bg",u"Cirpan",17622,42.2,25.3333333 ],
    [ u"bg",u"Dalgopol",4911,43.05,27.35 ],
    [ u"bg",u"Debelec",4396,43.0333333,25.6166667 ],
    [ u"bg",u"Devin",6766,41.7333333,24.4 ],
    [ u"bg",u"Dimitrovgrad",42827,42.05,25.6 ],
    [ u"bg",u"Dimovo",1145,43.7416667,22.7269444 ],
    [ u"bg",u"Dobric",92309,43.5666667,27.8333333 ],
    [ u"bg",u"Dolna Banja",4471,42.3,23.7666667 ],
    [ u"bg",u"Dolna Mitropolija",3746,43.4666667,24.5333333 ],
    [ u"bg",u"Dolni Dabnik",5561,43.4,24.4333333 ],
    [ u"bg",u"Dospat",2391,41.65,24.1666667 ],
    [ u"bg",u"Dragoman",3196,42.9188889,22.9316667 ],
    [ u"bg",u"Drjanovo",8017,42.9827778,25.4922222 ],
    [ u"bg",u"Dulovo",6463,43.8166667,27.15 ],
    [ u"bg",u"Dupnica",38656,42.2666667,23.1166667 ],
    [ u"bg",u"Dve Mogili",4561,43.6,25.8666667 ],
    [ u"bg",u"Elena",6171,42.9333333,25.8833333 ],
    [ u"bg",u"Elhovo",11723,42.1666667,26.5666667 ],
    [ u"bg",u"Elin Pelin",4699,42.6666667,23.6 ],
    [ u"bg",u"Etropole",11024,42.8333333,24.0 ],
    [ u"bg",u"Gabrovo",61109,42.8747222,25.3341667 ],
    [ u"bg",u"Galabovo",9080,42.1333333,25.85 ],
    [ u"bg",u"Godec",4551,43.015,23.0441667 ],
    [ u"bg",u"Gramada",1812,43.8344444,22.6586111 ],
    [ u"bg",u"Guljanci",4135,43.6333333,24.7 ],
    [ u"bg",u"Gurkovo",2933,42.6666667,25.7333333 ],
    [ u"bg",u"Gurkovo",2933,42.6666667,25.8 ],
    [ u"bg",u"Harmanli",20065,41.9333333,25.9 ],
    [ u"bg",u"Haskovo",78865,41.9402778,25.5694444 ],
    [ u"bg",u"Ihtiman",11554,42.4333333,23.8166667 ],
    [ u"bg",u"Iskar",4109,43.3833333,27.4833333 ],
    [ u"bg",u"Isperih",8276,43.7166667,26.8333333 ],
    [ u"bg",u"Ivajlovgrad",4451,41.5333333,26.1333333 ],
    [ u"bg",u"Jablanica",2662,43.0313889,24.1127778 ],
    [ u"bg",u"Jakoruda",5931,42.0252778,23.6841667 ],
    [ u"bg",u"Jambol",75290,42.4833333,26.5 ],
    [ u"bg",u"Kalofer",3736,42.6166667,24.9833333 ],
    [ u"bg",u"Kameno",5133,42.5666667,27.3 ],
    [ u"bg",u"Kaolinovo",1489,43.6166667,27.1166667 ],
    [ u"bg",u"Karlovo",24464,42.6333333,24.8 ],
    [ u"bg",u"Karnobat",19902,42.65,26.9833333 ],
    [ u"bg",u"Kaspican",3211,43.3,27.1833333 ],
    [ u"bg",u"Kavarna",10626,43.4333333,28.3333333 ],
    [ u"bg",u"Kazanlak",50336,42.6166667,25.4 ],
    [ u"bg",u"Kermen",2172,42.5,26.25 ],
    [ u"bg",u"Kilifarevo",2484,42.9833333,25.6333333 ],
    [ u"bg",u"Kjustendil",47315,42.2838889,22.6911111 ],
    [ u"bg",u"Klisura",1708,42.7,24.45 ],
    [ u"bg",u"Kneza",9201,43.5,24.0833333 ],
    [ u"bg",u"Kocerinovo",2431,42.0833333,23.0666667 ],
    [ u"bg",u"Kojnare",3678,43.35,24.1333333 ],
    [ u"bg",u"Koprivstica",2618,42.6333333,24.35 ],
    [ u"bg",u"Kostenec",9660,42.2666667,23.8166667 ],
    [ u"bg",u"Kostinbrod",11239,42.8166667,23.2166667 ],
    [ u"bg",u"Kotel",7117,42.8833333,26.45 ],
    [ u"bg",u"Kozloduj",10602,43.7833333,23.7333333 ],
    [ u"bg",u"Kresna",3756,41.7333333,23.15 ],
    [ u"bg",u"Kresna",3756,41.8,23.1833333 ],
    [ u"bg",u"Kricim",8478,42.05,24.4666667 ],
    [ u"bg",u"Krivodol",2646,43.3744444,23.4844444 ],
    [ u"bg",u"Krumovgrad",4478,41.4666667,25.65 ],
    [ u"bg",u"Kubrat",7327,43.8,26.5 ],
    [ u"bg",u"Kula",3393,43.8877778,22.5213889 ],
    [ u"bg",u"Laki",2720,41.85,24.8166667 ],
    [ u"bg",u"Letnica",3980,43.3116667,25.0733333 ],
    [ u"bg",u"Levski",13203,43.3666667,25.1333333 ],
    [ u"bg",u"Ljaskovec",9000,43.1111111,25.7283333 ],
    [ u"bg",u"Ljubimec",7623,41.8333333,26.0833333 ],
    [ u"bg",u"Lom",24906,43.8138889,23.2361111 ],
    [ u"bg",u"Lovec",39788,43.1333333,24.7166667 ],
    [ u"bg",u"Loznica",2512,43.9666667,27.9166667 ],
    [ u"bg",u"Lukovit",9020,43.2,24.1666667 ],
    [ u"bg",u"Madan",7179,41.5,24.95 ],
    [ u"bg",u"Magliz",3465,42.6,25.55 ],
    [ u"bg",u"Malko Tarnovo",2920,41.9833333,27.5333333 ],
    [ u"bg",u"Melnik",251,41.5166667,23.4 ],
    [ u"bg",u"Mericleri",2233,42.1333333,25.5 ],
    [ u"bg",u"Mezdra",8667,43.15,23.7 ],
    [ u"bg",u"Momcilgrad",6974,41.5333333,25.4166667 ],
    [ u"bg",u"Montana",44982,43.4125,23.225 ],
    [ u"bg",u"Nedelino",4676,41.45,25.0833333 ],
    [ u"bg",u"Nesebar",5864,42.65,27.7333333 ],
    [ u"bg",u"Nikolaevo",2834,43.3166667,25.9833333 ],
    [ u"bg",u"Nikopol",4884,43.7,24.9 ],
    [ u"bg",u"Nova Zagora",24034,42.4833333,26.0166667 ],
    [ u"bg",u"Novi Iskar",13194,42.8,23.35 ],
    [ u"bg",u"Novi Pazar",13017,43.35,27.2 ],
    [ u"bg",u"Obzor",1864,42.8166667,27.8833333 ],
    [ u"bg",u"Omurtag",8858,43.1,26.4166667 ],
    [ u"bg",u"Opaka",3353,43.45,26.1666667 ],
    [ u"bg",u"Orjahovo",4464,43.7333333,23.9666667 ],
    [ u"bg",u"Panagjuriste",18755,42.5,24.1833333 ],
    [ u"bg",u"Pavlikeni",12129,43.2427778,25.3219444 ],
    [ u"bg",u"Pazardzik",76254,42.2,24.3333333 ],
    [ u"bg",u"Pernik",82185,42.6,23.0333333 ],
    [ u"bg",u"Perustica",5248,42.05,24.55 ],
    [ u"bg",u"Pestera",19161,42.0333333,24.3 ],
    [ u"bg",u"Petric",29956,41.4,23.2166667 ],
    [ u"bg",u"Pirdop",7923,42.7,24.1833333 ],
    [ u"bg",u"Plackovci",2098,42.8166667,25.4666667 ],
    [ u"bg",u"Pleven",132542,43.4166667,24.6166667 ],
    [ u"bg",u"Pliska",1115,43.3666667,27.1166667 ],
    [ u"bg",u"Plovdiv",332088,42.15,24.75 ],
    [ u"bg",u"Pomorie",12941,42.55,27.65 ],
    [ u"bg",u"Popovo",18836,43.35,26.2333333 ],
    [ u"bg",u"Pordim",2711,43.3833333,24.85 ],
    [ u"bg",u"Pravec",5071,42.8833333,23.9166667 ],
    [ u"bg",u"Primorsko",1807,42.2666667,27.7666667 ],
    [ u"bg",u"Provadija",14253,43.1833333,27.4333333 ],
    [ u"bg",u"Radnevo",13157,42.3,25.9333333 ],
    [ u"bg",u"Radomir",14971,42.5444444,22.9577778 ],
    [ u"bg",u"Rakitovo",8029,41.9833333,24.0833333 ],
    [ u"bg",u"Rakovski",16009,42.3,24.9666667 ],
    [ u"bg",u"Razgrad",31791,43.5333333,26.5166667 ],
    [ u"bg",u"Razlog",12347,41.8902778,23.4791667 ],
    [ u"bg",u"Rila",2936,42.1333333,23.1333333 ],
    [ u"bg",u"Roman",2329,43.15,23.9166667 ],
    [ u"bg",u"Rudozem",4041,41.4833333,24.85 ],
    [ u"bg",u"Ruse",157519,43.8563889,25.9708333 ],
    [ u"bg",u"Sabla",3603,43.5333333,28.5333333 ],
    [ u"bg",u"Sadovo",2461,42.1333333,24.9333333 ],
    [ u"bg",u"Saedinenie",6363,42.2666667,24.55 ],
    [ u"bg",u"Samokov",26582,42.3333333,23.55 ],
    [ u"bg",u"Sandanski",26282,41.5666667,23.2833333 ],
    [ u"bg",u"Senovo",1481,43.65,26.3666667 ],
    [ u"bg",u"Septemvri",8741,42.2166667,24.1 ],
    [ u"bg",u"Sevlievo",23574,43.0258333,25.1136111 ],
    [ u"bg",u"Silistra",38166,44.1166667,27.2666667 ],
    [ u"bg",u"Simeonovgrad",7509,42.0333333,25.8333333 ],
    [ u"bg",u"Simitli",7275,41.8833333,23.1166667 ],
    [ u"bg",u"Sipka",1520,42.7166667,25.3333333 ],
    [ u"bg",u"Slavjanovo",5160,43.4666667,24.8666667 ],
    [ u"bg",u"Sliven",94252,42.6858333,26.3291667 ],
    [ u"bg",u"Smoljan",31870,41.5852778,24.6919444 ],
    [ u"bg",u"Sofia",1062065,42.6833333,23.3166667 ],
    [ u"bg",u"Sopot",10141,43.0166667,24.4166667 ],
    [ u"bg",u"Sozopol",3548,42.4166667,27.7 ],
    [ u"bg",u"Sredec",9362,42.3488889,27.1941667 ],
    [ u"bg",u"Stara Zagora",137760,42.4327778,25.6419444 ],
    [ u"bg",u"Straldza",5865,42.6,26.6833333 ],
    [ u"bg",u"Strazica",5006,43.2333333,25.9666667 ],
    [ u"bg",u"Strelca",4699,42.5,24.3166667 ],
    [ u"bg",u"Suhindol",2407,43.1916667,25.1811111 ],
    [ u"bg",u"Sumen",85394,43.2766667,26.9291667 ],
    [ u"bg",u"Sungurlare",3441,42.7666667,26.7833333 ],
    [ u"bg",u"Suvorovo",4514,43.3333333,27.6 ],
    [ u"bg",u"Svilengrad",17378,41.7666667,26.2 ],
    [ u"bg",u"Svistov",29762,43.6230556,25.3538889 ],
    [ u"bg",u"Svoge",7093,42.9666667,23.35 ],
    [ u"bg",u"Tervel",7019,43.75,27.4 ],
    [ u"bg",u"Teteven",10697,42.9166667,24.2666667 ],
    [ u"bg",u"Topolovgrad",5824,42.0833333,26.3333333 ],
    [ u"bg",u"Tran",2608,42.8352778,22.6516667 ],
    [ u"bg",u"Trastenik",5627,43.5166667,24.4666667 ],
    [ u"bg",u"Trjavna",10180,42.8666667,25.5 ],
    [ u"bg",u"Trojan",22431,42.8833333,24.7166667 ],
    [ u"bg",u"Tutrakan",9472,44.05,26.6166667 ],
    [ u"bg",u"Tvardica",6434,42.7,25.9 ],
    [ u"bg",u"Ugarcin",2896,43.1,24.4166667 ],
    [ u"bg",u"Varna",307952,43.2166667,27.9166667 ],
    [ u"bg",u"Veliki Preslav",8669,43.1666667,26.8166667 ],
    [ u"bg",u"Velingrad",24129,42.0166667,24.0 ],
    [ u"bg",u"Vetovo",4835,43.7,26.2666667 ],
    [ u"bg",u"Vidin",50315,43.99,22.8725 ],
    [ u"bg",u"Vraca",48995,43.21,23.5625 ],
    [ u"bg",u"Zavet",2979,43.7666667,26.6666667 ],
    [ u"bg",u"Zemen",2145,42.4788889,22.7491667 ],
    [ u"bg",u"Zlatarica",2847,43.05,25.9 ],
    [ u"bg",u"Zlatica",4881,42.7166667,24.1333333 ],
    [ u"bg",u"Zlatograd",7673,41.3833333,25.1 ],
    [ u"bh",u"Manama",147097,26.2361111,50.5830556 ],
    [ u"bh",u"Sitrah",37690,26.1547222,50.6205556 ],
    [ u"bi",u"Bubanza",12728,-3.0833333,29.3944444 ],
    [ u"bi",u"Bujumbura",330539,-3.3761111,29.36 ],
    [ u"bi",u"Bururi",19740,-3.9511111,29.6166667 ],
    [ u"bi",u"Cankuzo",6585,-3.2194444,30.5527778 ],
    [ u"bi",u"Cibitoke",14220,-2.8861111,29.1236111 ],
    [ u"bi",u"Gitega",23168,-3.425,29.9333333 ],
    [ u"bi",u"Karuzi",10705,-3.1013889,30.1647222 ],
    [ u"bi",u"Kayanza",19443,-2.9222222,29.6222222 ],
    [ u"bi",u"Kirundo",6084,-2.5847222,30.0972222 ],
    [ u"bi",u"Makamba",19642,-4.1347222,29.805 ],
    [ u"bi",u"Muramvya",18039,-3.2680556,29.6166667 ],
    [ u"bi",u"Muyinga",71095,-2.8494444,30.3361111 ],
    [ u"bi",u"Mwaro",4924,-3.5263889,29.7027778 ],
    [ u"bi",u"Ngozi",21506,-2.9083333,29.8277778 ],
    [ u"bi",u"Rumonge",6074,-3.9722222,29.4388889 ],
    [ u"bi",u"Rutana",20894,-3.9191667,29.9936111 ],
    [ u"bi",u"Ruyigi",38459,-3.4763889,30.2486111 ],
    [ u"bj",u"Abomey",82158,7.1833333,1.9833333 ],
    [ u"bj",u"Abomey-Calavi",385823,6.45,2.35 ],
    [ u"bj",u"Allada",20094,6.65,2.15 ],
    [ u"bj",u"Aplahoué",19862,6.9333333,1.6833333 ],
    [ u"bj",u"Athiémé",13585,6.5833333,1.6666667 ],
    [ u"bj",u"Banikoara",22487,11.3,2.4333333 ],
    [ u"bj",u"Bassila",23616,9.0166667,1.6666667 ],
    [ u"bj",u"Bembèrèkè",24006,10.2288889,2.6652778 ],
    [ u"bj",u"Bétérou",13108,9.2,2.2666667 ],
    [ u"bj",u"Bohicon",125116,7.2,2.0666667 ],
    [ u"bj",u"Comé",29208,6.4,1.8833333 ],
    [ u"bj",u"Cotonou",690584,6.35,2.4333333 ],
    [ u"bj",u"Cové",38566,7.2333333,2.3 ],
    [ u"bj",u"Djougou",202834,9.705,1.6669444 ],
    [ u"bj",u"Dogbo",41312,6.8166667,1.7833333 ],
    [ u"bj",u"Kandi",109705,11.1341667,2.9386111 ],
    [ u"bj",u"Kétou",22341,7.3666667,2.6 ],
    [ u"bj",u"Lokossa",86987,6.6333333,1.7166667 ],
    [ u"bj",u"Malanville",37117,11.8613889,3.3858333 ],
    [ u"bj",u"Natitingou",80896,10.3066667,1.375 ],
    [ u"bj",u"Nikki",54009,9.9338889,3.2044444 ],
    [ u"bj",u"Ouidah",83506,6.3666667,2.0833333 ],
    [ u"bj",u"Parakou",163759,9.35,2.6166667 ],
    [ u"bj",u"Pobé",32983,6.9666667,2.6833333 ],
    [ u"bj",u"Sakété",30111,6.7166667,2.6666667 ],
    [ u"bj",u"Savalou",30187,7.9333333,1.9666667 ],
    [ u"bj",u"Savé",75973,8.0333333,2.4833333 ],
    [ u"bj",u"Tchaourou",20971,8.8833333,2.6 ],
    [ u"bm",u"Hamilton",902,32.2941667,-64.7838889 ],
    [ u"bm",u"Saint George",1802,32.3816667,-64.6780556 ],
    [ u"bo",u"Abapó",2419,-18.8333333,-63.4666667 ],
    [ u"bo",u"Achacachi",8447,-16.05,-68.6833333 ],
    [ u"bo",u"Aiquile",8225,-18.1666667,-65.1666667 ],
    [ u"bo",u"Arani",3906,-17.5666667,-65.7666667 ],
    [ u"bo",u"Ascensión",14431,-15.7,-63.0833333 ],
    [ u"bo",u"Atocha",1833,-20.9333333,-66.2333333 ],
    [ u"bo",u"Bermejo",28287,-22.65,-64.3666667 ],
    [ u"bo",u"Betanzos",4847,-19.5505556,-65.4533333 ],
    [ u"bo",u"Boyuibe",3075,-20.4166667,-63.2833333 ],
    [ u"bo",u"Buena Vista",4283,-17.45,-63.6666667 ],
    [ u"bo",u"Camargo",4715,-20.65,-65.2166667 ],
    [ u"bo",u"Camiri",27971,-20.05,-63.5166667 ],
    [ u"bo",u"Capinota",5157,-17.7166667,-66.2333333 ],
    [ u"bo",u"Caracollo",4708,-17.65,-67.1666667 ],
    [ u"bo",u"Caranavi",14915,-15.8166667,-67.55 ],
    [ u"bo",u"Challapata",8016,-18.9,-66.7666667 ],
    [ u"bo",u"Charagua",3026,-19.8,-63.2166667 ],
    [ u"bo",u"Chimoré",5147,-16.9833333,-65.1333333 ],
    [ u"bo",u"Chulumani",2953,-16.4,-67.5166667 ],
    [ u"bo",u"Cliza",8655,-17.6,-65.9333333 ],
    [ u"bo",u"Cobija",26583,-11.0333333,-68.7333333 ],
    [ u"bo",u"Cochabamba",900440,-17.3833333,-66.15 ],
    [ u"bo",u"Colomi",3923,-17.35,-65.8666667 ],
    [ u"bo",u"Colquechaca",1706,-18.6666667,-66.0166667 ],
    [ u"bo",u"Colquiri",3934,-17.4166667,-67.1333333 ],
    [ u"bo",u"Comarapa",4446,-17.9,-64.4833333 ],
    [ u"bo",u"Concepción",6901,-16.4333333,-60.9 ],
    [ u"bo",u"Copacabana",4508,-16.15,-69.0833333 ],
    [ u"bo",u"Coripata",2107,-16.3,-67.6 ],
    [ u"bo",u"Coroico",2361,-16.1833333,-67.7333333 ],
    [ u"bo",u"Cotoca",18349,-17.75,-62.9833333 ],
    [ u"bo",u"El Carmen",14297,-17.85,-63.2166667 ],
    [ u"bo",u"El Torno",15544,-17.9833333,-63.3833333 ],
    [ u"bo",u"Entre Ríos",2685,-21.5333333,-64.2 ],
    [ u"bo",u"Eucaliptus",2373,-17.5833333,-67.5166667 ],
    [ u"bo",u"Guanay",3915,-15.4833333,-67.8833333 ],
    [ u"bo",u"Guayaramerín",36010,-10.8,-65.3833333 ],
    [ u"bo",u"Huanuni",15492,-18.2666667,-66.85 ],
    [ u"bo",u"Irpa Irpa",2968,-17.7166667,-66.2666667 ],
    [ u"bo",u"Jorochito",4013,-18.05,-63.4333333 ],
    [ u"bo",u"La Bélgica",5504,-17.55,-63.2166667 ],
    [ u"bo",u"La Guardia",10259,-17.9,-63.3333333 ],
    [ u"bo",u"Lahuachaca",3235,-17.3666667,-67.6666667 ],
    [ u"bo",u"La Paz",812819,-16.5,-68.15 ],
    [ u"bo",u"Limoncito",3622,-18.0166667,-63.4 ],
    [ u"bo",u"Llallagua",28070,-18.4166667,-66.6333333 ],
    [ u"bo",u"Los Negros",3046,-17.7333333,-63.4333333 ],
    [ u"bo",u"Machacamarca",2045,-18.1666667,-67.0333333 ],
    [ u"bo",u"Mairana",4298,-18.1166667,-63.9333333 ],
    [ u"bo",u"Mapiri",2598,-15.25,-68.1666667 ],
    [ u"bo",u"Mineros",14386,-17.1166667,-63.2333333 ],
    [ u"bo",u"Mizque",2911,-17.9333333,-65.3166667 ],
    [ u"bo",u"Monteagudo",8290,-19.8166667,-63.9833333 ],
    [ u"bo",u"Montero",88623,-17.3333333,-63.25 ],
    [ u"bo",u"Oruro",208687,-17.9833333,-67.15 ],
    [ u"bo",u"Padilla",2920,-19.3,-64.3 ],
    [ u"bo",u"Pailón",9304,-17.65,-62.75 ],
    [ u"bo",u"Patacamaya",12261,-17.2333333,-67.9166667 ],
    [ u"bo",u"Poopó",1720,-18.3666667,-66.9666667 ],
    [ u"bo",u"Portachuelo",11486,-17.35,-63.4 ],
    [ u"bo",u"Potosí",141254,-19.5836111,-65.7530556 ],
    [ u"bo",u"Puerto Pailas",2675,-17.65,-62.8 ],
    [ u"bo",u"Puerto Quijarro",10393,-17.7833333,-57.7666667 ],
    [ u"bo",u"Puerto Suárez",12254,-18.95,-57.8 ],
    [ u"bo",u"Punata",15195,-17.55,-65.8333333 ],
    [ u"bo",u"Quime",2405,-16.9833333,-67.2166667 ],
    [ u"bo",u"Reyes",7376,-14.3166667,-67.3833333 ],
    [ u"bo",u"Riberalta",74018,-10.9833333,-66.1 ],
    [ u"bo",u"Roboré",9883,-18.3333333,-59.75 ],
    [ u"bo",u"Rurrenabaque",11750,-14.4666667,-67.5666667 ],
    [ u"bo",u"Samaipata",3250,-18.15,-63.8666667 ],
    [ u"bo",u"San Borja",19641,-14.8166667,-66.85 ],
    [ u"bo",u"San Carlos",4180,-17.4,-63.75 ],
    [ u"bo",u"San Ignacio",23570,-16.3666667,-60.95 ],
    [ u"bo",u"San Javier",7025,-16.3333333,-62.6333333 ],
    [ u"bo",u"San Joaquín",3557,-18.45,-59.55 ],
    [ u"bo",u"San José",9749,-17.85,-60.75 ],
    [ u"bo",u"San Julian",7706,-17.7833333,-62.8666667 ],
    [ u"bo",u"San Lorenzo",2921,-21.4333333,-64.7833333 ],
    [ u"bo",u"San Matías",6352,-16.3666667,-58.4 ],
    [ u"bo",u"San Miguel",4906,-16.7,-61.0166667 ],
    [ u"bo",u"San Pedro",2990,-18.2833333,-59.8166667 ],
    [ u"bo",u"San Rafael",2384,-16.75,-60.5666667 ],
    [ u"bo",u"San Ramón",4390,-13.2833333,-64.7166667 ],
    [ u"bo",u"San Ramón",6422,-14.4833333,-63.15 ],
    [ u"bo",u"Santa Bárbara",2434,-20.9166667,-66.05 ],
    [ u"bo",u"Santa Rita",2444,-17.9666667,-63.35 ],
    [ u"bo",u"Santa Rosa",4459,-14.1666667,-66.8833333 ],
    [ u"bo",u"Santa Rosa",4575,-16.7833333,-61.8 ],
    [ u"bo",u"Sipe Sipe",3777,-17.45,-66.3833333 ],
    [ u"bo",u"Sorata",2190,-15.7666667,-68.6333333 ],
    [ u"bo",u"Sucre",224846,-19.0430556,-65.2591667 ],
    [ u"bo",u"Tarabuco",2428,-19.1666667,-64.9166667 ],
    [ u"bo",u"Tarata",8045,-17.6166667,-66.0166667 ],
    [ u"bo",u"Tarija",159275,-21.5166667,-64.75 ],
    [ u"bo",u"Tipuani",2585,-15.55,-68.0 ],
    [ u"bo",u"Totoral",1645,-18.5166667,-66.8666667 ],
    [ u"bo",u"Trinidad",84264,-14.8333333,-64.9 ],
    [ u"bo",u"Tupiza",22234,-21.45,-65.7166667 ],
    [ u"bo",u"Uncia",5142,-18.45,-66.6166667 ],
    [ u"bo",u"Urubichá",3269,-15.3833333,-62.95 ],
    [ u"bo",u"Uyuni",10294,-20.4666667,-66.8333333 ],
    [ u"bo",u"Villamontes",18762,-21.25,-63.5 ],
    [ u"bo",u"Villazón",30254,-22.1,-65.6 ],
    [ u"bo",u"Viloco",1900,-16.95,-67.55 ],
    [ u"bo",u"Warnes",22038,-17.5,-63.1666667 ],
    [ u"bo",u"Yacuiba",82808,-22.0333333,-63.6833333 ],
    [ u"br",u"Abadiânia",7062,-16.1,-48.8 ],
    [ u"br",u"Abaeté",20371,-19.15,-45.45 ],
    [ u"br",u"Abaetetuba",78052,-1.7,-48.9 ],
    [ u"br",u"Abreu e Lima",81960,-7.9,-34.883333 ],
    [ u"br",u"Acajutiba",14349,-11.666667,-38.016667 ],
    [ u"br",u"Acará",12803,-1.95,-48.183333 ],
    [ u"br",u"Acaraú",28389,-2.883333,-40.116667 ],
    [ u"br",u"Acari",9159,-6.516667,-36.633333 ],
    [ u"br",u"Acopiara",24562,-6.1,-39.45 ],
    [ u"br",u"Açu",36126,-5.577222,-36.9075 ],
    [ u"br",u"Açucena",14506,-19.066667,-42.533333 ],
    [ u"br",u"Adamantina",31079,-21.683333,-51.066667 ],
    [ u"br",u"Afogados da Ingàzeira",25060,-7.75,-37.65 ],
    [ u"br",u"Afonso Bezerra",6947,-5.498056,-36.509167 ],
    [ u"br",u"Afonso Cláudio",13543,-20.083333,-41.133333 ],
    [ u"br",u"Afuá",7031,-.166667,-50.383333 ],
    [ u"br",u"Agrestina",14453,-8.45,-35.95 ],
    [ u"br",u"Água Branca",5161,-9.283333,-37.916667 ],
    [ u"br",u"Água Branca",13912,-5.883333,-42.633333 ],
    [ u"br",u"Aguaí",27503,-22.066667,-46.966667 ],
    [ u"br",u"Água Preta",16444,-8.7,-35.516667 ],
    [ u"br",u"Águas Belas",22563,-9.116667,-37.116667 ],
    [ u"br",u"Águas de Lindóia",18806,-22.483333,-46.65 ],
    [ u"br",u"Águas Formosas",11512,-17.083333,-40.95 ],
    [ u"br",u"Águas Vermelhas",16410,-15.75,-41.466667 ],
    [ u"br",u"Agudos",30808,-22.466667,-49 ],
    [ u"br",u"Águia Branca",2554,-18.983333,-40.733333 ],
    [ u"br",u"Aimorés",19133,-19.5,-41.066667 ],
    [ u"br",u"Alagoa Grande",16406,-7.05,-35.633333 ],
    [ u"br",u"Alagoa Nova",9182,-7.066667,-35.766667 ],
    [ u"br",u"Alagoinha",7474,-6.933333,-35.55 ],
    [ u"br",u"Alagoinhas",122692,-12.116667,-38.433333 ],
    [ u"br",u"Alcântara",5655,-2.4,-44.4 ],
    [ u"br",u"Alegre",19758,-20.766667,-41.533333 ],
    [ u"br",u"Alegrete",77540,-29.766667,-55.766667 ],
    [ u"br",u"Além Paraíba",33907,-21.866667,-42.683333 ],
    [ u"br",u"Alenquer",26291,-1.933333,-54.766667 ],
    [ u"br",u"Alexandria",9769,-6.416667,-38.016667 ],
    [ u"br",u"Alfenas",71407,-21.433333,-45.95 ],
    [ u"br",u"Alfredo Chaves",6422,-20.633333,-40.75 ],
    [ u"br",u"Alhandra",10788,-7.433333,-34.9 ],
    [ u"br",u"Aliança",17329,-7.583333,-35.216667 ],
    [ u"br",u"Almeirim",20464,-1.533333,-52.566667 ],
    [ u"br",u"Almenara",29333,-16.183333,-40.7 ],
    [ u"br",u"Almirante Tamandaré",89500,-25.3,-49.316667 ],
    [ u"br",u"Alpinópolis",13286,-20.866667,-46.383333 ],
    [ u"br",u"Alta Floresta",40468,-9.9,-55.9 ],
    [ u"br",u"Altamira",70890,-3.2,-52.2 ],
    [ u"br",u"Alterosa",9277,-21.25,-46.133333 ],
    [ u"br",u"Altinho",11913,-8.483333,-36.066667 ],
    [ u"br",u"Altinópolis",14616,-21.025278,-47.374444 ],
    [ u"br",u"Alto Araguaia",8780,-17.316667,-53.2 ],
    [ u"br",u"Alto Longá",4435,-5.25,-42.2 ],
    [ u"br",u"Altônia",11242,-23.933333,-53.9 ],
    [ u"br",u"Alto Paraguai",6149,-14.5,-56.516667 ],
    [ u"br",u"Alto Paraná",10888,-23.083333,-52.366667 ],
    [ u"br",u"Alto Piquiri",10039,-24.016667,-53.466667 ],
    [ u"br",u"Altos",28769,-5.05,-42.466667 ],
    [ u"br",u"Alvarães",5527,-3.2,-64.833333 ],
    [ u"br",u"Álvares Machado",21642,-22.133333,-51.5 ],
    [ u"br",u"Alvinópolis",12068,-20.1,-43.05 ],
    [ u"br",u"Alvorada",10232,-12.47,-49.082222 ],
    [ u"br",u"Amambaí",20261,-23.083333,-55.216667 ],
    [ u"br",u"Amapá",6256,2.05,-50.8 ],
    [ u"br",u"Amaraji",16660,-8.4,-35.45 ],
    [ u"br",u"Amarante",8828,-6.233333,-42.833333 ],
    [ u"br",u"Amarante do Maranhão",11510,-5.6,-46.75 ],
    [ u"br",u"Amargosa",22531,-13.033333,-39.6 ],
    [ u"br",u"América Dourada",14018,-11.466667,-41.433333 ],
    [ u"br",u"Americana",196026,-22.740278,-47.334444 ],
    [ u"br",u"Américo Brasiliense",34332,-21.716667,-48.116667 ],
    [ u"br",u"Amontada",13520,-3.383333,-39.833333 ],
    [ u"br",u"Amparo",41498,-22.7,-46.783333 ],
    [ u"br",u"Ampère",14275,-25.916667,-53.466667 ],
    [ u"br",u"Anadia",9574,-9.7,-36.3 ],
    [ u"br",u"Anagé",3762,-14.6,-41.133333 ],
    [ u"br",u"Anajatuba",5627,-3.266667,-44.616667 ],
    [ u"br",u"Ananás",8874,-6.360278,-47.91 ],
    [ u"br",u"Ananindeua",433956,-1.366667,-48.383333 ],
    [ u"br",u"Anápolis",319592,-16.333333,-48.966667 ],
    [ u"br",u"Anastácio",18817,-20.516667,-55.8 ],
    [ u"br",u"Andirá",20758,-23.0488,-50.2276 ],
    [ u"br",u"Andradas",26773,-22.066667,-46.566667 ],
    [ u"br",u"Andradina",52407,-20.9,-51.383333 ],
    [ u"br",u"Andrelândia",10079,-21.733333,-44.3 ],
    [ u"br",u"Angatuba",14476,-23.483333,-48.416667 ],
    [ u"br",u"Angicos",7729,-5.666389,-36.600833 ],
    [ u"br",u"Angra dos Reis",153637,-23,-44.3 ],
    [ u"br",u"Anicuns",15685,-16.466667,-49.966667 ],
    [ u"br",u"Anori",8064,-3.783333,-61.633333 ],
    [ u"br",u"Antonina",16152,-25.4314,-48.7184 ],
    [ u"br",u"Aparecida",34237,-22.8418,-45.2287 ],
    [ u"br",u"Aparecida do Taboado",17332,-20.083333,-51.083333 ],
    [ u"br",u"Apiaí",18260,-24.511926,-48.844671 ],
    [ u"br",u"Apodi",16757,-5.65,-37.8 ],
    [ u"br",u"Apucarana",107086,-23.55,-51.483333 ],
    [ u"br",u"Aquidabã",10596,-10.283333,-37.033333 ],
    [ u"br",u"Aquidauana",35304,-20.466667,-55.8 ],
    [ u"br",u"Aquiraz",65117,-3.9,-38.366667 ],
    [ u"br",u"Aracaju",490184,-10.916667,-37.066667 ],
    [ u"br",u"Aracati",44294,-4.566667,-37.766667 ],
    [ u"br",u"Araçatuba",170028,-21.2,-50.416667 ],
    [ u"br",u"Araci",15089,-11.333333,-38.95 ],
    [ u"br",u"Aracoiaba",13425,-4.383333,-38.816667 ],
    [ u"br",u"Araçoiaba",13095,-7.8,-35.05 ],
    [ u"br",u"Araçoiaba da Serra",15395,-23.5049,-47.6185 ],
    [ u"br",u"Aracruz",58272,-19.816667,-40.266667 ],
    [ u"br",u"Araçuaí",22005,-16.866667,-42.066667 ],
    [ u"br",u"Aragarças",16781,-15.916667,-52.25 ],
    [ u"br",u"Araguaçu",7603,-12.894167,-49.773056 ],
    [ u"br",u"Araguaína",114959,-7.16,-48.0575 ],
    [ u"br",u"Araguari",96567,-18.633333,-48.183333 ],
    [ u"br",u"Araguatins",17106,-5.600278,-47.933056 ],
    [ u"br",u"Araioses",8667,-2.89,-41.903611 ],
    [ u"br",u"Arapiraca",166566,-9.75,-36.65 ],
    [ u"br",u"Arapongas",97513,-23.383333,-51.45 ],
    [ u"br",u"Araquari",35691,-26.3692,-48.7221 ],
    [ u"br",u"Arara",7641,-6.833333,-35.75 ],
    [ u"br",u"Araranguá",43445,-28.933333,-49.483333 ],
    [ u"br",u"Araraquara",185191,-21.783333,-48.166667 ],
    [ u"br",u"Araras",107465,-22.366667,-47.383333 ],
    [ u"br",u"Arari",16777,-3.466667,-44.783333 ],
    [ u"br",u"Araripe",11860,-7.2,-40.133333 ],
    [ u"br",u"Araripina",38570,-7.55,-40.566667 ],
    [ u"br",u"Araruama",109638,-22.883333,-42.333333 ],
    [ u"br",u"Araruna",7667,-6.533333,-35.733333 ],
    [ u"br",u"Arauá",4747,-11.266667,-37.616667 ],
    [ u"br",u"Araucária",111303,-25.583333,-49.416667 ],
    [ u"br",u"Araxá",82597,-19.583333,-46.916667 ],
    [ u"br",u"Arcos",33356,-20.283333,-45.533333 ],
    [ u"br",u"Arcoverde",57164,-8.416667,-36.916667 ],
    [ u"br",u"Areado",10689,-21.35,-46.15 ],
    [ u"br",u"Areal",11041,-22.228889,-43.106944 ],
    [ u"br",u"Areia",13825,-6.966667,-35.7 ],
    [ u"br",u"Areia Branca",18372,-4.953889,-37.132222 ],
    [ u"br",u"Areia Branca",7414,-10.766667,-37.316667 ],
    [ u"br",u"Arenápolis",9060,-14.433333,-56.816667 ],
    [ u"br",u"Arês",7231,-6.183333,-35.15 ],
    [ u"br",u"Arinos",10078,-15.916667,-46.066667 ],
    [ u"br",u"Aripuanã",27043,-9.166667,-60.633333 ],
    [ u"br",u"Ariquemes",58102,-9.933333,-63.066667 ],
    [ u"br",u"Armação dos Búzios",23463,-22.75,-41.883333 ],
    [ u"br",u"Aroeiras",7019,-7.516667,-35.683333 ],
    [ u"br",u"Arraial do Cabo",26164,-22.966667,-42.016667 ],
    [ u"br",u"Arraias",6881,-12.977222,-46.891667 ],
    [ u"br",u"Arroio do Meio",16331,-29.4,-51.95 ],
    [ u"br",u"Arroio dos Ratos",13405,-30.083333,-51.716667 ],
    [ u"br",u"Arroio Grande",16117,-32.233333,-53.083333 ],
    [ u"br",u"Artur Nogueira",40404,-22.583333,-47.15 ],
    [ u"br",u"Arujá",72078,-23.4,-46.333333 ],
    [ u"br",u"Assaí",12545,-23.366667,-50.816667 ],
    [ u"br",u"Assaré",11369,-6.866667,-39.866667 ],
    [ u"br",u"Assis",87473,-22.666667,-50.416667 ],
    [ u"br",u"Astolfo Dutra",10999,-21.316667,-42.866667 ],
    [ u"br",u"Astorga",20129,-23.216667,-51.666667 ],
    [ u"br",u"Atalaia",18908,-9.516667,-36.033333 ],
    [ u"br",u"Atibaia",110970,-23.124167,-46.562222 ],
    [ u"br",u"Augusto Correa",16280,-1.033333,-46.666667 ],
    [ u"br",u"Auriflama",11971,-20.683333,-50.566667 ],
    [ u"br",u"Aurora",10757,-6.95,-38.966667 ],
    [ u"br",u"Autazes",9614,-3.583333,-59.133333 ],
    [ u"br",u"Avaré",81287,-23.083333,-48.916667 ],
    [ u"br",u"Axixá do Tocantins",9007,-5.551111,-47.595556 ],
    [ u"br",u"Bacabal",72374,-4.233333,-44.783333 ],
    [ u"br",u"Bady Bassitt",14216,-20.933333,-49.466667 ],
    [ u"br",u"Baependi",12853,-21.95,-44.883333 ],
    [ u"br",u"Bagé",98943,-31.333333,-54.1 ],
    [ u"br",u"Baião",12316,-2.683333,-49.683333 ],
    [ u"br",u"Baixa Grande",7534,-11.95,-40.183333 ],
    [ u"br",u"Baixo Guandu",19292,-19.516667,-41.016667 ],
    [ u"br",u"Balsas",68058,-7.516667,-46.033333 ],
    [ u"br",u"Bambuí",18840,-20.016667,-45.966667 ],
    [ u"br",u"Bananeiras",7371,-6.75,-35.616667 ],
    [ u"br",u"Bandeirantes",29495,-23.1,-50.35 ],
    [ u"br",u"Barão de Cocais",22387,-19.933333,-43.466667 ],
    [ u"br",u"Barão de Melgaço",4353,-16.216667,-55.966667 ],
    [ u"br",u"Baraúna",14113,-5.083333,-37.616667 ],
    [ u"br",u"Barbacena",122213,-21.233333,-43.766667 ],
    [ u"br",u"Barbalha",33944,-7.316667,-39.283333 ],
    [ u"br",u"Barbosa Ferraz",9048,-24.066667,-52.05 ],
    [ u"br",u"Barcarena",29872,-1.5,-48.666667 ],
    [ u"br",u"Barcelos",7356,-1,-62.966667 ],
    [ u"br",u"Bariri",28802,-22.066667,-48.733333 ],
    [ u"br",u"Barra",20895,-11.083333,-43.166667 ],
    [ u"br",u"Barra Bonita",37247,-22.483333,-48.533333 ],
    [ u"br",u"Barra da Estiva",12618,-13.633333,-41.316667 ],
    [ u"br",u"Barra de São Francisco",20743,-18.75,-40.866667 ],
    [ u"br",u"Barra do Bugres",31313,-15.083333,-57.183333 ],
    [ u"br",u"Barra do Corda",48902,-5.5,-45.25 ],
    [ u"br",u"Barra do Garças",52402,-15.883333,-52.25 ],
    [ u"br",u"Barra do Piraí",87669,-22.466111,-43.827778 ],
    [ u"br",u"Barra dos Coqueiros",28590,-10.9,-37.05 ],
    [ u"br",u"Barra Mansa",164054,-22.533333,-44.183333 ],
    [ u"br",u"Barras",21597,-4.25,-42.3 ],
    [ u"br",u"Barra Velha",17665,-26.6406,-48.6851 ],
    [ u"br",u"Barreiras",158296,-12.133333,-45 ],
    [ u"br",u"Barreirinha",11257,-2.793611,-57.068889 ],
    [ u"br",u"Barreirinhas",17437,-2.75,-42.833333 ],
    [ u"br",u"Barreiros",35565,-8.816667,-35.2 ],
    [ u"br",u"Barretos",101222,-20.55,-48.55 ],
    [ u"br",u"Barrinha",26981,-21.2,-48.15 ],
    [ u"br",u"Barro",11519,-6.716667,-38.866667 ],
    [ u"br",u"Barroquinha",12410,-2.983333,-41.083333 ],
    [ u"br",u"Barroso",16975,-21.183333,-43.966667 ],
    [ u"br",u"Barueri",251999,-23.516667,-46.883333 ],
    [ u"br",u"Bastos",17681,-21.933333,-50.716667 ],
    [ u"br",u"Bataiporã",7346,-22.333333,-53.283333 ],
    [ u"br",u"Batalha",11820,-9.683333,-37.133333 ],
    [ u"br",u"Batalha",8744,-4.016667,-42.083333 ],
    [ u"br",u"Batatais",51977,-20.883333,-47.616667 ],
    [ u"br",u"Baturité",22417,-4.333333,-38.883333 ],
    [ u"br",u"Bauru",335031,-22.316667,-49.066667 ],
    [ u"br",u"Bayeux",91058,-7.133333,-34.933333 ],
    [ u"br",u"Bebedouro",71863,-20.933333,-48.466667 ],
    [ u"br",u"Beberibe",37028,-4.183333,-38.133333 ],
    [ u"br",u"Bela Cruz",12715,-3.05,-40.183333 ],
    [ u"br",u"Bela Vista",18127,-22.1,-56.516667 ],
    [ u"br",u"Bela Vista de Goiás",14289,-16.966667,-48.95 ],
    [ u"br",u"Bela Vista do Paraíso",14332,-23,-51.2 ],
    [ u"br",u"Belém",1407737,-1.45,-48.483333 ],
    [ u"br",u"Belém",15550,-6.716667,-35.5 ],
    [ u"br",u"Belém de São Francisco",11124,-8.766667,-38.966667 ],
    [ u"br",u"Belford Roxo",466101,-22.761995,-43.404654 ],
    [ u"br",u"Belmonte",9806,-15.85,-38.9 ],
    [ u"br",u"Belo Horizonte",2373255,-19.916667,-43.933333 ],
    [ u"br",u"Belo Jardim",49923,-8.333333,-36.433333 ],
    [ u"br",u"Belo Oriente",18471,-19.233333,-42.466667 ],
    [ u"br",u"Beneditinos",5005,-5.45,-42.366667 ],
    [ u"br",u"Benevides",49813,-1.366667,-48.25 ],
    [ u"br",u"Benjamin Constant",13998,-4.374444,-70.029722 ],
    [ u"br",u"Bento Gonçalves",90854,-29.166667,-51.516667 ],
    [ u"br",u"Bequimão",5695,-2.433333,-44.783333 ],
    [ u"br",u"Bernardino de Campos",9342,-23.033333,-49.483333 ],
    [ u"br",u"Betim",384038,-19.966667,-44.216667 ],
    [ u"br",u"Bezerros",51437,-8.233333,-35.75 ],
    [ u"br",u"Bicas",12684,-21.716667,-43.066667 ],
    [ u"br",u"Biguaçu",51993,-27.5,-48.666667 ],
    [ u"br",u"Birigui",102279,-21.3,-50.316667 ],
    [ u"br",u"Biritiba-Mirim",26459,-23.583333,-46.033333 ],
    [ u"br",u"Blumenau",293955,-26.9222,-49.0615 ],
    [ u"br",u"Boa Esperança",9254,-18.55,-40.283333 ],
    [ u"br",u"Boa Esperança",33840,-21.083333,-45.566667 ],
    [ u"br",u"Boa Esperança do Sul",10787,-21.983333,-48.383333 ],
    [ u"br",u"Boa Viagem",24671,-5.116667,-39.733333 ],
    [ u"br",u"Boa Vista",235159,2.816667,-60.666667 ],
    [ u"br",u"Bôca da Mata",17834,-9.6,-36.25 ],
    [ u"br",u"Bôca do Acre",14427,-8.75,-67.383333 ],
    [ u"br",u"Bocaiúva",32115,-17.116667,-43.816667 ],
    [ u"br",u"Bodocó",11329,-7.783333,-39.916667 ],
    [ u"br",u"Boituva",48756,-23.283333,-47.683333 ],
    [ u"br",u"Bom Conselho",27801,-9.166667,-36.683333 ],
    [ u"br",u"Bom Despacho",40304,-19.716667,-45.25 ],
    [ u"br",u"Bom Jardim",12343,-7.016667,-46.483333 ],
    [ u"br",u"Bom Jardim",11716,-22.15,-42.416667 ],
    [ u"br",u"Bom Jardim",13523,-7.783333,-35.583333 ],
    [ u"br",u"Bom Jesus",12666,-9.066667,-44.366667 ],
    [ u"br",u"Bom Jesus da Lapa",40693,-13.25,-43.416667 ],
    [ u"br",u"Bom Jesus do Galho",12476,-19.833333,-42.316667 ],
    [ u"br",u"Bom Jesus do Itabapoana",30822,-21.133333,-41.683333 ],
    [ u"br",u"Bom Jesus dos Perdões",12422,-23.133333,-46.466667 ],
    [ u"br",u"Bom Sucesso",13786,-21.033333,-44.766667 ],
    [ u"br",u"Bonfim",5769,3.083333,-59.95 ],
    [ u"br",u"Bonito",14504,-21.133333,-56.466667 ],
    [ u"br",u"Bonito",8867,-8.483333,-35.733333 ],
    [ u"br",u"Boqueirão",11566,-7.483333,-36.116667 ],
    [ u"br",u"Boquim",14848,-11.15,-37.616667 ],
    [ u"br",u"Boquira",6306,-12.816667,-42.766667 ],
    [ u"br",u"Borba",11918,-4.388889,-59.593611 ],
    [ u"br",u"Borborema",11759,-21.616667,-49.066667 ],
    [ u"br",u"Borda da Mata",12814,-22.266667,-46.166667 ],
    [ u"br",u"Botelhos",11073,-21.65,-46.4 ],
    [ u"br",u"Botucatu",113865,-22.866667,-48.433333 ],
    [ u"br",u"Braço do Norte",22375,-28.283333,-49.183333 ],
    [ u"br",u"Bragança",57164,-1.05,-46.766667 ],
    [ u"br",u"Bragança Paulista",125099,-22.95,-46.566667 ],
    [ u"br",u"Brasiléia",11200,-11,-68.733333 ],
    [ u"br",u"Brasília",2207812,-15.783333,-47.916667 ],
    [ u"br",u"Brasília de Minas",14730,-16.211944,-44.430833 ],
    [ u"br",u"Brejinho",7625,-6.183333,-35.35 ],
    [ u"br",u"Brejo",11636,-3.683333,-42.783333 ],
    [ u"br",u"Brejo da Madre de Deus",27370,-8.15,-36.366667 ],
    [ u"br",u"Brejo Santo",27384,-7.483333,-39 ],
    [ u"br",u"Breves",46474,-1.666667,-50.483333 ],
    [ u"br",u"Brodowski",18366,-20.983333,-47.666667 ],
    [ u"br",u"Brotas",18690,-22.283333,-48.116667 ],
    [ u"br",u"Brumadinho",27564,-20.133333,-44.216667 ],
    [ u"br",u"Brumado",41990,-14.216667,-41.666667 ],
    [ u"br",u"Brusque",88286,-27.1,-48.933333 ],
    [ u"br",u"Bueno Brandão",5777,-22.45,-46.35 ],
    [ u"br",u"Buerarema",16002,-14.95,-39.316667 ],
    [ u"br",u"Buíque",20324,-8.616667,-37.15 ],
    [ u"br",u"Bujaru",6189,-1.516667,-48.016667 ],
    [ u"br",u"Buri",15959,-23.8,-48.583333 ],
    [ u"br",u"Buritama",12712,-21.05,-50.133333 ],
    [ u"br",u"Buriti Alegre",9427,-18.15,-49.05 ],
    [ u"br",u"Buriti Bravo",17693,-5.833333,-43.833333 ],
    [ u"br",u"Buriti",7025,-3.916667,-42.95 ],
    [ u"br",u"Buriti dos Lopes",9475,-3.166667,-41.866667 ],
    [ u"br",u"Buritis",16243,-15.616667,-46.433333 ],
    [ u"br",u"Buritizeiro",25104,-17.35,-44.966667 ],
    [ u"br",u"Butiá",19494,-30.116667,-51.966667 ],
    [ u"br",u"Caaporã",13770,-7.516667,-34.9 ],
    [ u"br",u"Caarapó",13863,-22.633333,-54.8 ],
    [ u"br",u"Cabedelo",54841,-6.966667,-34.833333 ],
    [ u"br",u"Cabo Frio",108241,-22.883333,-42.016667 ],
    [ u"br",u"Cabreúva",38743,-23.3,-47.133333 ],
    [ u"br",u"Cabrobó",16096,-8.516667,-39.316667 ],
    [ u"br",u"Caçador",63727,-26.783333,-51 ],
    [ u"br",u"Caçapava",72341,-23.1,-45.716667 ],
    [ u"br",u"Caçapava do Sul",17522,-30.5,-53.5 ],
    [ u"br",u"Cacequi",12868,-29.883333,-54.816667 ],
    [ u"br",u"Cáceres",73431,-16.066667,-57.683333 ],
    [ u"br",u"Cachoeira",16145,-12.6,-38.966667 ],
    [ u"br",u"Cachoeira do Sul",74696,-30.033333,-52.9 ],
    [ u"br",u"Cachoeiras de Macacu",46178,-22.466667,-42.65 ],
    [ u"br",u"Cachoeirinha",121086,-29.95,-51.083333 ],
    [ u"br",u"Cachoeirinha",12905,-8.483333,-36.233333 ],
    [ u"br",u"Cachoeiro de Itapemirim",187023,-20.85,-41.1 ],
    [ u"br",u"Cacimba de Dentro",7447,-6.65,-35.783333 ],
    [ u"br",u"Cacimbinhas",4618,-9.4,-37 ],
    [ u"br",u"Cacoal",55566,-11.5,-61.416667 ],
    [ u"br",u"Caconde",12434,-21.55,-46.633333 ],
    [ u"br",u"Caçu",10098,-18.616667,-51.066667 ],
    [ u"br",u"Caculé",12143,-14.5,-42.216667 ],
    [ u"br",u"Caeté",33232,-19.9,-43.666667 ],
    [ u"br",u"Caetés",5386,-8.766667,-36.633333 ],
    [ u"br",u"Caetité",27188,-14.066667,-42.483333 ],
    [ u"br",u"Cafarnaum",12940,-11.7,-41.466667 ],
    [ u"br",u"Cafelândia",13777,-21.816667,-49.583333 ],
    [ u"br",u"Caiapônia",10947,-16.95,-51.816667 ],
    [ u"br",u"Caicó",54935,-6.45,-37.1 ],
    [ u"br",u"Caieiras",87199,-23.36193,-46.740681 ],
    [ u"br",u"Cajamar",56684,-23.35,-46.883333 ],
    [ u"br",u"Cajati",27566,-24.728502,-48.110541 ],
    [ u"br",u"Cajàzeiras",43914,-6.9,-38.566667 ],
    [ u"br",u"Cajueiro",15063,-9.716667,-36.45 ],
    [ u"br",u"Cajuru",19540,-21.283333,-47.3 ],
    [ u"br",u"Caldas Novas",63681,-17.75,-48.633333 ],
    [ u"br",u"Camaçari",188763,-12.483333,-38.216667 ],
    [ u"br",u"Camamu",13924,-13.95,-39.116667 ],
    [ u"br",u"Camanducaia",17823,-22.766667,-46.15 ],
    [ u"br",u"Camapuã",11119,-19.5,-54.083333 ],
    [ u"br",u"Camaquã",53170,-30.85,-51.816667 ],
    [ u"br",u"Camaragibe",148966,-8.016667,-34.966667 ],
    [ u"br",u"Cambará",21380,-23.0411,-50.0741 ],
    [ u"br",u"Cambé",91081,-23.233333,-51.25 ],
    [ u"br",u"Camboriú",49101,-26.983333,-48.633333 ],
    [ u"br",u"Cambuci",9395,-21.566667,-41.916667 ],
    [ u"br",u"Cambuí",21247,-22.616667,-46.066667 ],
    [ u"br",u"Cambuquira",10116,-21.85,-45.3 ],
    [ u"br",u"Cametá",45202,-2.25,-49.5 ],
    [ u"br",u"Camocim",44482,-2.89,-40.846111 ],
    [ u"br",u"Camocim de São Félix",10270,-8.35,-35.766667 ],
    [ u"br",u"Campanha",12507,-21.833333,-45.4 ],
    [ u"br",u"Campestre",11802,-21.716667,-46.25 ],
    [ u"br",u"Campina Grande",348943,-7.216667,-35.883333 ],
    [ u"br",u"Campina Grande do Sul",31112,-25.3,-49.083333 ],
    [ u"br",u"Campinas",1031573,-22.9,-47.083333 ],
    [ u"br",u"Campina Verde",13137,-19.516667,-49.466667 ],
    [ u"br",u"Campo Alegre",16786,-9.8,-36.35 ],
    [ u"br",u"Campo Bom",54762,-29.683333,-51.05 ],
    [ u"br",u"Campo do Brito",8011,-10.75,-37.5 ],
    [ u"br",u"Campo Formoso",23921,-10.516667,-40.333333 ],
    [ u"br",u"Campo Grande",3054,-10.233333,-36.5 ],
    [ u"br",u"Campo Grande",729164,-20.45,-54.616667 ],
    [ u"br",u"Campo Largo",94669,-25.433333,-49.533333 ],
    [ u"br",u"Campo Maior",31740,-4.816667,-42.166667 ],
    [ u"br",u"Campos Altos",12648,-19.683333,-46.166667 ],
    [ u"br",u"Campos Belos",15583,-13.05,-46.883333 ],
    [ u"br",u"Campos",387422,-21.75,-41.3 ],
    [ u"br",u"Campos do Jordão",53320,-22.7264,-45.5792 ],
    [ u"br",u"Campos Gerais",22260,-21.233333,-45.766667 ],
    [ u"br",u"Campos Novos",22563,-27.4,-51.2 ],
    [ u"br",u"Campos Sales",17648,-7.066667,-40.383333 ],
    [ u"br",u"Campo Verde",22842,-20.416667,-54.066667 ],
    [ u"br",u"Cananéia",13786,-25.016667,-47.95 ],
    [ u"br",u"Canapi",4219,-9.133333,-37.5 ],
    [ u"br",u"Canarana",10785,-11.683333,-41.766667 ],
    [ u"br",u"Canavieiras",26376,-15.65,-38.95 ],
    [ u"br",u"Candeias",75673,-12.666667,-38.55 ],
    [ u"br",u"Candelária",15200,-29.666667,-52.8 ],
    [ u"br",u"Cândido de Abreu",5102,-24.583333,-51.333333 ],
    [ u"br",u"Cândido Mendes",8613,-1.45,-45.716667 ],
    [ u"br",u"Cândido Mota",28145,-22.716667,-50.383333 ],
    [ u"br",u"Canela",33529,-29.366667,-50.833333 ],
    [ u"br",u"Canguaretama",18873,-6.383333,-35.133333 ],
    [ u"br",u"Canguçu",20134,-31.4,-52.683333 ],
    [ u"br",u"Canhotinho",12074,-8.883333,-36.2 ],
    [ u"br",u"Canindé",42721,-4.366667,-39.316667 ],
    [ u"br",u"Canindé de São Francisco",11053,-9.65,-37.8 ],
    [ u"br",u"Canoas",328297,-29.933333,-51.183333 ],
    [ u"br",u"Canoinhas",38863,-26.166667,-50.4 ],
    [ u"br",u"Cansanção",9905,-10.683333,-39.516667 ],
    [ u"br",u"Cantagalo",14019,-21.966667,-42.366667 ],
    [ u"br",u"Cantanhede",8344,-3.65,-44.4 ],
    [ u"br",u"Canto do Buriti",11715,-8.116667,-42.966667 ],
    [ u"br",u"Canutama",6320,-6.533333,-64.333333 ],
    [ u"br",u"Capanema",47768,-1.2,-47.183333 ],
    [ u"br",u"Capão Bonito",37207,-24.016667,-48.333333 ],
    [ u"br",u"Capão da Canoa",35896,-29.766667,-50.016667 ],
    [ u"br",u"Capela",12520,-9.416667,-36.066667 ],
    [ u"br",u"Capela",16024,-10.5,-37.066667 ],
    [ u"br",u"Capela do Alto",11991,-23.466667,-47.75 ],
    [ u"br",u"Capelinha",20074,-17.7,-42.516667 ],
    [ u"br",u"Capim Grosso",17322,-11.366667,-40.016667 ],
    [ u"br",u"Capinópolis",12486,-18.683333,-49.583333 ],
    [ u"br",u"Capinzal",23799,-27.333333,-51.6 ],
    [ u"br",u"Capitão Poço",32704,-1.75,-47.083333 ],
    [ u"br",u"Capivari",35519,-23.000722,-47.502026 ],
    [ u"br",u"Capoeiras",4861,-8.75,-36.633333 ],
    [ u"br",u"Caraguatatuba",90844,-23.616667,-45.416667 ],
    [ u"br",u"Caraí",6750,-17.2,-41.7 ],
    [ u"br",u"Carambeí",13466,-24.933333,-50.083333 ],
    [ u"br",u"Carandaí",16657,-20.933333,-43.916667 ],
    [ u"br",u"Carangola",25322,-20.733333,-42.033333 ],
    [ u"br",u"Carapicuíba",361120,-23.516667,-46.833333 ],
    [ u"br",u"Caratinga",60067,-19.783333,-42.133333 ],
    [ u"br",u"Carauari",18059,-4.879167,-66.898056 ],
    [ u"br",u"Caraúbas",12462,-5.53,-37.303056 ],
    [ u"br",u"Caravelas",11322,-17.75,-39.25 ],
    [ u"br",u"Caràzinho",59418,-28.3,-52.8 ],
    [ u"br",u"Cardoso",10556,-20.066667,-49.9 ],
    [ u"br",u"Careiro",6659,-3.2,-59.75 ],
    [ u"br",u"Careiro da Várzea",1092,-3.2,-59.75 ],
    [ u"br",u"Cariacica",330681,-20.266667,-40.416667 ],
    [ u"br",u"Carinhanha",11408,-14.3,-43.783333 ],
    [ u"br",u"Carira",10276,-10.35,-37.7 ],
    [ u"br",u"Cariré",5488,-3.95,-40.45 ],
    [ u"br",u"Caririaçu",12971,-7.033333,-39.283333 ],
    [ u"br",u"Carlos Barbosa",19106,-29.3,-51.5 ],
    [ u"br",u"Carlos Chagas",13206,-17.716667,-40.75 ],
    [ u"br",u"Carmo",11555,-21.933333,-42.616667 ],
    [ u"br",u"Carmo do Cajuru",16333,-20.183333,-44.766667 ],
    [ u"br",u"Carmo do Paranaíba",26537,-18.983333,-46.35 ],
    [ u"br",u"Carmo do Rio Claro",14446,-20.966667,-46.116667 ],
    [ u"br",u"Carmo do Rio Verde",6053,-15.35,-49.7 ],
    [ u"br",u"Carnaíba",6019,-8.7,-37.666667 ],
    [ u"br",u"Carolina",16229,-7.333333,-47.466667 ],
    [ u"br",u"Carpina",70690,-7.85,-35.25 ],
    [ u"br",u"Caruaru",235375,-8.283333,-35.966667 ],
    [ u"br",u"Carutapera",12819,-1.216667,-46.016667 ],
    [ u"br",u"Casa Branca",22498,-21.766667,-47.083333 ],
    [ u"br",u"Casa Nova",33319,-9.416667,-41.133333 ],
    [ u"br",u"Cascavel",52357,-4.116667,-38.233333 ],
    [ u"br",u"Cascavel",257174,-24.95,-53.466667 ],
    [ u"br",u"Casimiro de Abreu",19087,-22.483333,-42.2 ],
    [ u"br",u"Cássia",14391,-20.6,-46.933333 ],
    [ u"br",u"Cassilândia",18498,-19.15,-51.75 ],
    [ u"br",u"Castanhal",137410,-1.3,-47.916667 ],
    [ u"br",u"Castelo",20198,-20.6,-41.2 ],
    [ u"br",u"Castelo do Piauí",8589,-5.333333,-41.55 ],
    [ u"br",u"Castilho",11419,-20.866667,-51.483333 ],
    [ u"br",u"Castro Alves",13869,-12.75,-39.433333 ],
    [ u"br",u"Castro",42092,-24.783333,-50 ],
    [ u"br",u"Cataguases",62619,-21.4,-42.683333 ],
    [ u"br",u"Catalão",63545,-18.166667,-47.95 ],
    [ u"br",u"Catanduva",109615,-21.133333,-48.966667 ],
    [ u"br",u"Catende",23323,-8.666667,-35.716667 ],
    [ u"br",u"Catolé do Rocha",19812,-6.35,-37.75 ],
    [ u"br",u"Catu",39933,-12.35,-38.383333 ],
    [ u"br",u"Caucaia",275023,-3.7,-38.65 ],
    [ u"br",u"Cavalcante",3747,-13.8,-47.5 ],
    [ u"br",u"Caxambu",22701,-21.983333,-44.933333 ],
    [ u"br",u"Caxias",117393,-4.833333,-43.35 ],
    [ u"br",u"Caxias do Sul",381277,-29.1689,-51.1785 ],
    [ u"br",u"Ceará-Mirim",32668,-5.633333,-35.433333 ],
    [ u"br",u"Cedro",14644,-6.6,-39.05 ],
    [ u"br",u"Centenário do Sul",8358,-22.8,-51.616667 ],
    [ u"br",u"Centralina",9497,-18.566667,-49.216667 ],
    [ u"br",u"Ceres",18760,-15.283333,-49.583333 ],
    [ u"br",u"Cerqueira César",14261,-23.05,-49.166667 ],
    [ u"br",u"Cerquilho",35367,-23.201218,-47.757822 ],
    [ u"br",u"Cêrro Largo",9548,-28.15,-54.75 ],
    [ u"br",u"Chã Grande",17117,-8.233333,-35.45 ],
    [ u"br",u"Chapada dos Guimarães",13657,-15.433333,-55.75 ],
    [ u"br",u"Chapadinha",40805,-3.733333,-43.35 ],
    [ u"br",u"Chapecó",160160,-27.083333,-52.983333 ],
    [ u"br",u"Charqueada",12391,-22.5,-47.766667 ],
    [ u"br",u"Charqueadas",32076,-29.966667,-51.633333 ],
    [ u"br",u"Chavantes",10306,-23.033333,-49.716667 ],
    [ u"br",u"Chopinzinho",14142,-25.85,-52.5 ],
    [ u"br",u"Choròzinho",9755,-4.3,-38.483333 ],
    [ u"br",u"Cianorte",55995,-23.616667,-52.616667 ],
    [ u"br",u"Cícero Dantas",18317,-10.6,-38.383333 ],
    [ u"br",u"Cidreira",8965,-30.183333,-50.2 ],
    [ u"br",u"Cláudio",21825,-20.433333,-44.766667 ],
    [ u"br",u"Clevelândia",14701,-26.4,-52.35 ],
    [ u"br",u"Coaraci",32345,-14.633333,-39.533333 ],
    [ u"br",u"Coari",50491,-4.109444,-63.138889 ],
    [ u"br",u"Cocal",12097,-3.466667,-41.566667 ],
    [ u"br",u"Codajás",11185,-3.833333,-62.083333 ],
    [ u"br",u"Codó",83289,-4.483333,-43.883333 ],
    [ u"br",u"Coelho Neto",36185,-4.25,-43 ],
    [ u"br",u"Coité do Nóia",2529,-9.666667,-36.5 ],
    [ u"br",u"Colatina",101193,-19.533333,-40.616667 ],
    [ u"br",u"Colina",15042,-20.733333,-48.583333 ],
    [ u"br",u"Colinas",25159,-6.033333,-44.233333 ],
    [ u"br",u"Colombo",217002,-25.283333,-49.233333 ],
    [ u"br",u"Colônia Leopoldina",11914,-8.95,-35.65 ],
    [ u"br",u"Colorado",20449,-22.816667,-51.95 ],
    [ u"br",u"Conceição da Barra",19310,-18.583333,-39.75 ],
    [ u"br",u"Conceição da Feira",15838,-12.5,-39 ],
    [ u"br",u"Conceição das Alagoas",16152,-19.916667,-48.383333 ],
    [ u"br",u"Conceição do Almeida",9691,-12.8,-39.2 ],
    [ u"br",u"Conceição do Araguaia",27116,-8.241111,-49.296111 ],
    [ u"br",u"Conceição do Castelo",4538,-20.366667,-41.25 ],
    [ u"br",u"Conceição do Coité",35172,-11.55,-39.266667 ],
    [ u"br",u"Conceição do Mato Dentro",10708,-19.016667,-43.416667 ],
    [ u"br",u"Conceição do Rio Verde",12402,-21.883333,-45.083333 ],
    [ u"br",u"Conchal",21351,-22.333333,-47.166667 ],
    [ u"br",u"Conchas",14301,-23.016667,-48 ],
    [ u"br",u"Concórdia",55368,-27.233333,-52.016667 ],
    [ u"br",u"Condado",19585,-7.583333,-35.1 ],
    [ u"br",u"Conde",15565,-11.816667,-37.616667 ],
    [ u"br",u"Congonhas",48819,-20.5,-43.866667 ],
    [ u"br",u"Conselheiro Lafaiete",111598,-20.666667,-43.8 ],
    [ u"br",u"Conselheiro Pena",12735,-19.166667,-41.5 ],
    [ u"br",u"Contagem",627132,-19.916667,-44.1 ],
    [ u"br",u"Coração de Jesus",12410,-16.684444,-44.360278 ],
    [ u"br",u"Coração de Maria",6571,-12.233333,-38.75 ],
    [ u"br",u"Corbélia",12725,-24.8,-53.3 ],
    [ u"br",u"Cordeiro",15602,-22.033333,-42.366667 ],
    [ u"br",u"Cordeirópolis",25639,-22.483333,-47.466667 ],
    [ u"br",u"Coreaú",12383,-3.55,-40.65 ],
    [ u"br",u"Coremas",11897,-7.016667,-37.966667 ],
    [ u"br",u"Corinto",22121,-18.35,-44.45 ],
    [ u"br",u"Cornélio Procópio",45031,-23.133333,-50.65 ],
    [ u"br",u"Coroatá",34130,-4.133333,-44.133333 ],
    [ u"br",u"Coromandel",22648,-18.466667,-47.216667 ],
    [ u"br",u"Coronel Fabriciano",100918,-19.516667,-42.633333 ],
    [ u"br",u"Coronel Vivida",15841,-25.966667,-52.566667 ],
    [ u"br",u"Correia Pinto",13752,-27.583333,-50.4 ],
    [ u"br",u"Corrente",13967,-10.436111,-45.131111 ],
    [ u"br",u"Correntina",13187,-13.333333,-44.65 ],
    [ u"br",u"Corumbá",96523,-19.016667,-57.65 ],
    [ u"br",u"Coruripe",31428,-10.133333,-36.166667 ],
    [ u"br",u"Cosmópolis",47773,-22.633333,-47.2 ],
    [ u"br",u"Costa Rica",12931,-23.416667,-54.65 ],
    [ u"br",u"Cotia",174832,-23.616667,-46.933333 ],
    [ u"br",u"Coxim",30216,-18.5,-54.75 ],
    [ u"br",u"Crateús",52934,-5.166667,-40.666667 ],
    [ u"br",u"Crato",88788,-7.233333,-39.383333 ],
    [ u"br",u"Cravinhos",32690,-21.316667,-47.75 ],
    [ u"br",u"Criciúma",161957,-28.666667,-49.383333 ],
    [ u"br",u"Cristalina",36532,-16.75,-47.6 ],
    [ u"br",u"Cristinápolis",6430,-11.483333,-37.766667 ],
    [ u"br",u"Crixás",11560,-14.45,-49.966667 ],
    [ u"br",u"Cruz Alta",65276,-28.65,-53.6 ],
    [ u"br",u"Cruz",8723,-2.95,-40.183333 ],
    [ u"br",u"Cruz das Almas",47846,-12.666667,-39.1 ],
    [ u"br",u"Cruz do Espírito Santo",5812,-7.133333,-35.1 ],
    [ u"br",u"Cruzeiro",72023,-22.566667,-44.966667 ],
    [ u"br",u"Cruzeiro do Oeste",15058,-23.766667,-53.066667 ],
    [ u"br",u"Cruzeiro do Sul",45517,-7.633333,-72.6 ],
    [ u"br",u"Cruzília",12816,-21.833333,-44.8 ],
    [ u"br",u"Cubatão",118412,-23.883333,-46.416667 ],
    [ u"br",u"Cuiabá",521961,-15.583333,-56.083333 ],
    [ u"br",u"Cuité",11392,-6.483333,-36.15 ],
    [ u"br",u"Cumaru",6861,-8,-35.7 ],
    [ u"br",u"Cunha",11896,-23.083333,-44.966667 ],
    [ u"br",u"Cupira",19096,-8.616667,-35.95 ],
    [ u"br",u"Curaçá",11858,-8.983333,-39.9 ],
    [ u"br",u"Curitiba",1718433,-25.416667,-49.25 ],
    [ u"br",u"Curitibanos",32142,-27.3,-50.6 ],
    [ u"br",u"Currais Novos",35561,-6.25,-36.516667 ],
    [ u"br",u"Curuçá",10843,-.716667,-47.833333 ],
    [ u"br",u"Cururupu",22007,-1.833333,-44.866667 ],
    [ u"br",u"Curvelo",63955,-18.75,-44.416667 ],
    [ u"br",u"Custódia",18107,-8.116667,-37.65 ],
    [ u"br",u"Delmiro Gouveia",35260,-9.383333,-37.983333 ],
    [ u"br",u"Demerval Lobão",15285,-5.366667,-42.683333 ],
    [ u"br",u"Descalvado",26138,-21.9,-47.616667 ],
    [ u"br",u"Destêrro",5374,-7.283333,-37.1 ],
    [ u"br",u"Diadema",390641,-23.7,-46.616667 ],
    [ u"br",u"Diamantina",37344,-18.25,-43.6 ],
    [ u"br",u"Diamantino",15700,-14.416667,-56.45 ],
    [ u"br",u"Dianópolis",12896,-11.700556,-46.743056 ],
    [ u"br",u"Divinópolis",193835,-20.15,-44.9 ],
    [ u"br",u"Dois Córregos",20975,-22.366667,-48.35 ],
    [ u"br",u"Dois Irmãos",28926,-29.583333,-51.083333 ],
    [ u"br",u"Dois Riachos",4565,-9.383333,-37.083333 ],
    [ u"br",u"Dois Vizinhos",22766,-25.783333,-53.083333 ],
    [ u"br",u"Domingos Martins",6061,-20.366667,-40.666667 ],
    [ u"br",u"Dom Pedrito",36912,-30.983333,-54.666667 ],
    [ u"br",u"Dom Pedro",15570,-4.483333,-44.45 ],
    [ u"br",u"Dona Inês",3709,-6.616667,-35.633333 ],
    [ u"br",u"Dores do Indaiá",12859,-19.45,-45.6 ],
    [ u"br",u"Dourados",162206,-22.216667,-54.8 ],
    [ u"br",u"Dracena",37940,-21.533333,-51.483333 ],
    [ u"br",u"Duartina",11903,-22.4,-49.416667 ],
    [ u"br",u"Duque de Caxias",818339,-22.790321,-43.325009 ],
    [ u"br",u"Ecoporanga",13774,-18.383333,-40.833333 ],
    [ u"br",u"Edéia",9838,-17.3,-49.916667 ],
    [ u"br",u"Eirunepé",17175,-6.666667,-69.866667 ],
    [ u"br",u"Eldorado",9075,-23.783333,-54.316667 ],
    [ u"br",u"Elesbão Veloso",10430,-6.216667,-42.133333 ],
    [ u"br",u"Elias Fausto",12705,-23.033333,-47.383333 ],
    [ u"br",u"Elói Mendes",19413,-21.616667,-45.566667 ],
    [ u"br",u"Embu",221737,-23.65,-46.85 ],
    [ u"br",u"Embu-Guaçu",76311,-23.816667,-46.8 ],
    [ u"br",u"Encantado",16637,-29.25,-51.883333 ],
    [ u"br",u"Encruzilhada do Sul",17199,-30.533333,-52.516667 ],
    [ u"br",u"Encruzilhada",4711,-15.516667,-40.9 ],
    [ u"br",u"Engenheiro Beltrão",14955,-23.783333,-52.25 ],
    [ u"br",u"Entre Rios",27406,-11.933333,-38.083333 ],
    [ u"br",u"Envira",9957,-7.3,-70.216667 ],
    [ u"br",u"Erechim",96089,-27.633333,-52.283333 ],
    [ u"br",u"Escada",48084,-8.366667,-35.233333 ],
    [ u"br",u"Esmeraldas",103252,-19.75,-44.316667 ],
    [ u"br",u"Espera Feliz",13031,-20.65,-41.916667 ],
    [ u"br",u"Esperança",18817,-7.016667,-35.85 ],
    [ u"br",u"Esperantina",21044,-3.9,-42.233333 ],
    [ u"br",u"Esperantinópolis",13167,-4.883333,-44.883333 ],
    [ u"br",u"Espinosa",17549,-14.933333,-42.833333 ],
    [ u"br",u"Espirito Santo do Pinhal",37449,-22.2,-46.75 ],
    [ u"br",u"Esplanada",18859,-11.783333,-37.95 ],
    [ u"br",u"Espumoso",10340,-28.733333,-52.85 ],
    [ u"br",u"Estância",55655,-11.266667,-37.433333 ],
    [ u"br",u"Estância Velha",40391,-29.65,-51.183333 ],
    [ u"br",u"Esteio",84903,-29.85,-51.166667 ],
    [ u"br",u"Estreito",17647,-5.783333,-43.25 ],
    [ u"br",u"Estrêla",24200,-28.1,-50.983333 ],
    [ u"br",u"Euclides da Cunha",29739,-10.516667,-39.016667 ],
    [ u"br",u"Eusébio",37290,-3.9,-38.45 ],
    [ u"br",u"Extrema",13682,-22.85,-46.316667 ],
    [ u"br",u"Extremóz",17992,-5.7,-35.3 ],
    [ u"br",u"Exu",10875,-7.516667,-39.716667 ],
    [ u"br",u"Fagundes",5137,-7.35,-35.8 ],
    [ u"br",u"Farias Brito",11288,-6.916667,-39.566667 ],
    [ u"br",u"Farroupilha",57651,-29.233333,-51.35 ],
    [ u"br",u"Fartura",12405,-23.383333,-49.5 ],
    [ u"br",u"Faxinal",13464,-23.983333,-51.366667 ],
    [ u"br",u"Feijó",12951,-8.15,-70.35 ],
    [ u"br",u"Feira de Santana",481926,-12.25,-38.95 ],
    [ u"br",u"Feira Grande",3985,-9.85,-36.7 ],
    [ u"br",u"Feira Nova",12985,-7.933333,-35.35 ],
    [ u"br",u"Fernandópolis",61932,-20.266667,-50.233333 ],
    [ u"br",u"Ferraz de Vasconcelos",167904,-23.533333,-46.366667 ],
    [ u"br",u"Firminópolis",9084,-16.666667,-50.316667 ],
    [ u"br",u"Flexeiras",7783,-9.266667,-35.716667 ],
    [ u"br",u"Flores da Cunha",20522,-29.0287,-51.1822 ],
    [ u"br",u"Flores",11694,-7.85,-37.983333 ],
    [ u"br",u"Floresta",18100,-8.6,-38.566667 ],
    [ u"br",u"Florestópolis",13250,-22.866667,-51.4 ],
    [ u"br",u"Floriano",48588,-6.783333,-43.016667 ],
    [ u"br",u"Florianópolis",412731,-27.583333,-48.566667 ],
    [ u"br",u"Fonte Boa",16060,-2.533333,-66.016667 ],
    [ u"br",u"Formiga",56405,-20.45,-45.416667 ],
    [ u"br",u"Formosa do Rio Prêto",14365,-11.046389,-45.059722 ],
    [ u"br",u"Formosa",81233,-15.533333,-47.333333 ],
    [ u"br",u"Formoso do Araguaia",14963,-11.796667,-49.466944 ],
    [ u"br",u"Forquilhinha",23021,-28.75,-49.466667 ],
    [ u"br",u"Fortaleza",2416920,-3.316667,-41.416667 ],
    [ u"br",u"Fortuna",9755,-5.683333,-44.066667 ],
    [ u"br",u"Foz do Iguaçu",293526,-25.55,-54.583333 ],
    [ u"br",u"Franca",305047,-20.533333,-47.4 ],
    [ u"br",u"Francisco Beltrão",57618,-26.083333,-53.066667 ],
    [ u"br",u"Francisco Morato",171793,-23.279503,-46.746403 ],
    [ u"br",u"Francisco Sá",13997,-16.466667,-43.5 ],
    [ u"br",u"Franco da Rocha",108860,-23.324821,-46.718475 ],
    [ u"br",u"Frederico Westphalen",20896,-27.366667,-53.4 ],
    [ u"br",u"Frei Paulo",7047,-10.55,-37.533333 ],
    [ u"br",u"Frutal",40931,-20.033333,-48.916667 ],
    [ u"br",u"Fundão",12715,-19.916667,-40.4 ],
    [ u"br",u"Gameleira",19424,-8.583333,-35.4 ],
    [ u"br",u"Gandu",21566,-13.75,-39.5 ],
    [ u"br",u"Garanhuns",110087,-8.9,-36.483333 ],
    [ u"br",u"Gararu",2977,-9.966667,-37.083333 ],
    [ u"br",u"Garça",41303,-22.233333,-49.616667 ],
    [ u"br",u"Garibaldi",30364,-29.25,-51.533333 ],
    [ u"br",u"Gaspar",33659,-26.933333,-48.966667 ],
    [ u"br",u"General Salgado",8084,-20.65,-50.366667 ],
    [ u"br",u"Getúlio Vargas",13695,-27.833333,-52.266667 ],
    [ u"br",u"Gilbués",4920,-9.838889,-45.353889 ],
    [ u"br",u"Girau do Ponciano",9606,-9.916667,-36.833333 ],
    [ u"br",u"Giruá",12170,-28.033333,-54.35 ],
    [ u"br",u"Glória do Goitá",17374,-8.016667,-35.283333 ],
    [ u"br",u"Goiana",43981,-7.55,-34.983333 ],
    [ u"br",u"Goianápolis",10114,-16.5,-49.016667 ],
    [ u"br",u"Goianésia",47884,-15.3,-49.116667 ],
    [ u"br",u"Goiânia",1171209,-16.666667,-49.266667 ],
    [ u"br",u"Goianinha",13434,-6.266667,-35.2 ],
    [ u"br",u"Goianira",22823,-16.5,-49.433333 ],
    [ u"br",u"Goiás",19098,-15.933333,-50.133333 ],
    [ u"br",u"Goiatuba",25925,-18.016667,-49.366667 ],
    [ u"br",u"Governador Dix-Sept Rosado",6626,-5.466667,-37.516667 ],
    [ u"br",u"Governador Valadares",250882,-18.85,-41.933333 ],
    [ u"br",u"Grajaú",30218,-5.816667,-46.133333 ],
    [ u"br",u"Gramado",26365,-29.4,-50.9 ],
    [ u"br",u"Granja",25880,-3.1,-40.833333 ],
    [ u"br",u"Grão Mogol",3278,-16.566667,-42.9 ],
    [ u"br",u"Gravatá",61250,-8.2,-35.566667 ],
    [ u"br",u"Gravataí",238782,-29.9426,-50.9933 ],
    [ u"br",u"Guaçuí",19787,-20.766667,-41.683333 ],
    [ u"br",u"Guaíba",101026,-30.111111,-51.316667 ],
    [ u"br",u"Guaíra",27611,-24.066667,-54.25 ],
    [ u"br",u"Guaíra",34093,-20.316667,-48.3 ],
    [ u"br",u"Guaiuba",21822,-4.033333,-38.633333 ],
    [ u"br",u"Guajará",9776,-2.966667,-57.666667 ],
    [ u"br",u"Guajará-Mirim",34123,-10.8,-65.366667 ],
    [ u"br",u"Guanambi",58879,-14.216667,-42.783333 ],
    [ u"br",u"Guanhães",23728,-18.783333,-42.95 ],
    [ u"br",u"Guapiaçu",14065,-20.833333,-49.216667 ],
    [ u"br",u"Guapimirim",31202,-22.533333,-42.983333 ],
    [ u"br",u"Guapó",10075,-16.816667,-49.533333 ],
    [ u"br",u"Guaporé",20050,-28.85,-51.9 ],
    [ u"br",u"Guarabira",43750,-6.85,-35.483333 ],
    [ u"br",u"Guaraciaba do Norte",18186,-4.166667,-40.766667 ],
    [ u"br",u"Guará",18263,-20.433333,-47.833333 ],
    [ u"br",u"Guaramirim",21422,-26.45,-49 ],
    [ u"br",u"Guaranésia",17437,-21.3,-46.8 ],
    [ u"br",u"Guaraniaçu",7781,-25.1,-52.866667 ],
    [ u"br",u"Guarapari",100927,-20.666667,-40.5 ],
    [ u"br",u"Guarapuava",150851,-25.383333,-51.45 ],
    [ u"br",u"Guararapes",27558,-21.25,-50.633333 ],
    [ u"br",u"Guararema",23572,-23.4132,-46.0377 ],
    [ u"br",u"Guaratinga",9519,-16.566667,-39.566667 ],
    [ u"br",u"Guaratinguetá",105882,-22.815156,-45.18923 ],
    [ u"br",u"Guaratuba",18906,-25.8804,-48.571 ],
    [ u"br",u"Guariba",30464,-21.35,-48.233333 ],
    [ u"br",u"Guarujá",310430,-24,-46.266667 ],
    [ u"br",u"Guarulhos",1169601,-23.45068,-46.526175 ],
    [ u"br",u"Guaxupé",47890,-21.3,-46.7 ],
    [ u"br",u"Guia Lopes da Laguna",9681,-21.433333,-56.116667 ],
    [ u"br",u"Guiratinga",10938,-16.35,-53.75 ],
    [ u"br",u"Gurinhém",5618,-7.133333,-35.45 ],
    [ u"br",u"Gurupá",6461,-1.416667,-51.65 ],
    [ u"br",u"Gurupi",64790,-11.7225,-49.012222 ],
    [ u"br",u"Hidrolândia",10299,-4.416667,-40.416667 ],
    [ u"br",u"Hidrolândia",7082,-16.966667,-49.233333 ],
    [ u"br",u"Horizonte",51181,-4.083333,-38.483333 ],
    [ u"br",u"Horizontina",14416,-27.616667,-54.316667 ],
    [ u"br",u"Hortolândia",203537,-22.85,-47.25 ],
    [ u"br",u"Humaitá",31207,-7.516389,-63.022222 ],
    [ u"br",u"Humberto de Campos",5208,-2.616667,-43.45 ],
    [ u"br",u"Iaciara",9207,-14.15,-46.666667 ],
    [ u"br",u"Iaçu",22665,-12.75,-40.216667 ],
    [ u"br",u"Ibaiti",25797,-23.8469,-50.1886 ],
    [ u"br",u"Ibateguara",8755,-8.983333,-35.866667 ],
    [ u"br",u"Ibaté",29550,-21.95,-48 ],
    [ u"br",u"Ibatiba",12265,-20.233333,-41.516667 ],
    [ u"br",u"Ibiá",18428,-19.483333,-46.533333 ],
    [ u"br",u"Ibiapina",9205,-3.916667,-40.9 ],
    [ u"br",u"Ibicaraí",19575,-14.85,-39.6 ],
    [ u"br",u"Ibicuí",10640,-14.85,-39.983333 ],
    [ u"br",u"Ibimirim",12272,-8.533333,-37.7 ],
    [ u"br",u"Ibipeba",14444,-11.633333,-42.033333 ],
    [ u"br",u"Ibiporã",44791,-23.283333,-51.05 ],
    [ u"br",u"Ibiraçu",8921,-19.833333,-40.366667 ],
    [ u"br",u"Ibirama",18360,-27.0546,-49.516 ],
    [ u"br",u"Ibirapitanga",7302,-14.15,-39.366667 ],
    [ u"br",u"Ibirataia",19943,-14.066667,-39.633333 ],
    [ u"br",u"Ibirité",141376,-20.033333,-44.066667 ],
    [ u"br",u"Ibirubá",14180,-28.633333,-53.1 ],
    [ u"br",u"Ibitinga",49075,-21.75,-48.816667 ],
    [ u"br",u"Ibiúna",22860,-23.654522,-47.218152 ],
    [ u"br",u"Ibotirama",17354,-12.183333,-43.216667 ],
    [ u"br",u"Içara",51455,-28.7,-49.3 ],
    [ u"br",u"Icatu",3648,-2.766667,-44.066667 ],
    [ u"br",u"Icó",28323,-6.4,-38.85 ],
    [ u"br",u"Iconha",5051,-20.8,-40.8 ],
    [ u"br",u"Igaci",6480,-9.55,-36.633333 ],
    [ u"br",u"Igaraçu do Tietê",22758,-22.516667,-48.566667 ],
    [ u"br",u"Igarapava",29058,-20.05,-47.783333 ],
    [ u"br",u"Igarapé-Açu",24136,-1.116667,-47.616667 ],
    [ u"br",u"Igarapé",21427,-20.066667,-44.3 ],
    [ u"br",u"Igarapé-Miri",26838,-1.983333,-48.966667 ],
    [ u"br",u"Igarassu",86458,-7.833333,-34.9 ],
    [ u"br",u"Igreja Nova",4606,-10.116667,-36.65 ],
    [ u"br",u"Igrejinha",28680,-29.566667,-50.8 ],
    [ u"br",u"Iguaba Grande",11104,-22.833333,-42.216667 ],
    [ u"br",u"Iguaí",14218,-14.75,-40.066667 ],
    [ u"br",u"Iguape",23785,-24.716667,-47.55 ],
    [ u"br",u"Iguatemi",9619,-23.666667,-54.566667 ],
    [ u"br",u"Iguatu",70381,-6.366667,-39.3 ],
    [ u"br",u"Ijuí",71203,-28.383333,-53.916667 ],
    [ u"br",u"Ilhabela",32903,-23.783333,-45.35 ],
    [ u"br",u"Ilhéus",155503,-14.816667,-39.033333 ],
    [ u"br",u"Imaculada",4014,-7.366667,-37.5 ],
    [ u"br",u"Imbituba",43450,-28.233333,-48.666667 ],
    [ u"br",u"Imbituva",19671,-25.2,-50.583333 ],
    [ u"br",u"Imperatriz",218110,-5.533333,-47.483333 ],
    [ u"br",u"Indaial",44360,-26.8922,-49.2239 ],
    [ u"br",u"Indaiatuba",179914,-23.083333,-47.233333 ],
    [ u"br",u"Independência",11113,-5.383333,-40.316667 ],
    [ u"br",u"Indiaroba",4989,-11.533333,-37.516667 ],
    [ u"br",u"Ingá",8751,-7.283333,-35.6 ],
    [ u"br",u"Inhambupe",14735,-11.783333,-38.35 ],
    [ u"br",u"Inhapi",7550,-9.233333,-37.75 ],
    [ u"br",u"Inhapim",13594,-19.55,-42.116667 ],
    [ u"br",u"Inhuma",7056,-6.666667,-41.7 ],
    [ u"br",u"Inhumas",44058,-16.366667,-49.5 ],
    [ u"br",u"Ipaba",15971,-19.383333,-42.416667 ],
    [ u"br",u"Ipameri",18607,-17.716667,-48.15 ],
    [ u"br",u"Ipanema",11705,-19.783333,-41.733333 ],
    [ u"br",u"Ipanguaçu",4624,-5.497778,-36.853333 ],
    [ u"br",u"Ipatinga",228750,-19.5,-42.533333 ],
    [ u"br",u"Ipaussú",10833,-23.05,-49.616667 ],
    [ u"br",u"Iperó",17161,-23.35,-47.683333 ],
    [ u"br",u"Ipiaú",38763,-14.133333,-39.733333 ],
    [ u"br",u"Ipirá",27218,-12.166667,-39.733333 ],
    [ u"br",u"Ipixuna",5814,-7.051667,-71.693056 ],
    [ u"br",u"Ipojuca",53365,-8.4,-35.066667 ],
    [ u"br",u"Iporã",10353,-23.983333,-53.616667 ],
    [ u"br",u"Iporá",28254,-16.466667,-51.116667 ],
    [ u"br",u"Ipuã",12370,-20.45,-48.033333 ],
    [ u"br",u"Ipubi",16424,-7.65,-40.116667 ],
    [ u"br",u"Ipueiras",17111,-7.033333,-40.45 ],
    [ u"br",u"Ipu",26679,-4.333333,-40.7 ],
    [ u"br",u"Iracemápolis",16796,-22.583333,-47.533333 ],
    [ u"br",u"Iranduba",11181,-3.25,-60.1 ],
    [ u"br",u"Iraquara",5131,-12.25,-41.6 ],
    [ u"br",u"Irará",9099,-12.033333,-38.766667 ],
    [ u"br",u"Irati",45831,-25.4735,-50.6524 ],
    [ u"br",u"Irauçuba",13282,-3.75,-39.783333 ],
    [ u"br",u"Irecê",63628,-11.3,-41.866667 ],
    [ u"br",u"Irituia",5602,-1.766667,-47.433333 ],
    [ u"br",u"Irupi",3505,-20.35,-41.633333 ],
    [ u"br",u"Itabaiana",19101,-7.333333,-35.333333 ],
    [ u"br",u"Itabaiana",63889,-10.683333,-37.433333 ],
    [ u"br",u"Itabaianinha",17149,-11.266667,-37.783333 ],
    [ u"br",u"Itaberaba",47303,-12.533333,-40.3 ],
    [ u"br",u"Itaberaí",22130,-16.033333,-49.8 ],
    [ u"br",u"Itaberá",11098,-23.85,-49.15 ],
    [ u"br",u"Itabira",99498,-19.616667,-43.216667 ],
    [ u"br",u"Itabirito",39453,-20.2484,-43.8063 ],
    [ u"br",u"Itaboraí",182500,-22.75,-42.866667 ],
    [ u"br",u"Itabuna",205666,-14.8,-39.266667 ],
    [ u"br",u"Itacarambi",13084,-15.016667,-44.05 ],
    [ u"br",u"Itacaré",12490,-14.3,-39 ],
    [ u"br",u"Itacoatiara",45995,-3.05,-58.433333 ],
    [ u"br",u"Itagibá",9843,-14.283333,-39.85 ],
    [ u"br",u"Itagi",10534,-14.166667,-40.016667 ],
    [ u"br",u"Itaguaçu",8202,-19.8,-40.85 ],
    [ u"br",u"Itaguaí",100756,-22.870755,-43.773821 ],
    [ u"br",u"Itaíba",13870,-8.95,-37.416667 ],
    [ u"br",u"Itaí",22305,-23.4,-49.1 ],
    [ u"br",u"Itainópolis",2922,-7.4,-41.516667 ],
    [ u"br",u"Itaitinga",30939,-3.966667,-38.516667 ],
    [ u"br",u"Itaituba",64758,-4.216667,-56.016667 ],
    [ u"br",u"Itajaí",155719,-26.883333,-48.65 ],
    [ u"br",u"Itajobi",12231,-21.316667,-49.066667 ],
    [ u"br",u"Itajubá",81871,-22.433333,-45.45 ],
    [ u"br",u"Itajuípe",15517,-14.683333,-39.366667 ],
    [ u"br",u"Itamaracá",14969,-7.75,-34.833333 ],
    [ u"br",u"Itamaraju",47630,-17.066667,-39.533333 ],
    [ u"br",u"Itamarandiba",18064,-17.85,-42.85 ],
    [ u"br",u"Itambacuri",14652,-18.016667,-41.7 ],
    [ u"br",u"Itambé",23559,-15.25,-40.616667 ],
    [ u"br",u"Itanhaém",90387,-24.183333,-46.783333 ],
    [ u"br",u"Itanhandu",11274,-22.3,-44.95 ],
    [ u"br",u"Itanhém",13517,-17.15,-40.333333 ],
    [ u"br",u"Itaobim",15938,-16.566667,-41.833333 ],
    [ u"br",u"Itaocara",16763,-21.683333,-42.066667 ],
    [ u"br",u"Itapaci",16118,-14.95,-49.566667 ],
    [ u"br",u"Itapagé",32043,-3.683333,-39.566667 ],
    [ u"br",u"Itaparica",20101,-12.9,-38.7 ],
    [ u"br",u"Itapecerica da Serra",151608,-23.716667,-46.833333 ],
    [ u"br",u"Itapecerica",16684,-20.466667,-45.116667 ],
    [ u"br",u"Itapema",36766,-27.099167,-48.615 ],
    [ u"br",u"Itapemirim",17536,-21.016667,-40.833333 ],
    [ u"br",u"Itaperuçu",26552,-25.2,-49.366667 ],
    [ u"br",u"Itaperuna",84436,-21.2,-41.9 ],
    [ u"br",u"Itapetinga",59723,-15.25,-40.25 ],
    [ u"br",u"Itapetininga",126245,-23.6,-48.05 ],
    [ u"br",u"Itapeva",62958,-23.966667,-48.866667 ],
    [ u"br",u"Itapevi",201752,-23.55,-46.933333 ],
    [ u"br",u"Itapicuru",4994,-11.316667,-38.25 ],
    [ u"br",u"Itapipoca",55785,-3.5,-39.583333 ],
    [ u"br",u"Itapira",61608,-22.433333,-46.833333 ],
    [ u"br",u"Itapirapuã",7923,-15.866667,-50.6 ],
    [ u"br",u"Itapissuma",16674,-7.766667,-34.9 ],
    [ u"br",u"Itápolis",34553,-21.583333,-48.766667 ],
    [ u"br",u"Itaporã",12327,-22.016667,-54.9 ],
    [ u"br",u"Itaporanga",15890,-7.3,-38.166667 ],
    [ u"br",u"Itaporanga",10202,-23.7,-49.483333 ],
    [ u"br",u"Itapuí",10445,-22.233333,-48.683333 ],
    [ u"br",u"Itapuranga",19709,-15.583333,-49.983333 ],
    [ u"br",u"Itaquaquecetuba",336686,-23.483333,-46.35 ],
    [ u"br",u"Itaqui",34631,-29.133333,-56.55 ],
    [ u"br",u"Itaquitinga",11128,-7.666667,-35.1 ],
    [ u"br",u"Itarana",4060,-19.85,-40.866667 ],
    [ u"br",u"Itarantim",12370,-15.65,-40.05 ],
    [ u"br",u"Itararé",44810,-24.116667,-49.333333 ],
    [ u"br",u"Itarema",10330,-2.9,-39.966667 ],
    [ u"br",u"Itatiaia",12571,-22.5,-44.566667 ],
    [ u"br",u"Itatiba",67935,-23,-46.85 ],
    [ u"br",u"Itatinga",15696,-23.116667,-48.6 ],
    [ u"br",u"Itatuba",4951,-7.383333,-35.65 ],
    [ u"br",u"Itaú de Minas",14888,-20.716667,-46.75 ],
    [ u"br",u"Itaueira",5146,-7.6,-43.033333 ],
    [ u"br",u"Itaúna",77402,-20.066667,-44.566667 ],
    [ u"br",u"Itinga",4917,-16.6,-41.783333 ],
    [ u"br",u"Itirapina",13229,-22.25,-47.816667 ],
    [ u"br",u"Itiruçu",11499,-13.516667,-40.15 ],
    [ u"br",u"Itiúba",9410,-10.716667,-39.85 ],
    [ u"br",u"Itororó",17325,-15.116667,-40.1 ],
    [ u"br",u"Ituaçu",4891,-13.816667,-41.3 ],
    [ u"br",u"Ituberá",19888,-13.733333,-39.15 ],
    [ u"br",u"Itu",137589,-23.266667,-47.316667 ],
    [ u"br",u"Ituiutaba",85346,-18.966667,-49.466667 ],
    [ u"br",u"Itumbiara",79583,-18.416667,-49.216667 ],
    [ u"br",u"Itupeva",25183,-17.416667,-40.483333 ],
    [ u"br",u"Itupiranga",21301,-5.15,-49.333333 ],
    [ u"br",u"Ituporanga",13038,-27.416667,-49.6 ],
    [ u"br",u"Iturama",29805,-19.733333,-50.183333 ],
    [ u"br",u"Ituverava",36998,-20.333333,-47.783333 ],
    [ u"br",u"Iúna",14290,-20.35,-41.533333 ],
    [ u"br",u"Ivaiporã",23316,-24.25,-51.75 ],
    [ u"br",u"Ivoti",18172,-29.6,-51.166667 ],
    [ u"br",u"Jaboatão",702632,-8.116667,-35.016667 ],
    [ u"br",u"Jaboticabal",69396,-21.266667,-48.316667 ],
    [ u"br",u"Jacaraú",7035,-6.666667,-35.3 ],
    [ u"br",u"Jacareacanga",1402,-6.266667,-57.65 ],
    [ u"br",u"Jacareí",213114,-23.316667,-45.966667 ],
    [ u"br",u"Jacarezinho",35090,-23.171382,-49.991453 ],
    [ u"br",u"Jaciara",22739,-15.983333,-54.95 ],
    [ u"br",u"Jacobina",47639,-11.183333,-40.516667 ],
    [ u"br",u"Jacupiranga",11149,-24.700034,-48.004445 ],
    [ u"br",u"Jacutinga",18470,-22.283333,-46.616667 ],
    [ u"br",u"Jaguaquara",41499,-13.533333,-39.966667 ],
    [ u"br",u"Jaguarão",29613,-32.566667,-53.383333 ],
    [ u"br",u"Jaguarari",22617,-10.266667,-40.2 ],
    [ u"br",u"Jaguariaíva",30627,-24.25,-49.7 ],
    [ u"br",u"Jaguaribe",23066,-5.883333,-38.616667 ],
    [ u"br",u"Jaguariúna",31718,-22.683333,-46.983333 ],
    [ u"br",u"Jaguaruana",21791,-4.833333,-37.783333 ],
    [ u"br",u"Jaguaruna",11650,-28.6,-49.033333 ],
    [ u"br",u"Jaicós",7107,-7.35,-41.133333 ],
    [ u"br",u"Jales",43832,-20.266667,-50.55 ],
    [ u"br",u"Janaúba",56573,-15.8,-43.316667 ],
    [ u"br",u"Jandaia do Sul",17507,-23.6,-51.65 ],
    [ u"br",u"Jandira",113607,-23.516667,-46.9 ],
    [ u"br",u"Januária",34812,-15.483333,-44.366667 ],
    [ u"br",u"Japaratuba",8092,-10.583333,-36.95 ],
    [ u"br",u"Japeri",95102,-22.648889,-43.658611 ],
    [ u"br",u"Japoatã",4207,-10.333333,-36.8 ],
    [ u"br",u"Japurá",1908,-1.395833,-69.422222 ],
    [ u"br",u"Jaraguá do Sul",130132,-26.483333,-49.066667 ],
    [ u"br",u"Jaraguá",30410,-15.75,-49.333333 ],
    [ u"br",u"Jardim de Piranhas",10935,-6.366667,-37.333333 ],
    [ u"br",u"Jardim do Seridó",9520,-6.583333,-36.766667 ],
    [ u"br",u"Jardim",7189,-3.433333,-39.016667 ],
    [ u"br",u"Jardim",23781,-21.466667,-56.15 ],
    [ u"br",u"Jardinópolis",34719,-21.033333,-47.766667 ],
    [ u"br",u"Jarinu",17905,-23.103333,-46.728056 ],
    [ u"br",u"Jaru",28018,-10.433333,-62.45 ],
    [ u"br",u"Jataí",76548,-17.883333,-51.716667 ],
    [ u"br",u"Jataìzinho",10014,-23.216667,-50.966667 ],
    [ u"br",u"Jaú",119209,-22.3,-48.55 ],
    [ u"br",u"Jequié",127479,-13.85,-40.083333 ],
    [ u"br",u"Jequitinhonha",15463,-16.433333,-41 ],
    [ u"br",u"Jeremoabo",16642,-10.066667,-38.35 ],
    [ u"br",u"Jerônimo Monteiro",6902,-20.783333,-41.4 ],
    [ u"br",u"Ji-Paraná",100128,-10.833333,-61.966667 ],
    [ u"br",u"Jitaúna",11619,-14.016667,-39.95 ],
    [ u"br",u"Joaçaba",23516,-27.166667,-51.5 ],
    [ u"br",u"Joaíma",9022,-16.65,-41.033333 ],
    [ u"br",u"Joanópolis",11772,-22.933333,-46.283333 ],
    [ u"br",u"João Alfredo",11334,-7.866667,-35.583333 ],
    [ u"br",u"João Câmara",19886,-5.533333,-35.8 ],
    [ u"br",u"João Monlevade",72763,-19.833333,-43.133333 ],
    [ u"br",u"João Neiva",10383,-19.75,-40.4 ],
    [ u"br",u"João Pessoa",650896,-7.116667,-34.866667 ],
    [ u"br",u"João Pinheiro",28083,-17.75,-46.166667 ],
    [ u"br",u"Joaquim Gomes",14808,-9.2,-35.716667 ],
    [ u"br",u"Joaquim Nabuco",9965,-8.616667,-35.533333 ],
    [ u"br",u"Joinville",461312,-26.3,-48.833333 ],
    [ u"br",u"José Bonifácio",27828,-21.05,-49.683333 ],
    [ u"br",u"José de Freitas",21433,-4.75,-42.583333 ],
    [ u"br",u"Juatuba",24551,-19.95,-44.333333 ],
    [ u"br",u"Juàzeirinho",8846,-6.816667,-38.05 ],
    [ u"br",u"Juazeiro do Norte",225234,-7.2,-39.333333 ],
    [ u"br",u"Juàzeiro",137807,-9.5,-40.5 ],
    [ u"br",u"Jucás",14822,-6.533333,-39.533333 ],
    [ u"br",u"Jucurutu",11535,-6.033333,-37.016667 ],
    [ u"br",u"Juiz de Fora",470201,-21.751667,-43.352778 ],
    [ u"br",u"Júlio de Castilhos",16487,-29.233333,-53.683333 ],
    [ u"br",u"Jundiaí",321595,-23.183333,-46.866667 ],
    [ u"br",u"Jundiá",2267,-8.933333,-35.566667 ],
    [ u"br",u"Junqueiro",7740,-9.933333,-36.483333 ],
    [ u"br",u"Junqueirópolis",13965,-21.533333,-51.433333 ],
    [ u"br",u"Juquiá",13497,-24.316667,-47.633333 ],
    [ u"br",u"Juquitiba",13961,-23.927482,-47.069543 ],
    [ u"br",u"Juripiranga",8320,-7.366667,-35.233333 ],
    [ u"br",u"Juru",3796,-7.533333,-37.816667 ],
    [ u"br",u"Juruti",13333,-2.166667,-56.066667 ],
    [ u"br",u"Jussara",16374,-23.6,-52.466667 ],
    [ u"br",u"Jutaí",5863,-5.183333,-68.9 ],
    [ u"br",u"Lábrea",19624,-7.266667,-64.783333 ],
    [ u"br",u"Ladário",15790,-19.016667,-57.583333 ],
    [ u"br",u"Lagarto",45446,-10.9,-37.683333 ],
    [ u"br",u"Lages",164679,-27.8,-50.316667 ],
    [ u"br",u"Lagoa da Canoa",13428,-9.816667,-36.766667 ],
    [ u"br",u"Lagoa da Prata",43119,-20.016667,-45.55 ],
    [ u"br",u"Lagoa do Itaenga",17719,-7.916667,-35.333333 ],
    [ u"br",u"Lagoa Formosa",11822,-18.783333,-46.4 ],
    [ u"br",u"Lagoa Nova",5984,-6.1,-36.483333 ],
    [ u"br",u"Lagoa Santa",38487,-19.633333,-43.883333 ],
    [ u"br",u"Lagoa Sêca",8103,-7.15,-35.85 ],
    [ u"br",u"Lagoa Vermelha",24446,-28.216667,-51.533333 ],
    [ u"br",u"Lago da Pedra",25996,-4.333333,-45.166667 ],
    [ u"br",u"Laguna",39712,-28.483333,-48.783333 ],
    [ u"br",u"Lajeado",65408,-29.45,-51.966667 ],
    [ u"br",u"Lajedo",25262,-8.383333,-36.55 ],
    [ u"br",u"Laje",4708,-10.183333,-40.966667 ],
    [ u"br",u"Lambari",14516,-21.966667,-45.35 ],
    [ u"br",u"Lapa",25621,-25.765833,-49.717778 ],
    [ u"br",u"Lapão",11253,-11.4,-41.833333 ],
    [ u"br",u"Laranja da Terra",3016,-19.9,-41.066667 ],
    [ u"br",u"Laranjal Paulista",21264,-23.048726,-47.835968 ],
    [ u"br",u"Laranjeiras do Sul",18425,-25.416667,-52.416667 ],
    [ u"br",u"Laranjeiras",23251,-10.8,-37.166667 ],
    [ u"br",u"Lauro Müller",10036,-28.4,-49.383333 ],
    [ u"br",u"Lavras da Mangabeira",17221,-6.75,-38.95 ],
    [ u"br",u"Lavras",81474,-21.233333,-45 ],
    [ u"br",u"Leme",81211,-22.2,-47.4 ],
    [ u"br",u"Lençóis Paulista",57376,-22.6,-48.783333 ],
    [ u"br",u"Leopoldina",46743,-21.533333,-42.633333 ],
    [ u"br",u"Lima Duarte",13480,-21.85,-43.8 ],
    [ u"br",u"Limeira",289671,-22.561667,-47.402778 ],
    [ u"br",u"Limoeiro de Anadia",2770,-9.733333,-36.516667 ],
    [ u"br",u"Limoeiro do Ajuru",4109,-1.916667,-49.383333 ],
    [ u"br",u"Limoeiro do Norte",29450,-5.133333,-38.083333 ],
    [ u"br",u"Limoeiro",42329,-7.866667,-35.45 ],
    [ u"br",u"Linhares",105084,-19.416667,-40.066667 ],
    [ u"br",u"Lins",69452,-21.666667,-49.75 ],
    [ u"br",u"Livramento",19914,-13.65,-41.833333 ],
    [ u"br",u"Loanda",18233,-22.9,-53.166667 ],
    [ u"br",u"Londrina",471836,-23.3,-51.15 ],
    [ u"br",u"Lorena",76507,-22.733333,-45.133333 ],
    [ u"br",u"Louveira",31098,-23.066667,-46.966667 ],
    [ u"br",u"Lucélia",14807,-21.733333,-51.016667 ],
    [ u"br",u"Luís Correia",11480,-2.883611,-41.666111 ],
    [ u"br",u"Luziânia",143601,-16.25,-47.933333 ],
    [ u"br",u"Luzilândia",12999,-3.466667,-42.366667 ],
    [ u"br",u"Luz",14396,-19.8,-45.666667 ],
    [ u"br",u"Macaé",143031,-22.383333,-41.783333 ],
    [ u"br",u"Macaíba",40016,-5.716667,-35.55 ],
    [ u"br",u"Macapá",338937,.033333,-51.05 ],
    [ u"br",u"Macaparana",14363,-7.566667,-35.45 ],
    [ u"br",u"Macatuba",16180,-22.516667,-48.683333 ],
    [ u"br",u"Macaúbas",14598,-13.033333,-42.7 ],
    [ u"br",u"Macau",18070,-5.116667,-36.633333 ],
    [ u"br",u"Maceió",955010,-9.666667,-35.716667 ],
    [ u"br",u"Machado",33003,-21.683333,-45.933333 ],
    [ u"br",u"Madre de Deus",14887,-12.733333,-38.616667 ],
    [ u"br",u"Mafra",40081,-26.1181,-49.8023 ],
    [ u"br",u"Magé",216342,-22.655556,-43.015278 ],
    [ u"br",u"Mairi",13475,-11.716667,-40.133333 ],
    [ u"br",u"Mairinque",44457,-23.544368,-47.183467 ],
    [ u"br",u"Mairiporã",54417,-23.322628,-46.586935 ],
    [ u"br",u"Major Isidoro",8507,-9.533333,-37 ],
    [ u"br",u"Malacacheta",8820,-17.833333,-42.083333 ],
    [ u"br",u"Malhador",5574,-10.65,-37.3 ],
    [ u"br",u"Mamanguape",27607,-6.833333,-35.116667 ],
    [ u"br",u"Manacapuru",52460,-3.3,-60.616667 ],
    [ u"br",u"Manaíra",4913,-7.7,-38.166667 ],
    [ u"br",u"Manaquiri",9986,-3.316667,-60.35 ],
    [ u"br",u"Manaus",1598227,-3.113333,-60.025278 ],
    [ u"br",u"Mâncio Lima",7086,-7.616667,-72.9 ],
    [ u"br",u"Mandaguaçu",14866,-23.333333,-52.083333 ],
    [ u"br",u"Mandaguari",38239,-23.533333,-51.7 ],
    [ u"br",u"Manga",11733,-14.766667,-43.933333 ],
    [ u"br",u"Mangaratiba",27023,-22.9609,-44.0402 ],
    [ u"br",u"Manhuaçu",54608,-20.25,-42.033333 ],
    [ u"br",u"Manhumirim",15544,-20.366667,-41.95 ],
    [ u"br",u"Manicoré",14058,-5.812222,-61.2975 ],
    [ u"br",u"Manoel Urbano",4066,-8.883333,-69.3 ],
    [ u"br",u"Mantena",18715,-18.783333,-40.983333 ],
    [ u"br",u"Mantenópolis",8547,-18.883333,-41.1 ],
    [ u"br",u"Maraã",4387,-1.833333,-65.366667 ],
    [ u"br",u"Marabá",145865,-5.35,-49.116667 ],
    [ u"br",u"Maracaçumé",14164,-2.05,-45.933333 ],
    [ u"br",u"Maracaí",11960,-22.6,-50.65 ],
    [ u"br",u"Maracaju",22690,-21.633333,-55.15 ],
    [ u"br",u"Maracanã",12683,-.766667,-47.45 ],
    [ u"br",u"Maracanaú",193532,-3.866667,-38.633333 ],
    [ u"br",u"Maracás",22050,-13.433333,-40.45 ],
    [ u"br",u"Maragogi",16066,-9.016667,-35.216667 ],
    [ u"br",u"Maragogipe",20921,-12.766667,-38.916667 ],
    [ u"br",u"Maraial",14204,-8.783333,-35.833333 ],
    [ u"br",u"Marapanim",10236,-.7,-47.7 ],
    [ u"br",u"Marataízes",25397,-21.033333,-40.833333 ],
    [ u"br",u"Maraú",2956,-14.1,-39 ],
    [ u"br",u"Marau",26860,-28.45,-52.2 ],
    [ u"br",u"Maravilha",13865,-26.783333,-53.15 ],
    [ u"br",u"Marco",14502,-3.133333,-40.15 ],
    [ u"br",u"Mar de Espanha",9678,-21.865833,-43.009722 ],
    [ u"br",u"Marechal Cândido Rondon",43028,-24.566667,-54.066667 ],
    [ u"br",u"Marechal Deodoro",50579,-9.716667,-35.9 ],
    [ u"br",u"Marechal Floriano",5869,-20.416667,-40.666667 ],
    [ u"br",u"Marialva",26001,-23.466667,-51.7 ],
    [ u"br",u"Mariana",45237,-20.383333,-43.416667 ],
    [ u"br",u"Maribondo",10475,-9.583333,-36.233333 ],
    [ u"br",u"Maricá",79552,-22.916667,-42.816667 ],
    [ u"br",u"Marilândia",3900,-19.416667,-40.516667 ],
    [ u"br",u"Marília",212222,-22.216667,-49.933333 ],
    [ u"br",u"Mari",17535,-7.083333,-35.333333 ],
    [ u"br",u"Maringá",311727,-23.416667,-51.916667 ],
    [ u"br",u"Martinho Campos",9198,-19.333333,-45.216667 ],
    [ u"br",u"Martinópolis",18488,-22.183333,-51.2 ],
    [ u"br",u"Maruim",12153,-10.75,-37.083333 ],
    [ u"br",u"Mascote",18899,-15.55,-39.283333 ],
    [ u"br",u"Massapê",22193,-3.516667,-40.316667 ],
    [ u"br",u"Massaranduba",3153,-7.183333,-35.766667 ],
    [ u"br",u"Mata de São João",26680,-12.516667,-38.283333 ],
    [ u"br",u"Mata Grande",4654,-9.111667,-37.7 ],
    [ u"br",u"Matão",72469,-21.583333,-48.366667 ],
    [ u"br",u"Matelândia",10816,-25.2413,-53.983 ],
    [ u"br",u"Mateus Leme",24890,-19.983333,-44.416667 ],
    [ u"br",u"Matias Barbosa",12072,-21.869722,-43.318611 ],
    [ u"br",u"Matias Olímpio",4012,-3.716667,-42.55 ],
    [ u"br",u"Matinha",6851,-3.1,-45.033333 ],
    [ u"br",u"Matinhos",32008,-25.816667,-48.533333 ],
    [ u"br",u"Matipó",12997,-20.283333,-42.35 ],
    [ u"br",u"Mato Verde",7783,-15.383333,-42.866667 ],
    [ u"br",u"Matozinhos",30844,-19.583333,-44.116667 ],
    [ u"br",u"Matriz de Camaragibe",18705,-9.15,-35.516667 ],
    [ u"br",u"Mauá",386077,-23.666667,-46.45 ],
    [ u"br",u"Maués",22476,-3.4,-57.7 ],
    [ u"br",u"Mauriti",20064,-7.383333,-38.766667 ],
    [ u"br",u"Mazagão",6500,-.116667,-51.283333 ],
    [ u"br",u"Medeiros Neto",15255,-17.333333,-40.233333 ],
    [ u"br",u"Medianeira",34069,-25.283333,-54.083333 ],
    [ u"br",u"Medina",14686,-16.25,-41.483333 ],
    [ u"br",u"Mendes",17308,-22.526111,-43.724722 ],
    [ u"br",u"Messias",12376,-9.416667,-35.833333 ],
    [ u"br",u"Miguel Alves",10439,-4.166667,-42.9 ],
    [ u"br",u"Miguel Calmon",13748,-11.433333,-40.6 ],
    [ u"br",u"Miguelópolis",18262,-20.2,-48.05 ],
    [ u"br",u"Miguel Pereira",23850,-22.452778,-43.476389 ],
    [ u"br",u"Milagres",12588,-7.283333,-38.95 ],
    [ u"br",u"Mimoso do Sul",14045,-21.066667,-41.366667 ],
    [ u"br",u"Minador do Negrão",1986,-9.333333,-36.866667 ],
    [ u"br",u"Minas Novas",7365,-17.25,-42.6 ],
    [ u"br",u"Mineiros",38951,-17.566667,-52.566667 ],
    [ u"br",u"Mirabela",8934,-16.258056,-44.159167 ],
    [ u"br",u"Miracatu",11679,-24.283333,-47.466667 ],
    [ u"br",u"Miracema do Tocantins",29181,-9.529167,-48.319722 ],
    [ u"br",u"Miracema",26684,-21.416667,-42.183333 ],
    [ u"br",u"Mirador",6955,-6.366667,-44.366667 ],
    [ u"br",u"Miraí",8500,-21.2,-42.616667 ],
    [ u"br",u"Miranda",13189,-20.233333,-56.366667 ],
    [ u"br",u"Mirandópolis",23379,-21.15,-51.1 ],
    [ u"br",u"Miranorte",12446,-9.476667,-48.480278 ],
    [ u"br",u"Mirante do Paranapanema",9387,-22.283333,-51.9 ],
    [ u"br",u"Mirassol",51559,-20.766667,-49.466667 ],
    [ u"br",u"Missão Velha",13106,-7.25,-39.133333 ],
    [ u"br",u"Mocajuba",16567,-2.583333,-49.5 ],
    [ u"br",u"Mococa",59656,-21.466667,-47.016667 ],
    [ u"br",u"Mogeiro",4767,-7.3,-35.466667 ],
    [ u"br",u"Moita Bonita",3602,-10.583333,-37.366667 ],
    [ u"br",u"Moji das Cruzes",325753,-23.516667,-46.183333 ],
    [ u"br",u"Moji-Mirim",78245,-22.433333,-46.95 ],
    [ u"br",u"Moju",21511,-1.883333,-48.766667 ],
    [ u"br",u"Mombaça",17065,-5.75,-39.633333 ],
    [ u"br",u"Monção",11051,-3.5,-45.25 ],
    [ u"br",u"Mongaguá",45931,-24.1,-46.616667 ],
    [ u"br",u"Monsenhor Gil",4751,-5.583333,-42.616667 ],
    [ u"br",u"Montanha",11934,-18.133333,-40.35 ],
    [ u"br",u"Montanhas",8442,-6.483333,-35.3 ],
    [ u"br",u"Monte Alegre de Minas",12451,-18.866667,-48.866667 ],
    [ u"br",u"Monte Alegre de Sergipe",6816,-10.033333,-37.55 ],
    [ u"br",u"Monte Alegre",22841,-2.016667,-54.066667 ],
    [ u"br",u"Monte Alegre",6643,-5.889722,-36.301389 ],
    [ u"br",u"Monte Alto",41894,-21.283333,-48.483333 ],
    [ u"br",u"Monte Aprazível",16308,-20.75,-49.7 ],
    [ u"br",u"Monte Azul",11222,-15.15,-42.883333 ],
    [ u"br",u"Monte Azul Paulista",18117,-20.916667,-48.633333 ],
    [ u"br",u"Monte Carmelo",44041,-18.716667,-47.483333 ],
    [ u"br",u"Monteiro",17727,-7.883333,-37.116667 ],
    [ u"br",u"Monte Mor",40291,-22.95,-47.333333 ],
    [ u"br",u"Montenegro",54058,-29.7,-51.466667 ],
    [ u"br",u"Montes Altos",3518,-5.833333,-47.066667 ],
    [ u"br",u"Monte Santo de Minas",16617,-21.2,-46.983333 ],
    [ u"br",u"Monte Santo",7398,-10.433333,-39.333333 ],
    [ u"br",u"Montes Claros",332384,-16.716667,-43.866667 ],
    [ u"br",u"Monte Sião",11090,-22.433333,-46.566667 ],
    [ u"br",u"Morada Nova",37390,-5.116667,-38.383333 ],
    [ u"br",u"Moreira Sales",8699,-24.016667,-53.05 ],
    [ u"br",u"Moreno",45238,-8.116667,-35.1 ],
    [ u"br",u"Morrinhos",34144,-17.733333,-49.116667 ],
    [ u"br",u"Morro Agudo",25266,-20.733333,-48.066667 ],
    [ u"br",u"Morro da Fumaça",13952,-28.666667,-49.2 ],
    [ u"br",u"Morros",4829,-9.446667,-46.300278 ],
    [ u"br",u"Mossoró",202010,-5.191389,-37.344722 ],
    [ u"br",u"Mozarlândia",11252,-14.783333,-50.583333 ],
    [ u"br",u"Muaná",7464,-1.533333,-49.216667 ],
    [ u"br",u"Mucurici",9524,-18.1,-40.516667 ],
    [ u"br",u"Mucuri",26823,-18.083333,-39.566667 ],
    [ u"br",u"Mulungu",4181,-7.033333,-35.466667 ],
    [ u"br",u"Mundo Novo",11912,-11.866667,-40.466667 ],
    [ u"br",u"Muniz Freire",8312,-20.466667,-41.416667 ],
    [ u"br",u"Muqui",8614,-20.95,-41.3 ],
    [ u"br",u"Muriaé",91174,-21.133333,-42.366667 ],
    [ u"br",u"Murici",20420,-9.316667,-35.933333 ],
    [ u"br",u"Muritiba",22388,-12.916667,-39.25 ],
    [ u"br",u"Mutuípe",10016,-13.25,-39.516667 ],
    [ u"br",u"Mutum",12582,-19.816667,-41.433333 ],
    [ u"br",u"Muzambinho",16254,-21.366667,-46.533333 ],
    [ u"br",u"Nanuque",37825,-17.833333,-40.35 ],
    [ u"br",u"Não-Me-Toque",12556,-28.466667,-52.816667 ],
    [ u"br",u"Natal",763057,-5.783333,-35.216667 ],
    [ u"br",u"Natividade",12014,-21.05,-41.983333 ],
    [ u"br",u"Natuba",3333,-7.633333,-35.566667 ],
    [ u"br",u"Navegantes",47782,-26.9,-48.65 ],
    [ u"br",u"Naviraí",36453,-23.133333,-54.216667 ],
    [ u"br",u"Nazaré da Mata",26485,-7.733333,-35.233333 ],
    [ u"br",u"Nazaré",25604,-13.033333,-39 ],
    [ u"br",u"Neópolis",12422,-10.3,-36.583333 ],
    [ u"br",u"Nepomuceno",18911,-21.233333,-45.25 ],
    [ u"br",u"Nerópolis",21870,-16.416667,-49.233333 ],
    [ u"br",u"Nhamundá",7772,-2.233333,-56.716667 ],
    [ u"br",u"Nilópolis",147283,-22.808487,-43.419792 ],
    [ u"br",u"Nioaque",6899,-21.133333,-55.8 ],
    [ u"br",u"Niquelândia",27544,-14.45,-48.45 ],
    [ u"br",u"Nísia Floresta",10115,-6.066667,-35.133333 ],
    [ u"br",u"Niterói",456461,-22.90214,-43.130301 ],
    [ u"br",u"Nobres",12010,-14.733333,-56.333333 ],
    [ u"br",u"Nortelândia",9636,-14.416667,-56.8 ],
    [ u"br",u"Nossa Senhora da Glória",18613,-10.233333,-37.416667 ],
    [ u"br",u"Nossa Senhora das Dores",14550,-10.483333,-37.216667 ],
    [ u"br",u"Nossa Senhora do Socorro",163996,-10.866667,-37.116667 ],
    [ u"br",u"Nova Aurora",9013,-22.866667,-52.566667 ],
    [ u"br",u"Nova Cruz",23166,-6.466667,-35.433333 ],
    [ u"br",u"Nova Era",15595,-19.75,-43.05 ],
    [ u"br",u"Nova Esperança",24833,-23.182485,-52.203005 ],
    [ u"br",u"Nova Floresta",8623,-6.45,-36.2 ],
    [ u"br",u"Nova Friburgo",153363,-22.266667,-42.533333 ],
    [ u"br",u"Nova Granada",15716,-20.483333,-49.316667 ],
    [ u"br",u"Nova Iguaçu",1002129,-22.759188,-43.431887 ],
    [ u"br",u"Nova Lima",88400,-19.983333,-43.85 ],
    [ u"br",u"Nova Londrina",11042,-22.75,-53 ],
    [ u"br",u"Nova Odessa",49433,-22.783333,-47.3 ],
    [ u"br",u"Nova Olímpia",19283,-14.816667,-57.333333 ],
    [ u"br",u"Nova Olinda do Norte",12344,-3.75,-59.05 ],
    [ u"br",u"Nova Petrópolis",16050,-29.366667,-51.133333 ],
    [ u"br",u"Nova Prata",17943,-28.783333,-51.6 ],
    [ u"br",u"Nova Russas",21986,-4.7,-40.566667 ],
    [ u"br",u"Nova Serrana",51103,-19.866667,-44.983333 ],
    [ u"br",u"Nova Soure",11340,-11.233333,-38.483333 ],
    [ u"br",u"Nova Venécia",28363,-18.716667,-40.4 ],
    [ u"br",u"Nova Viçosa",56001,-17.883333,-39.366667 ],
    [ u"br",u"Novo Aripuanã",11044,-5.120278,-60.378889 ],
    [ u"br",u"Novo Cruzeiro",10385,-17.483333,-41.883333 ],
    [ u"br",u"Novo Hamburgo",253846,-29.683333,-51.133333 ],
    [ u"br",u"Novo Horizonte",30159,-21.466667,-49.216667 ],
    [ u"br",u"Novo Lino",5538,-9.016667,-35.616667 ],
    [ u"br",u"Nôvo Oriente",14529,-5.533333,-40.766667 ],
    [ u"br",u"Óbidos",24971,-1.908333,-55.518889 ],
    [ u"br",u"Ocara",6793,-4.483333,-38.616667 ],
    [ u"br",u"Oeiras do Pará",10163,-1.966667,-49.85 ],
    [ u"br",u"Oeiras",21071,-7.016667,-42.133333 ],
    [ u"br",u"Olímpia",45200,-20.733333,-48.9 ],
    [ u"br",u"Olinda",366761,-8.016667,-34.85 ],
    [ u"br",u"Olindina",12317,-11.366667,-38.35 ],
    [ u"br",u"Oliveira dos Brejinhos",5596,-12.316667,-42.9 ],
    [ u"br",u"Oliveira",34711,-20.683333,-44.816667 ],
    [ u"br",u"Olivença",2848,-9.516667,-37.183333 ],
    [ u"br",u"Oriximiná",35582,-1.765278,-55.863889 ],
    [ u"br",u"Orizona",7583,-17.05,-48.3 ],
    [ u"br",u"Orlândia",44767,-20.716667,-47.883333 ],
    [ u"br",u"Orleans",16422,-28.35,-49.3 ],
    [ u"br",u"Orobó",5884,-7.733333,-35.6 ],
    [ u"br",u"Orós",16329,-6.25,-38.916667 ],
    [ u"br",u"Ortigueira",11541,-24.2,-50.916667 ],
    [ u"br",u"Osasco",677869,-23.566667,-46.783333 ],
    [ u"br",u"Osório",34628,-29.9,-50.266667 ],
    [ u"br",u"Osvaldo Cruz",25747,-21.783333,-50.833333 ],
    [ u"br",u"Otacílio Costa",14557,-27.566667,-50.116667 ],
    [ u"br",u"Ourém",8145,-1.55,-47.1 ],
    [ u"br",u"Ouricuri",29318,-7.883333,-40.083333 ],
    [ u"br",u"Ourinhos",97801,-22.983333,-49.866667 ],
    [ u"br",u"Ouro Branco",26687,-20.533333,-43.7 ],
    [ u"br",u"Ouro Fino",21076,-28.983333,-52.816667 ],
    [ u"br",u"Ouro Prêto do Oeste",26686,-10.666667,-62.3 ],
    [ u"br",u"Ouro Prêto",63679,-20.383333,-43.5 ],
    [ u"br",u"Pacaembu",10101,-21.566667,-51.283333 ],
    [ u"br",u"Pacajus",41558,-4.166667,-38.466667 ],
    [ u"br",u"Pacatuba",55292,-3.966667,-38.616667 ],
    [ u"br",u"Pacatuba",2616,-10.433333,-36.65 ],
    [ u"br",u"Padre Bernardo",16118,-15.35,-48.5 ],
    [ u"br",u"Padre Paraíso",10608,-17.1,-41.516667 ],
    [ u"br",u"Paiçandu",34365,-23.45,-52.033333 ],
    [ u"br",u"Palhoça",122425,-27.633333,-48.666667 ],
    [ u"br",u"Palmares do Sul",8393,-30.266667,-50.516667 ],
    [ u"br",u"Palmares",41680,-8.683333,-35.6 ],
    [ u"br",u"Palmas de Monte Alto",7091,-14.266667,-43.166667 ],
    [ u"br",u"Palmas",39150,-26.5,-52 ],
    [ u"br",u"Palmas",196332,-10.222778,-48.277778 ],
    [ u"br",u"Palmeira das Missões",30954,-27.916667,-53.283333 ],
    [ u"br",u"Palmeirais",4262,-5.966667,-43.066667 ],
    [ u"br",u"Palmeira",18630,-25.426111,-50.003333 ],
    [ u"br",u"Palmeiras de Goiás",13573,-16.816667,-49.916667 ],
    [ u"br",u"Palmital",18540,-22.783333,-50.2 ],
    [ u"br",u"Palotina",23059,-24.283333,-53.833333 ],
    [ u"br",u"Panambi",30408,-28.3,-53.5 ],
    [ u"br",u"Pancas",8184,-19.233333,-40.85 ],
    [ u"br",u"Panelas",12625,-8.666667,-36.016667 ],
    [ u"br",u"Panorama",14227,-21.35,-51.85 ],
    [ u"br",u"Pão de Açúcar",11497,-9.75,-37.433333 ],
    [ u"br",u"Papagaios",11850,-19.533333,-44.75 ],
    [ u"br",u"Paracambi",36099,-22.608611,-43.712778 ],
    [ u"br",u"Paracatu",70754,-17.216667,-46.866667 ],
    [ u"br",u"Paracuru",21197,-3.4,-39.066667 ],
    [ u"br",u"Pará de Minas",75787,-19.85,-44.616667 ],
    [ u"br",u"Paragominas",69616,-2.966667,-47.483333 ],
    [ u"br",u"Paraguaçu",15742,-21.55,-45.733333 ],
    [ u"br",u"Paraguaçu Paulista",39120,-22.416667,-50.566667 ],
    [ u"br",u"Paraíba do Sul",35518,-22.1575,-43.290556 ],
    [ u"br",u"Paraibano",12364,-6.5,-44.016667 ],
    [ u"br",u"Paraipaba",18424,-3.433333,-39.116667 ],
    [ u"br",u"Paraisópolis",13563,-22.55,-45.783333 ],
    [ u"br",u"Parambu",14656,-6.216667,-40.716667 ],
    [ u"br",u"Paramirim",7421,-13.433333,-42.25 ],
    [ u"br",u"Paranaguá",141014,-25.516667,-48.5 ],
    [ u"br",u"Paranaíba",32218,-19.666667,-51.183333 ],
    [ u"br",u"Paranapanema",16218,-23.383333,-48.716667 ],
    [ u"br",u"Paranã",2751,-12.640556,-47.7925 ],
    [ u"br",u"Paranavaí",72849,-23.066667,-52.466667 ],
    [ u"br",u"Paranhos",6516,-23.916667,-55.416667 ],
    [ u"br",u"Paraopeba",19151,-19.3,-44.416667 ],
    [ u"br",u"Paratinga",10262,-12.7,-43.166667 ],
    [ u"br",u"Parati",15118,-23.216667,-44.716667 ],
    [ u"br",u"Paraúna",9731,-17.033333,-50.433333 ],
    [ u"br",u"Parelhas",16377,-6.683333,-36.65 ],
    [ u"br",u"Parintins",64429,-2.6,-56.733333 ],
    [ u"br",u"Paripiranga",6965,-10.683333,-37.866667 ],
    [ u"br",u"Pariquera-Açu",13436,-24.716667,-47.883333 ],
    [ u"br",u"Parnaíba",138011,-2.909167,-41.774722 ],
    [ u"br",u"Parnamirim",150347,-5.916667,-35.25 ],
    [ u"br",u"Parnamirim",7928,-8.083333,-39.566667 ],
    [ u"br",u"Parnarama",12202,-5.683333,-43.1 ],
    [ u"br",u"Parobé",48560,-29.633333,-50.833333 ],
    [ u"br",u"Passagem Franca",7376,-6.166667,-43.783333 ],
    [ u"br",u"Passa Quatro",12765,-22.383333,-44.966667 ],
    [ u"br",u"Passira",12664,-7.95,-35.633333 ],
    [ u"br",u"Passo de Camaragibe",5523,-9.25,-35.433333 ],
    [ u"br",u"Passo Fundo",179532,-28.266667,-52.4 ],
    [ u"br",u"Passos",98753,-20.716667,-46.616667 ],
    [ u"br",u"Pastos Bons",10469,-6.6,-44.083333 ],
    [ u"br",u"Pato Branco",65754,-26.216667,-52.666667 ],
    [ u"br",u"Patos de Minas",126236,-18.583333,-46.533333 ],
    [ u"br",u"Patos",92577,-7.016667,-37.266667 ],
    [ u"br",u"Patrocínio",71964,-18.95,-46.983333 ],
    [ u"br",u"Patu",8842,-6.1,-37.633333 ],
    [ u"br",u"Pau Brasil",8136,-15.45,-39.65 ],
    [ u"br",u"Pau dos Ferros",25051,-6.116667,-38.166667 ],
    [ u"br",u"Pauini",7633,-7.666667,-66.966667 ],
    [ u"br",u"Paulínia",65596,-22.75,-47.166667 ],
    [ u"br",u"Paulista",3677,-6.583333,-37.616667 ],
    [ u"br",u"Paulista",289977,-7.95,-34.883333 ],
    [ u"br",u"Paulo Afonso",85353,-9.35,-38.233333 ],
    [ u"br",u"Paulo Ramos",8888,-4.216667,-45.183333 ],
    [ u"br",u"Peabiru",12345,-23.9,-52.333333 ],
    [ u"br",u"Peçanha",6903,-18.55,-42.566667 ],
    [ u"br",u"Pederneiras",38020,-22.383333,-48.766667 ],
    [ u"br",u"Pedra Azul",20899,-16.016667,-41.266667 ],
    [ u"br",u"Pedra Branca",20072,-5.45,-39.716667 ],
    [ u"br",u"Pedra",11197,-8.5,-36.95 ],
    [ u"br",u"Pedras de Fogo",13894,-7.383333,-35.116667 ],
    [ u"br",u"Pedregulho",11216,-20.266667,-47.483333 ],
    [ u"br",u"Pedreira",39199,-22.716667,-46.916667 ],
    [ u"br",u"Pedreiras",33909,-4.566667,-44.65 ],
    [ u"br",u"Pedro II",22039,-4.416667,-41.466667 ],
    [ u"br",u"Pedro Leopoldo",49262,-19.633333,-44.05 ],
    [ u"br",u"Pedro Velho",6366,-6.433333,-35.233333 ],
    [ u"br",u"Pelotas",320680,-31.766667,-52.333333 ],
    [ u"br",u"Penalva",17186,-3.3,-45.166667 ],
    [ u"br",u"Penápolis",54478,-21.4,-50.066667 ],
    [ u"br",u"Pendências",9363,-5.263333,-36.723056 ],
    [ u"br",u"Penedo",42099,-10.283333,-36.6 ],
    [ u"br",u"Penha",20097,-26.766667,-48.65 ],
    [ u"br",u"Pentecoste",19681,-3.8,-39.283333 ],
    [ u"br",u"Perdões",17821,-21.083333,-45.083333 ],
    [ u"br",u"Pereira Barreto",22537,-20.633333,-51.116667 ],
    [ u"br",u"Peruíbe",63032,-24.316667,-47 ],
    [ u"br",u"Pesqueira",41896,-8.366667,-36.7 ],
    [ u"br",u"Petrolândia",20575,-9.083333,-38.3 ],
    [ u"br",u"Petrolina de Goiás",7710,-16.1,-49.333333 ],
    [ u"br",u"Petrolina",194653,-9.4,-40.5 ],
    [ u"br",u"Petrópolis",272694,-22.510833,-43.184444 ],
    [ u"br",u"Piaçabuçu",9862,-10.4,-36.416667 ],
    [ u"br",u"Piancó",10482,-7.2,-37.95 ],
    [ u"br",u"Picos",57496,-7.083333,-41.466667 ],
    [ u"br",u"Picuí",10779,-6.516667,-36.35 ],
    [ u"br",u"Piedade",27913,-23.713098,-47.414578 ],
    [ u"br",u"Pilão Arcado",6715,-10.15,-42.433333 ],
    [ u"br",u"Pilar do Sul",19107,-23.816667,-47.7 ],
    [ u"br",u"Pilar",30617,-9.6,-35.933333 ],
    [ u"br",u"Pilar",7588,-7.25,-35.266667 ],
    [ u"br",u"Pimenta Bueno",25785,-11.65,-61.2 ],
    [ u"br",u"Pimenteiras",3819,-6.233333,-41.416667 ],
    [ u"br",u"Pindamonhangaba",132220,-22.916667,-45.466667 ],
    [ u"br",u"Pindobaçu",17242,-10.733333,-40.35 ],
    [ u"br",u"Pindorama",12248,-21.2,-48.916667 ],
    [ u"br",u"Pinhão",15141,-25.716667,-51.633333 ],
    [ u"br",u"Pinheiral",19469,-22.516667,-43.983333 ],
    [ u"br",u"Pinheiro Machado",11176,-31.566667,-53.383333 ],
    [ u"br",u"Pinheiro",38894,-2.516667,-45.083333 ],
    [ u"br",u"Pio IX",4973,-6.833333,-40.616667 ],
    [ u"br",u"Pio XII",14773,-3.883333,-45.283333 ],
    [ u"br",u"Piquete",13845,-22.6,-45.183333 ],
    [ u"br",u"Piracaia",26076,-23.05,-46.35 ],
    [ u"br",u"Piracanjuba",16736,-17.3,-49.016667 ],
    [ u"br",u"Piracicaba",342216,-22.716667,-47.633333 ],
    [ u"br",u"Piracuruca",18852,-3.933333,-41.7 ],
    [ u"br",u"Piraí do Sul",16409,-24.516667,-49.933333 ],
    [ u"br",u"Piraí",19105,-22.627778,-43.901944 ],
    [ u"br",u"Pirajuí",17503,-21.983333,-49.483333 ],
    [ u"br",u"Piraju",25271,-23.2,-49.383333 ],
    [ u"br",u"Piranhas",1170,-9.45,-37.766667 ],
    [ u"br",u"Piranhas",9887,-16.516667,-51.85 ],
    [ u"br",u"Pirapemas",6441,-3.716667,-44.233333 ],
    [ u"br",u"Pirapora do Bom Jesus",14690,-23.4,-47 ],
    [ u"br",u"Pirapora",51657,-17.35,-44.933333 ],
    [ u"br",u"Pirapòzinho",21711,-22.25,-51.5 ],
    [ u"br",u"Piraquara",41162,-25.433333,-49.066667 ],
    [ u"br",u"Pirassununga",60414,-21.983333,-47.416667 ],
    [ u"br",u"Pirenópolis",13615,-15.85,-48.95 ],
    [ u"br",u"Pires do Rio",24823,-17.3,-48.283333 ],
    [ u"br",u"Piripiri",44866,-4.266667,-41.783333 ],
    [ u"br",u"Piritiba",16230,-11.733333,-40.566667 ],
    [ u"br",u"Pirpirituba",8355,-6.766667,-35.5 ],
    [ u"br",u"Pitanga",18652,-24.766667,-51.733333 ],
    [ u"br",u"Pitangueiras",28541,-21.033333,-48.216667 ],
    [ u"br",u"Pitangui",18859,-19.666667,-44.9 ],
    [ u"br",u"Pitimbu",7862,-7.466667,-34.8 ],
    [ u"br",u"Piúma",17634,-20.833333,-40.716667 ],
    [ u"br",u"Plácido de Castro",11950,-10.333333,-67.183333 ],
    [ u"br",u"Planaltina",88855,-15.616667,-47.666667 ],
    [ u"br",u"Poá",107434,-23.533333,-46.333333 ],
    [ u"br",u"Poção de Pedras",12337,-4.75,-44.933333 ],
    [ u"br",u"Pocinhos",7803,-7.066667,-36.05 ],
    [ u"br",u"Poço Branco",7112,-5.633333,-35.666667 ],
    [ u"br",u"Poço das Trincheiras",1775,-9.3,-37.266667 ],
    [ u"br",u"Poções",35255,-14.516667,-40.35 ],
    [ u"br",u"Poconé",21485,-16.259722,-56.626944 ],
    [ u"br",u"Poços de Caldas",146590,-21.8,-46.566667 ],
    [ u"br",u"Poço Verde",12167,-10.7,-38.183333 ],
    [ u"br",u"Pojuca",25102,-12.35,-38.333333 ],
    [ u"br",u"Pombal",21751,-6.766667,-37.783333 ],
    [ u"br",u"Pombos",15895,-8.15,-35.4 ],
    [ u"br",u"Pomerode",21898,-26.75,-49.183333 ],
    [ u"br",u"Pompéia",18015,-22.133333,-50.166667 ],
    [ u"br",u"Pompeu",25278,-19.166667,-45.1 ],
    [ u"br",u"Ponta Grossa",292179,-25.083333,-50.15 ],
    [ u"br",u"Pontal do Paraná",14969,-25.58,-48.354167 ],
    [ u"br",u"Pontalina",13640,-17.516667,-49.45 ],
    [ u"br",u"Pontal",32567,-21.05,-48.083333 ],
    [ u"br",u"Ponta Porã",55765,-22.533333,-55.716667 ],
    [ u"br",u"Ponte Nova",48188,-20.4,-42.9 ],
    [ u"br",u"Pontes e Lacerda",29383,-15.2,-59.366667 ],
    [ u"br",u"Ponto Novo",7141,-10.866667,-40.133333 ],
    [ u"br",u"Porangatu",32758,-13.433333,-49.166667 ],
    [ u"br",u"Porciúncula",12511,-20.966667,-42.033333 ],
    [ u"br",u"Porecatu",11390,-22.716667,-51.4 ],
    [ u"br",u"Portão",21051,-29.7,-51.25 ],
    [ u"br",u"Porteirinha",14144,-15.733333,-43.033333 ],
    [ u"br",u"Portel",21315,-1.95,-50.816667 ],
    [ u"br",u"Porto Alegre",1372763,-30.033333,-51.2 ],
    [ u"br",u"Porto Belo",14722,-27.1575,-48.539722 ],
    [ u"br",u"Pôrto Calvo",17347,-9.066667,-35.4 ],
    [ u"br",u"Pôrto da Fôlha",9420,-9.916667,-37.283333 ],
    [ u"br",u"Pôrto de Moz",9912,-1.75,-52.233333 ],
    [ u"br",u"Porto Feliz",41016,-23.213333,-47.523056 ],
    [ u"br",u"Pôrto Ferreira",49128,-21.85,-47.466667 ],
    [ u"br",u"Pôrto Franco",14874,-6.333333,-47.4 ],
    [ u"br",u"Pôrto Murtinho",12672,-21.7,-57.866667 ],
    [ u"br",u"Porto Nacional",40862,-10.708056,-48.308333 ],
    [ u"br",u"Pôrto",6535,-3.9,-42.7 ],
    [ u"br",u"Pôrto Real do Colégio",6001,-10.183333,-36.816667 ],
    [ u"br",u"Porto Real",12061,-22.4172,-44.2861 ],
    [ u"br",u"Pôrto Seguro",123196,-16.433333,-39.083333 ],
    [ u"br",u"Pôrto União",28907,-26.25,-51.083333 ],
    [ u"br",u"Pôrto Velho",306206,-8.766667,-63.9 ],
    [ u"br",u"Pôrto Walter",1816,-8.261111,-72.738889 ],
    [ u"br",u"Posse",20003,-14.083333,-46.366667 ],
    [ u"br",u"Pouso Alegre",115203,-22.216667,-45.933333 ],
    [ u"br",u"Pradópolis",13193,-21.366667,-48.066667 ],
    [ u"br",u"Prado",15466,-17.35,-39.216667 ],
    [ u"br",u"Praia Grande",250032,-24,-46.4 ],
    [ u"br",u"Prainha",6481,-1.8,-53.483333 ],
    [ u"br",u"Prata",19896,-19.3,-48.916667 ],
    [ u"br",u"Presidente Bernardes",12954,-22.05,-51.55 ],
    [ u"br",u"Presidente Dutra",30330,-5.25,-44.5 ],
    [ u"br",u"Presidente Epitácio",38742,-21.766667,-52.1 ],
    [ u"br",u"Presidente Médici",11923,-11.283333,-61.916667 ],
    [ u"br",u"Presidente Olegário",13587,-18.416667,-46.416667 ],
    [ u"br",u"Presidente Prudente",209507,-22.116667,-51.366667 ],
    [ u"br",u"Presidente Venceslau",34026,-21.866667,-51.833333 ],
    [ u"br",u"Princesa Isabel",12616,-7.733333,-38 ],
    [ u"br",u"Promissão",27032,-21.533333,-49.866667 ],
    [ u"br",u"Propriá",23787,-10.216667,-36.85 ],
    [ u"br",u"Prudentópolis",19611,-25.2,-50.95 ],
    [ u"br",u"Puxinanã",3210,-7.15,-35.966667 ],
    [ u"br",u"Quaraí",23229,-30.383333,-56.45 ],
    [ u"br",u"Quatá",10370,-22.266667,-50.7 ],
    [ u"br",u"Quatis",10289,-22.4099,-44.2594 ],
    [ u"br",u"Quatro Barras",17526,-25.366667,-49.083333 ],
    [ u"br",u"Quebrângulo",6587,-9.333333,-36.483333 ],
    [ u"br",u"Queimadas",10439,-10.966667,-39.633333 ],
    [ u"br",u"Queimadas",20446,-7.35,-35.916667 ],
    [ u"br",u"Queimados",135742,-22.722897,-43.556316 ],
    [ u"br",u"Quijingue",4293,-10.75,-39.2 ],
    [ u"br",u"Quipapá",11533,-8.833333,-36.033333 ],
    [ u"br",u"Quirinópolis",32104,-18.533333,-50.5 ],
    [ u"br",u"Quixadá",49328,-4.966667,-39.016667 ],
    [ u"br",u"Quixeramobim",34322,-5.2,-39.283333 ],
    [ u"br",u"Quixeré",11258,-5.083333,-37.983333 ],
    [ u"br",u"Rancharia",25531,-22.25,-50.916667 ],
    [ u"br",u"Raposa",11883,-6.516667,-44.183333 ],
    [ u"br",u"Raposos",13263,-19.95,-43.8 ],
    [ u"br",u"Raul Soares",13210,-20.083333,-42.366667 ],
    [ u"br",u"Realeza",10389,-25.783333,-53.516667 ],
    [ u"br",u"Recife",1478118,-8.05,-34.9 ],
    [ u"br",u"Recreio",8882,-21.533333,-42.466667 ],
    [ u"br",u"Redenção",14174,-4.216667,-38.716667 ],
    [ u"br",u"Regeneração",13608,-6.25,-42.683333 ],
    [ u"br",u"Regente Feijó",17219,-22.25,-51.333333 ],
    [ u"br",u"Registro",45698,-24.5,-47.833333 ],
    [ u"br",u"Remanso",22780,-9.683333,-42.066667 ],
    [ u"br",u"Remígio",9659,-6.933333,-35.783333 ],
    [ u"br",u"Reriutaba",12076,-4.166667,-40.583333 ],
    [ u"br",u"Resende",111515,-22.4679,-44.4575 ],
    [ u"br",u"Reserva",11097,-24.633333,-50.866667 ],
    [ u"br",u"Resplendor",15131,-19.333333,-41.25 ],
    [ u"br",u"Riachão das Neves",11236,-11.766667,-44.933333 ],
    [ u"br",u"Riachão do Dantas",4615,-11.066667,-37.733333 ],
    [ u"br",u"Riachão do Jacuípe",16911,-11.8,-39.35 ],
    [ u"br",u"Riachão",12428,-7.366667,-46.616667 ],
    [ u"br",u"Riacho de Santana",12658,-13.616667,-42.95 ],
    [ u"br",u"Rialma",9270,-15.3,-49.566667 ],
    [ u"br",u"Ribas do Rio Pardo",11935,-20.45,-53.766667 ],
    [ u"br",u"Ribeira do Pombal",28236,-10.833333,-38.533333 ],
    [ u"br",u"Ribeirão Bonito",10877,-22.066667,-48.166667 ],
    [ u"br",u"Ribeirão Branco",9718,-24.216667,-48.783333 ],
    [ u"br",u"Ribeirão das Neves",406840,-19.783333,-44.1 ],
    [ u"br",u"Ribeirão do Pinhal",11275,-23.4,-50.3 ],
    [ u"br",u"Ribeirão Pires",111890,-23.716667,-46.416667 ],
    [ u"br",u"Ribeirão Prêto",551278,-21.166667,-47.8 ],
    [ u"br",u"Ribeirão",29819,-8.516667,-35.383333 ],
    [ u"br",u"Ribeirópolis",11215,-10.533333,-37.433333 ],
    [ u"br",u"Rio Bananal",4814,-19.266667,-40.333333 ],
    [ u"br",u"Rio Bonito",35997,-22.716667,-42.616667 ],
    [ u"br",u"Rio Branco do Sul",26441,-25.166667,-49.3 ],
    [ u"br",u"Rio Branco",257645,-9.966667,-67.8 ],
    [ u"br",u"Rio Brilhante",18837,-21.8,-54.55 ],
    [ u"br",u"Rio Casca",11769,-20.216667,-42.65 ],
    [ u"br",u"Rio Claro",12620,-22.716667,-44.15 ],
    [ u"br",u"Rio Claro",180151,-22.4,-47.55 ],
    [ u"br",u"Rio das Ostras",46619,-22.533333,-41.95 ],
    [ u"br",u"Rio das Pedras",23722,-22.833333,-47.6 ],
    [ u"br",u"Rio de Janeiro",6023742,-22.9,-43.233333 ],
    [ u"br",u"Rio do Sul",51945,-27.2181,-49.6436 ],
    [ u"br",u"Rio Formoso",15518,-8.666667,-35.15 ],
    [ u"br",u"Rio Grande da Serra",38162,-23.8,-46.333333 ],
    [ u"br",u"Rio Grande",187842,-32.033333,-52.083333 ],
    [ u"br",u"Rio Largo",63389,-9.483333,-35.85 ],
    [ u"br",u"Rio Negrinho",41915,-26.239449,-49.499857 ],
    [ u"br",u"Rio Negro",23007,-26.0934,-49.7895 ],
    [ u"br",u"Rio Novo do Sul",6717,-20.866667,-40.933333 ],
    [ u"br",u"Rio Novo",6258,-21.483333,-43.133333 ],
    [ u"br",u"Rio Pardo de Minas",9540,-15.616667,-42.55 ],
    [ u"br",u"Rio Pardo",26999,-29.983333,-52.366667 ],
    [ u"br",u"Rio Piracicaba",10439,-19.916667,-43.183333 ],
    [ u"br",u"Rio Pomba",13707,-21.283333,-43.183333 ],
    [ u"br",u"Rio Real",24006,-11.466667,-37.933333 ],
    [ u"br",u"Rio Tinto",11804,-6.8,-35.083333 ],
    [ u"br",u"Rio Verde de Mato Grosso",16613,-18.933333,-54.866667 ],
    [ u"br",u"Rodrigues Alves",3827,-11.9,-65 ],
    [ u"br",u"Rolândia",51005,-23.3,-51.366667 ],
    [ u"br",u"Rolante",15594,-29.666667,-50.566667 ],
    [ u"br",u"Rolim de Moura",37953,-13.083333,-62.266667 ],
    [ u"br",u"Rondonópolis",152921,-16.466667,-54.633333 ],
    [ u"br",u"Rosário do Sul",36722,-30.25,-54.916667 ],
    [ u"br",u"Rosário Oeste",10469,-14.833333,-56.416667 ],
    [ u"br",u"Rosário",23271,-2.95,-44.233333 ],
    [ u"br",u"Rubiataba",16128,-15.133333,-49.8 ],
    [ u"br",u"Russas",39465,-4.933333,-37.966667 ],
    [ u"br",u"Ruy Barbosa",21093,-12.3,-40.45 ],
    [ u"br",u"Sabará",158359,-19.9,-43.8 ],
    [ u"br",u"Sabinópolis",9713,-18.666667,-43.1 ],
    [ u"br",u"Sacramento",16983,-19.883333,-47.45 ],
    [ u"br",u"Salgado de São Félix",4266,-7.35,-35.433333 ],
    [ u"br",u"Salgado",5457,-11.033333,-37.466667 ],
    [ u"br",u"Salgueiro",42153,-8.066667,-39.1 ],
    [ u"br",u"Salinas",25747,-16.166667,-42.283333 ],
    [ u"br",u"Salinópolis",40999,-.616667,-47.333333 ],
    [ u"br",u"Salto de Pirapora",32228,-23.6494,-47.5715 ],
    [ u"br",u"Salto",98389,-23.2,-47.283333 ],
    [ u"br",u"Salvador",2711903,-12.983333,-38.516667 ],
    [ u"br",u"Sananduva",9601,-27.95,-51.8 ],
    [ u"br",u"Santa Adélia",12585,-21.266667,-48.8 ],
    [ u"br",u"Santa Bárbara",19991,-19.933333,-43.4 ],
    [ u"br",u"Santa Branca",8661,-23.4,-45.883333 ],
    [ u"br",u"Santa Cecília",15092,-26.933333,-50.45 ],
    [ u"br",u"Santa Cruz Cabrália",19549,-16.283333,-39.033333 ],
    [ u"br",u"Santa Cruz das Palmeiras",25801,-21.816667,-47.25 ],
    [ u"br",u"Santa Cruz do Capibaribe",76451,-7.95,-36.2 ],
    [ u"br",u"Santa Cruz do Rio Pardo",37336,-22.916667,-49.616667 ],
    [ u"br",u"Santa Cruz do Sul",106115,-29.716667,-52.433333 ],
    [ u"br",u"Santa Cruz",27776,-6.216667,-36.016667 ],
    [ u"br",u"Santa Fé do Sul",25802,-20.216667,-50.933333 ],
    [ u"br",u"Santa Gertrudes",18490,-22.466667,-47.516667 ],
    [ u"br",u"Santa Helena de Goiás",34254,-17.716667,-50.583333 ],
    [ u"br",u"Santa Helena",16045,-2.233333,-45.3 ],
    [ u"br",u"Santa Inês",10521,-13.283333,-39.8 ],
    [ u"br",u"Santa Inês",67426,-3.65,-45.366667 ],
    [ u"br",u"Santa Isabel do Pará",39284,-1.266667,-48.183333 ],
    [ u"br",u"Santa Isabel do Rio Negro",4142,-.4,-65.033333 ],
    [ u"br",u"Santa Isabel",33709,-23.3158,-46.2241 ],
    [ u"br",u"Santa Leopoldina",2327,-20.1,-40.533333 ],
    [ u"br",u"Santa Luzia",22910,-7.633333,-47.2 ],
    [ u"br",u"Santa Luzia",243506,-19.783333,-43.866667 ],
    [ u"br",u"Santa Luzia",13243,-6.883333,-36.933333 ],
    [ u"br",u"Santa Maria da Boa Vista",14695,-8.816667,-39.816667 ],
    [ u"br",u"Santa Maria da Vitória",23489,-13.4,-44.2 ],
    [ u"br",u"Santa Maria do Pará",12915,-1.35,-47.566667 ],
    [ u"br",u"Santa Maria do Suaçuí",9936,-18.2,-42.416667 ],
    [ u"br",u"Santa Maria",249224,-29.683333,-53.8 ],
    [ u"br",u"Santana de Parnaíba",98991,-23.45,-46.916667 ],
    [ u"br",u"Santana do Acaraú",14707,-3.45,-40.2 ],
    [ u"br",u"Santana do Ipanema",26147,-9.366667,-37.233333 ],
    [ u"br",u"Santana do Livramento",89696,-30.883333,-55.516667 ],
    [ u"br",u"Santana do Matos",8050,-5.956111,-36.652778 ],
    [ u"br",u"Santana do Mundaú",6439,-9.15,-36.183333 ],
    [ u"br",u"Santana do Paraíso",25537,-19.366667,-42.533333 ],
    [ u"br",u"Santana",12629,-14.466667,-41.8 ],
    [ u"br",u"Santa Quitéria do Maranhão",17180,-3.516667,-42.533333 ],
    [ u"br",u"Santa Quitéria",24391,-4.333333,-40.166667 ],
    [ u"br",u"Santarém",189053,-2.433333,-54.7 ],
    [ u"br",u"Santa Rita do Passa Quatro",24579,-21.7,-47.466667 ],
    [ u"br",u"Santa Rita do Sapucaí",28766,-22.25,-45.7 ],
    [ u"br",u"Santa Rita",13226,-3.833333,-43.883333 ],
    [ u"br",u"Santa Rita",119895,-7.133333,-34.966667 ],
    [ u"br",u"Santa Rosa de Viterbo",21473,-21.466667,-47.35 ],
    [ u"br",u"Santa Rosa",58958,-27.866667,-54.483333 ],
    [ u"br",u"Santa Teresa",9160,-19.916667,-40.6 ],
    [ u"br",u"Santa Vitória do Palmar",27776,-33.516667,-53.35 ],
    [ u"br",u"Santa Vitória",11657,-18.833333,-50.133333 ],
    [ u"br",u"Santiago",46612,-29.183333,-54.883333 ],
    [ u"br",u"Santo Amaro da Imperatriz",18420,-27.683333,-48.766667 ],
    [ u"br",u"Santo Amaro das Brotas",9302,-10.783333,-37.066667 ],
    [ u"br",u"Santo Amaro",46749,-12.533333,-38.716667 ],
    [ u"br",u"Santo Anastácio",17233,-21.966667,-51.65 ],
    [ u"br",u"Santo André",662387,-23.666667,-46.516667 ],
    [ u"br",u"Santo Ângelo",64607,-28.3,-54.266667 ],
    [ u"br",u"Santo Antônio da Platina",35260,-23.2942,-50.075 ],
    [ u"br",u"Santo Antônio de Jesus",73959,-12.966667,-39.266667 ],
    [ u"br",u"Santo Antônio de Pádua",33076,-21.533333,-42.183333 ],
    [ u"br",u"Santo Antônio de Posse",18149,-22.6,-46.916667 ],
    [ u"br",u"Santo Antônio do Amparo",16730,-20.95,-44.916667 ],
    [ u"br",u"Santo Antônio do Içá",9302,-3.083333,-67.95 ],
    [ u"br",u"Santo Antônio do Leverger",6387,-15.866667,-56.083333 ],
    [ u"br",u"Santo Antônio do Monte",22592,-20.083333,-45.283333 ],
    [ u"br",u"Santo Antônio do Sudoeste",11723,-26.068889,-53.725278 ],
    [ u"br",u"Santo Antônio do Tauá",8921,-1.183333,-48.133333 ],
    [ u"br",u"Santo Antônio",12529,-6.3,-35.45 ],
    [ u"br",u"Santo Augusto",10305,-27.85,-53.783333 ],
    [ u"br",u"Santo Estêvão",27280,-12.433333,-39.216667 ],
    [ u"br",u"Santos Dumont",41582,-21.466667,-43.566667 ],
    [ u"br",u"Santos",411411,-23.95,-46.333333 ],
    [ u"br",u"São Benedito do Rio Prêto",12081,-3.333333,-43.583333 ],
    [ u"br",u"São Bento do Sul",77598,-26.249722,-49.3825 ],
    [ u"br",u"São Bento do Una",24506,-8.533333,-36.366667 ],
    [ u"br",u"São Bento",17245,-2.7,-44.833333 ],
    [ u"br",u"São Bento",24749,-6.283333,-37.75 ],
    [ u"br",u"São Bernardo do Campo",743386,-23.7,-46.55 ],
    [ u"br",u"São Bernardo",11171,-3.366667,-42.4 ],
    [ u"br",u"São Borja",59614,-28.65,-56 ],
    [ u"br",u"São Caetano de Odivelas",8862,-.75,-48.033333 ],
    [ u"br",u"São Caetano do Sul",136456,-23.6,-46.566667 ],
    [ u"br",u"São Caitano",25259,-8.35,-36.1 ],
    [ u"br",u"São Carlos",205039,-22.016667,-47.9 ],
    [ u"br",u"São Cristóvão",71540,-11.016667,-37.2 ],
    [ u"br",u"São Desidério",7295,-12.366667,-44.966667 ],
    [ u"br",u"São Domingos do Maranhão",18275,-5.7,-44.366667 ],
    [ u"br",u"São Domingos do Prata",9466,-19.866667,-42.966667 ],
    [ u"br",u"São Domingos",4784,-13.4,-46.316667 ],
    [ u"br",u"São Felipe",9574,-14.816667,-41.383333 ],
    [ u"br",u"São Félix do Xingu",16478,-6.633333,-51.983333 ],
    [ u"br",u"São Fidélis",27793,-21.65,-41.733333 ],
    [ u"br",u"São Francisco de Assis",14305,-29.55,-55.133333 ],
    [ u"br",u"São Francisco de Paula",13292,-29.45,-50.583333 ],
    [ u"br",u"São Francisco do Conde",24615,-12.65,-38.683333 ],
    [ u"br",u"São Francisco do Sul",36225,-26.233333,-48.65 ],
    [ u"br",u"São Francisco",33033,-15.95,-44.866667 ],
    [ u"br",u"São Gabriel da Cachoeira",15232,-.133333,-67.083333 ],
    [ u"br",u"São Gabriel",55435,-30.333333,-54.316667 ],
    [ u"br",u"São Geraldo do Araguaia",12925,-6.4,-48.533333 ],
    [ u"br",u"São Gonçalo do Amarante",23583,-3.6,-38.966667 ],
    [ u"br",u"São Gonçalo do Amarante",10381,-5.766667,-35.333333 ],
    [ u"br",u"São Gonçalo do Sapucaí",19487,-21.9,-45.6 ],
    [ u"br",u"São Gonçalo dos Campos",14822,-12.416667,-38.966667 ],
    [ u"br",u"São Gonçalo",939101,-22.800278,-43.025556 ],
    [ u"br",u"São Gotardo",34145,-19.316667,-46.05 ],
    [ u"br",u"São Jerônimo",17057,-29.966667,-51.716667 ],
    [ u"br",u"São João Batista",3634,-2.966667,-44.85 ],
    [ u"br",u"São João Batista",14539,-27.266667,-48.833333 ],
    [ u"br",u"São João da Barra",20606,-21.633333,-41.05 ],
    [ u"br",u"São João da Boa Vista",76541,-21.966667,-46.783333 ],
    [ u"br",u"São João da Ponte",8373,-15.933333,-44.016667 ],
    [ u"br",u"São João del Rei",78593,-21.15,-44.266667 ],
    [ u"br",u"São João de Meriti",454855,-22.798614,-43.360894 ],
    [ u"br",u"São João de Pirabas",10065,-.766667,-47.166667 ],
    [ u"br",u"São João do Paraíso",8859,-15.316667,-42.016667 ],
    [ u"br",u"São João do Piauí",12689,-8.35,-42.25 ],
    [ u"br",u"São João dos Patos",19539,-6.5,-43.7 ],
    [ u"br",u"São João Evangelista",10049,-18.533333,-42.75 ],
    [ u"br",u"São João Nepomuceno",23155,-21.55,-43.016667 ],
    [ u"br",u"São João",6926,-8.866667,-36.366667 ],
    [ u"br",u"São Joaquim da Barra",42720,-20.583333,-47.883333 ],
    [ u"br",u"São Joaquim de Bicas",14630,-20.05,-44.283333 ],
    [ u"br",u"São Joaquim do Monte",13520,-8.416667,-35.85 ],
    [ u"br",u"São Joaquim",16250,-28.3,-49.933333 ],
    [ u"br",u"São José da Coroa Grande",11512,-8.9,-35.15 ],
    [ u"br",u"São José da Laje",12811,-9,-36.033333 ],
    [ u"br",u"São José da Tapera",12392,-9.633333,-37.383333 ],
    [ u"br",u"São José de Mipibu",15317,-6.083333,-35.25 ],
    [ u"br",u"São José de Piranhas",7628,-7.116667,-38.5 ],
    [ u"br",u"São José de Ribamar",27777,-2.55,-44.05 ],
    [ u"br",u"São José do Belmonte",14211,-7.866667,-38.766667 ],
    [ u"br",u"São José do Calçado",7442,-21.033333,-41.666667 ],
    [ u"br",u"São José do Campestre",10254,-6.3,-35.7 ],
    [ u"br",u"São José do Egito",18219,-7.466667,-37.266667 ],
    [ u"br",u"São José do Rio Pardo",46990,-21.6,-46.9 ],
    [ u"br",u"São José do Rio Prêto",374706,-20.8,-49.383333 ],
    [ u"br",u"São José dos Campos",613776,-23.183333,-45.883333 ],
    [ u"br",u"São José dos Pinhais",229988,-25.516667,-49.216667 ],
    [ u"br",u"São José",203142,-27.633333,-48.65 ],
    [ u"br",u"São Leopoldo",209233,-29.766667,-51.15 ],
    [ u"br",u"São Lourenço da Mata",88417,-8,-35.05 ],
    [ u"br",u"São Lourenço da Serra",13331,-23.866667,-46.95 ],
    [ u"br",u"São Lourenço do Oeste",14872,-26.4,-52.766667 ],
    [ u"br",u"São Lourenço do Sul",25341,-31.366667,-51.966667 ],
    [ u"br",u"São Lourenço",41144,-22.116667,-45.05 ],
    [ u"br",u"São Luís de Montes Belos",23619,-16.533333,-50.333333 ],
    [ u"br",u"São Luís do Quitunde",20564,-9.333333,-35.55 ],
    [ u"br",u"São Luís",917252,-2.516667,-44.266667 ],
    [ u"br",u"São Luiz Gonzaga",31798,-28.4,-54.966667 ],
    [ u"br",u"São Manuel",33588,-22.733333,-48.566667 ],
    [ u"br",u"São Marcos",18591,-28.966667,-51.066667 ],
    [ u"br",u"São Mateus do Maranhão",28234,-4.033333,-44.466667 ],
    [ u"br",u"São Mateus do Sul",24904,-25.866667,-50.383333 ],
    [ u"br",u"São Mateus",77119,-18.733333,-39.85 ],
    [ u"br",u"São Miguel do Araguaia",18810,-13.316667,-50.216667 ],
    [ u"br",u"São Miguel do Guamá",28266,-1.616667,-47.45 ],
    [ u"br",u"São Miguel do Iguaçu",15434,-25.35,-54.166667 ],
    [ u"br",u"São Miguel do Oeste",27360,-26.75,-53.566667 ],
    [ u"br",u"São Miguel dos Campos",40891,-9.783333,-36.083333 ],
    [ u"br",u"São Miguel do Tapuio",7964,-5.5,-41.333333 ],
    [ u"br",u"São Miguel",12838,-5.466667,-35.366667 ],
    [ u"br",u"São Paulo de Olivença",11763,-3.45,-68.8 ],
    [ u"br",u"São Paulo do Potengi",9334,-5.916667,-35.75 ],
    [ u"br",u"São Paulo",10021437,-23.473293,-46.665803 ],
    [ u"br",u"São Pedro da Aldeia",55014,-22.85,-42.1 ],
    [ u"br",u"São Pedro do Piauí",7408,-5.933333,-42.716667 ],
    [ u"br",u"São Pedro do Sul",12137,-29.616667,-54.166667 ],
    [ u"br",u"São Pedro",27068,-22.55,-47.9 ],
    [ u"br",u"São Raimundo das Mangabeiras",10216,-7.016667,-45.483333 ],
    [ u"br",u"São Raimundo Nonato",19569,-9.016667,-42.7 ],
    [ u"br",u"São Roque",50541,-23.528458,-47.135273 ],
    [ u"br",u"São Sebastião do Caí",19013,-29.583333,-51.383333 ],
    [ u"br",u"São Sebastião do Paraíso",57239,-20.916667,-47 ],
    [ u"br",u"São Sebastião do Passé",31050,-12.516667,-38.466667 ],
    [ u"br",u"São Sebastião",9551,-9.933333,-36.566667 ],
    [ u"br",u"São Sebastião",76369,-23.8,-45.416667 ],
    [ u"br",u"São Sepé",19182,-30.166667,-53.566667 ],
    [ u"br",u"São Simão",12351,-21.5,-47.55 ],
    [ u"br",u"São Tomé",6137,-5.971389,-36.073611 ],
    [ u"br",u"São Vicente",324464,-23.966667,-46.383333 ],
    [ u"br",u"Sapé",36149,-7.1,-35.216667 ],
    [ u"br",u"Sapiranga",76053,-29.633333,-51 ],
    [ u"br",u"Sapucaia",12329,-22,-42.9 ],
    [ u"br",u"Sapucaia",130939,-29.833333,-51.15 ],
    [ u"br",u"Saquarema",62057,-22.933333,-42.5 ],
    [ u"br",u"Sarandi",84698,-23.433333,-51.866667 ],
    [ u"br",u"Sarandi",15159,-27.933333,-52.916667 ],
    [ u"br",u"Sarzedo",20800,-20.033333,-44.15 ],
    [ u"br",u"Satuba",15898,-9.566667,-35.816667 ],
    [ u"br",u"Saubara",15669,-12.75,-38.75 ],
    [ u"br",u"Schroeder",15515,-26.433333,-49.066667 ],
    [ u"br",u"Seabra",16765,-12.416667,-41.766667 ],
    [ u"br",u"Seara",10976,-27.116667,-52.283333 ],
    [ u"br",u"Senador Canedo",61801,-16.716667,-49.083333 ],
    [ u"br",u"Senador Guiomard",11727,-10.166667,-67.833333 ],
    [ u"br",u"Senador José Porfírio",5708,-2.583333,-51.916667 ],
    [ u"br",u"Senador Pompeu",16516,-5.583333,-39.366667 ],
    [ u"br",u"Sena Madureira",20516,-9.066667,-68.666667 ],
    [ u"br",u"Sengés",14868,-24.1,-49.483333 ],
    [ u"br",u"Senhor do Bonfim",48472,-10.45,-40.183333 ],
    [ u"br",u"Sento Sé",19596,-9.666667,-41.3 ],
    [ u"br",u"Seropédica",54846,-22.747222,-43.716944 ],
    [ u"br",u"Serra Branca",8765,-6.533333,-38.266667 ],
    [ u"br",u"Serrana",39826,-21.233333,-47.6 ],
    [ u"br",u"Serra Negra",22632,-22.6,-46.7 ],
    [ u"br",u"Serra",394160,-20.116667,-40.3 ],
    [ u"br",u"Serra Talhada",51204,-7.983333,-38.3 ],
    [ u"br",u"Serrinha",49079,-11.65,-39 ],
    [ u"br",u"Sêrro",12616,-18.616667,-43.383333 ],
    [ u"br",u"Sertânia",18190,-8.083333,-37.266667 ],
    [ u"br",u"Sertanópolis",13904,-23.066667,-51.033333 ],
    [ u"br",u"Sertãozinho",99213,-21.133333,-47.983333 ],
    [ u"br",u"Sete Lagoas",201337,-19.45,-44.233333 ],
    [ u"br",u"Severiano Melo",2503,-5.766667,-37.95 ],
    [ u"br",u"Severínia",13212,-20.833333,-48.8 ],
    [ u"br",u"Siderópolis",8536,-28.583333,-49.433333 ],
    [ u"br",u"Sidrolândia",16878,-20.916667,-54.966667 ],
    [ u"br",u"Silva Jardim",16889,-22.466667,-42.3 ],
    [ u"br",u"Silvânia",11377,-16.666667,-48.6 ],
    [ u"br",u"Simão Dias",18386,-10.733333,-37.816667 ],
    [ u"br",u"Simões",4332,-7.6,-40.816667 ],
    [ u"br",u"Simplício Mendes",7076,-7.85,-41.9 ],
    [ u"br",u"Sítio Novo do Tocantins",5787,-5.518333,-47.461111 ],
    [ u"br",u"Sobradinho",19304,-12.5,-39.116667 ],
    [ u"br",u"Sobradinho",13397,-29.4,-53.05 ],
    [ u"br",u"Sobral",157998,-3.7,-40.35 ],
    [ u"br",u"Socorro",24272,-22.6,-46.533333 ],
    [ u"br",u"Solânea",17031,-6.75,-35.65 ],
    [ u"br",u"Soledade",8090,-7.05,-36.35 ],
    [ u"br",u"Soledade",24791,-28.833333,-52.5 ],
    [ u"br",u"Sombrio",14864,-29.116667,-49.666667 ],
    [ u"br",u"Sorocaba",558874,-23.483333,-47.45 ],
    [ u"br",u"Soure",18212,-.733333,-48.516667 ],
    [ u"br",u"Sousa",47927,-6.75,-38.233333 ],
    [ u"br",u"Sumaré",227982,-22.8,-47.283333 ],
    [ u"br",u"Sumé",10441,-7.65,-36.916667 ],
    [ u"br",u"Surubim",34581,-7.833333,-35.75 ],
    [ u"br",u"Suzano",283319,-23.533333,-46.333333 ],
    [ u"br",u"Tabatinga",28230,-4.240833,-69.942222 ],
    [ u"br",u"Tabatinga",11617,-21.716667,-48.683333 ],
    [ u"br",u"Tabira",16926,-7.583333,-37.55 ],
    [ u"br",u"Taboão da Serra",214527,-23.6,-46.766667 ],
    [ u"br",u"Tabuleiro do Norte",16633,-5.25,-38.116667 ],
    [ u"br",u"Taguatinga",9330,-12.465556,-46.366944 ],
    [ u"br",u"Taiobeiras",24351,-15.816667,-42.233333 ],
    [ u"br",u"Taipu",4606,-5.616667,-35.6 ],
    [ u"br",u"Tamandaré",17954,-8.75,-35.1 ],
    [ u"br",u"Tambaú",19957,-21.7,-47.266667 ],
    [ u"br",u"Tamboril",14292,-4.833333,-40.333333 ],
    [ u"br",u"Tanabi",18228,-20.616667,-49.616667 ],
    [ u"br",u"Tangará",8067,-6.183333,-35.816667 ],
    [ u"br",u"Tanguá",23740,-22.733333,-42.716667 ],
    [ u"br",u"Tanhaçu",6620,-14.016667,-41.283333 ],
    [ u"br",u"Tapauá",13211,-5.620278,-63.1875 ],
    [ u"br",u"Tapejara",10726,-23.683333,-52.883333 ],
    [ u"br",u"Tapejara",14064,-28.066667,-52 ],
    [ u"br",u"Taperoá",8095,-13.516667,-39.1 ],
    [ u"br",u"Taperoá",8879,-7.2,-36.816667 ],
    [ u"br",u"Tapes",18570,-30.666667,-51.383333 ],
    [ u"br",u"Tapiramutá",16549,-11.85,-40.783333 ],
    [ u"br",u"Taquarana",5288,-9.633333,-36.483333 ],
    [ u"br",u"Taquara",48052,-29.65,-50.783333 ],
    [ u"br",u"Taquari",27108,-29.8,-51.85 ],
    [ u"br",u"Taquaritinga do Norte",13379,-7.9,-36.05 ],
    [ u"br",u"Taquaritinga",50099,-21.4,-48.5 ],
    [ u"br",u"Taquarituba",21493,-23.516667,-49.25 ],
    [ u"br",u"Tarauacá",16526,-8.166667,-70.766667 ],
    [ u"br",u"Tarumã",10337,-22.75,-50.566667 ],
    [ u"br",u"Tatuí",93582,-23.346655,-47.848368 ],
    [ u"br",u"Tauá",29189,-5.966667,-40.3 ],
    [ u"br",u"Taubaté",251647,-23.033333,-45.55 ],
    [ u"br",u"Tavares",4939,-7.633333,-37.9 ],
    [ u"br",u"Tefé",44943,-3.366667,-64.7 ],
    [ u"br",u"Teixeira",9954,-7.216667,-37.25 ],
    [ u"br",u"Telêmaco Borba",58880,-24.35,-50.616667 ],
    [ u"br",u"Teodoro Sampaio",15193,-22.516667,-52.166667 ],
    [ u"br",u"Teófilo Otoni",101172,-17.85,-41.5 ],
    [ u"br",u"Terenos",6086,-20.433333,-54.833333 ],
    [ u"br",u"Teresina",744526,-5.083333,-42.816667 ],
    [ u"br",u"Teresópolis",123980,-22.424064,-42.968013 ],
    [ u"br",u"Terra Boa",12958,-23.75,-52.45 ],
    [ u"br",u"Terra Nova",11169,-12.366667,-40.666667 ],
    [ u"br",u"Terra Rica",10346,-22.716667,-52.633333 ],
    [ u"br",u"Terra Roxa",10911,-23.855708,-50.031397 ],
    [ u"br",u"Terra Santa",13512,-2.1,-56.483333 ],
    [ u"br",u"Teutônia",21834,-29.433333,-51.8 ],
    [ u"br",u"Tianguá",45697,-3.733333,-40.983333 ],
    [ u"br",u"Tibagi",12644,-24.5,-50.4 ],
    [ u"br",u"Tietê",32062,-23.100174,-47.714392 ],
    [ u"br",u"Tijucas",22482,-27.241111,-48.631389 ],
    [ u"br",u"Timbaúba",45122,-7.516667,-35.316667 ],
    [ u"br",u"Timbiras",17875,-4.25,-43.95 ],
    [ u"br",u"Timbó",33766,-26.833333,-49.3 ],
    [ u"br",u"Timon",124429,-5.1,-42.816667 ],
    [ u"br",u"Timóteo",91723,-19.583333,-42.666667 ],
    [ u"br",u"Tiradentes",4439,-21.116667,-44.183333 ],
    [ u"br",u"Tobias Barreto",29741,-11.183333,-38.016667 ],
    [ u"br",u"Tocantinópolis",23383,-6.324444,-47.277778 ],
    [ u"br",u"Tocantins",12876,-21.166667,-43.033333 ],
    [ u"br",u"Toledo",97846,-24.733333,-53.75 ],
    [ u"br",u"Tomar do Geru",4394,-11.383333,-37.85 ],
    [ u"br",u"Tomé-Açu",34054,-2.416667,-48.15 ],
    [ u"br",u"Tonantins",4561,-2.783333,-67.783333 ],
    [ u"br",u"Toritama",23941,-8.016667,-36.066667 ],
    [ u"br",u"Tôrres",32791,-29.35,-49.733333 ],
    [ u"br",u"Touros",7662,-5.2,-35.466667 ],
    [ u"br",u"Traipu",8427,-9.966667,-36.983333 ],
    [ u"br",u"Trairi",23135,-3.283333,-39.25 ],
    [ u"br",u"Tramandaí",34735,-29.966667,-50.133333 ],
    [ u"br",u"Tremedal",3252,-14.966667,-41.4 ],
    [ u"br",u"Tremembé",31720,-22.966667,-45.55 ],
    [ u"br",u"Três Barras",14855,-26.1,-50.316667 ],
    [ u"br",u"Três Corações",63458,-21.7,-45.266667 ],
    [ u"br",u"Três Coroas",21051,-29.533333,-50.8 ],
    [ u"br",u"Três de Maio",18278,-27.783333,-54.233333 ],
    [ u"br",u"Três Lagoas",78714,-20.8,-51.716667 ],
    [ u"br",u"Três Passos",17286,-27.45,-53.933333 ],
    [ u"br",u"Três Pontas",43750,-21.366667,-45.516667 ],
    [ u"br",u"Três Rios",71945,-22.111389,-43.207778 ],
    [ u"br",u"Trindade",97523,-16.666667,-49.5 ],
    [ u"br",u"Trindade",19313,-7.8,-40.283333 ],
    [ u"br",u"Triunfo",3871,-6.566667,-38.6 ],
    [ u"br",u"Triunfo",14749,-29.933333,-51.716667 ],
    [ u"br",u"Tubarão",67246,-28.5,-49.016667 ],
    [ u"br",u"Tucano",31209,-10.966667,-38.8 ],
    [ u"br",u"Tucumã",15031,-.183333,-50.05 ],
    [ u"br",u"Tucuruí",76339,-3.7,-49.7 ],
    [ u"br",u"Tuntum",16402,-5.233333,-44.65 ],
    [ u"br",u"Tupaciguara",24398,-18.583333,-48.7 ],
    [ u"br",u"Tupanatinga",5768,-8.75,-37.333333 ],
    [ u"br",u"Tupanciretã",17488,-29.083333,-53.85 ],
    [ u"br",u"Tupã",62036,-21.933333,-50.5 ],
    [ u"br",u"Tupi Paulista",10877,-21.4,-51.566667 ],
    [ u"br",u"Turiaçu",10471,-1.683333,-45.35 ],
    [ u"br",u"Turmalina",8798,-17.283333,-42.75 ],
    [ u"br",u"Tutóia",12212,-2.75,-42.266667 ],
    [ u"br",u"Uarini",2796,-2.916667,-65.133333 ],
    [ u"br",u"Uauá",11425,-9.833333,-39.466667 ],
    [ u"br",u"Ubaíra",8069,-13.266667,-39.65 ],
    [ u"br",u"Ubaitaba",28376,-14.3,-39.333333 ],
    [ u"br",u"Ubajara",13802,-3.85,-40.933333 ],
    [ u"br",u"Ubatã",15605,-14.2,-39.516667 ],
    [ u"br",u"Ubatuba",79008,-23.433333,-45.066667 ],
    [ u"br",u"Ubá",97829,-21.116667,-42.933333 ],
    [ u"br",u"Uberaba",260847,-19.75,-47.916667 ],
    [ u"br",u"Uberlândia",563545,-18.916667,-48.3 ],
    [ u"br",u"Uiraúna",7823,-6.516667,-38.416667 ],
    [ u"br",u"Umarizal",8781,-5.983333,-37.816667 ],
    [ u"br",u"Umbaúba",12880,-11.366667,-37.65 ],
    [ u"br",u"Umbuzeiro",4588,-7.683333,-35.666667 ],
    [ u"br",u"Umbuzeiro",4588,-7.7,-35.666667 ],
    [ u"br",u"Umirim",12220,-3.683333,-39.333333 ],
    [ u"br",u"Umuarama",89688,-23.75,-53.333333 ],
    [ u"br",u"Unaí",60203,-16.383333,-46.883333 ],
    [ u"br",u"Una",22650,-15.3,-39.066667 ],
    [ u"br",u"União da Victoria",48741,-26.216667,-51.083333 ],
    [ u"br",u"União dos Palmares",41179,-9.166667,-36.033333 ],
    [ u"br",u"União",15678,-4.583333,-42.866667 ],
    [ u"br",u"Upanema",6704,-5.644444,-37.257778 ],
    [ u"br",u"Urbano Santos",12268,-3.2,-43.383333 ],
    [ u"br",u"Uruaçu",30088,-14.5,-49.166667 ],
    [ u"br",u"Uruana",10258,-15.5,-49.683333 ],
    [ u"br",u"Uruburetama",12076,-3.633333,-39.5 ],
    [ u"br",u"Urucará",8603,-2.536667,-57.758056 ],
    [ u"br",u"Uruçuca",24414,-14.583333,-39.266667 ],
    [ u"br",u"Uruçuí",12243,-7.233333,-44.55 ],
    [ u"br",u"Urucurituba",10180,-2.683333,-57.666667 ],
    [ u"br",u"Uruguaiana",123482,-29.75,-57.083333 ],
    [ u"br",u"Urupês",10745,-21.216667,-49.283333 ],
    [ u"br",u"Urussanga",10670,-28.516667,-49.316667 ],
    [ u"br",u"Utinga",11949,-10.983333,-42.95 ],
    [ u"br",u"Vacaria",56766,-28.5,-50.933333 ],
    [ u"br",u"Valença do Piauí",15881,-6.4,-41.75 ],
    [ u"br",u"Valença",63233,-13.366667,-39.083333 ],
    [ u"br",u"Valença",61145,-22.241944,-43.701389 ],
    [ u"br",u"Valente",12591,-11.566667,-39.45 ],
    [ u"br",u"Valinhos",88631,-22.95,-47.016667 ],
    [ u"br",u"Valparaíso",15939,-21.216667,-50.85 ],
    [ u"br",u"Vargem Alta",4672,-20.666667,-41 ],
    [ u"br",u"Vargem Grande do Sul",36214,-21.833333,-46.883333 ],
    [ u"br",u"Vargem Grande",21420,-3.55,-43.933333 ],
    [ u"br",u"Varginha",116573,-21.55,-45.433333 ],
    [ u"br",u"Varjota",16462,-4.133333,-40.5 ],
    [ u"br",u"Várzea Alegre",21842,-5.35,-40.383333 ],
    [ u"br",u"Várzea da Palma",28706,-17.6,-44.733333 ],
    [ u"br",u"Várzea Grande",249766,-15.65,-56.133333 ],
    [ u"br",u"Várzea Paulista",110938,-23.2,-46.833333 ],
    [ u"br",u"Varzelândia",6398,-15.7,-44.033333 ],
    [ u"br",u"Vassouras",21175,-22.406111,-43.664167 ],
    [ u"br",u"Vazante",15459,-18,-46.9 ],
    [ u"br",u"Venâncio Aires",40628,-29.6,-52.183333 ],
    [ u"br",u"Vera Cruz",30557,-12.633333,-41.033333 ],
    [ u"br",u"Veranópolis",19862,-28.95,-51.55 ],
    [ u"br",u"Vespasiano",94750,-19.666667,-43.916667 ],
    [ u"br",u"Viamão",285274,-30.083333,-51.033333 ],
    [ u"br",u"Viana",55123,-20.383333,-40.5 ],
    [ u"br",u"Viana",26690,-3.216667,-45 ],
    [ u"br",u"Vianópolis",7807,-16.75,-48.533333 ],
    [ u"br",u"Vicência",10378,-7.666667,-35.333333 ],
    [ u"br",u"Viçosa do Ceará",16637,-3.566667,-41.083333 ],
    [ u"br",u"Viçosa",19574,-9.4,-36.233333 ],
    [ u"br",u"Viçosa",68681,-20.75,-42.883333 ],
    [ u"br",u"Videira",42441,-27,-51.133333 ],
    [ u"br",u"Vigia",29229,-.8,-48.133333 ],
    [ u"br",u"Vila Velha",394937,-20.333333,-40.283333 ],
    [ u"br",u"Vilhena",63237,-12.716667,-60.116667 ],
    [ u"br",u"Vinhedo",56493,-23.016667,-46.983333 ],
    [ u"br",u"Viradouro",17172,-20.883333,-48.3 ],
    [ u"br",u"Visconde do Rio Branco",29010,-21.016667,-42.833333 ],
    [ u"br",u"Viseu",18958,-1.2,-46.116667 ],
    [ u"br",u"Vitória da Conquista",253144,-14.85,-40.85 ],
    [ u"br",u"Vitória de Santo Antão",107385,-8.116667,-35.3 ],
    [ u"br",u"Vitória do Mearim",15775,-3.466667,-44.883333 ],
    [ u"br",u"Vitória",312662,-20.316667,-40.35 ],
    [ u"br",u"Vitorino Freire",13267,-4.066667,-45.166667 ],
    [ u"br",u"Volta Redonda",249584,-22.533333,-44.116667 ],
    [ u"br",u"Votorantim",99392,-23.541318,-47.444671 ],
    [ u"br",u"Wanderlândia",6545,-6.835833,-47.799167 ],
    [ u"br",u"Wenceslau Braz",15726,-23.85,-49.8 ],
    [ u"br",u"Xambioá",9281,-6.4325,-48.381944 ],
    [ u"br",u"Xanxerê",32958,-26.883333,-52.383333 ],
    [ u"br",u"Xapuri",5721,-10.65,-68.516667 ],
    [ u"br",u"Xaxim",21376,-26.933333,-52.516667 ],
    [ u"br",u"Xique-Xique",35435,-10.833333,-42.733333 ],
    [ u"bs",u"Albert Town",25,22.6,-74.35 ],
    [ u"bs",u"Alice Town",950,25.7166667,-79.3 ],
    [ u"bs",u"Andros Town",2456,24.7,-77.7666667 ],
    [ u"bs",u"Clarence Town",1751,23.1,-74.9833333 ],
    [ u"bs",u"Cockburn Town",831,24.0333333,-74.5166667 ],
    [ u"bs",u"Colonel Hill",240,22.7666667,-74.2166667 ],
    [ u"bs",u"Duncan Town",70,22.1908333,-75.7258333 ],
    [ u"bs",u"Dunmore Town",1523,25.5,-76.65 ],
    [ u"bs",u"Freeport",46535,26.5333333,-78.7 ],
    [ u"bs",u"High Rock",3744,26.6208333,-78.2833333 ],
    [ u"bs",u"Marsh Harbour",5314,26.55,-77.05 ],
    [ u"bs",u"Matthew Town",452,20.95,-73.6666667 ],
    [ u"bs",u"Nassau",227936,25.0833333,-77.35 ],
    [ u"bs",u"Nicholls Town",270,25.1333333,-78.0 ],
    [ u"bs",u"Pirates Well",217,22.4333333,-73.0666667 ],
    [ u"bs",u"Port Nelson",91,23.6333333,-74.8333333 ],
    [ u"bs",u"Rock Sound",1396,24.9,-76.2 ],
    [ u"bs",u"Snug Corner",407,22.5333333,-73.8833333 ],
    [ u"bs",u"Sweeting Cay",483,26.6,-77.8833333 ],
    [ u"bt",u"Chhukha",1203,27.0666667,89.5833333 ],
    [ u"bt",u"Damphu",2040,27.0166667,90.1 ],
    [ u"bt",u"Gasa",1612,27.9166667,89.6833333 ],
    [ u"bt",u"Geylegphug",7464,26.85,90.5 ],
    [ u"bt",u"Ha",1505,27.3666667,89.2833333 ],
    [ u"bt",u"Jakar",4829,27.55,90.7333333 ],
    [ u"bt",u"Lhuntshi",1935,27.65,91.15 ],
    [ u"bt",u"Mongar",1397,27.25,91.2 ],
    [ u"bt",u"Paro",4536,27.4333333,89.4166667 ],
    [ u"bt",u"Pemagatsel",1720,27.0333333,91.45 ],
    [ u"bt",u"Phuntsholing",65892,26.85,89.3833333 ],
    [ u"bt",u"Punakha",18170,27.6166667,89.8666667 ],
    [ u"bt",u"Samdrup Jongkhar",14134,26.8166667,91.5666667 ],
    [ u"bt",u"Shemgang",1182,27.2333333,90.65 ],
    [ u"bt",u"Taga Dzong",3168,27.0666667,89.8833333 ],
    [ u"bt",u"Tashigang",4519,27.3166667,91.5666667 ],
    [ u"bt",u"Tongsa",2365,27.5166667,90.5 ],
    [ u"bt",u"Wangdiphodrang",3393,27.4833333,89.9 ],
    [ u"bw",u"Boatlaname",853,-23.6,25.8333333 ],
    [ u"bw",u"Bobonong",18136,-21.9666667,28.3333333 ],
    [ u"bw",u"Bokaa",4131,-24.45,26.0166667 ],
    [ u"bw",u"Bokspits",547,-26.9,20.7 ],
    [ u"bw",u"Bonwapitse",568,-23.0166667,26.6666667 ],
    [ u"bw",u"Dekar",1043,-21.5333333,21.9333333 ],
    [ u"bw",u"Dutlwe",1126,-23.9833333,23.9 ],
    [ u"bw",u"Francistown",89979,-21.1666667,27.5166667 ],
    [ u"bw",u"Gabane",12884,-24.6666667,25.7822222 ],
    [ u"bw",u"Gaborone",208411,-24.6463889,25.9119444 ],
    [ u"bw",u"Ghanzi",12141,-21.5666667,21.7833333 ],
    [ u"bw",u"Gweta",4689,-20.1833333,25.2333333 ],
    [ u"bw",u"Hukuntsi",4403,-24.0,21.75 ],
    [ u"bw",u"Kachikau",961,-18.1666667,24.4666667 ],
    [ u"bw",u"Kalakamati",962,-20.6333333,27.3 ],
    [ u"bw",u"Kalamare",2339,-22.8666667,26.5 ],
    [ u"bw",u"Kang",4229,-23.75,22.8333333 ],
    [ u"bw",u"Kanye",44718,-24.9833333,25.35 ],
    [ u"bw",u"Kasane",9250,-17.8166667,25.15 ],
    [ u"bw",u"Khakhea",2133,-24.65,23.5 ],
    [ u"bw",u"Khudumelapye",2035,-23.8833333,24.75 ],
    [ u"bw",u"Kobojango",1756,-21.8166667,28.7833333 ],
    [ u"bw",u"Kopong",6896,-24.4833333,25.8833333 ],
    [ u"bw",u"Lehututu",1942,-23.9666667,21.8666667 ],
    [ u"bw",u"Lephepe",822,-23.3166667,25.8 ],
    [ u"bw",u"Letlhakane",18137,-21.4166667,25.5833333 ],
    [ u"bw",u"Letlhakeng",6782,-24.0666667,25.0333333 ],
    [ u"bw",u"Lobatse",30883,-25.2166667,25.6666667 ],
    [ u"bw",u"Machaneng",2139,-23.1833333,27.5 ],
    [ u"bw",u"Mahalapye",44473,-23.0666667,26.8333333 ],
    [ u"bw",u"Makalamabedi",376,-20.3333333,23.8166667 ],
    [ u"bw",u"Makaleng",1166,-20.9,27.2833333 ],
    [ u"bw",u"Manyana",3338,-23.4,21.7166667 ],
    [ u"bw",u"Masunga",3640,-20.6666667,27.4166667 ],
    [ u"bw",u"Mathathane",1987,-22.2666667,28.75 ],
    [ u"bw",u"Maunatlala",3361,-22.5666667,27.5666667 ],
    [ u"bw",u"Maun",49948,-19.9833333,23.4166667 ],
    [ u"bw",u"Mmathubudukwane",2221,-24.6,26.4333333 ],
    [ u"bw",u"Mochudi",41834,-24.4166667,26.15 ],
    [ u"bw",u"Mogapi",1917,-22.3333333,27.8333333 ],
    [ u"bw",u"Mogapinyana",1515,-22.3666667,27.6 ],
    [ u"bw",u"Mogoditshane",43417,-24.6269444,25.8655556 ],
    [ u"bw",u"Moiyabana",2768,-22.4333333,26.4166667 ],
    [ u"bw",u"Mokobeng",1822,-22.9833333,27.5833333 ],
    [ u"bw",u"Molepolole",63251,-24.4166667,25.5333333 ],
    [ u"bw",u"Mookane",2397,-23.7333333,26.6333333 ],
    [ u"bw",u"Mopipi",3301,-21.1833333,24.8833333 ],
    [ u"bw",u"Mosetse",1780,-20.75,26.65 ],
    [ u"bw",u"Moshupa",19563,-24.8,25.3833333 ],
    [ u"bw",u"Nata",4794,-20.2166667,26.1833333 ],
    [ u"bw",u"Nkoyaphiri",1578,-24.6322222,25.8313889 ],
    [ u"bw",u"Nokaneng",1763,-19.6666667,22.2666667 ],
    [ u"bw",u"Orapa",9190,-21.2833333,25.3666667 ],
    [ u"bw",u"Otse",6275,-25.0166667,25.7333333 ],
    [ u"bw",u"Palapye",30652,-22.55,27.1333333 ],
    [ u"bw",u"Pandamatenga",1685,-18.2666667,25.65 ],
    [ u"bw",u"Pilane",1277,-24.45,26.1333333 ],
    [ u"bw",u"Pilikwe",1375,-22.7833333,27.2333333 ],
    [ u"bw",u"Ramotswa",21451,-24.8666667,25.8166667 ],
    [ u"bw",u"Ratholo",2377,-22.6833333,27.5833333 ],
    [ u"bw",u"Sebina",3030,-20.8666667,27.25 ],
    [ u"bw",u"Sefophe",4114,-22.1833333,27.9666667 ],
    [ u"bw",u"Sehithwa",1614,-20.4666667,22.7166667 ],
    [ u"bw",u"Sekoma",1083,-24.4,23.8833333 ],
    [ u"bw",u"Serowe",47421,-22.3833333,26.7166667 ],
    [ u"bw",u"Shakawe",5651,-18.3666667,21.85 ],
    [ u"bw",u"Tamasane",1070,-22.3166667,27.3666667 ],
    [ u"bw",u"Thamaga",20757,-24.7166667,25.5333333 ],
    [ u"bw",u"Tobane",1925,-21.95,27.9 ],
    [ u"bw",u"Tonota",17760,-21.4833333,27.4833333 ],
    [ u"bw",u"Tsabong",8326,-26.05,22.45 ],
    [ u"bw",u"Tshane",969,-24.0333333,21.9 ],
    [ u"bw",u"Tsienyane",5222,-21.0166667,24.3333333 ],
    [ u"bw",u"Werda",2149,-25.2666667,23.2833333 ],
    [ u"by",u"Braslav",12378,55.6338889,27.0538889 ],
    [ u"by",u"Brest",300716,52.1,23.7 ],
    [ u"by",u"Disna",2738,55.5666667,28.2166667 ],
    [ u"by",u"Dzerzhinsk",24610,53.685,27.1419444 ],
    [ u"by",u"Gomel",481000,52.4416667,30.9833333 ],
    [ u"by",u"Haradok",13380,55.4602778,30.0 ],
    [ u"by",u"Horki",33897,54.2833333,30.9911111 ],
    [ u"by",u"Hrodna",317366,53.6813889,23.8147222 ],
    [ u"by",u"Ivanava",13614,52.1325,25.5461111 ],
    [ u"by",u"Kleck",9641,53.0652778,26.6416667 ],
    [ u"by",u"Kobryn",50691,52.2161111,24.3663889 ],
    [ u"by",u"Lida",98036,53.8833333,25.2997222 ],
    [ u"by",u"Lyuban",10107,52.8,28.0 ],
    [ u"by",u"Malaryta",9692,51.7833333,24.0833333 ],
    [ u"by",u"Masty",16102,53.4077778,24.5327778 ],
    [ u"by",u"Mazyr",112136,52.05,29.2666667 ],
    [ u"by",u"Minsk",1742123,53.9,27.5666667 ],
    [ u"by",u"Navahrudak",30748,53.6,25.8333333 ],
    [ u"by",u"Orsha",125347,54.5152778,30.4052778 ],
    [ u"by",u"Pastavy",20218,55.1163889,26.8338889 ],
    [ u"by",u"Pinsk",130777,52.1213889,26.0727778 ],
    [ u"by",u"Salihorsk",101614,52.8,27.5333333 ],
    [ u"by",u"Senno",9987,54.8041667,29.7044444 ],
    [ u"by",u"Slonim",51435,53.0866667,25.3219444 ],
    [ u"by",u"Stolin",10491,51.8833333,26.85 ],
    [ u"by",u"Vawkavysk",47300,53.1519444,24.4555556 ],
    [ u"by",u"Zabinka",10921,52.2005556,24.0233333 ],
    [ u"by",u"Zlobin",73089,52.8922222,30.0280556 ],
    [ u"bz",u"Belize",61462,17.4833333,-88.1833333 ],
    [ u"bz",u"Belmopan",13381,17.25,-88.7666667 ],
    [ u"bz",u"Benque Viejo",7092,17.075,-89.1391667 ],
    [ u"bz",u"Corozal",8724,18.3833333,-88.3833333 ],
    [ u"bz",u"Dangriga",10750,16.9666667,-88.2166667 ],
    [ u"bz",u"Orange Walk",15298,18.0666667,-88.55 ],
    [ u"bz",u"Punta Gorda",5026,16.1,-88.8 ],
    [ u"bz",u"San Ignacio",16813,17.1561111,-89.0713889 ],
    [ u"bz",u"San Pedro",8418,17.9166667,-87.95 ],
    [ u"ca",u"Abbotsford",151685,49.05,-122.3 ],
    [ u"ca",u"Acton",8204,43.633333,-80.033333 ],
    [ u"ca",u"Acton Vale",5135,45.633333,-72.566667 ],
    [ u"ca",u"Airdrie",24673,51.266667,-114.016667 ],
    [ u"ca",u"Aklavik",648,68.216667,-135 ],
    [ u"ca",u"Albanel",1087,48.866667,-72.416667 ],
    [ u"ca",u"Alberton",1147,46.8,-64.066667 ],
    [ u"ca",u"Aldergrove",11963,49.06,-122.46 ],
    [ u"ca",u"Alexandria",3559,45.3,-74.633333 ],
    [ u"ca",u"Alfred",1424,45.55,-74.866667 ],
    [ u"ca",u"Alliston",10224,44.15,-79.866667 ],
    [ u"ca",u"Alma",29527,48.55,-71.65 ],
    [ u"ca",u"Almonte",4921,45.216667,-76.2 ],
    [ u"ca",u"Altona",3613,49.1,-97.566667 ],
    [ u"ca",u"Amherst",9336,45.833333,-64.2 ],
    [ u"ca",u"Amherstburg",11459,42.1,-83.1 ],
    [ u"ca",u"Amos",10435,48.566667,-78.116667 ],
    [ u"ca",u"Amqui",5117,48.466667,-67.433333 ],
    [ u"ca",u"Antigonish",5003,45.616667,-61.966667 ],
    [ u"ca",u"Armstrong",4275,50.45,-119.183333 ],
    [ u"ca",u"Arnprior",9607,45.433333,-76.366667 ],
    [ u"ca",u"Arthur",2413,43.833333,-80.533333 ],
    [ u"ca",u"Asbestos",7190,45.783333,-71.933333 ],
    [ u"ca",u"Ashcroft",1796,50.716667,-121.266667 ],
    [ u"ca",u"Assiniboia",2320,49.616667,-105.983333 ],
    [ u"ca",u"Athabasca",2539,54.716667,-113.266667 ],
    [ u"ca",u"Atikokan",3760,48.75,-91.616667 ],
    [ u"ca",u"Attawapiskat",1366,52.916667,-82.433333 ],
    [ u"ca",u"Aylmer",7527,42.783333,-80.983333 ],
    [ u"ca",u"Ayr",3841,43.283333,-80.45 ],
    [ u"ca",u"Bagotville",1081,48.35,-70.883333 ],
    [ u"ca",u"Baie-Comeau",10435,49.216667,-68.15 ],
    [ u"ca",u"Baie-Saint-Paul",4512,47.433333,-70.5 ],
    [ u"ca",u"Banff",7502,51.166667,-115.566667 ],
    [ u"ca",u"Barraute",1180,48.433333,-77.633333 ],
    [ u"ca",u"Barrhead",4430,54.116667,-114.4 ],
    [ u"ca",u"Barrie",182070,44.383333,-79.7 ],
    [ u"ca",u"Bassano",1388,50.783333,-112.466667 ],
    [ u"ca",u"Bathurst",18179,47.6,-65.65 ],
    [ u"ca",u"Bay Roberts",13735,47.583333,-53.3 ],
    [ u"ca",u"Beamsville",9556,43.166667,-79.466667 ],
    [ u"ca",u"Beauceville",4480,46.2,-70.766667 ],
    [ u"ca",u"Beaumont",7366,53.37,-113.41 ],
    [ u"ca",u"Beaupré",5287,47.05,-70.883333 ],
    [ u"ca",u"Beauséjour",2886,50.066667,-96.516667 ],
    [ u"ca",u"Beaverlodge",2219,55.2,-119.45 ],
    [ u"ca",u"Beaverton",3237,44.433333,-79.15 ],
    [ u"ca",u"Bedford",2711,45.116667,-72.983333 ],
    [ u"ca",u"Belleville",65368,44.166667,-77.383333 ],
    [ u"ca",u"Beloeil",43016,45.566667,-73.2 ],
    [ u"ca",u"Berthierville",4411,46.083333,-73.166667 ],
    [ u"ca",u"Berwick",2271,45.033333,-64.733333 ],
    [ u"ca",u"Betsiamites",1652,48.95,-68.65 ],
    [ u"ca",u"Biggar",2068,52.05,-107.983333 ],
    [ u"ca",u"Black Diamond",3663,50.7,-114.233333 ],
    [ u"ca",u"Blackfalds",3198,52.383333,-113.8 ],
    [ u"ca",u"Blairmore",2095,49.6,-114.433333 ],
    [ u"ca",u"Blenheim",5065,42.333333,-82 ],
    [ u"ca",u"Blind River",2966,46.183333,-82.95 ],
    [ u"ca",u"Bobcaygeon",3015,44.533333,-78.55 ],
    [ u"ca",u"Boissevain",1557,49.233333,-100.05 ],
    [ u"ca",u"Bolton",21709,43.883333,-79.733333 ],
    [ u"ca",u"Bon Accord",1611,53.833333,-113.416667 ],
    [ u"ca",u"Bonaventure",1480,48.05,-65.466667 ],
    [ u"ca",u"Bonavista",3658,48.633333,-53.1 ],
    [ u"ca",u"Bonnyville",6003,54.267778,-110.750833 ],
    [ u"ca",u"Botwood",2940,49.15,-55.366667 ],
    [ u"ca",u"Bow Island",1792,49.866667,-111.366667 ],
    [ u"ca",u"Bracebridge",8238,45.033333,-79.3 ],
    [ u"ca",u"Bradford",18811,44.116667,-79.566667 ],
    [ u"ca",u"Brandon",26234,49.833333,-99.95 ],
    [ u"ca",u"Brantford",87761,43.133333,-80.266667 ],
    [ u"ca",u"Bridgetown",1063,44.85,-65.15 ],
    [ u"ca",u"Bridgewater",8070,44.366667,-64.516667 ],
    [ u"ca",u"Brighton",5152,44.033333,-77.733333 ],
    [ u"ca",u"Brockville",23887,44.583333,-75.683333 ],
    [ u"ca",u"Brooks",12745,50.566667,-111.9 ],
    [ u"ca",u"Brownsburg",2597,45.683333,-74.4 ],
    [ u"ca",u"Buckingham",21373,45.583333,-75.416667 ],
    [ u"ca",u"Burgeo",1627,47.6,-57.633333 ],
    [ u"ca",u"Burns Lake",2635,54.216667,-125.766667 ],
    [ u"ca",u"Cabano",2710,47.683333,-68.883333 ],
    [ u"ca",u"Cache Creek",1061,50.8,-121.316667 ],
    [ u"ca",u"Caledon East",2085,43.866667,-79.866667 ],
    [ u"ca",u"Caledonia",9065,43.066667,-79.95 ],
    [ u"ca",u"Calgary",968475,51.083333,-114.083333 ],
    [ u"ca",u"Calmar",2000,53.25,-113.783333 ],
    [ u"ca",u"Campbellford",3882,44.3,-77.8 ],
    [ u"ca",u"Campbell River",33430,50.016667,-125.25 ],
    [ u"ca",u"Campbellton",12064,48,-66.666667 ],
    [ u"ca",u"Camrose",15687,53.016667,-112.816667 ],
    [ u"ca",u"Canmore",12289,51.1,-115.35 ],
    [ u"ca",u"Cannington",2120,44.35,-79.033333 ],
    [ u"ca",u"Canora",2055,51.633333,-102.433333 ],
    [ u"ca",u"Cap-aux-Meules",1686,47.383333,-61.866667 ],
    [ u"ca",u"Cap-Chat",1466,49.083333,-66.683333 ],
    [ u"ca",u"Capreol",3666,46.7,-80.916667 ],
    [ u"ca",u"Caraquet",4620,47.783333,-64.95 ],
    [ u"ca",u"Carberry",1575,49.866667,-99.35 ],
    [ u"ca",u"Carbonear",6814,47.733333,-53.25 ],
    [ u"ca",u"Cardinal",1837,44.783333,-75.366667 ],
    [ u"ca",u"Cardston",3654,49.2,-113.316667 ],
    [ u"ca",u"Carleton Place",9743,45.133333,-76.133333 ],
    [ u"ca",u"Carlyle",1177,49.633333,-102.266667 ],
    [ u"ca",u"Carman",2948,49.5,-98 ],
    [ u"ca",u"Carnduff",950,49.166667,-101.783333 ],
    [ u"ca",u"Caronport",972,50.45,-105.816667 ],
    [ u"ca",u"Carstairs",2370,51.533333,-114.1 ],
    [ u"ca",u"Casselman",3074,45.3,-75.083333 ],
    [ u"ca",u"Castlegar",8715,49.316667,-117.666667 ],
    [ u"ca",u"Catalina",1352,48.516667,-53.083333 ],
    [ u"ca",u"Causapscal",2033,48.35,-67.216667 ],
    [ u"ca",u"Chandler",2863,48.333333,-64.666667 ],
    [ u"ca",u"Channel-Port aux Basques",4220,47.566667,-59.15 ],
    [ u"ca",u"Chapais",1824,49.783333,-74.866667 ],
    [ u"ca",u"Chapleau",2991,47.833333,-83.4 ],
    [ u"ca",u"Charlottetown",42403,46.233333,-63.133333 ],
    [ u"ca",u"Chase",2471,50.816667,-119.683333 ],
    [ u"ca",u"Chatham",44554,42.4,-82.183333 ],
    [ u"ca",u"Chemainus",2718,48.916667,-123.7 ],
    [ u"ca",u"Chesley",1986,44.3,-81.1 ],
    [ u"ca",u"Chester",1531,44.533333,-64.233333 ],
    [ u"ca",u"Chestermere",3590,51.03,-113.83 ],
    [ u"ca",u"Chesterville",1582,45.1,-75.216667 ],
    [ u"ca",u"Chilliwack",51942,49.166667,-121.95 ],
    [ u"ca",u"Chute-aux-Outardes",2000,49.116667,-68.383333 ],
    [ u"ca",u"Clairmont",1483,55.266667,-118.8 ],
    [ u"ca",u"Claresholm",3808,50.033333,-113.583333 ],
    [ u"ca",u"Clermont",2912,47.683333,-70.233333 ],
    [ u"ca",u"Clinton",3292,43.6,-81.533333 ],
    [ u"ca",u"Clyde River",1017,70.45,-68.566667 ],
    [ u"ca",u"Coaldale",6317,49.733333,-112.616667 ],
    [ u"ca",u"Coaticook",7021,45.133333,-71.8 ],
    [ u"ca",u"Cobourg",18100,43.966667,-78.166667 ],
    [ u"ca",u"Cochrane",16367,51.2,-114.45 ],
    [ u"ca",u"Cochrane",4407,49.066667,-81.016667 ],
    [ u"ca",u"Colborne",2155,44.016667,-77.883333 ],
    [ u"ca",u"Colchester",2307,41.983333,-82.933333 ],
    [ u"ca",u"Collingwood",15809,44.5,-80.216667 ],
    [ u"ca",u"Contrecoeur",3587,45.85,-73.233333 ],
    [ u"ca",u"Cookshire",1568,45.416667,-71.616667 ],
    [ u"ca",u"Corner Brook",18693,48.95,-57.933333 ],
    [ u"ca",u"Cornwall",48823,45.016667,-74.733333 ],
    [ u"ca",u"Cornwall",2272,46.24,-63.21 ],
    [ u"ca",u"Courtenay",32793,49.683333,-125 ],
    [ u"ca",u"Cowansville",10888,45.2,-72.75 ],
    [ u"ca",u"Crabtree",2248,45.966667,-73.466667 ],
    [ u"ca",u"Cranbrook",18610,49.516667,-115.766667 ],
    [ u"ca",u"Creemore",1391,44.316667,-80.1 ],
    [ u"ca",u"Creston",4816,49.1,-116.516667 ],
    [ u"ca",u"Crossfield",2512,51.433333,-114.033333 ],
    [ u"ca",u"Crystal Beach",7062,45.05,-79.4 ],
    [ u"ca",u"Cumberland",2630,49.616667,-125.016667 ],
    [ u"ca",u"Dalhousie",4137,48.066667,-66.366667 ],
    [ u"ca",u"Dalmeny",1504,52.333333,-106.783333 ],
    [ u"ca",u"Danville",1761,45.783333,-72.016667 ],
    [ u"ca",u"Dauphin",8418,51.15,-100.05 ],
    [ u"ca",u"Davidson",967,51.266667,-105.966667 ],
    [ u"ca",u"Dawson Creek",10802,55.766667,-120.233333 ],
    [ u"ca",u"Deep River",4296,46.166667,-77.566667 ],
    [ u"ca",u"Deer Lake",4163,49.183333,-57.433333 ],
    [ u"ca",u"Delhi",4227,42.85,-80.5 ],
    [ u"ca",u"Deloraine",1068,49.183333,-100.5 ],
    [ u"ca",u"Desbiens",1147,48.416667,-71.95 ],
    [ u"ca",u"Deseronto",1897,44.2,-77.033333 ],
    [ u"ca",u"Devon",5225,53.366667,-113.733333 ],
    [ u"ca",u"Didsbury",4134,51.666667,-114.133333 ],
    [ u"ca",u"Digby",2052,44.6,-65.75 ],
    [ u"ca",u"Disraeli",2678,45.9,-71.35 ],
    [ u"ca",u"Dolbeau",12916,48.866667,-72.233333 ],
    [ u"ca",u"Donnacona",8014,46.666667,-71.733333 ],
    [ u"ca",u"Drayton Valley",6099,53.216667,-114.983333 ],
    [ u"ca",u"Dresden",2727,42.583333,-82.166667 ],
    [ u"ca",u"Drumheller",6557,51.466667,-112.7 ],
    [ u"ca",u"Drummondville",59489,45.883333,-72.483333 ],
    [ u"ca",u"Dryden",6924,49.783333,-92.833333 ],
    [ u"ca",u"Duncan",22199,48.783333,-123.7 ],
    [ u"ca",u"Dunnville",6006,42.9,-79.616667 ],
    [ u"ca",u"Durham",2861,44.183333,-80.816667 ],
    [ u"ca",u"East Angus",3634,45.483333,-71.666667 ],
    [ u"ca",u"Edmonton",822319,53.55,-113.5 ],
    [ u"ca",u"Edmundston",17937,47.366667,-68.333333 ],
    [ u"ca",u"Edson",7975,53.583333,-116.416667 ],
    [ u"ca",u"Eganville",1299,45.533333,-77.1 ],
    [ u"ca",u"Elk Point",1514,53.9,-110.9 ],
    [ u"ca",u"Elliot Lake",12508,46.383333,-82.65 ],
    [ u"ca",u"Elmira",8614,43.6,-80.55 ],
    [ u"ca",u"Elmvale",2298,44.583333,-79.866667 ],
    [ u"ca",u"Enderby",2830,50.55,-119.133333 ],
    [ u"ca",u"Englehart",1685,47.816667,-79.866667 ],
    [ u"ca",u"Erin",3053,43.766667,-80.066667 ],
    [ u"ca",u"Espanola",4682,46.25,-81.766667 ],
    [ u"ca",u"Essex",7396,42.166667,-82.816667 ],
    [ u"ca",u"Esterhazy",2194,50.65,-102.083333 ],
    [ u"ca",u"Estevan",9904,49.15,-103 ],
    [ u"ca",u"Eston",979,51.15,-108.75 ],
    [ u"ca",u"Exeter",4702,43.35,-81.483333 ],
    [ u"ca",u"Fairview",3312,56.066667,-118.4 ],
    [ u"ca",u"Farnham",6061,45.283333,-72.966667 ],
    [ u"ca",u"Fenelon Falls",1979,44.533333,-78.75 ],
    [ u"ca",u"Fergus",17673,43.7,-80.366667 ],
    [ u"ca",u"Ferme-Neuve",2115,46.7,-75.45 ],
    [ u"ca",u"Fernie",5019,49.5,-115.066667 ],
    [ u"ca",u"Flin Flon",6002,54.766667,-101.883333 ],
    [ u"ca",u"Foam Lake",1138,51.65,-103.533333 ],
    [ u"ca",u"Forest",3018,43.1,-82 ],
    [ u"ca",u"Forestville",3570,48.733333,-69.066667 ],
    [ u"ca",u"Fort Erie",15953,42.9,-78.933333 ],
    [ u"ca",u"Fort Frances",7931,48.616667,-93.416667 ],
    [ u"ca",u"Fort Nelson",4207,58.816667,-122.533333 ],
    [ u"ca",u"Fort Saint James",2392,54.433333,-124.25 ],
    [ u"ca",u"Fort Saint John",16656,56.25,-120.833333 ],
    [ u"ca",u"Fredericton",52337,45.95,-66.633333 ],
    [ u"ca",u"Fruitvale",3790,49.116667,-117.55 ],
    [ u"ca",u"Gambo",1614,48.783333,-54.216667 ],
    [ u"ca",u"Gananoque",5458,44.333333,-76.166667 ],
    [ u"ca",u"Gander",8772,48.95,-54.55 ],
    [ u"ca",u"Gaspé",3331,48.833333,-64.483333 ],
    [ u"ca",u"Georgetown",32372,43.65,-79.933333 ],
    [ u"ca",u"Geraldton",2349,49.716667,-86.966667 ],
    [ u"ca",u"Gibsons",6821,49.4,-123.5 ],
    [ u"ca",u"Gimli",2009,50.633333,-97 ],
    [ u"ca",u"Glace Bay",21504,46.2,-59.966667 ],
    [ u"ca",u"Glencoe",2273,42.75,-81.7 ],
    [ u"ca",u"Goderich",8032,43.733333,-81.7 ],
    [ u"ca",u"Golden",4038,51.3,-116.966667 ],
    [ u"ca",u"Granby",53979,45.383333,-72.733333 ],
    [ u"ca",u"Grand Bank",4623,47.1,-55.783333 ],
    [ u"ca",u"Grand Bend",2059,43.316667,-81.75 ],
    [ u"ca",u"Grand Centre",12386,54.416667,-110.215278 ],
    [ u"ca",u"Grande Prairie",41463,55.166667,-118.8 ],
    [ u"ca",u"Grande-Rivière",1508,48.383333,-64.5 ],
    [ u"ca",u"Grand Falls",5675,47.05,-67.733333 ],
    [ u"ca",u"Grand Forks",4208,49.05,-118.466667 ],
    [ u"ca",u"Grand Valley",1856,43.9,-80.316667 ],
    [ u"ca",u"Gravelbourg",1109,49.883333,-106.55 ],
    [ u"ca",u"Gravenhurst",5839,44.916667,-79.366667 ],
    [ u"ca",u"Grenfell",997,50.416667,-102.916667 ],
    [ u"ca",u"Grimshaw",2560,56.183333,-117.6 ],
    [ u"ca",u"Guelph",115763,43.55,-80.25 ],
    [ u"ca",u"Gull Lake",949,50.1,-108.483333 ],
    [ u"ca",u"Hagersville",2624,42.95,-80.05 ],
    [ u"ca",u"Haileybury",10991,47.433333,-79.633333 ],
    [ u"ca",u"Haines Junction",1148,60.75,-137.5 ],
    [ u"ca",u"Halifax",266012,44.65,-63.6 ],
    [ u"ca",u"Hamilton",653637,43.25,-79.833333 ],
    [ u"ca",u"Hampton",2637,45.533333,-65.833333 ],
    [ u"ca",u"Hanna",3140,51.633333,-111.916667 ],
    [ u"ca",u"Hanover",7255,44.15,-81.033333 ],
    [ u"ca",u"Hantsport",1253,45.066667,-64.183333 ],
    [ u"ca",u"Harbour Breton",1898,47.483333,-55.833333 ],
    [ u"ca",u"Hare Bay",968,48.85,-54.016667 ],
    [ u"ca",u"Harriston",2148,43.916667,-80.883333 ],
    [ u"ca",u"Harrow",3100,42.033333,-82.916667 ],
    [ u"ca",u"Hastings",1276,44.3,-77.95 ],
    [ u"ca",u"Hauterive",12816,49.183333,-68.266667 ],
    [ u"ca",u"Havelock",1403,44.433333,-77.883333 ],
    [ u"ca",u"Havre-Saint-Pierre",2966,50.25,-63.583333 ],
    [ u"ca",u"Hawkesbury",12283,45.616667,-74.6 ],
    [ u"ca",u"Hay River",3030,60.85,-115.7 ],
    [ u"ca",u"Hearst",4746,49.7,-83.666667 ],
    [ u"ca",u"Hébertville",1691,48.4,-71.683333 ],
    [ u"ca",u"Hensall",1261,43.433333,-81.5 ],
    [ u"ca",u"High Level",3621,58.516667,-117.133333 ],
    [ u"ca",u"High Prairie",2878,55.433333,-116.483333 ],
    [ u"ca",u"High River",9826,50.583333,-113.866667 ],
    [ u"ca",u"Hinton",9889,53.4,-117.583333 ],
    [ u"ca",u"Hope",4598,49.383333,-121.433333 ],
    [ u"ca",u"Hornepayne",1386,49.216667,-84.783333 ],
    [ u"ca",u"Houston",2884,54.4,-126.65 ],
    [ u"ca",u"Hudson Bay",1661,52.85,-102.383333 ],
    [ u"ca",u"Humboldt",4822,52.2,-105.116667 ],
    [ u"ca",u"Huntingdon",2865,45.083333,-74.183333 ],
    [ u"ca",u"Huntsville",7972,45.333333,-79.216667 ],
    [ u"ca",u"Indian Head",1642,50.533333,-103.666667 ],
    [ u"ca",u"Ingersoll",11874,43.033333,-80.883333 ],
    [ u"ca",u"Inuvik",3022,68.35,-133.7 ],
    [ u"ca",u"Invermere",2871,50.5,-116.033333 ],
    [ u"ca",u"Inverness",1639,46.233333,-61.283333 ],
    [ u"ca",u"Iqaluit",6124,63.733333,-68.5 ],
    [ u"ca",u"Iroquois Falls",4232,48.766667,-80.666667 ],
    [ u"ca",u"Iroquois",1297,44.85,-75.316667 ],
    [ u"ca",u"Irricana",1091,51.316667,-113.616667 ],
    [ u"ca",u"Jasper",3907,52.883333,-118.083333 ],
    [ u"ca",u"Joliette",34772,46.033333,-73.433333 ],
    [ u"ca",u"Kamloops",68715,50.666667,-120.333333 ],
    [ u"ca",u"Kamsack",1877,51.566667,-101.9 ],
    [ u"ca",u"Kanata",93541,45.333333,-75.9 ],
    [ u"ca",u"Kapuskasing",9240,49.416667,-82.433333 ],
    [ u"ca",u"Kedgwick",1146,47.633333,-67.333333 ],
    [ u"ca",u"Kelowna",125110,49.9,-119.483333 ],
    [ u"ca",u"Kelvington",941,52.166667,-103.516667 ],
    [ u"ca",u"Kemptville",4229,45.016667,-75.633333 ],
    [ u"ca",u"Kenora",13075,49.766667,-94.466667 ],
    [ u"ca",u"Kensington",1424,46.433333,-63.65 ],
    [ u"ca",u"Kentville",12636,45.066667,-64.5 ],
    [ u"ca",u"Kerrobert",1038,51.916667,-109.133333 ],
    [ u"ca",u"Killam",1056,52.783333,-111.85 ],
    [ u"ca",u"Killarney",2362,49.183333,-99.666667 ],
    [ u"ca",u"Kimberley",6513,49.683333,-115.983333 ],
    [ u"ca",u"Kincardine",6771,44.166667,-81.633333 ],
    [ u"ca",u"Kindersley",4249,51.466667,-109.133333 ],
    [ u"ca",u"Kingston",114243,44.233333,-76.483333 ],
    [ u"ca",u"Kirkland Lake",7776,48.15,-80.033333 ],
    [ u"ca",u"Kitchener",409111,43.45,-80.5 ],
    [ u"ca",u"Kitimat",10278,54,-128.7 ],
    [ u"ca",u"Labelle",1239,46.283333,-74.733333 ],
    [ u"ca",u"Lac-au-Saumon",1198,48.416667,-67.333333 ],
    [ u"ca",u"Lac du Bonnet",1134,50.266667,-96.05 ],
    [ u"ca",u"Lachute",9562,45.65,-74.333333 ],
    [ u"ca",u"Lac-Mégantic",4658,45.583333,-70.883333 ],
    [ u"ca",u"Lacolle",1528,45.083333,-73.366667 ],
    [ u"ca",u"Lacombe",10059,52.466667,-113.733333 ],
    [ u"ca",u"Ladysmith",8740,48.983333,-123.816667 ],
    [ u"ca",u"Lake Cowichan",2870,48.816667,-124.033333 ],
    [ u"ca",u"Lakefield",2888,44.433333,-78.266667 ],
    [ u"ca",u"La Malbaie",4447,47.65,-70.166667 ],
    [ u"ca",u"Lamont",1779,53.75,-112.783333 ],
    [ u"ca",u"Langenburg",1034,50.833333,-101.7 ],
    [ u"ca",u"Langham",1070,52.366667,-106.966667 ],
    [ u"ca",u"Lanigan",1204,51.85,-105.033333 ],
    [ u"ca",u"La Ronge",3071,55.1,-105.3 ],
    [ u"ca",u"La Sarre",7206,48.8,-79.2 ],
    [ u"ca",u"La Tuque",9503,47.45,-72.783333 ],
    [ u"ca",u"Laurentides",4922,45.85,-73.766667 ],
    [ u"ca",u"Lavaltrie",8762,45.883333,-73.283333 ],
    [ u"ca",u"Leamington",30428,42.05,-82.583333 ],
    [ u"ca",u"Leduc",15562,53.266667,-113.533333 ],
    [ u"ca",u"Les Escoumins",2042,48.35,-69.416667 ],
    [ u"ca",u"Lethbridge",70619,49.7,-112.833333 ],
    [ u"ca",u"Lewisporte",2935,49.233333,-55.066667 ],
    [ u"ca",u"Lillooet",2585,50.683333,-121.933333 ],
    [ u"ca",u"Lindsay",17987,44.35,-78.733333 ],
    [ u"ca",u"Linière",2167,46.05,-70.516667 ],
    [ u"ca",u"Listowel",6237,43.733333,-80.966667 ],
    [ u"ca",u"Little Current",1652,45.966667,-81.933333 ],
    [ u"ca",u"Lively",7081,46.433333,-81.15 ],
    [ u"ca",u"Liverpool",2781,44.033333,-64.716667 ],
    [ u"ca",u"Lloydminster",22677,53.27,-110.03 ],
    [ u"ca",u"Lloydminster",22677,53.283333,-110 ],
    [ u"ca",u"Logan Lake",2190,50.48,-120.81 ],
    [ u"ca",u"London",346774,42.983333,-81.25 ],
    [ u"ca",u"Longlac",1846,49.783333,-86.55 ],
    [ u"ca",u"Louisbourg",1031,45.916667,-59.983333 ],
    [ u"ca",u"Louiseville",5819,46.25,-72.933333 ],
    [ u"ca",u"Lucan",2123,43.183333,-81.4 ],
    [ u"ca",u"Luceville",1373,48.516667,-68.333333 ],
    [ u"ca",u"Lucknow",1275,43.95,-81.516667 ],
    [ u"ca",u"Lumby",1625,50.25,-118.966667 ],
    [ u"ca",u"Lumsden",1477,50.65,-104.866667 ],
    [ u"ca",u"Lunenburg",2473,44.366667,-64.316667 ],
    [ u"ca",u"Macamic",1559,48.766667,-79 ],
    [ u"ca",u"Mackenzie",4978,55.33,-123.09 ],
    [ u"ca",u"Macklin",1257,52.333333,-109.95 ],
    [ u"ca",u"Madoc",1827,44.516667,-77.483333 ],
    [ u"ca",u"Magog",15550,45.266667,-72.15 ],
    [ u"ca",u"Magrath",2095,49.416667,-112.883333 ],
    [ u"ca",u"Malartic",3710,48.133333,-78.116667 ],
    [ u"ca",u"Manitouwadge",3115,49.133333,-85.8 ],
    [ u"ca",u"Maniwaki",4236,46.366667,-75.966667 ],
    [ u"ca",u"Maple Creek",2121,49.916667,-109.466667 ],
    [ u"ca",u"Marathon",4627,48.75,-86.366667 ],
    [ u"ca",u"Marieville",5600,45.433333,-73.166667 ],
    [ u"ca",u"Markdale",1514,44.316667,-80.65 ],
    [ u"ca",u"Marmora",1678,44.483333,-77.683333 ],
    [ u"ca",u"Marystown",4558,47.166667,-55.166667 ],
    [ u"ca",u"Maskinongé",1105,46.216667,-73.016667 ],
    [ u"ca",u"Matagami",1966,49.75,-77.633333 ],
    [ u"ca",u"Matane",11826,48.85,-67.516667 ],
    [ u"ca",u"Mattawa",2415,46.316667,-78.7 ],
    [ u"ca",u"Mayo",540,63.6,-135.916667 ],
    [ u"ca",u"Meadow Lake",4281,54.129722,-108.434722 ],
    [ u"ca",u"Meaford",4816,44.6,-80.583333 ],
    [ u"ca",u"Medicine Hat",63140,50.033333,-110.683333 ],
    [ u"ca",u"Melfort",5410,52.866667,-104.6 ],
    [ u"ca",u"Melita",1167,49.266667,-100.983333 ],
    [ u"ca",u"Melville",4279,50.933333,-102.8 ],
    [ u"ca",u"Merritt",7179,50.116667,-120.783333 ],
    [ u"ca",u"Metabetchouan",2329,48.433333,-71.866667 ],
    [ u"ca",u"Middleton",1680,44.95,-65.066667 ],
    [ u"ca",u"Midland",31502,44.75,-79.9 ],
    [ u"ca",u"Mildmay",1258,44.033333,-81.116667 ],
    [ u"ca",u"Millbrook",1550,44.15,-78.45 ],
    [ u"ca",u"Millet",2142,53.083333,-113.466667 ],
    [ u"ca",u"Milton",23472,43.516667,-79.883333 ],
    [ u"ca",u"Milverton",1803,43.566667,-80.933333 ],
    [ u"ca",u"Minnedosa",2526,50.25,-99.833333 ],
    [ u"ca",u"Mitchell",4416,43.466667,-81.183333 ],
    [ u"ca",u"Moncton",87467,46.083333,-64.766667 ],
    [ u"ca",u"Montague",2005,46.166667,-62.65 ],
    [ u"ca",u"Mont-Joli",6124,48.583333,-68.183333 ],
    [ u"ca",u"Montmagny",9645,46.966667,-70.55 ],
    [ u"ca",u"Montreal",3268513,45.5,-73.583333 ],
    [ u"ca",u"Moose Factory",2060,51.25,-80.6 ],
    [ u"ca",u"Moose Jaw",32166,50.4,-105.55 ],
    [ u"ca",u"Moosomin",2206,50.15,-101.666667 ],
    [ u"ca",u"Morden",6395,49.183333,-98.1 ],
    [ u"ca",u"Morinville",8108,53.8,-113.65 ],
    [ u"ca",u"Morrisburg",2728,44.9,-75.183333 ],
    [ u"ca",u"Morris",1742,49.35,-97.366667 ],
    [ u"ca",u"Mount Forest",4842,43.966667,-80.733333 ],
    [ u"ca",u"Murdochville",1139,48.966667,-65.516667 ],
    [ u"ca",u"Nakusp",1706,50.233333,-117.8 ],
    [ u"ca",u"Nanaimo",84906,49.15,-123.916667 ],
    [ u"ca",u"Nanticoke",24732,42.8,-80.066667 ],
    [ u"ca",u"Nanton",1936,50.35,-113.766667 ],
    [ u"ca",u"Napanee",8197,44.25,-76.95 ],
    [ u"ca",u"Napierville",3124,45.183333,-73.4 ],
    [ u"ca",u"Neepawa",3151,50.233333,-99.45 ],
    [ u"ca",u"Nelson",9813,49.483333,-117.283333 ],
    [ u"ca",u"New Glasgow",20322,45.583333,-62.633333 ],
    [ u"ca",u"New Richmond",2213,48.166667,-65.833333 ],
    [ u"ca",u"New Waterford",11026,46.25,-60.083333 ],
    [ u"ca",u"Nicolet",5257,46.216667,-72.6 ],
    [ u"ca",u"Nipawin",3994,53.366667,-104.016667 ],
    [ u"ca",u"Normandin",2728,48.833333,-72.516667 ],
    [ u"ca",u"Norman Wells",1027,65.283333,-126.85 ],
    [ u"ca",u"North Battleford",19440,52.766667,-108.283333 ],
    [ u"ca",u"North Bay",50171,46.3,-79.45 ],
    [ u"ca",u"Norwich",2651,42.983333,-80.6 ],
    [ u"ca",u"Norwood",1746,44.383333,-77.983333 ],
    [ u"ca",u"Notre-Dame-du-Lac",1545,47.6,-68.8 ],
    [ u"ca",u"Okotoks",14827,50.716667,-113.966667 ],
    [ u"ca",u"Olds",6947,51.783333,-114.1 ],
    [ u"ca",u"Oliver",4647,49.183333,-119.55 ],
    [ u"ca",u"Omemee",1393,44.3,-78.55 ],
    [ u"ca",u"One Hundred Mile House",1737,51.65,-121.283333 ],
    [ u"ca",u"Orangeville",32641,43.916667,-80.083333 ],
    [ u"ca",u"Orillia",30179,44.6,-79.416667 ],
    [ u"ca",u"Ormstown",1562,45.133333,-74 ],
    [ u"ca",u"Oromocto",8998,45.85,-66.466667 ],
    [ u"ca",u"Oshawa",247989,43.9,-78.866667 ],
    [ u"ca",u"Osoyoos",4314,49.033333,-119.466667 ],
    [ u"ca",u"Ottawa",874433,45.416667,-75.7 ],
    [ u"ca",u"Outlook",1989,51.5,-107.05 ],
    [ u"ca",u"Owen Sound",22625,44.566667,-80.85 ],
    [ u"ca",u"Oxbow",1058,49.216667,-102.166667 ],
    [ u"ca",u"Oxford",1283,45.733333,-63.866667 ],
    [ u"ca",u"Paisley",1091,44.3,-81.283333 ],
    [ u"ca",u"Palmerston",2660,43.833333,-80.85 ],
    [ u"ca",u"Pangnirtung",1320,66.133333,-65.75 ],
    [ u"ca",u"Papineauville",1600,45.616667,-75.016667 ],
    [ u"ca",u"Paris",10437,43.2,-80.383333 ],
    [ u"ca",u"Parkhill",1851,43.166667,-81.683333 ],
    [ u"ca",u"Parksville",21150,49.3,-124.316667 ],
    [ u"ca",u"Parrsboro",1472,45.4,-64.316667 ],
    [ u"ca",u"Parry Sound",6469,45.333333,-80.033333 ],
    [ u"ca",u"Peace River",5340,56.233333,-117.283333 ],
    [ u"ca",u"Peachland",1305,49.766667,-119.75 ],
    [ u"ca",u"Pemberton",1644,50.316667,-122.816667 ],
    [ u"ca",u"Pembroke",15551,45.816667,-77.116667 ],
    [ u"ca",u"Penhold",1818,52.133333,-113.866667 ],
    [ u"ca",u"Penticton",37721,49.5,-119.583333 ],
    [ u"ca",u"Perth",6481,44.883333,-76.233333 ],
    [ u"ca",u"Petawawa",11256,45.9,-77.283333 ],
    [ u"ca",u"Peterborough",75879,44.3,-78.333333 ],
    [ u"ca",u"Petrolia",5453,42.883333,-82.15 ],
    [ u"ca",u"Picton",4820,44.016667,-77.15 ],
    [ u"ca",u"Pictou",3732,45.666667,-62.7 ],
    [ u"ca",u"Pierreville",2172,46.066667,-72.8 ],
    [ u"ca",u"Pilot Butte",1728,50.466667,-104.416667 ],
    [ u"ca",u"Pinawa",1562,50.15,-95.883333 ],
    [ u"ca",u"Pincher Creek",3855,49.483333,-113.95 ],
    [ u"ca",u"Plaster Rock",1180,46.9,-67.383333 ],
    [ u"ca",u"Plessisville",7186,46.216667,-71.766667 ],
    [ u"ca",u"Ponoka",6656,52.683333,-113.566667 ],
    [ u"ca",u"Pont-Rouge",4978,46.75,-71.7 ],
    [ u"ca",u"Port Alberni",21282,49.233333,-124.8 ],
    [ u"ca",u"Port-Cartier",5851,50.016667,-66.866667 ],
    [ u"ca",u"Port Dover",5838,42.783333,-80.2 ],
    [ u"ca",u"Port Elgin",7147,44.433333,-81.383333 ],
    [ u"ca",u"Port Hardy",4628,50.716667,-127.5 ],
    [ u"ca",u"Port Hawkesbury",3564,45.6,-61.35 ],
    [ u"ca",u"Port Hope",11765,43.95,-78.3 ],
    [ u"ca",u"Portneuf",2694,46.683333,-71.883333 ],
    [ u"ca",u"Port Perry",7652,44.1,-78.933333 ],
    [ u"ca",u"Port Stanley",2663,42.666667,-81.216667 ],
    [ u"ca",u"Powassan",1243,46.066667,-79.35 ],
    [ u"ca",u"Powell River",12779,49.883333,-124.55 ],
    [ u"ca",u"Preeceville",1003,51.95,-102.666667 ],
    [ u"ca",u"Prescott",4466,44.716667,-75.516667 ],
    [ u"ca",u"Price",1830,48.6,-68.116667 ],
    [ u"ca",u"Prince Albert",34608,53.2,-105.75 ],
    [ u"ca",u"Prince George",65558,53.916667,-122.766667 ],
    [ u"ca",u"Prince Rupert",14708,54.316667,-130.333333 ],
    [ u"ca",u"Princeton",2706,49.45,-120.5 ],
    [ u"ca",u"Princeville",4041,46.166667,-71.883333 ],
    [ u"ca",u"Provost",2082,52.35,-110.266667 ],
    [ u"ca",u"Quebec",645623,46.8,-71.25 ],
    [ u"ca",u"Quesnel",13788,52.983333,-122.483333 ],
    [ u"ca",u"Rawdon",4978,46.033333,-73.7 ],
    [ u"ca",u"Raymond",3365,49.466667,-112.666667 ],
    [ u"ca",u"Red Deer",73595,52.266667,-113.8 ],
    [ u"ca",u"Redwater",2284,46.9,-79.633333 ],
    [ u"ca",u"Regina",176182,50.45,-104.616667 ],
    [ u"ca",u"Renfrew",8018,45.466667,-76.683333 ],
    [ u"ca",u"Revelstoke",7533,51,-118.183333 ],
    [ u"ca",u"Richmond",3472,45.183333,-75.833333 ],
    [ u"ca",u"Richmond",3485,45.666667,-72.15 ],
    [ u"ca",u"Ridgetown",3547,42.433333,-81.883333 ],
    [ u"ca",u"Rigaud",2525,45.466667,-74.3 ],
    [ u"ca",u"Rimbey",2227,52.633333,-114.216667 ],
    [ u"ca",u"Rimouski",38420,48.433333,-68.516667 ],
    [ u"ca",u"Rivers",1165,50.033333,-100.216667 ],
    [ u"ca",u"Riviere-au-Renard",2565,48.983333,-64.383333 ],
    [ u"ca",u"Rivière-du-Loup",15219,47.833333,-69.533333 ],
    [ u"ca",u"Roberval",9287,48.516667,-72.216667 ],
    [ u"ca",u"Roblin",1903,51.233333,-101.35 ],
    [ u"ca",u"Rockland",9023,45.533333,-75.283333 ],
    [ u"ca",u"Rocky Mountain House",6527,52.366667,-114.916667 ],
    [ u"ca",u"Rodney",1164,42.566667,-81.683333 ],
    [ u"ca",u"Rosetown",2309,51.55,-107.983333 ],
    [ u"ca",u"Rossland",3619,49.083333,-117.816667 ],
    [ u"ca",u"Sackville",2891,45.883333,-64.35 ],
    [ u"ca",u"Saint-Agapit",2048,46.566667,-71.433333 ],
    [ u"ca",u"Saint-Alexandre",1139,47.683333,-69.633333 ],
    [ u"ca",u"Saint-Ambroise",2015,48.55,-71.316667 ],
    [ u"ca",u"Saint-André-Avellin",1868,45.716667,-75.05 ],
    [ u"ca",u"Saint Andrews",1809,45.066667,-67.033333 ],
    [ u"ca",u"Saint-Anselme",1861,46.616667,-70.966667 ],
    [ u"ca",u"Saint Anthony",2492,51.383333,-55.6 ],
    [ u"ca",u"Saint-Augustin",3961,51.233333,-58.65 ],
    [ u"ca",u"Saint-Césaire",3175,45.4,-73 ],
    [ u"ca",u"Saint-Denis",1067,45.783333,-73.15 ],
    [ u"ca",u"Saint-Donat-de-Montcalm",1685,46.316667,-74.216667 ],
    [ u"ca",u"Sainte-Adèle",5467,45.95,-74.15 ],
    [ u"ca",u"Sainte-Agathe-des-Monts",5706,46.033333,-74.283333 ],
    [ u"ca",u"Sainte-Anne-des-Monts",5602,49.116667,-66.483333 ],
    [ u"ca",u"Sainte-Claire",2565,46.6,-70.85 ],
    [ u"ca",u"Sainte-Julienne",3211,45.966667,-73.716667 ],
    [ u"ca",u"Sainte-Marie",8735,46.433333,-71.016667 ],
    [ u"ca",u"Sainte-Martine",2535,45.233333,-73.8 ],
    [ u"ca",u"Sainte-Thècle",1340,46.8,-72.5 ],
    [ u"ca",u"Saint-Fabien",1157,48.283333,-68.866667 ],
    [ u"ca",u"Saint-Félicien",8088,48.65,-72.45 ],
    [ u"ca",u"Saint-Félix-de-Valois",3165,46.166667,-73.416667 ],
    [ u"ca",u"Saint-Gabriel",2901,46.283333,-73.366667 ],
    [ u"ca",u"Saint-Gédéon",1859,48.483333,-71.783333 ],
    [ u"ca",u"Saint-Georges",21416,46.116667,-70.666667 ],
    [ u"ca",u"Saint-Germain-de-Grantham",2145,45.833333,-72.566667 ],
    [ u"ca",u"Saint-Henri-de-Lévis",1380,46.683333,-71.066667 ],
    [ u"ca",u"Saint-Honoré",1742,47.716667,-69.133333 ],
    [ u"ca",u"Saint-Hyacinthe",50327,45.633333,-72.933333 ],
    [ u"ca",u"Saint-Jacques",2985,45.95,-73.583333 ],
    [ u"ca",u"Saint-Jean-de-Dieu",1161,48.016667,-69.05 ],
    [ u"ca",u"Saint-Jean-Port-Joli",1929,47.2,-70.266667 ],
    [ u"ca",u"Saint-Jérôme",54948,45.766667,-74 ],
    [ u"ca",u"Saint John",87857,45.266667,-66.066667 ],
    [ u"ca",u"Saint-Jovite",4020,46.116667,-74.583333 ],
    [ u"ca",u"Saint Leonard",1350,47.166667,-67.916667 ],
    [ u"ca",u"Saint-Marc-des-Carrières",2358,46.683333,-72.033333 ],
    [ u"ca",u"Saint Marys",6647,43.25,-81.133333 ],
    [ u"ca",u"Saint-Michel-des-Saints",1835,46.666667,-73.916667 ],
    [ u"ca",u"Saint-Pacôme",1371,47.416667,-69.95 ],
    [ u"ca",u"Saint-Pascal",2465,47.516667,-69.816667 ],
    [ u"ca",u"Saint Paul",5321,53.983333,-111.283333 ],
    [ u"ca",u"Saint-Pie",3034,45.5,-72.9 ],
    [ u"ca",u"Saint-Prosper",3095,46.2,-70.483333 ],
    [ u"ca",u"Saint Quentin",2207,47.5,-67.383333 ],
    [ u"ca",u"Saint-Raphaël",1276,46.783333,-70.75 ],
    [ u"ca",u"Saint-Raymond",3570,46.883333,-71.833333 ],
    [ u"ca",u"Saint-Rémi",4192,45.25,-73.6 ],
    [ u"ca",u"Saint-Sauveur-des-Monts",4869,45.9,-74.166667 ],
    [ u"ca",u"Saint Stephen",4518,45.2,-67.266667 ],
    [ u"ca",u"Saint Thomas",38694,42.783333,-81.183333 ],
    [ u"ca",u"Saint-Tite",2456,46.716667,-72.566667 ],
    [ u"ca",u"Salaberry-de-Valleyfield",38662,45.25,-74.133333 ],
    [ u"ca",u"Salisbury",1891,46.033333,-65.05 ],
    [ u"ca",u"Salmon Arm",10093,50.7,-119.283333 ],
    [ u"ca",u"Salmo",1125,49.2,-117.283333 ],
    [ u"ca",u"Sarnia",82998,42.966667,-82.4 ],
    [ u"ca",u"Saskatoon",198957,52.133333,-106.666667 ],
    [ u"ca",u"Sault Sainte Marie",63967,46.5,-84.333333 ],
    [ u"ca",u"Sayabec",1702,48.55,-67.683333 ],
    [ u"ca",u"Seaforth",2843,43.55,-81.383333 ],
    [ u"ca",u"Sechelt",5977,49.466667,-123.766667 ],
    [ u"ca",u"Selkirk",9653,50.15,-96.883333 ],
    [ u"ca",u"Senneterre",3228,48.4,-77.25 ],
    [ u"ca",u"Sept-Îles",22582,50.2,-66.383333 ],
    [ u"ca",u"Sexsmith",1743,55.35,-118.783333 ],
    [ u"ca",u"Shaunavon",1658,49.65,-108.416667 ],
    [ u"ca",u"Shawinigan",49161,46.55,-72.733333 ],
    [ u"ca",u"Shawville",1608,45.6,-76.483333 ],
    [ u"ca",u"Shediac",4735,46.216667,-64.533333 ],
    [ u"ca",u"Shelburne",1939,43.766667,-65.316667 ],
    [ u"ca",u"Shelburne",4390,44.066667,-80.2 ],
    [ u"ca",u"Shellbrook",1192,53.216667,-106.4 ],
    [ u"ca",u"Sherbrooke",129447,45.4,-71.9 ],
    [ u"ca",u"Sicamous",2732,50.833333,-119 ],
    [ u"ca",u"Simcoe",13446,42.833333,-80.3 ],
    [ u"ca",u"Sioux Lookout",3730,50.1,-91.916667 ],
    [ u"ca",u"Slave Lake",7661,55.283333,-114.783333 ],
    [ u"ca",u"Smithers",5438,54.766667,-127.166667 ],
    [ u"ca",u"Smiths Falls",10553,44.9,-76.016667 ],
    [ u"ca",u"Smithville",3504,43.1,-79.533333 ],
    [ u"ca",u"Smoky Lake",1063,54.113056,-112.473611 ],
    [ u"ca",u"Sooke",6145,48.383333,-123.733333 ],
    [ u"ca",u"Sorel",33591,46.05,-73.116667 ],
    [ u"ca",u"Souris",1752,49.616667,-100.25 ],
    [ u"ca",u"Souris",1284,46.35,-62.25 ],
    [ u"ca",u"Southampton",3549,44.5,-81.366667 ],
    [ u"ca",u"South River",1193,45.85,-79.366667 ],
    [ u"ca",u"Spirit River",1157,55.783333,-118.833333 ],
    [ u"ca",u"Springdale",2779,49.483333,-56.1 ],
    [ u"ca",u"Springhill",3940,45.633333,-64.05 ],
    [ u"ca",u"Spruce Grove",17767,53.533333,-113.916667 ],
    [ u"ca",u"Stayner",4104,44.416667,-80.083333 ],
    [ u"ca",u"Steinbach",9607,49.516667,-96.683333 ],
    [ u"ca",u"Stephenville Crossing",1183,48.516667,-58.416667 ],
    [ u"ca",u"Stephenville",6278,48.55,-58.566667 ],
    [ u"ca",u"Stettler",5494,52.333333,-112.683333 ],
    [ u"ca",u"Stirling",2270,44.3,-77.55 ],
    [ u"ca",u"Stonewall",4177,50.133333,-97.316667 ],
    [ u"ca",u"Stony Mountain",1770,50.066667,-97.216667 ],
    [ u"ca",u"Stony Plain",8939,53.533333,-114 ],
    [ u"ca",u"Stratford",30234,43.366667,-80.983333 ],
    [ u"ca",u"Strathmore",10009,51.04,-113.42 ],
    [ u"ca",u"Strathroy",13525,42.95,-81.616667 ],
    [ u"ca",u"Sturgeon Falls",6314,46.366667,-79.933333 ],
    [ u"ca",u"Sudbury",109724,46.5,-80.966667 ],
    [ u"ca",u"Summerland",6292,49.6,-119.666667 ],
    [ u"ca",u"Summerside",14808,46.4,-63.783333 ],
    [ u"ca",u"Sussex",4048,45.716667,-65.516667 ],
    [ u"ca",u"Sutton",6680,44.3,-79.366667 ],
    [ u"ca",u"Swan River",4198,52.1,-101.266667 ],
    [ u"ca",u"Swift Current",14702,50.283333,-107.766667 ],
    [ u"ca",u"Sydney Mines",15474,46.233333,-60.216667 ],
    [ u"ca",u"Sydney",32660,46.15,-60.166667 ],
    [ u"ca",u"Sylvan Lake",10520,52.3,-114.083333 ],
    [ u"ca",u"Taber",8163,49.783333,-112.15 ],
    [ u"ca",u"Tavistock",2654,43.316667,-80.833333 ],
    [ u"ca",u"Teeswater",1171,43.983333,-81.283333 ],
    [ u"ca",u"Temiscaming",1854,46.716667,-79.083333 ],
    [ u"ca",u"Terrace Bay",2060,48.783333,-87.1 ],
    [ u"ca",u"Terrace",19443,54.5,-128.583333 ],
    [ u"ca",u"The Pas",6055,53.816667,-101.233333 ],
    [ u"ca",u"Thessalon",1464,46.25,-83.55 ],
    [ u"ca",u"Thetford Mines",22007,46.083333,-71.3 ],
    [ u"ca",u"Thompson",12467,55.75,-97.866667 ],
    [ u"ca",u"Thornbury",1970,44.55,-80.45 ],
    [ u"ca",u"Three Hills",3051,51.7,-113.266667 ],
    [ u"ca",u"Thunder Bay",99336,48.4,-89.233333 ],
    [ u"ca",u"Thurso",2476,45.583333,-75.233333 ],
    [ u"ca",u"Tilbury",4858,42.25,-82.433333 ],
    [ u"ca",u"Tilsonburg",14843,42.866667,-80.733333 ],
    [ u"ca",u"Timmins",32901,48.466667,-81.333333 ],
    [ u"ca",u"Tofield",1911,53.366667,-112.666667 ],
    [ u"ca",u"Torbay",3097,47.65,-52.733333 ],
    [ u"ca",u"Toronto",4612187,43.666667,-79.416667 ],
    [ u"ca",u"Tottenham",5101,44.016667,-79.8 ],
    [ u"ca",u"Trail",9707,49.1,-117.716667 ],
    [ u"ca",u"Trois-Pistoles",3695,48.116667,-69.166667 ],
    [ u"ca",u"Trois-Rivières",119693,46.35,-72.55 ],
    [ u"ca",u"Truro",20650,45.366667,-63.3 ],
    [ u"ca",u"Tuktoyaktuk",978,69.45,-133.066667 ],
    [ u"ca",u"Tweed",1626,44.466667,-77.3 ],
    [ u"ca",u"Two Hills",1147,53.716667,-111.75 ],
    [ u"ca",u"Ucluelet",1566,48.933333,-125.516667 ],
    [ u"ca",u"Unity",2096,52.433333,-109.166667 ],
    [ u"ca",u"Uxbridge",9020,44.1,-79.116667 ],
    [ u"ca",u"Valcourt",2451,45.483333,-72.316667 ],
    [ u"ca",u"Val-David",1211,46.033333,-74.2 ],
    [ u"ca",u"Vallée-Jonction",1216,46.366667,-70.916667 ],
    [ u"ca",u"Valleyview",1951,55.066667,-117.283333 ],
    [ u"ca",u"Vancouver",1837970,49.25,-123.133333 ],
    [ u"ca",u"Vanderhoof",1462,54.016667,-124.016667 ],
    [ u"ca",u"Vankleek Hill",2136,45.516667,-74.65 ],
    [ u"ca",u"Vegreville",5678,53.5,-112.05 ],
    [ u"ca",u"Verchères",4030,45.766667,-73.35 ],
    [ u"ca",u"Vermilion",4151,53.35,-110.85 ],
    [ u"ca",u"Vernon",47275,50.266667,-119.266667 ],
    [ u"ca",u"Victoria",289625,48.433333,-123.35 ],
    [ u"ca",u"Victoriaville",34426,46.05,-71.966667 ],
    [ u"ca",u"Viking",1106,53.083333,-111.783333 ],
    [ u"ca",u"Ville-Marie",2831,47.333333,-79.433333 ],
    [ u"ca",u"Virden",3237,49.85,-100.933333 ],
    [ u"ca",u"Vulcan",1853,50.4,-113.25 ],
    [ u"ca",u"Wabana",2362,47.65,-52.933333 ],
    [ u"ca",u"Wadena",1319,51.95,-103.8 ],
    [ u"ca",u"Wainwright",5380,52.833333,-110.866667 ],
    [ u"ca",u"Walkerton",5250,44.133333,-81.15 ],
    [ u"ca",u"Wallaceburg",10693,42.583333,-82.366667 ],
    [ u"ca",u"Warman",3252,52.316667,-106.566667 ],
    [ u"ca",u"Warwick",3340,45.95,-71.983333 ],
    [ u"ca",u"Wasaga Beach",7567,44.52,-79.99 ],
    [ u"ca",u"Waterford",3033,42.933333,-80.283333 ],
    [ u"ca",u"Waterloo",110800,43.466667,-80.533333 ],
    [ u"ca",u"Waterloo",4064,45.35,-72.516667 ],
    [ u"ca",u"Watford",1716,42.95,-81.883333 ],
    [ u"ca",u"Watrous",1689,51.666667,-105.466667 ],
    [ u"ca",u"Wawa",3463,48,-84.783333 ],
    [ u"ca",u"Wellington",2052,43.95,-77.35 ],
    [ u"ca",u"Wembley",1574,55.15,-119.15 ],
    [ u"ca",u"Westlock",5067,54.15,-113.866667 ],
    [ u"ca",u"West Lorne",1540,42.6,-81.6 ],
    [ u"ca",u"Wetaskiwin",11302,52.966667,-113.383333 ],
    [ u"ca",u"Weyburn",9362,49.666667,-103.85 ],
    [ u"ca",u"Wheatley",2028,42.1,-82.45 ],
    [ u"ca",u"Whitchurch-Stouffville",11696,43.966667,-79.25 ],
    [ u"ca",u"Whitecourt",8763,54.133333,-115.683333 ],
    [ u"ca",u"Whitehorse",19616,60.716667,-135.05 ],
    [ u"ca",u"White Rock",66450,49.033333,-122.816667 ],
    [ u"ca",u"Wiarton",2481,44.733333,-81.133333 ],
    [ u"ca",u"Wilkie",1198,52.416667,-108.7 ],
    [ u"ca",u"Williams Lake",14168,52.116667,-122.15 ],
    [ u"ca",u"Winchester",2564,45.1,-75.35 ],
    [ u"ca",u"Windsor",3864,44.983333,-64.133333 ],
    [ u"ca",u"Windsor",278013,42.333333,-83.033333 ],
    [ u"ca",u"Windsor",5408,45.583333,-72 ],
    [ u"ca",u"Wingham",3047,43.883333,-81.3 ],
    [ u"ca",u"Winkler",8270,49.183333,-97.933333 ],
    [ u"ca",u"Winnipeg",632069,49.883333,-97.166667 ],
    [ u"ca",u"Wolfville",3523,45.083333,-64.366667 ],
    [ u"ca",u"Woodstock",5032,46.15,-67.566667 ],
    [ u"ca",u"Woodstock",33893,43.133333,-80.75 ],
    [ u"ca",u"Wynyard",1793,51.766667,-104.183333 ],
    [ u"ca",u"Wyoming",2324,42.95,-82.116667 ],
    [ u"ca",u"Yamachiche",1255,46.283333,-72.833333 ],
    [ u"ca",u"Yarmouth",7500,43.833333,-66.116667 ],
    [ u"ca",u"Yellowknife",15866,62.45,-114.35 ],
    [ u"ca",u"Yorkton",15172,51.216667,-102.466667 ],
    [ u"cd",u"Aketi",35158,2.733333,23.766667 ],
    [ u"cd",u"Bandundu",118203,-3.316667,17.366667 ],
    [ u"cd",u"Basoko",43706,1.233333,23.6 ],
    [ u"cd",u"Beni",89643,.5,29.466667 ],
    [ u"cd",u"Binga",60037,2.383333,20.5 ],
    [ u"cd",u"Boende",32089,-.216667,20.866667 ],
    [ u"cd",u"Bolobo",27860,-2.166667,16.233333 ],
    [ u"cd",u"Boma",344522,-5.85,13.05 ],
    [ u"cd",u"Bondo",17858,3.816667,23.666667 ],
    [ u"cd",u"Bongandanga",4104,1.5,21.05 ],
    [ u"cd",u"Bosobolo",14552,4.183333,19.9 ],
    [ u"cd",u"Bukama",38801,-9.2,25.85 ],
    [ u"cd",u"Bukavu",225431,-2.508333,28.860833 ],
    [ u"cd",u"Bulungu",48340,-4.55,18.6 ],
    [ u"cd",u"Bumba",95514,2.183333,22.466667 ],
    [ u"cd",u"Bunia",96757,1.566667,30.25 ],
    [ u"cd",u"Businga",28917,3.333333,20.883333 ],
    [ u"cd",u"Buta",45674,2.8,24.733333 ],
    [ u"cd",u"Butembo",154649,.15,29.283333 ],
    [ u"cd",u"Demba",22261,-5.51,22.266667 ],
    [ u"cd",u"Dibaya",4571,-6.5,22.95 ],
    [ u"cd",u"Gandajika",154414,-6.75,23.95 ],
    [ u"cd",u"Gbadolite",50489,4.283333,21.016667 ],
    [ u"cd",u"Gemena",117631,3.25,19.766667 ],
    [ u"cd",u"Goma",144151,-1.679167,29.222778 ],
    [ u"cd",u"Ilebo",107086,-4.316667,20.583333 ],
    [ u"cd",u"Inongo",40110,-1.95,18.266667 ],
    [ u"cd",u"Isiro",127068,2.766667,27.616667 ],
    [ u"cd",u"Kabalo",29857,-6.05,26.916667 ],
    [ u"cd",u"Kabare",37031,-2.468333,28.824167 ],
    [ u"cd",u"Kabinda",58999,-6.133333,24.483333 ],
    [ u"cd",u"Kalemie",147065,-5.933333,29.2 ],
    [ u"cd",u"Kambove",36731,-10.876389,26.596944 ],
    [ u"cd",u"Kamina",73616,-8.738611,24.990556 ],
    [ u"cd",u"Kampene",37031,-3.6,26.666667 ],
    [ u"cd",u"Kananga",463556,-5.895833,22.417778 ],
    [ u"cd",u"Kaniama",29435,-7.516667,24.183333 ],
    [ u"cd",u"Kasangulu",27960,-4.591111,15.170833 ],
    [ u"cd",u"Kasongo",55115,-4.45,26.666667 ],
    [ u"cd",u"Kasongo-Lunda",20059,-6.466667,16.816667 ],
    [ u"cd",u"Kikwit",186995,-5.038611,18.818056 ],
    [ u"cd",u"Kindu",135690,-2.95,25.95 ],
    [ u"cd",u"Kinshasa",7787832,-4.3,15.3 ],
    [ u"cd",u"Kipushi",62382,-11.766667,27.233333 ],
    [ u"cd",u"Kisangani",539164,.516667,25.2 ],
    [ u"cd",u"Kongolo",31969,-5.383333,27 ],
    [ u"cd",u"Libenge",27051,3.65,18.633333 ],
    [ u"cd",u"Likasi",422726,-10.981389,26.733333 ],
    [ u"cd",u"Lisala",70082,2.15,21.516667 ],
    [ u"cd",u"Lodja",68239,-3.483333,23.433333 ],
    [ u"cd",u"Lubao",43065,-5.366667,25.75 ],
    [ u"cd",u"Lubumbashi",1374808,-11.666667,27.466667 ],
    [ u"cd",u"Luebo",35181,-5.35,21.416667 ],
    [ u"cd",u"Lusambo",41413,-4.966667,23.45 ],
    [ u"cd",u"Mangai",37185,-4.05,19.533333 ],
    [ u"cd",u"Manono",37583,-7.3,27.416667 ],
    [ u"cd",u"Matadi",180115,-5.816667,13.45 ],
    [ u"cd",u"Mbandaka",184189,.066667,18.266667 ],
    [ u"cd",u"Mbanza-Ngungu",86351,-5.25,14.866667 ],
    [ u"cd",u"Mbuji-Mayi",874974,-6.15,23.6 ],
    [ u"cd",u"Moba",29854,-7.05,29.783333 ],
    [ u"cd",u"Mushie",33060,-3.016667,16.9 ],
    [ u"cd",u"Mweka",50672,-4.85,21.566667 ],
    [ u"cd",u"Mwene-Ditu",189215,-7,23.45 ],
    [ u"cd",u"Nioki",40692,-2.716667,17.683333 ],
    [ u"cd",u"Tshela",38843,-4.983333,12.933333 ],
    [ u"cd",u"Tshikapa",267508,-6.416667,20.8 ],
    [ u"cd",u"Uvira",170422,-3.406667,29.145833 ],
    [ u"cd",u"Wamba",17371,2.15,28 ],
    [ u"cd",u"Watsa",24515,3.05,29.533333 ],
    [ u"cd",u"Yangambi",35529,.783333,24.466667 ],
    [ u"cf",u"Alindao",20125,5.0333333,21.2166667 ],
    [ u"cf",u"Baboua",9034,5.8,14.8166667 ],
    [ u"cf",u"Bambari",54783,5.7619444,20.6672222 ],
    [ u"cf",u"Bangassou",34720,4.7333333,22.8166667 ],
    [ u"cf",u"Bangui",684190,4.3666667,18.5833333 ],
    [ u"cf",u"Baoro",8937,5.6666667,15.9666667 ],
    [ u"cf",u"Batangafo",19810,7.3,18.3 ],
    [ u"cf",u"Berbérati",59963,4.2666667,15.7833333 ],
    [ u"cf",u"Bimbo",55849,4.3,18.55 ],
    [ u"cf",u"Birao",11833,10.2833333,22.7833333 ],
    [ u"cf",u"Boali",4696,4.8,18.1166667 ],
    [ u"cf",u"Bocaranga",14002,6.9833333,15.65 ],
    [ u"cf",u"Boda",20621,4.3166667,17.4666667 ],
    [ u"cf",u"Bossangoa",39607,6.4833333,17.45 ],
    [ u"cf",u"Bossembélé",11518,5.2666667,17.65 ],
    [ u"cf",u"Bouar",55031,5.95,15.6 ],
    [ u"cf",u"Bouca",19383,6.5,18.2833333 ],
    [ u"cf",u"Bozoum",36548,6.3166667,16.3833333 ],
    [ u"cf",u"Bria",47190,6.5333333,21.9833333 ],
    [ u"cf",u"Carnot",83761,4.9333333,15.8666667 ],
    [ u"cf",u"Damara",16056,4.9666667,18.7 ],
    [ u"cf",u"Dekoa",17390,6.3166667,19.0666667 ],
    [ u"cf",u"Gambo",6210,4.65,22.2666667 ],
    [ u"cf",u"Gamboula",8028,4.1333333,15.15 ],
    [ u"cf",u"Grimari",16486,5.7333333,20.05 ],
    [ u"cf",u"Ippy",24274,6.25,21.2 ],
    [ u"cf",u"Kabo",17683,7.5833333,18.6333333 ],
    [ u"cf",u"Kembé",22348,4.6,21.9 ],
    [ u"cf",u"Kouango",9694,4.9666667,19.9833333 ],
    [ u"cf",u"Mbaïki",76350,3.8833333,18.0 ],
    [ u"cf",u"Mobaye",24518,4.3166667,21.1833333 ],
    [ u"cf",u"Mongoumba",11663,3.6333333,18.6 ],
    [ u"cf",u"Ndélé",11941,8.4091667,20.6530556 ],
    [ u"cf",u"Nola",53270,3.5333333,16.0666667 ],
    [ u"cf",u"Obo",14038,5.4,26.5 ],
    [ u"cf",u"Ouadda",5901,8.0666667,22.4 ],
    [ u"cf",u"Ouango",5453,4.3166667,22.55 ],
    [ u"cf",u"Paoua",31595,7.25,16.4333333 ],
    [ u"cf",u"Rafaï",16814,4.95,23.9166667 ],
    [ u"cf",u"Sibut",32547,5.7333333,19.0833333 ],
    [ u"cf",u"Zemio",7453,5.0333333,25.1333333 ],
    [ u"cg",u"Brazzaville",1115773,-4.2591667,15.2847222 ],
    [ u"cg",u"Djambala",9650,-2.5447222,14.7533333 ],
    [ u"cg",u"Ewo",4923,-0.8725,14.8205556 ],
    [ u"cg",u"Gamboma",20877,-1.8763889,15.8644444 ],
    [ u"cg",u"Impfondo",20859,1.6380556,18.0666667 ],
    [ u"cg",u"Kinkala",13882,-4.3613889,14.7644444 ],
    [ u"cg",u"Loandjili",26387,-4.7561111,11.8577778 ],
    [ u"cg",u"Loubomo",70734,-4.1997222,12.6738889 ],
    [ u"cg",u"Madingou",22760,-4.1536111,13.55 ],
    [ u"cg",u"Matsanga",3582,-1.9158333,12.6680556 ],
    [ u"cg",u"Mossendjo",21555,-2.9505556,12.7261111 ],
    [ u"cg",u"Nkayi",70945,-4.1655556,13.2927778 ],
    [ u"cg",u"Ouésso",16691,1.6136111,16.0516667 ],
    [ u"cg",u"Owando",16590,-0.4869444,15.9080556 ],
    [ u"cg",u"Sémbé",2514,1.6480556,14.5805556 ],
    [ u"cg",u"Sibiti",19089,-3.6858333,13.3458333 ],
    [ u"ch",u"Aadorf",7100,47.492721,8.898326 ],
    [ u"ch",u"Aarau",15007,47.389616,8.052354 ],
    [ u"ch",u"Aarburg",6484,47.319634,7.901413 ],
    [ u"ch",u"Adliswil",16144,47.311896,8.528684 ],
    [ u"ch",u"Aesch",10396,47.469456,7.595763 ],
    [ u"ch",u"Affoltern",10415,47.281224,8.45346 ],
    [ u"ch",u"Aigle",7897,46.318103,6.964567 ],
    [ u"ch",u"Allschwil",18745,47.550744,7.535994 ],
    [ u"ch",u"Alpnach",5139,46.940195,8.274263 ],
    [ u"ch",u"Altdorf",8833,46.880422,8.644409 ],
    [ u"ch",u"Altstatten",10585,47.379433,9.548989 ],
    [ u"ch",u"Amriswil",11543,47.546992,9.298365 ],
    [ u"ch",u"Appenzell",5541,47.328914,9.410547 ],
    [ u"ch",u"Arbon",13125,47.515392,9.434779 ],
    [ u"ch",u"Arlesheim",9737,47.495875,7.619839 ],
    [ u"ch",u"Arosa",2162,46.777926,9.676206 ],
    [ u"ch",u"Arth",10100,47.06337,8.523485 ],
    [ u"ch",u"Ascona",5236,46.156255,8.778395 ],
    [ u"ch",u"Au",6864,47.432211,9.633869 ],
    [ u"ch",u"Baar",20752,47.196254,8.529544 ],
    [ u"ch",u"Baden",16659,47.478029,8.302764 ],
    [ u"ch",u"Bad Ragaz",4786,47.005367,9.501217 ],
    [ u"ch",u"Bagnes",7114,46.083333,7.216667 ],
    [ u"ch",u"Balsthal",5576,47.31591,7.693047 ],
    [ u"ch",u"Basel",164474,47.558395,7.573271 ],
    [ u"ch",u"Bassersdorf",9860,47.443184,8.625859 ],
    [ u"ch",u"Bellinzona",17006,46.195201,9.02283 ],
    [ u"ch",u"Belp",9594,46.890805,7.499042 ],
    [ u"ch",u"Bern",123018,46.916667,7.466667 ],
    [ u"ch",u"Bernex",9266,46.177162,6.074159 ],
    [ u"ch",u"Bex",5995,46.252137,7.011408 ],
    [ u"ch",u"Biasca",5937,46.360581,8.969103 ],
    [ u"ch",u"Biberist",7463,47.185591,7.56005 ],
    [ u"ch",u"Biel",49675,47.141666,7.257589 ],
    [ u"ch",u"Binningen",15046,47.533588,7.568512 ],
    [ u"ch",u"Birmensdorf",5630,47.35465,8.437566 ],
    [ u"ch",u"Birsfelden",10627,47.554953,7.645868 ],
    [ u"ch",u"Blonay",5294,46.465737,6.895053 ],
    [ u"ch",u"Bolligen",6291,46.974194,7.495697 ],
    [ u"ch",u"Bottmingen",5956,47.522735,7.569016 ],
    [ u"ch",u"Boudry",5038,46.953019,6.83897 ],
    [ u"ch",u"Bremgarten",6702,47.352604,8.329955 ],
    [ u"ch",u"Brugg",9159,47.481527,8.203014 ],
    [ u"ch",u"Bubikon",6160,47.267748,8.818391 ],
    [ u"ch",u"Buchrain",5802,47.086016,8.346213 ],
    [ u"ch",u"Buchs",6397,47.387774,8.073525 ],
    [ u"ch",u"Buchs",10361,47.169856,9.47544 ],
    [ u"ch",u"Bulach",14776,47.518898,8.536967 ],
    [ u"ch",u"Bulle",12460,46.619499,7.056743 ],
    [ u"ch",u"Buochs",5272,46.973976,8.422788 ],
    [ u"ch",u"Burgdorf",14943,47.058495,7.622139 ],
    [ u"ch",u"Bussigny",7317,46.551102,6.555973 ],
    [ u"ch",u"Carouge",19688,46.186153,6.13463 ],
    [ u"ch",u"Cham",13431,47.182126,8.463576 ],
    [ u"ch",u"Chavannes",5740,46.528825,6.592058 ],
    [ u"ch",u"Chene-Bougeries",9821,46.197545,6.162082 ],
    [ u"ch",u"Chene-Bourg",8038,46.193049,6.196567 ],
    [ u"ch",u"Chiasso",8232,45.83491,9.02054 ],
    [ u"ch",u"Chur",32874,46.856753,9.526918 ],
    [ u"ch",u"Colombier",5133,46.967085,6.856604 ],
    [ u"ch",u"Conthey",6747,46.225283,7.303715 ],
    [ u"ch",u"Crissier",6915,46.55165,6.571253 ],
    [ u"ch",u"Delemont",11567,47.366429,7.329005 ],
    [ u"ch",u"Derendingen",5916,47.198505,7.588438 ],
    [ u"ch",u"Diepoldsau",5351,47.384835,9.655969 ],
    [ u"ch",u"Dietikon",22443,47.404446,8.394984 ],
    [ u"ch",u"Dietlikon",7121,47.425084,8.618775 ],
    [ u"ch",u"Domat",6818,46.834827,9.450752 ],
    [ u"ch",u"Dornach",5940,47.478042,7.616417 ],
    [ u"ch",u"Dubendorf",23051,47.395395,8.618366 ],
    [ u"ch",u"Dudingen",7088,46.849152,7.188475 ],
    [ u"ch",u"Durnten",6225,47.277691,8.842176 ],
    [ u"ch",u"Ebikon",11473,47.079366,8.340411 ],
    [ u"ch",u"Ebnat-Kappel",4740,47.261951,9.124726 ],
    [ u"ch",u"Ecublens",10655,46.60915,6.808706 ],
    [ u"ch",u"Egg",8585,47.300555,8.687429 ],
    [ u"ch",u"Einsiedeln",13188,47.126727,8.745245 ],
    [ u"ch",u"Embrach",8517,47.507063,8.595681 ],
    [ u"ch",u"Emmen",27290,47.081101,8.30477 ],
    [ u"ch",u"Epalinges",7521,46.551775,6.668288 ],
    [ u"ch",u"Eschenbach",5167,47.239806,8.921562 ],
    [ u"ch",u"Ettingen",4917,47.482675,7.549821 ],
    [ u"ch",u"Fallanden",6987,47.370719,8.639834 ],
    [ u"ch",u"Flawil",9878,47.414611,9.182838 ],
    [ u"ch",u"Flums",4936,47.092512,9.342604 ],
    [ u"ch",u"Frauenfeld",22639,47.558159,8.898544 ],
    [ u"ch",u"Freienbach",14900,47.204077,8.756933 ],
    [ u"ch",u"Frenkendorf",5984,47.506858,7.716483 ],
    [ u"ch",u"Fribourg",33806,46.79572,7.154748 ],
    [ u"ch",u"Frutigen",6668,46.58782,7.64751 ],
    [ u"ch",u"Fully",5965,46.138485,7.114872 ],
    [ u"ch",u"Gelterkinden",5541,47.464968,7.85174 ],
    [ u"ch",u"Geneva",181492,46.195602,6.148113 ],
    [ u"ch",u"Gerlafingen",5032,47.169782,7.575051 ],
    [ u"ch",u"Giubiasco",7926,46.176481,9.008847 ],
    [ u"ch",u"Gland",11194,46.421233,6.266986 ],
    [ u"ch",u"Glarus",5889,47.04057,9.068036 ],
    [ u"ch",u"Gossau",17268,47.41694,9.251252 ],
    [ u"ch",u"Gossau",9028,47.306992,8.757972 ],
    [ u"ch",u"Grabs",6244,47.182061,9.443083 ],
    [ u"ch",u"Granichen",6444,47.359297,8.10243 ],
    [ u"ch",u"Greifensee",5080,47.367869,8.680017 ],
    [ u"ch",u"Grenchen",16135,47.19354,7.396577 ],
    [ u"ch",u"Heimberg",5586,46.794824,7.604332 ],
    [ u"ch",u"Hergiswil",5477,46.984209,8.310356 ],
    [ u"ch",u"Herisau",15444,47.386276,9.280779 ],
    [ u"ch",u"Herrliberg",5922,47.288144,8.612224 ],
    [ u"ch",u"Herzogenbuchsee",5734,47.187406,7.707457 ],
    [ u"ch",u"Hinwil",10533,47.300822,8.842076 ],
    [ u"ch",u"Hochdorf",7793,47.168408,8.291788 ],
    [ u"ch",u"Hombrechtikon",7795,47.25208,8.77437 ],
    [ u"ch",u"Horgen",18055,47.255924,8.598672 ],
    [ u"ch",u"Horw",12110,47.016917,8.309556 ],
    [ u"ch",u"Hunenberg",8060,47.178931,8.423515 ],
    [ u"ch",u"Huttwil",4480,47.11502,7.862087 ],
    [ u"ch",u"Igis",7078,46.945308,9.57218 ],
    [ u"ch",u"Ingenbohl",7964,47.004642,8.614768 ],
    [ u"ch",u"Interlaken",5057,46.683872,7.866376 ],
    [ u"ch",u"Jona",17806,47.230265,8.841838 ],
    [ u"ch",u"Kerns",5375,46.900882,8.276516 ],
    [ u"ch",u"Kilchberg",6918,47.318309,8.551172 ],
    [ u"ch",u"Kirchberg",8073,47.411412,9.039848 ],
    [ u"ch",u"Kirchberg",5279,47.086574,7.588896 ],
    [ u"ch",u"Kloten",18141,47.449817,8.594777 ],
    [ u"ch",u"Koniz",35961,46.923391,7.408688 ],
    [ u"ch",u"Konolfingen",4509,46.879674,7.622618 ],
    [ u"ch",u"Kreuzlingen",17233,47.648212,9.180338 ],
    [ u"ch",u"Kriens",26117,47.035366,8.276307 ],
    [ u"ch",u"Kusnacht",13000,47.31776,8.581943 ],
    [ u"ch",u"Kussnacht",11771,47.085571,8.442057 ],
    [ u"ch",u"Kuttigen",5092,47.415658,8.047673 ],
    [ u"ch",u"La Chaux-de-Fonds",36971,47.104417,6.828892 ],
    [ u"ch",u"Lachen",6879,47.191524,8.856195 ],
    [ u"ch",u"Langenthal",14533,47.21526,7.796072 ],
    [ u"ch",u"Langnau",8731,46.93936,7.78738 ],
    [ u"ch",u"Langnau",6721,47.285027,8.534167 ],
    [ u"ch",u"La Tour-de-Peilz",10835,46.453552,6.858596 ],
    [ u"ch",u"Laufen",5223,47.420878,7.507521 ],
    [ u"ch",u"Lausanne",118015,46.533333,6.666667 ],
    [ u"ch",u"Lausen",5043,47.475823,7.765687 ],
    [ u"ch",u"Le Grand-Saconnex",8457,46.226419,6.123303 ],
    [ u"ch",u"Le Locle",9933,47.059533,6.752278 ],
    [ u"ch",u"Le Mont-sur-Lausanne",5139,46.557743,6.634562 ],
    [ u"ch",u"Lengnau",4302,47.183824,7.373714 ],
    [ u"ch",u"Lenzburg",7616,47.384048,8.181798 ],
    [ u"ch",u"Liestal",12491,47.482779,7.742975 ],
    [ u"ch",u"Littau",16403,47.050004,8.262739 ],
    [ u"ch",u"Locarno",13998,46.16497,8.799253 ],
    [ u"ch",u"Losone",6060,46.133333,8.75 ],
    [ u"ch",u"Lugano",26327,46.006182,8.951142 ],
    [ u"ch",u"Lutry",8625,46.504873,6.685161 ],
    [ u"ch",u"Luzern",57269,47.083333,8.266667 ],
    [ u"ch",u"Lyss",10892,47.077573,7.31162 ],
    [ u"ch",u"Malters",6303,47.03628,8.181928 ],
    [ u"ch",u"Mannedorf",10164,47.252851,8.690581 ],
    [ u"ch",u"Martigny",14413,46.104593,7.076771 ],
    [ u"ch",u"Massagno",5918,46.015621,8.945343 ],
    [ u"ch",u"Maur",9577,47.339262,8.671352 ],
    [ u"ch",u"Meggen",6593,47.04722,8.369489 ],
    [ u"ch",u"Meilen",11723,47.270429,8.643675 ],
    [ u"ch",u"Meiringen",4708,46.726776,8.183961 ],
    [ u"ch",u"Mendrisio",6192,45.86741,8.982097 ],
    [ u"ch",u"Menziken",5645,47.242487,8.19047 ],
    [ u"ch",u"Meyrin",19691,46.228245,6.064189 ],
    [ u"ch",u"Minusio",6772,46.175242,8.820102 ],
    [ u"ch",u"Mohlin",8353,47.556412,7.846873 ],
    [ u"ch",u"Monthey",16002,46.255457,6.960665 ],
    [ u"ch",u"Montreux",23703,46.433715,6.913179 ],
    [ u"ch",u"Morges",13759,46.511255,6.495693 ],
    [ u"ch",u"Moutier",7476,47.277733,7.369712 ],
    [ u"ch",u"Munchenbuchsee",10774,47.020946,7.448956 ],
    [ u"ch",u"Munchenstein",12059,47.510513,7.617668 ],
    [ u"ch",u"Munsingen",11326,46.87309,7.568647 ],
    [ u"ch",u"Muri",6307,47.270428,8.3382 ],
    [ u"ch",u"Muri",12280,46.931714,7.494164 ],
    [ u"ch",u"Murten",5377,46.92684,7.110343 ],
    [ u"ch",u"Muttenz",16646,47.525259,7.644511 ],
    [ u"ch",u"Naters",7472,46.32448,7.99137 ],
    [ u"ch",u"Nendaz",5477,46.191142,7.311152 ],
    [ u"ch",u"Neuchatel",31216,46.993089,6.93005 ],
    [ u"ch",u"Neuenhof",7358,47.452596,8.325772 ],
    [ u"ch",u"Neuenkirch",5683,47.099891,8.204161 ],
    [ u"ch",u"Nidau",6932,47.129167,7.238464 ],
    [ u"ch",u"Nyon",17071,46.388848,6.239319 ],
    [ u"ch",u"Oberengstringen",6106,47.410151,8.460978 ],
    [ u"ch",u"Oberentfelden",6981,47.360291,8.039193 ],
    [ u"ch",u"Oberglatt",5346,47.475281,8.520368 ],
    [ u"ch",u"Oberriet",7717,47.319883,9.566079 ],
    [ u"ch",u"Obersiggenthal",7683,47.489554,8.290437 ],
    [ u"ch",u"Oberuzwil",5600,47.430722,9.124194 ],
    [ u"ch",u"Oberwil",9957,47.508519,7.555238 ],
    [ u"ch",u"Oftringen",10062,47.31382,7.925327 ],
    [ u"ch",u"Ollon",6494,46.297564,6.99499 ],
    [ u"ch",u"Olten",16555,47.357058,7.909101 ],
    [ u"ch",u"Onex",16796,46.183909,6.101809 ],
    [ u"ch",u"Opfikon",13395,47.432553,8.580231 ],
    [ u"ch",u"Orbe",5466,46.724717,6.530103 ],
    [ u"ch",u"Payerne",7758,46.82201,6.93608 ],
    [ u"ch",u"Peseux",5580,46.982998,6.881593 ],
    [ u"ch",u"Pfaffikon",9987,47.364528,8.78395 ],
    [ u"ch",u"Plan-les-Ouates",8135,46.167615,6.119125 ],
    [ u"ch",u"Porrentruy",6453,47.415327,7.075221 ],
    [ u"ch",u"Pratteln",14861,47.52118,7.688415 ],
    [ u"ch",u"Pregassona",7491,46.02142,8.969476 ],
    [ u"ch",u"Prilly",10774,46.522445,6.622151 ],
    [ u"ch",u"Pully",16640,46.510544,6.656071 ],
    [ u"ch",u"Rapperswil",7959,47.227986,8.825954 ],
    [ u"ch",u"Regensdorf",15756,47.429855,8.465128 ],
    [ u"ch",u"Reinach",7756,47.259435,8.188453 ],
    [ u"ch",u"Renens",17530,46.539894,6.588096 ],
    [ u"ch",u"Rheinfelden",10657,47.562979,7.780108 ],
    [ u"ch",u"Richterswil",11398,47.207416,8.705841 ],
    [ u"ch",u"Risch",8645,46.409984,7.338869 ],
    [ u"ch",u"Romanshorn",9060,47.565858,9.378694 ],
    [ u"ch",u"Rothrist",7141,47.305162,7.890945 ],
    [ u"ch",u"Rumlang",6304,47.451787,8.526777 ],
    [ u"ch",u"Ruschlikon",5246,47.307744,8.555743 ],
    [ u"ch",u"Ruswil",6441,47.084253,8.126446 ],
    [ u"ch",u"Ruti",11361,47.261507,8.852445 ],
    [ u"ch",u"Saanen",6644,46.489557,7.259609 ],
    [ u"ch",u"Saint-Imier",4701,47.152195,6.995124 ],
    [ u"ch",u"Sankt Margrethen",4995,47.442304,9.629598 ],
    [ u"ch",u"Sargans",4991,47.048421,9.444797 ],
    [ u"ch",u"Sarnen",9405,46.898509,8.250681 ],
    [ u"ch",u"Saviese",5653,46.251153,7.345578 ],
    [ u"ch",u"Schaffhausen",34445,47.697316,8.634929 ],
    [ u"ch",u"Schattdorf",4779,46.865501,8.654655 ],
    [ u"ch",u"Schlieren",13762,47.39646,8.448587 ],
    [ u"ch",u"Schonenwerd",4470,47.3691,8.001674 ],
    [ u"ch",u"Schubelbach",8292,47.173785,8.927867 ],
    [ u"ch",u"Schwyz",14425,47.027858,8.656112 ],
    [ u"ch",u"Seon",4556,47.3449,8.156071 ],
    [ u"ch",u"Seuzach",7061,47.536974,8.731668 ],
    [ u"ch",u"Sevelen",4450,47.122292,9.489926 ],
    [ u"ch",u"Sierre",14648,46.293235,7.536934 ],
    [ u"ch",u"Sion",28246,46.229076,7.359417 ],
    [ u"ch",u"Sirnach",6658,47.463275,8.990668 ],
    [ u"ch",u"Sissach",5680,47.467368,7.799596 ],
    [ u"ch",u"Solothurn",15292,47.206649,7.516605 ],
    [ u"ch",u"Spiez",12310,46.684733,7.691108 ],
    [ u"ch",u"Spreitenbach",10544,47.420159,8.363006 ],
    [ u"ch",u"Stafa",13040,47.239059,8.725646 ],
    [ u"ch",u"Stans",7620,46.958449,8.365995 ],
    [ u"ch",u"Steffisburg",15396,46.778074,7.63249 ],
    [ u"ch",u"Steinhausen",8640,47.195101,8.485809 ],
    [ u"ch",u"Suhr",9522,47.371725,8.079669 ],
    [ u"ch",u"Sulgen",3081,47.5377,9.18497 ],
    [ u"ch",u"Sumiswald",5072,47.027467,7.745257 ],
    [ u"ch",u"Sursee",7962,47.170881,8.111132 ],
    [ u"ch",u"Teufen",5621,47.390723,9.389564 ],
    [ u"ch",u"Thalwil",16389,47.289515,8.567546 ],
    [ u"ch",u"Therwil",8986,47.501166,7.552859 ],
    [ u"ch",u"Thonex",13018,46.188186,6.196893 ],
    [ u"ch",u"Thun",41539,46.751176,7.621663 ],
    [ u"ch",u"Trimbach",6127,47.365605,7.886797 ],
    [ u"ch",u"Uetendorf",5538,46.773917,7.572506 ],
    [ u"ch",u"Unterageri",7248,47.136445,8.585305 ],
    [ u"ch",u"Unterseen",5283,46.6853,7.847225 ],
    [ u"ch",u"Untersiggenthal",6551,47.503174,8.254838 ],
    [ u"ch",u"Urdorf",9247,47.382958,8.428597 ],
    [ u"ch",u"Urtenen",5255,47.026668,7.500814 ],
    [ u"ch",u"Uster",29583,47.351997,8.713687 ],
    [ u"ch",u"Uznach",5648,47.224209,8.982634 ],
    [ u"ch",u"Uzwil",12185,47.438134,9.139218 ],
    [ u"ch",u"Vernier",29767,46.217693,6.08511 ],
    [ u"ch",u"Versoix",11660,46.284017,6.161659 ],
    [ u"ch",u"Vevey",16014,46.465264,6.841168 ],
    [ u"ch",u"Veyrier",9375,46.166485,6.185442 ],
    [ u"ch",u"Viganello",6330,46.015037,8.967779 ],
    [ u"ch",u"Villars-sur-Glane",9379,46.791892,7.117215 ],
    [ u"ch",u"Villmergen",5244,47.349173,8.245828 ],
    [ u"ch",u"Visp",6560,46.294524,7.884736 ],
    [ u"ch",u"Volketswil",14592,47.389983,8.691548 ],
    [ u"ch",u"Wadenswil",19473,47.228726,8.670585 ],
    [ u"ch",u"Wahlern",6292,46.828062,7.353178 ],
    [ u"ch",u"Wald",9016,47.276331,8.914128 ],
    [ u"ch",u"Wallisellen",12820,47.418328,8.589816 ],
    [ u"ch",u"Wattwil",8129,47.302253,9.08757 ],
    [ u"ch",u"Weinfelden",9529,47.566194,9.107546 ],
    [ u"ch",u"Wettingen",18509,47.470495,8.31636 ],
    [ u"ch",u"Wetzikon",19377,47.325771,8.795716 ],
    [ u"ch",u"Wil",17234,47.462147,9.04289 ],
    [ u"ch",u"Windisch",6815,47.476756,8.220846 ],
    [ u"ch",u"Winterthur",91368,47.500035,8.7251 ],
    [ u"ch",u"Wittenbach",8283,47.463075,9.37761 ],
    [ u"ch",u"Wohlen",14163,47.352359,8.278768 ],
    [ u"ch",u"Wohlen",9310,46.972336,7.358493 ],
    [ u"ch",u"Wollerau",6891,47.19478,8.719029 ],
    [ u"ch",u"Worb",11586,46.930286,7.562099 ],
    [ u"ch",u"Yverdon",23756,46.777908,6.635502 ],
    [ u"ch",u"Zermatt",5607,46.021256,7.74912 ],
    [ u"ch",u"Zofingen",12327,47.289945,7.947274 ],
    [ u"ch",u"Zollikofen",9144,46.995678,7.459013 ],
    [ u"ch",u"Zollikon",12534,47.338967,8.577801 ],
    [ u"ch",u"Zuchwil",8815,47.207778,7.561126 ],
    [ u"ch",u"Zug",24197,47.172421,8.517445 ],
    [ u"ch",u"Zumikon",5082,47.327409,8.620752 ],
    [ u"ch",u"Zurich",346185,47.366667,8.55 ],
    [ u"ci",u"Abengourou",144074,6.729722,-3.496389 ],
    [ u"ci",u"Abidjan",3692570,5.309657,-4.012656 ],
    [ u"ci",u"Aboisso",48148,5.467794,-3.207111 ],
    [ u"ci",u"Adiaké",22030,5.286337,-3.304025 ],
    [ u"ci",u"Adzopé",81150,6.106944,-3.861944 ],
    [ u"ci",u"Affery",37424,6.320352,-3.952347 ],
    [ u"ci",u"Agboville",108684,5.92801,-4.213186 ],
    [ u"ci",u"Agnibilékrou",59780,7.131132,-3.204147 ],
    [ u"ci",u"Akoupé",51387,6.38423,-3.887589 ],
    [ u"ci",u"Alépé",11794,5.500397,-3.663083 ],
    [ u"ci",u"Anyama",158250,5.494622,-4.051831 ],
    [ u"ci",u"Arrah",43408,6.673419,-3.969383 ],
    [ u"ci",u"Ayamé",15442,5.605204,-3.157086 ],
    [ u"ci",u"Bangolo",17712,7.01232,-7.486395 ],
    [ u"ci",u"Béoumi",25940,7.673951,-5.580855 ],
    [ u"ci",u"Biankouma",42756,7.739093,-7.613774 ],
    [ u"ci",u"Bingerville",83105,5.355809,-3.885371 ],
    [ u"ci",u"Bocanda",14051,7.062635,-4.499484 ],
    [ u"ci",u"Bondoukou",79013,8.040201,-2.800034 ],
    [ u"ci",u"Bongouanou",38756,6.651749,-4.204061 ],
    [ u"ci",u"Bonoua",40637,5.27247,-3.596248 ],
    [ u"ci",u"Botro",15581,7.852488,-5.310628 ],
    [ u"ci",u"Bouaflé",89344,6.990406,-5.744204 ],
    [ u"ci",u"Bouaké",572149,7.693846,-5.030307 ],
    [ u"ci",u"Bouna",40188,9.269265,-2.995098 ],
    [ u"ci",u"Boundiali",61998,9.521667,-6.486944 ],
    [ u"ci",u"Dabakala",22834,8.363209,-4.428628 ],
    [ u"ci",u"Dabou",95057,5.325556,-4.376853 ],
    [ u"ci",u"Daloa",217876,6.877355,-6.450221 ],
    [ u"ci",u"Danané",68687,7.259572,-8.154981 ],
    [ u"ci",u"Daoukro",56310,7.058552,-3.964625 ],
    [ u"ci",u"Dimbokro",73789,6.64678,-4.70519 ],
    [ u"ci",u"Divo",184481,5.83739,-5.357229 ],
    [ u"ci",u"Duekoué",68872,6.74202,-7.349183 ],
    [ u"ci",u"Ferkessédougou",74966,9.5928,-5.194487 ],
    [ u"ci",u"Gagnoa",125647,6.131934,-5.950601 ],
    [ u"ci",u"Grand-Lahou",13205,5.135526,-5.023964 ],
    [ u"ci",u"Guibéroua",16030,6.238687,-6.171465 ],
    [ u"ci",u"Guiglo",63528,6.543682,-7.493495 ],
    [ u"ci",u"Hiré",30232,6.188777,-5.294634 ],
    [ u"ci",u"Issia",88251,6.492241,-6.585576 ],
    [ u"ci",u"Jacqueville",14743,5.205148,-4.414604 ],
    [ u"ci",u"Katiola",83695,8.137278,-5.10095 ],
    [ u"ci",u"Korhogo",172114,9.458031,-5.629608 ],
    [ u"ci",u"Lakota",50651,5.847523,-5.681997 ],
    [ u"ci",u"Mankono",25351,8.058611,-6.189722 ],
    [ u"ci",u"Man",140217,7.412513,-7.55383 ],
    [ u"ci",u"Ndiékro",11794,7.426754,-4.765391 ],
    [ u"ci",u"Ndouci",25134,5.863835,-4.760897 ],
    [ u"ci",u"Odienné",71188,9.505114,-7.564332 ],
    [ u"ci",u"Oumé",78872,6.383086,-5.417591 ],
    [ u"ci",u"Sakassou",15068,7.454624,-5.292628 ],
    [ u"ci",u"San-Pédro",195873,4.748508,-6.636301 ],
    [ u"ci",u"Sassandra",30124,4.95,-6.083333 ],
    [ u"ci",u"Séguéla",79565,7.961111,-6.673056 ],
    [ u"ci",u"Sinfra",85875,6.621026,-5.911442 ],
    [ u"ci",u"Soubré",123214,5.783766,-6.59388 ],
    [ u"ci",u"Tabou",21511,4.42295,-7.3528 ],
    [ u"ci",u"Tanda",27098,7.803355,-3.168325 ],
    [ u"ci",u"Tiassalé",52186,5.898394,-4.822926 ],
    [ u"ci",u"Tiebissou",24605,7.157722,-5.2248 ],
    [ u"ci",u"Tingréla",67746,10.48115,-6.406939 ],
    [ u"ci",u"Touba",47538,8.283333,-7.683333 ],
    [ u"ci",u"Toulépleu",17965,6.579742,-8.410906 ],
    [ u"ci",u"Toumodi",51560,6.557986,-5.017688 ],
    [ u"ci",u"Vavoua",54249,7.381944,-6.477778 ],
    [ u"ci",u"Yamoussoukro",200659,6.820548,-5.276741 ],
    [ u"ci",u"Zuénoula",52630,7.430272,-6.050541 ],
    [ u"ck",u"Amuri",285,-18.8538889,-159.7963889 ],
    [ u"ck",u"Avarua",13374,-21.2077778,-159.775 ],
    [ u"ck",u"Omoka",180,-8.9816667,-158.0605556 ],
    [ u"ck",u"Roto",74,-10.8833333,-165.8333333 ],
    [ u"ck",u"Tauhunu",69,-10.425,-161.0352778 ],
    [ u"cl",u"Ancud",28020,-41.869722,-73.820278 ],
    [ u"cl",u"Angol",44856,-37.8,-72.716667 ],
    [ u"cl",u"Antofagasta",309835,-23.65,-70.4 ],
    [ u"cl",u"Arauco",24659,-37.25,-73.316667 ],
    [ u"cl",u"Arica",186000,-18.475,-70.30417 ],
    [ u"cl",u"Buin",55440,-33.733333,-70.75 ],
    [ u"cl",u"Bulnes",12715,-36.733333,-72.3 ],
    [ u"cl",u"Cabildo",12784,-32.432778,-71.133611 ],
    [ u"cl",u"Cabrero",18327,-37.033333,-72.4 ],
    [ u"cl",u"Calama",143085,-22.466667,-68.933333 ],
    [ u"cl",u"Calbuco",12490,-41.768011,-73.127296 ],
    [ u"cl",u"Calera",49107,-32.783333,-71.2 ],
    [ u"cl",u"Canete",20158,-37.8,-73.383333 ],
    [ u"cl",u"Carahue",11875,-38.7,-73.166667 ],
    [ u"cl",u"Castro",29926,-42.463611,-73.808333 ],
    [ u"cl",u"Cauquenes",31363,-35.966667,-72.35 ],
    [ u"cl",u"Chiguayante",82545,-36.916667,-73.016667 ],
    [ u"cl",u"Chillan",150396,-36.6,-72.116667 ],
    [ u"cl",u"Chimbarongo",17356,-34.7,-71.05 ],
    [ u"cl",u"Coihaique",45788,-45.566667,-72.066667 ],
    [ u"cl",u"Coihueco",7346,-36.616667,-71.833333 ],
    [ u"cl",u"Collipulli",16392,-37.95,-72.433333 ],
    [ u"cl",u"Concepcion",215414,-36.833333,-73.05 ],
    [ u"cl",u"Constitucion",37917,-35.333333,-72.416667 ],
    [ u"cl",u"Copiapo",129281,-27.366667,-70.333333 ],
    [ u"cl",u"Coquimbo",161319,-29.953333,-71.343611 ],
    [ u"cl",u"Coronel",92941,-37.016667,-73.133333 ],
    [ u"cl",u"Curanilahue",30611,-37.466667,-73.35 ],
    [ u"cl",u"Curico",102439,-34.983333,-71.233333 ],
    [ u"cl",u"Diego de Almagro",18137,-26.366667,-70.05 ],
    [ u"cl",u"El Monte",23090,-33.683333,-71.016667 ],
    [ u"cl",u"Freire",7813,-38.95,-72.633333 ],
    [ u"cl",u"Graneros",23301,-34.066667,-70.733333 ],
    [ u"cl",u"Illapel",22816,-31.630833,-71.165278 ],
    [ u"cl",u"Iquique",227501,-20.22083,-70.14306 ],
    [ u"cl",u"Laja",16550,-37.266667,-72.7 ],
    [ u"cl",u"La Ligua",24857,-32.433333,-71.233333 ],
    [ u"cl",u"Lampa",29250,-33.283333,-70.9 ],
    [ u"cl",u"La Serena",154523,-29.907778,-71.254167 ],
    [ u"cl",u"La Union",26299,-40.283333,-73.083333 ],
    [ u"cl",u"Lautaro",21579,-38.516667,-72.45 ],
    [ u"cl",u"Lebu",22345,-37.616667,-73.65 ],
    [ u"cl",u"Limache",35876,-32.983333,-71.283333 ],
    [ u"cl",u"Linares",69536,-35.85,-71.6 ],
    [ u"cl",u"Llaillay",16646,-32.85,-70.966667 ],
    [ u"cl",u"Loncoche",15590,-39.366667,-72.633333 ],
    [ u"cl",u"Longavi",6325,-35.966667,-71.683333 ],
    [ u"cl",u"Los Andes",56859,-32.833333,-70.616667 ],
    [ u"cl",u"Los Angeles",125431,-37.466667,-72.35 ],
    [ u"cl",u"Lota",49763,-37.083333,-73.166667 ],
    [ u"cl",u"Machali",27595,-34.183333,-70.666667 ],
    [ u"cl",u"Melipilla",63100,-33.7,-71.216667 ],
    [ u"cl",u"Molina",28775,-35.116667,-71.283333 ],
    [ u"cl",u"Monte Patria",13945,-30.691944,-70.946667 ],
    [ u"cl",u"Mulchen",22170,-37.716667,-72.233333 ],
    [ u"cl",u"Nacimiento",21220,-37.5,-72.666667 ],
    [ u"cl",u"Nueva Imperial",18777,-38.733333,-72.95 ],
    [ u"cl",u"Osorno",135774,-40.566667,-73.15 ],
    [ u"cl",u"Ovalle",77139,-30.598333,-71.200278 ],
    [ u"cl",u"Paine",32765,-33.816667,-70.75 ],
    [ u"cl",u"Panguipulli",16312,-39.633333,-72.333333 ],
    [ u"cl",u"Parral",26905,-36.15,-71.833333 ],
    [ u"cl",u"Penaflor",65494,-33.616667,-70.916667 ],
    [ u"cl",u"Penco",46091,-36.733333,-72.983333 ],
    [ u"cl",u"Pitrufquen",13743,-38.983333,-72.65 ],
    [ u"cl",u"Puerto Montt",160055,-41.469848,-72.944745 ],
    [ u"cl",u"Puerto Varas",24958,-41.319461,-72.985378 ],
    [ u"cl",u"Punta Arenas",117432,-53.15,-70.916667 ],
    [ u"cl",u"Purranque",13619,-40.916667,-73.166667 ],
    [ u"cl",u"Quillota",67779,-32.883333,-71.266667 ],
    [ u"cl",u"Quilpue",130264,-33.045,-71.449444 ],
    [ u"cl",u"Rancagua",212696,-34.17083,-70.74444 ],
    [ u"cl",u"Rengo",38101,-34.416667,-70.866667 ],
    [ u"cl",u"Rio Bueno",15456,-40.316667,-72.966667 ],
    [ u"cl",u"Salamanca",13265,-31.775,-70.972222 ],
    [ u"cl",u"San Antonio",85651,-33.593333,-71.621667 ],
    [ u"cl",u"San Bernardo",249856,-33.6,-70.716667 ],
    [ u"cl",u"San Carlos",31517,-36.416667,-71.966667 ],
    [ u"cl",u"San Clemente",13656,-35.55,-71.483333 ],
    [ u"cl",u"San Felipe",59294,-32.75,-70.733333 ],
    [ u"cl",u"San Javier",22427,-35.6,-71.75 ],
    [ u"cl",u"Santa Cruz",33283,-34.633333,-71.366667 ],
    [ u"cl",u"Santiago",4837248,-33.45,-70.666667 ],
    [ u"cl",u"San Vicente",22573,-34.433333,-71.083333 ],
    [ u"cl",u"Talagante",51763,-33.666667,-70.933333 ],
    [ u"cl",u"Talcahuano",252969,-36.716667,-73.116667 ],
    [ u"cl",u"Talca",197480,-35.433333,-71.666667 ],
    [ u"cl",u"Taltal",10018,-25.4,-70.483333 ],
    [ u"cl",u"Temuco",238131,-38.733333,-72.6 ],
    [ u"cl",u"Teno",6858,-34.866667,-71.183333 ],
    [ u"cl",u"Tocopilla",24461,-22.09198,-70.19792 ],
    [ u"cl",u"Tome",46698,-36.616667,-72.95 ],
    [ u"cl",u"Traiguen",14481,-38.25,-72.683333 ],
    [ u"cl",u"Valdivia",133420,-39.8,-73.233333 ],
    [ u"cl",u"Vallenar",44895,-28.570833,-70.758056 ],
    [ u"cl",u"Valparaiso",282450,-33.047778,-71.601111 ],
    [ u"cl",u"Victoria",24555,-38.216667,-72.333333 ],
    [ u"cl",u"Vicuna",13496,-30.031944,-70.708056 ],
    [ u"cl",u"Vilcun",9241,-38.65,-72.233333 ],
    [ u"cl",u"Villa Alemana",97320,-33.042222,-71.373333 ],
    [ u"cl",u"Villarrica",31603,-39.266667,-72.216667 ],
    [ u"cl",u"Vina del Mar",294553,-33.008056,-71.519722 ],
    [ u"cl",u"Yumbel",11111,-37.083333,-72.566667 ],
    [ u"cm",u"Abong Mbang",14661,3.9833333,13.1833333 ],
    [ u"cm",u"Akom",9709,2.7833333,10.5666667 ],
    [ u"cm",u"Akonolinga",17181,3.7666667,12.25 ],
    [ u"cm",u"Ambam",8476,2.3833333,11.2833333 ],
    [ u"cm",u"Bafang",80966,5.15,10.1833333 ],
    [ u"cm",u"Bafia",69511,4.75,11.2333333 ],
    [ u"cm",u"Bafoussam",290798,5.4666667,10.4166667 ],
    [ u"cm",u"Bafut",18946,6.0833333,10.1 ],
    [ u"cm",u"Bali",72909,5.8833333,10.0166667 ],
    [ u"cm",u"Bamenda",393871,5.9333333,10.1666667 ],
    [ u"cm",u"Bana",5727,5.15,10.2666667 ],
    [ u"cm",u"Bangangté",65608,5.15,10.5166667 ],
    [ u"cm",u"Banyo",40936,6.75,11.8166667 ],
    [ u"cm",u"Batouri",43970,4.4333333,14.3666667 ],
    [ u"cm",u"Bertoua",218217,4.5833333,13.6833333 ],
    [ u"cm",u"Bétaré Oya",11866,5.6,14.0833333 ],
    [ u"cm",u"Bogo",16952,10.7361111,14.6108333 ],
    [ u"cm",u"Bonabéri",8091,4.0844444,9.6661111 ],
    [ u"cm",u"Buea",64372,4.1594444,9.2366667 ],
    [ u"cm",u"Dibombari",4811,4.1816667,9.645 ],
    [ u"cm",u"Djang",96436,5.45,10.0666667 ],
    [ u"cm",u"Douala",1338144,4.0502778,9.7 ],
    [ u"cm",u"Doumé",5609,4.2333333,13.45 ],
    [ u"cm",u"Ébolowa",88140,2.9,11.15 ],
    [ u"cm",u"Edéa",203170,3.8,10.1333333 ],
    [ u"cm",u"Eséka",22221,3.65,10.7666667 ],
    [ u"cm",u"Fontem",42835,5.4666667,9.8833333 ],
    [ u"cm",u"Foumban",92673,5.7166667,10.9166667 ],
    [ u"cm",u"Foumbot",84417,5.5,10.6333333 ],
    [ u"cm",u"Fundong",43693,6.25,10.2666667 ],
    [ u"cm",u"Garoua Boulaï",46771,5.8833333,14.55 ],
    [ u"cm",u"Garoua",436932,9.3,13.4 ],
    [ u"cm",u"Guider",84928,9.9341667,13.9486111 ],
    [ u"cm",u"Idenao",17800,4.2475,9.0047222 ],
    [ u"cm",u"Kaélé",25199,10.1091667,14.4508333 ],
    [ u"cm",u"Kousséri",435986,12.0783333,15.0308333 ],
    [ u"cm",u"Kribi",55401,2.95,9.9166667 ],
    [ u"cm",u"Kumba",144428,4.6438889,9.4386111 ],
    [ u"cm",u"Kumbo",53970,6.2,10.6666667 ],
    [ u"cm",u"Lagdo",24596,9.05,13.7333333 ],
    [ u"cm",u"Limbe",72106,4.0127778,9.2202778 ],
    [ u"cm",u"Lolodorf",22345,3.2333333,10.7333333 ],
    [ u"cm",u"Loum",177448,4.7161111,9.7463889 ],
    [ u"cm",u"Manjo",37795,4.8452778,9.8247222 ],
    [ u"cm",u"Maroua",319974,10.5955556,14.3247222 ],
    [ u"cm",u"Mbalmayo",80483,3.5166667,11.5 ],
    [ u"cm",u"Mbengwi",9785,6.0166667,10.0 ],
    [ u"cm",u"Mbouda",111690,5.6333333,10.25 ],
    [ u"cm",u"Meïganga",80355,6.5166667,14.3 ],
    [ u"cm",u"Melong",37216,5.1166667,9.95 ],
    [ u"cm",u"Mfou",10033,3.9666667,11.9333333 ],
    [ u"cm",u"Mindif",10538,10.4027778,14.44 ],
    [ u"cm",u"Mme",6149,6.3333333,10.2333333 ],
    [ u"cm",u"Mokolo",275750,10.7402778,13.8027778 ],
    [ u"cm",u"Monatélé",11327,4.2666667,11.2 ],
    [ u"cm",u"Mora",55488,11.0425,14.1447222 ],
    [ u"cm",u"Mutengene",47638,4.0994444,9.3080556 ],
    [ u"cm",u"Muyuka",31384,4.2972222,9.4055556 ],
    [ u"cm",u"Mvangué",1908,2.9666667,11.5166667 ],
    [ u"cm",u"Nanga Eboko",29909,4.6833333,12.3666667 ],
    [ u"cm",u"Ngaoundéré",231376,7.3166667,13.5833333 ],
    [ u"cm",u"Njinikom",8247,6.2333333,10.2833333 ],
    [ u"cm",u"Nkongsamba",117076,4.9533333,9.9325 ],
    [ u"cm",u"Nkoteng",50622,4.5166667,12.0333333 ],
    [ u"cm",u"Obala",30012,4.1666667,11.5333333 ],
    [ u"cm",u"Ombessa",1833,4.6,11.25 ],
    [ u"cm",u"Poli",5727,8.4833333,13.25 ],
    [ u"cm",u"Rey Bouba",11454,8.6666667,14.1833333 ],
    [ u"cm",u"Saa",5727,4.3666667,11.45 ],
    [ u"cm",u"Sangmélima",54427,2.9333333,11.9833333 ],
    [ u"cm",u"Tcholliré",23267,8.4,14.1666667 ],
    [ u"cm",u"Tibati",35711,6.4666667,12.6333333 ],
    [ u"cm",u"Tignère",4353,7.3666667,12.65 ],
    [ u"cm",u"Tiko",56104,4.0786111,9.3680556 ],
    [ u"cm",u"Wum",69072,6.3833333,10.0666667 ],
    [ u"cm",u"Yabassi",7560,4.4544444,9.9655556 ],
    [ u"cm",u"Yagoua",80510,10.3427778,15.2405556 ],
    [ u"cm",u"Yaoundé",1299446,3.8666667,11.5166667 ],
    [ u"cm",u"Yokadouma",13287,3.5166667,15.05 ],
    [ u"cn",u"Acheng",144665,45.545452,126.977031 ],
    [ u"cn",u"Aksu",340020,41.123056,80.264444 ],
    [ u"cn",u"Alihe",61582,50.566667,123.716667 ],
    [ u"cn",u"Altay",139341,47.866667,88.116667 ],
    [ u"cn",u"Anbu",162964,23.448953,116.680916 ],
    [ u"cn",u"Anda",181271,46.4,125.316667 ],
    [ u"cn",u"Angangxi",59211,47.15,123.81 ],
    [ u"cn",u"Anjiang",55421,27.319444,110.103056 ],
    [ u"cn",u"Anju",54098,30.349556,105.455937 ],
    [ u"cn",u"Ankang",132654,32.68,109.017222 ],
    [ u"cn",u"Anlu",71198,31.2575,113.678333 ],
    [ u"cn",u"Anqing",358661,30.509167,117.050556 ],
    [ u"cn",u"Anqiu",105665,36.434167,119.1925 ],
    [ u"cn",u"Anshan",1199275,41.123611,122.99 ],
    [ u"cn",u"Anshun",351936,26.25,105.933333 ],
    [ u"cn",u"Anyang",781129,36.099444,114.328889 ],
    [ u"cn",u"Aojiang",74636,27.59564,120.555371 ],
    [ u"cn",u"Babu",65603,24.416667,111.516667 ],
    [ u"cn",u"Badaojiang",183880,41.943056,126.428611 ],
    [ u"cn",u"Baicheng",316970,45.616667,122.816667 ],
    [ u"cn",u"Baijiantan",93697,45.633333,85.183333 ],
    [ u"cn",u"Baiquan",70472,47.583333,126.083333 ],
    [ u"cn",u"Baisha",57417,29.959702,115.064265 ],
    [ u"cn",u"Baishishan",56992,43.583333,127.566667 ],
    [ u"cn",u"Baiyin",188533,36.558333,104.208056 ],
    [ u"cn",u"Bamiantong",66170,44.933333,130.533333 ],
    [ u"cn",u"Bantou",118557,25.443056,118.403333 ],
    [ u"cn",u"Baoding",995652,38.851111,115.490278 ],
    [ u"cn",u"Baoji",438295,34.365907,107.359045 ],
    [ u"cn",u"Baoning",60542,31.55037,105.99381 ],
    [ u"cn",u"Baoqing",62991,46.331667,132.211111 ],
    [ u"cn",u"Baoshan",123791,46.558611,131.424444 ],
    [ u"cn",u"Baoying",80292,33.229167,119.309167 ],
    [ u"cn",u"Bayan",55186,46.083333,127.4 ],
    [ u"cn",u"Beian",145670,48.266667,126.6 ],
    [ u"cn",u"Beibei",112019,29.825556,106.433889 ],
    [ u"cn",u"Beidao",74767,34.568611,105.893333 ],
    [ u"cn",u"Beihai",289568,21.483333,109.1 ],
    [ u"cn",u"Beipiao",154999,41.791944,120.779167 ],
    [ u"cn",u"Bengbu",576648,32.940833,117.360833 ],
    [ u"cn",u"Benxi",987717,41.288611,123.765 ],
    [ u"cn",u"Bianzhuang",65381,34.848611,118.044722 ],
    [ u"cn",u"Bijie",77645,27.3125,105.294167 ],
    [ u"cn",u"Binzhou",62017,45.752809,127.479863 ],
    [ u"cn",u"Binzhou",70013,23.223785,108.802165 ],
    [ u"cn",u"Binzhou",115893,37.366667,118.016667 ],
    [ u"cn",u"Boli",95260,45.766667,130.516667 ],
    [ u"cn",u"Bose",90603,23.899722,106.613333 ],
    [ u"cn",u"Boshan",153596,36.483333,117.833333 ],
    [ u"cn",u"Botou",63045,38.066667,116.566667 ],
    [ u"cn",u"Bozhou",174140,33.877222,115.770278 ],
    [ u"cn",u"Buhe",106347,30.287567,112.229788 ],
    [ u"cn",u"Caidian",71891,30.583333,114.033333 ],
    [ u"cn",u"Cangzhou",527681,38.316667,116.866667 ],
    [ u"cn",u"Caohai",56744,26.85,104.233333 ],
    [ u"cn",u"Caohe",67370,30.2297,115.433461 ],
    [ u"cn",u"Chaihe",67963,44.766667,129.7 ],
    [ u"cn",u"Changchun",2537421,43.88,125.322778 ],
    [ u"cn",u"Changde",517780,29.046378,111.678304 ],
    [ u"cn",u"Changji",198776,44.016667,87.316667 ],
    [ u"cn",u"Changli",64476,39.704167,119.150556 ],
    [ u"cn",u"Changping",93174,40.218611,116.219722 ],
    [ u"cn",u"Changqing",82598,36.5575,116.727222 ],
    [ u"cn",u"Changtu",71284,42.778842,124.095447 ],
    [ u"cn",u"Changying",66392,34.116667,114.6 ],
    [ u"cn",u"Changzhou",949018,31.783333,119.966667 ],
    [ u"cn",u"Chaohu",138463,31.6,117.866667 ],
    [ u"cn",u"Chaoyang",410005,41.570278,120.458611 ],
    [ u"cn",u"Chaozhou",424787,23.665129,116.637864 ],
    [ u"cn",u"Chengde",449325,40.770278,118.169722 ],
    [ u"cn",u"Chengdu",3950437,30.666667,104.066667 ],
    [ u"cn",u"Chenghai",152453,23.461319,116.770071 ],
    [ u"cn",u"Chengmai",68720,19.6825,110.090278 ],
    [ u"cn",u"Chengzihe",98188,45.333333,131.066667 ],
    [ u"cn",u"Chenzhou",179038,25.8,113.033333 ],
    [ u"cn",u"Chifeng",346654,42.268333,118.963611 ],
    [ u"cn",u"Chizhou",148375,30.657778,117.483056 ],
    [ u"cn",u"Chongqing",3967028,29.562778,106.552778 ],
    [ u"cn",u"Choucheng",89629,29.315056,120.076764 ],
    [ u"cn",u"Chuncheng",153547,22.166667,111.783333 ],
    [ u"cn",u"Chuzhou",280582,32.321944,118.297778 ],
    [ u"cn",u"Cuiluan",54804,47.85,128.533333 ],
    [ u"cn",u"Daan",120340,29.382222,106.015 ],
    [ u"cn",u"Dafeng",84323,33.199728,120.457805 ],
    [ u"cn",u"Dalian",2035307,38.912222,121.602222 ],
    [ u"cn",u"Daliang",210411,22.850416,113.247006 ],
    [ u"cn",u"Dalianwan",55841,39.008611,121.715833 ],
    [ u"cn",u"Dali",134040,25.7,100.183333 ],
    [ u"cn",u"Dalinghe",56176,41.165278,121.366667 ],
    [ u"cn",u"Dancheng",65411,33.633333,115.183333 ],
    [ u"cn",u"Dandong",631973,40.129167,124.394722 ],
    [ u"cn",u"Dangtu",60335,31.559777,118.482888 ],
    [ u"cn",u"Danjiangkou",92008,32.542778,111.508611 ],
    [ u"cn",u"Danshui",126701,22.798396,114.467158 ],
    [ u"cn",u"Daokou",56637,35.563889,114.505833 ],
    [ u"cn",u"Dashiqiao",80223,40.637318,122.502508 ],
    [ u"cn",u"Dashitou",65683,43.306667,128.511389 ],
    [ u"cn",u"Datong",1052678,40.093611,113.291389 ],
    [ u"cn",u"Dawukou",131880,39.041944,106.395833 ],
    [ u"cn",u"Daxian",130749,31.215921,107.500922 ],
    [ u"cn",u"Daye",61847,30.083333,114.95 ],
    [ u"cn",u"Dayong",86083,29.129444,110.478333 ],
    [ u"cn",u"Dehui",108818,44.533333,125.7 ],
    [ u"cn",u"Dengfeng",62375,34.455278,113.028056 ],
    [ u"cn",u"Dengzhou",59338,32.682222,112.081944 ],
    [ u"cn",u"Dengzhou",85279,37.808611,120.750833 ],
    [ u"cn",u"Deqing",87576,30.541667,119.9575 ],
    [ u"cn",u"Deyang",152194,31.130192,104.381981 ],
    [ u"cn",u"Dezhou",379555,37.448611,116.2925 ],
    [ u"cn",u"Didao",109561,45.366667,130.8 ],
    [ u"cn",u"Dinghai",84380,30.010754,122.204649 ],
    [ u"cn",u"Dingtao",58206,35.068333,115.5625 ],
    [ u"cn",u"Dingzhou",152934,38.513056,114.995556 ],
    [ u"cn",u"Dongdu",72957,35.85,117.7 ],
    [ u"cn",u"Dongfeng",67820,42.640309,125.511762 ],
    [ u"cn",u"Donghai",188602,22.945935,115.642043 ],
    [ u"cn",u"Dongkan",72789,33.999722,119.830833 ],
    [ u"cn",u"Dongli",110107,20.791389,110.349722 ],
    [ u"cn",u"Dongling",171454,41.814444,123.575833 ],
    [ u"cn",u"Dongning",61440,44.062188,131.120752 ],
    [ u"cn",u"Dongsheng",99809,39.816085,109.977629 ],
    [ u"cn",u"Dongtai",110988,32.852311,120.309472 ],
    [ u"cn",u"Dongying",306450,37.456389,118.485556 ],
    [ u"cn",u"Dongzhen",98259,22.373029,110.947456 ],
    [ u"cn",u"Ducheng",95525,23.237294,111.53172 ],
    [ u"cn",u"Dunhua",148844,43.3725,128.2425 ],
    [ u"cn",u"Duobao",90257,30.670005,112.689517 ],
    [ u"cn",u"Duyun",91136,26.266667,107.516667 ],
    [ u"cn",u"Encheng",110921,22.183892,112.302597 ],
    [ u"cn",u"Enshi",95227,30.3,109.483333 ],
    [ u"cn",u"Erdaojiang",60831,41.776389,126.031944 ],
    [ u"cn",u"Erenhot",16427,43.6475,111.976667 ],
    [ u"cn",u"Ezhou",193652,30.396072,114.886546 ],
    [ u"cn",u"Fangshan",97026,39.698333,115.9925 ],
    [ u"cn",u"Feicheng",80929,35.260556,117.9675 ],
    [ u"cn",u"Fengcheng",120514,40.453611,124.071667 ],
    [ u"cn",u"Fengkou",67139,30.083333,113.266667 ],
    [ u"cn",u"Fengrun",65150,39.833333,118.116667 ],
    [ u"cn",u"Fengxian",57153,34.703882,116.587167 ],
    [ u"cn",u"Fengzhen",72444,40.439444,113.153611 ],
    [ u"cn",u"Fenyi",58478,27.811166,114.668047 ],
    [ u"cn",u"Foshan",627348,23.026771,113.131483 ],
    [ u"cn",u"Fujin",89442,47.26,132.032222 ],
    [ u"cn",u"Fuli",59160,46.721667,131.139444 ],
    [ u"cn",u"Fuling",166507,29.702222,107.391944 ],
    [ u"cn",u"Fulitun",76465,46.721667,131.139444 ],
    [ u"cn",u"Fushan",65622,37.495833,121.258056 ],
    [ u"cn",u"Fushun",1400646,41.7,123.883333 ],
    [ u"cn",u"Fuxin",689050,42.015556,121.658889 ],
    [ u"cn",u"Fuyang",170023,32.9,115.816667 ],
    [ u"cn",u"Fuyang",70183,30.053333,119.951944 ],
    [ u"cn",u"Fuyu",138704,45.183333,124.816667 ],
    [ u"cn",u"Fuyü",75147,47.641389,124.679444 ],
    [ u"cn",u"Fuzhou",1179720,26.061389,119.306111 ],
    [ u"cn",u"Gannan",59239,47.914722,123.503056 ],
    [ u"cn",u"Ganzhou",249071,25.85,114.933333 ],
    [ u"cn",u"Gaogou",56214,34.0175,119.188611 ],
    [ u"cn",u"Gaomi",150793,36.383333,119.752778 ],
    [ u"cn",u"Gaoyou",90911,32.785833,119.427778 ],
    [ u"cn",u"Gaozhou",166069,21.939243,110.846074 ],
    [ u"cn",u"Gejiu",136135,23.306022,103.163512 ],
    [ u"cn",u"Genhe",73631,50.783333,121.516667 ],
    [ u"cn",u"Gongzhuling",140909,43.507222,124.812222 ],
    [ u"cn",u"Guangshui",154771,31.616111,113.815556 ],
    [ u"cn",u"Guangyuan",213365,32.442015,105.822996 ],
    [ u"cn",u"Guangzhou",3152825,23.116667,113.25 ],
    [ u"cn",u"Gucheng",74038,32.266043,111.634759 ],
    [ u"cn",u"Guicheng",76430,23.096389,109.609167 ],
    [ u"cn",u"Guilin",649352,25.281944,110.286389 ],
    [ u"cn",u"Guiren",57446,33.669722,118.188889 ],
    [ u"cn",u"Guiyang",1171633,26.583333,106.716667 ],
    [ u"cn",u"Guozhen",85415,34.365907,107.359045 ],
    [ u"cn",u"Gushi",80666,32.2,115.8 ],
    [ u"cn",u"Guye",41484,39.733333,118.416667 ],
    [ u"cn",u"Haian",72654,32.543611,120.45 ],
    [ u"cn",u"Haibowan",218427,39.664722,106.812222 ],
    [ u"cn",u"Haicheng",191651,40.851582,122.747537 ],
    [ u"cn",u"Haicheng",130386,22.975326,115.331794 ],
    [ u"cn",u"Haikou",112644,24.779854,102.575483 ],
    [ u"cn",u"Haikou",615835,20.045833,110.341667 ],
    [ u"cn",u"Hailar",211066,49.2,119.7 ],
    [ u"cn",u"Hailin",85578,44.583333,129.416667 ],
    [ u"cn",u"Hailun",109881,47.45,126.933333 ],
    [ u"cn",u"Haimen",125427,23.193486,116.614218 ],
    [ u"cn",u"Haizhou",59098,34.581667,119.128889 ],
    [ u"cn",u"Hami",137072,42.8,93.45 ],
    [ u"cn",u"Hanchuan",87737,30.65,113.766667 ],
    [ u"cn",u"Handan",1358318,36.566667,114.533333 ],
    [ u"cn",u"Hangu",208369,39.248889,117.789167 ],
    [ u"cn",u"Hangzhou",1878129,30.29365,120.161419 ],
    [ u"cn",u"Hanting",90637,36.770833,119.210833 ],
    [ u"cn",u"Hanyang",71053,27.089167,119.645278 ],
    [ u"cn",u"Hanzhong",145986,33.072778,107.030278 ],
    [ u"cn",u"Harbin",3229883,45.75,126.65 ],
    [ u"cn",u"Hebi",244662,35.899167,114.1925 ],
    [ u"cn",u"Hecun",83009,36.533333,114.111111 ],
    [ u"cn",u"Hede",89107,33.768056,120.251667 ],
    [ u"cn",u"Hefei",1388904,31.863889,117.280833 ],
    [ u"cn",u"Hegang",743307,47.4,130.366667 ],
    [ u"cn",u"Heihe",109427,50.266667,127.466667 ],
    [ u"cn",u"Heishan",68603,41.689167,122.112778 ],
    [ u"cn",u"Helong",85756,42.539744,128.99722 ],
    [ u"cn",u"Hengshan",164844,45.2,130.916667 ],
    [ u"cn",u"Hengshui",456356,37.732222,115.701111 ],
    [ u"cn",u"Hengyang",759602,26.888056,112.615 ],
    [ u"cn",u"Heyang",97575,29.994722,106.257222 ],
    [ u"cn",u"Heze",254602,35.243056,115.441111 ],
    [ u"cn",u"Hohhot",774477,40.810556,111.652222 ],
    [ u"cn",u"Hongan",64831,31.362075,114.63689 ],
    [ u"cn",u"Honggang",147977,46.466667,124.866667 ],
    [ u"cn",u"Honghu",175761,29.816667,113.466667 ],
    [ u"cn",u"Hongjiang",59199,27.11,109.995556 ],
    [ u"cn",u"Houma",100630,35.61358,111.356601 ],
    [ u"cn",u"Huadian",139047,42.963333,126.747778 ],
    [ u"cn",u"Huaibei",903039,33.974444,116.791667 ],
    [ u"cn",u"Huaicheng",89294,23.905134,112.193144 ],
    [ u"cn",u"Huaidian",89978,33.433333,115.033333 ],
    [ u"cn",u"Huaihua",127322,27.549444,109.959167 ],
    [ u"cn",u"Huainan",1027655,32.626389,116.996944 ],
    [ u"cn",u"Huaiyin",555230,33.588611,119.019167 ],
    [ u"cn",u"Huaiyuan",65530,32.958933,117.165658 ],
    [ u"cn",u"Huanan",66087,46.216667,130.516667 ],
    [ u"cn",u"Huangchuan",72663,32.127222,115.039444 ],
    [ u"cn",u"Huangcun",104904,39.721389,116.329167 ],
    [ u"cn",u"Huangmei",77633,30.192347,116.024959 ],
    [ u"cn",u"Huangnihe",54959,43.558333,128.023889 ],
    [ u"cn",u"Huangpi",57554,30.884534,114.377886 ],
    [ u"cn",u"Huangpu",116307,23.053325,113.512148 ],
    [ u"cn",u"Huangyan",150448,28.647778,121.259444 ],
    [ u"cn",u"Huangzhai",60037,33.5,114.783333 ],
    [ u"cn",u"Huangzhou",122563,30.45,114.8 ],
    [ u"cn",u"Huanren",66147,41.260501,125.406431 ],
    [ u"cn",u"Huayang",90365,30.510299,104.054219 ],
    [ u"cn",u"Huazhou",91701,21.633333,110.583333 ],
    [ u"cn",u"Huicheng",125919,23.038449,116.28988 ],
    [ u"cn",u"Huilong",74818,31.811111,121.655 ],
    [ u"cn",u"Huinan",66315,42.6225,126.261389 ],
    [ u"cn",u"Huizhou",289201,23.083333,114.4 ],
    [ u"cn",u"Hulan Ergi",265344,47.204167,123.633333 ],
    [ u"cn",u"Hulan",109104,45.983333,126.6 ],
    [ u"cn",u"Humen",191891,22.818985,113.673064 ],
    [ u"cn",u"Hunchun",77028,42.8675,130.358056 ],
    [ u"cn",u"Huoqiu",61904,32.354727,116.293898 ],
    [ u"cn",u"Hushitai",61979,41.932222,123.511389 ],
    [ u"cn",u"Hutang",56370,31.533333,119.483333 ],
    [ u"cn",u"Huzhou",158320,30.870301,120.093297 ],
    [ u"cn",u"Jiamusi",549549,46.833333,130.35 ],
    [ u"cn",u"Jiancheng",82563,30.390968,104.549121 ],
    [ u"cn",u"Jiangdu",83936,32.436667,119.550833 ],
    [ u"cn",u"Jiangkou",59902,25.487222,119.198611 ],
    [ u"cn",u"Jiangmen",532419,22.583333,113.083333 ],
    [ u"cn",u"Jiangyan",70375,32.506111,120.142778 ],
    [ u"cn",u"Jiangyin",107918,31.905063,120.26851 ],
    [ u"cn",u"Jiangyin",107918,31.928249,120.312567 ],
    [ u"cn",u"Jiangyou",127225,31.766667,104.716667 ],
    [ u"cn",u"Jianhu",72474,33.277587,119.959845 ],
    [ u"cn",u"Jian",171718,27.05,114.9 ],
    [ u"cn",u"Jiaocheng",65170,26.661667,119.522778 ],
    [ u"cn",u"Jiaohe",123018,43.728611,127.344722 ],
    [ u"cn",u"Jiaojiang",470804,28.680278,121.442778 ],
    [ u"cn",u"Jiaonan",75656,35.878611,119.975278 ],
    [ u"cn",u"Jiaozhou",165026,36.283889,120.003333 ],
    [ u"cn",u"Jiaozuo",517540,35.239722,113.233056 ],
    [ u"cn",u"Jiaxing",466101,30.752198,120.749997 ],
    [ u"cn",u"Jiayuguan",122396,39.816667,98.3 ],
    [ u"cn",u"Jiazi",130298,22.877914,116.067054 ],
    [ u"cn",u"Jidong",58520,45.216667,131.083333 ],
    [ u"cn",u"Jiehu",69245,35.542778,118.455 ],
    [ u"cn",u"Jieshi",137444,22.813377,115.825742 ],
    [ u"cn",u"Jieshou",141993,33.25,115.35 ],
    [ u"cn",u"Jiexiu",77178,37.024444,111.9125 ],
    [ u"cn",u"Jijiang",61161,29.290556,106.254167 ],
    [ u"cn",u"Jilin",1881977,43.850833,126.560278 ],
    [ u"cn",u"Jimo",70733,36.389722,120.462222 ],
    [ u"cn",u"Jinan",2069266,36.668333,116.997222 ],
    [ u"cn",u"Jinchang",144363,38.495278,102.173889 ],
    [ u"cn",u"Jinchengjiang",104138,24.7,108.033333 ],
    [ u"cn",u"Jingcheng",61772,32.014167,120.2625 ],
    [ u"cn",u"Jingdezhen",310565,29.2947,117.207887 ],
    [ u"cn",u"Jinhua",142206,29.107778,119.654722 ],
    [ u"cn",u"Jining",258757,41.0275,113.105833 ],
    [ u"cn",u"Jining",450327,35.405,116.581389 ],
    [ u"cn",u"Jinji",56816,23.228056,110.826111 ],
    [ u"cn",u"Jinsha",95647,32.089817,121.073546 ],
    [ u"cn",u"Jinxiang",84231,27.432654,120.60625 ],
    [ u"cn",u"Jinxi",313247,40.764317,120.85327 ],
    [ u"cn",u"Jinzhou",604269,41.107778,121.141667 ],
    [ u"cn",u"Jishou",102332,28.316667,109.716667 ],
    [ u"cn",u"Jishui",77540,33.733333,115.4 ],
    [ u"cn",u"Jishu",103988,44.316667,126.8 ],
    [ u"cn",u"Jiujiang",258807,29.60794,115.887205 ],
    [ u"cn",u"Jiupu",123843,41.066667,122.95 ],
    [ u"cn",u"Jiuquan",72732,39.73817,98.499328 ],
    [ u"cn",u"Jiutai",175115,44.1525,125.832778 ],
    [ u"cn",u"Jixi",403759,45.3,130.966667 ],
    [ u"cn",u"Juegang",73317,32.31737,121.185525 ],
    [ u"cn",u"Juxian",66588,35.579444,118.832778 ],
    [ u"cn",u"Juye",58107,35.394722,116.088333 ],
    [ u"cn",u"Kaifeng",576915,34.744167,114.418611 ],
    [ u"cn",u"Kaihua",64404,23.368701,104.279996 ],
    [ u"cn",u"Kaili",151956,26.5,107.583333 ],
    [ u"cn",u"Kaitong",62537,44.813513,123.149999 ],
    [ u"cn",u"Kaiyuan",198423,23.697668,103.303723 ],
    [ u"cn",u"Karamay",174828,45.600376,84.860142 ],
    [ u"cn",u"Kashi",274717,39.454722,75.979722 ],
    [ u"cn",u"Keshan",84292,48.066667,125.9 ],
    [ u"cn",u"Korla",179465,41.759722,86.146944 ],
    [ u"cn",u"Kouqian",55957,43.639137,126.457835 ],
    [ u"cn",u"Kuandian",70867,40.728611,124.784722 ],
    [ u"cn",u"Kuche",68105,41.727778,82.936389 ],
    [ u"cn",u"Kunming",1023674,25.038889,102.718333 ],
    [ u"cn",u"Kunyang",65009,27.665833,120.565833 ],
    [ u"cn",u"Kuytun",187242,44.416667,85 ],
    [ u"cn",u"Laibin",59835,23.7,109.266667 ],
    [ u"cn",u"Laiwu",124108,36.192778,117.656944 ],
    [ u"cn",u"Laiyang",169594,36.975833,120.713611 ],
    [ u"cn",u"Laizhou",90070,37.171667,119.921389 ],
    [ u"cn",u"Langfang",720119,39.509722,116.694722 ],
    [ u"cn",u"Langxiang",57318,46.95,128.883333 ],
    [ u"cn",u"Lanxi",73706,29.21946,119.476953 ],
    [ u"cn",u"Lanxi",72528,46.262222,126.285556 ],
    [ u"cn",u"Lanzhou",1417742,36.056389,103.792222 ],
    [ u"cn",u"Laohekou",253112,32.385833,111.667778 ],
    [ u"cn",u"Lasa",118721,29.65,91.1 ],
    [ u"cn",u"Leiyang",129116,26.402382,112.859078 ],
    [ u"cn",u"Lengshuijiang",115399,27.688056,111.429444 ],
    [ u"cn",u"Lengshuitan",88935,26.411098,111.595592 ],
    [ u"cn",u"Leshan",154477,29.562275,103.76386 ],
    [ u"cn",u"Liancheng",100341,21.646734,110.28172 ],
    [ u"cn",u"Liangxiang",76744,39.731944,116.14 ],
    [ u"cn",u"Lianran",106795,24.922707,102.484959 ],
    [ u"cn",u"Lianyuan",66501,27.688333,111.664167 ],
    [ u"cn",u"Lianzhou",71423,21.668198,109.16946 ],
    [ u"cn",u"Lianzhou",92827,24.781111,112.3825 ],
    [ u"cn",u"Liaocheng",226930,36.443889,115.964722 ],
    [ u"cn",u"Liaoyang",687890,41.226111,123.056111 ],
    [ u"cn",u"Liaozhong",54691,41.506111,122.724167 ],
    [ u"cn",u"Licheng",172775,23.295537,113.828357 ],
    [ u"cn",u"Lichuan",72653,30.3,108.85 ],
    [ u"cn",u"Liling",98162,27.666667,113.5 ],
    [ u"cn",u"Linchuan",125847,27.938274,116.292688 ],
    [ u"cn",u"Linfen",232566,36.088889,111.518889 ],
    [ u"cn",u"Lingao",64874,19.907778,109.685833 ],
    [ u"cn",u"Lingdong",83636,46.566944,131.145278 ],
    [ u"cn",u"Lingyuan",91418,41.24,119.401111 ],
    [ u"cn",u"Linhai",152937,28.85,121.116667 ],
    [ u"cn",u"Linjiang",69149,41.806944,126.907778 ],
    [ u"cn",u"Linkou",77754,45.3,130.283333 ],
    [ u"cn",u"Linping",78180,30.4225,120.297222 ],
    [ u"cn",u"Linqing",110046,36.845556,115.711667 ],
    [ u"cn",u"Linqiong",55587,30.415872,103.460885 ],
    [ u"cn",u"Linqu",77472,36.515556,118.539722 ],
    [ u"cn",u"Linshui",109955,36.424722,114.204722 ],
    [ u"cn",u"Linshu",63285,34.916111,118.638889 ],
    [ u"cn",u"Linxia",202402,35.600278,103.206389 ],
    [ u"cn",u"Linxi",100316,39.7,118.433333 ],
    [ u"cn",u"Lishan",75882,34.378027,109.208925 ],
    [ u"cn",u"Lishui",98946,28.460417,119.910291 ],
    [ u"cn",u"Lishu",61584,43.304722,124.327778 ],
    [ u"cn",u"Liuhe",66975,42.240066,125.717173 ],
    [ u"cn",u"Liusha",118023,23.310722,116.168691 ],
    [ u"cn",u"Liuzhou",763168,24.312582,109.389157 ],
    [ u"cn",u"Liyang",72276,31.430795,119.523993 ],
    [ u"cn",u"Longfeng",152074,46.55,125.116667 ],
    [ u"cn",u"Longhua",65565,29.116667,107.266667 ],
    [ u"cn",u"Longjiang",106384,47.330278,123.183611 ],
    [ u"cn",u"Longjing",117185,42.771389,129.423333 ],
    [ u"cn",u"Longkou",60444,37.650833,120.328611 ],
    [ u"cn",u"Longyan",125778,25.107222,117.0225 ],
    [ u"cn",u"Loudi",150684,27.734444,111.994444 ],
    [ u"cn",u"Luancheng",597130,37.879167,114.651667 ],
    [ u"cn",u"Luan",179665,31.756944,116.491389 ],
    [ u"cn",u"Lubu",95820,23.174221,112.280936 ],
    [ u"cn",u"Lujiang",89119,31.233572,117.280566 ],
    [ u"cn",u"Luocheng",73581,29.384813,104.028621 ],
    [ u"cn",u"Luohe",417356,33.571667,114.035278 ],
    [ u"cn",u"Luorong",67593,24.405833,109.608611 ],
    [ u"cn",u"Luoyang",66188,24.959379,118.682998 ],
    [ u"cn",u"Luoyang",1390581,34.683611,112.453611 ],
    [ u"cn",u"Luoyang",123144,23.162442,114.273423 ],
    [ u"cn",u"Luqiao",427890,28.580835,121.377148 ],
    [ u"cn",u"Lushunkou",82345,38.8,121.266667 ],
    [ u"cn",u"Luyang",55489,33.735638,112.905085 ],
    [ u"cn",u"Luzhou",295056,28.872391,105.44049 ],
    [ u"cn",u"Maanshan",540198,31.695678,118.498248 ],
    [ u"cn",u"Mabai",63569,23.012792,104.450813 ],
    [ u"cn",u"Maba",113609,24.684125,113.598386 ],
    [ u"cn",u"Macheng",126366,31.178333,115.031944 ],
    [ u"cn",u"Manzhouli",54808,49.6,117.433333 ],
    [ u"cn",u"Maoming",473251,21.65,110.9 ],
    [ u"cn",u"Mata",81166,21.617844,111.336796 ],
    [ u"cn",u"Meihekou",99419,42.527222,125.675278 ],
    [ u"cn",u"Meilu",104168,21.45713,110.765907 ],
    [ u"cn",u"Mengcheng",69916,33.266109,116.566052 ],
    [ u"cn",u"Mengyin",65889,35.706944,117.926389 ],
    [ u"cn",u"Mentougou",197772,39.939167,116.091667 ],
    [ u"cn",u"Mianyang",264136,31.459339,104.754235 ],
    [ u"cn",u"Minggang",67945,32.458611,114.048611 ],
    [ u"cn",u"Mingguang",68351,32.780169,117.963776 ],
    [ u"cn",u"Mingshui",59369,47.166667,125.916667 ],
    [ u"cn",u"Mingshui",114858,36.716667,117.5 ],
    [ u"cn",u"Mingyue",58872,43.106944,128.921667 ],
    [ u"cn",u"Mishan",87257,45.543056,131.882222 ],
    [ u"cn",u"Miyang",72485,24.404167,103.442778 ],
    [ u"cn",u"Mudanjiang",665915,44.583333,129.6 ],
    [ u"cn",u"Mudu",61902,31.251958,120.511792 ],
    [ u"cn",u"Mujiayingzi",60627,42.116667,118.783333 ],
    [ u"cn",u"Nancha",121367,47.133333,129.266667 ],
    [ u"cn",u"Nanchang",1871351,28.55,115.933333 ],
    [ u"cn",u"Nanchong",204368,30.775757,106.102938 ],
    [ u"cn",u"Nanding",85495,36.748333,118.055833 ],
    [ u"cn",u"Nandu",61881,22.8525,110.823333 ],
    [ u"cn",u"Nanfeng",86129,23.743439,111.795934 ],
    [ u"cn",u"Nangong",82386,37.358056,115.374444 ],
    [ u"cn",u"Nanhai",80290,30.128189,111.778369 ],
    [ u"cn",u"Nanjing",3087010,32.061667,118.777778 ],
    [ u"cn",u"Nanlong",63405,31.35333,106.06309 ],
    [ u"cn",u"Nanma",74406,36.181667,118.158333 ],
    [ u"cn",u"Nanning",803788,22.816667,108.316667 ],
    [ u"cn",u"Nanpiao",157044,41.098218,120.747923 ],
    [ u"cn",u"Nantai",56478,40.924101,122.80437 ],
    [ u"cn",u"Nantong",666251,32.030278,120.874722 ],
    [ u"cn",u"Nanyang",251532,32.994722,112.532778 ],
    [ u"cn",u"Nanzhang",83604,31.783941,111.827518 ],
    [ u"cn",u"Nanzhou",54449,29.359551,112.402433 ],
    [ u"cn",u"Nehe",108253,48.483333,124.833333 ],
    [ u"cn",u"Neijiang",546854,29.583536,105.06216 ],
    [ u"cn",u"Nenjiang",87236,49.183333,125.216667 ],
    [ u"cn",u"Nianzishan",62131,47.516667,122.883333 ],
    [ u"cn",u"Ningan",66549,44.383333,129.433333 ],
    [ u"cn",u"Ningbo",719867,29.878186,121.549453 ],
    [ u"cn",u"Ninghai",68330,29.289167,121.424722 ],
    [ u"cn",u"Ninghai",56937,37.383333,121.583333 ],
    [ u"cn",u"Ningxiang",55312,28.25,112.55 ],
    [ u"cn",u"Ningyang",82994,35.764167,116.791389 ],
    [ u"cn",u"Nongan",98087,44.381982,125.168469 ],
    [ u"cn",u"Panshi",80200,42.942222,126.056111 ],
    [ u"cn",u"Panzhihua",461513,26.547902,101.705386 ],
    [ u"cn",u"Peking",7480601,39.928889,116.388333 ],
    [ u"cn",u"Pengcheng",68442,36.431111,114.17 ],
    [ u"cn",u"Pingdingshan",889675,33.738472,113.301194 ],
    [ u"cn",u"Pingdu",91077,36.784444,119.946389 ],
    [ u"cn",u"Pingliang",108156,35.539167,106.686111 ],
    [ u"cn",u"Pingshan",113631,22.993761,114.713109 ],
    [ u"cn",u"Pingxiang",372123,27.616667,113.85 ],
    [ u"cn",u"Pingyin",62050,36.283056,116.445278 ],
    [ u"cn",u"Pingyi",78254,35.500556,117.630833 ],
    [ u"cn",u"Pingzhuang",67273,42.037222,119.288889 ],
    [ u"cn",u"Pulandian",104277,39.395278,121.966944 ],
    [ u"cn",u"Pumiao",61690,22.75,108.483333 ],
    [ u"cn",u"Puqi",132891,29.716667,113.883333 ],
    [ u"cn",u"Puyang",666322,35.702778,115.005278 ],
    [ u"cn",u"Qianan",62337,44.993243,124.058109 ],
    [ u"cn",u"Qianguo",113611,45.117115,124.856761 ],
    [ u"cn",u"Qianjiang",179079,30.415128,112.88595 ],
    [ u"cn",u"Qidong",58287,26.768369,112.108136 ],
    [ u"cn",u"Qingan",60408,46.879444,127.506667 ],
    [ u"cn",u"Qingdao",1642245,36.098611,120.371944 ],
    [ u"cn",u"Qinggang",64182,46.683333,126.083333 ],
    [ u"cn",u"Qingquan",76154,30.45113,115.255931 ],
    [ u"cn",u"Qingyuan",151287,23.7,113.033333 ],
    [ u"cn",u"Qinhuangdao",759718,39.931667,119.588333 ],
    [ u"cn",u"Qinnan",55975,33.253056,119.913333 ],
    [ u"cn",u"Qinzhou",100996,21.95,108.616667 ],
    [ u"cn",u"Qiongshan",87657,20.005833,110.354167 ],
    [ u"cn",u"Qiqihar",882364,47.340833,123.967222 ],
    [ u"cn",u"Qitaihe",345033,45.8,130.85 ],
    [ u"cn",u"Qixia",79106,37.2975,120.825556 ],
    [ u"cn",u"Qixingtai",60169,30.413547,111.887388 ],
    [ u"cn",u"Qiyang",66442,26.573073,111.841839 ],
    [ u"cn",u"Quanzhou",184143,24.913889,118.585833 ],
    [ u"cn",u"Qufu",85144,35.596667,116.991111 ],
    [ u"cn",u"Qujing",146015,25.483333,103.783333 ],
    [ u"cn",u"Quzhou",82216,28.959444,118.868611 ],
    [ u"cn",u"Ranghulu",226298,46.65,124.866667 ],
    [ u"cn",u"Renqiu",98569,38.698889,116.093611 ],
    [ u"cn",u"Rizhao",246387,35.390278,119.545833 ],
    [ u"cn",u"Rongcheng",67397,25.725,119.379444 ],
    [ u"cn",u"Rongcheng",108908,29.845047,112.951441 ],
    [ u"cn",u"Rongcheng",102157,26.266667,104.016667 ],
    [ u"cn",u"Rongcheng",1001985,23.528858,116.364159 ],
    [ u"cn",u"Rucheng",77947,32.388333,120.555278 ],
    [ u"cn",u"Ruian",125208,27.776047,120.658588 ],
    [ u"cn",u"Sanbu",140454,22.36078,112.688088 ],
    [ u"cn",u"Sanchazi",66576,42.081667,126.600278 ],
    [ u"cn",u"Sanmenxia",357767,34.774722,111.181389 ],
    [ u"cn",u"Sanming",209444,26.248611,117.618611 ],
    [ u"cn",u"Shache",82509,38.416667,77.240556 ],
    [ u"cn",u"Shahe",125132,36.854722,114.4975 ],
    [ u"cn",u"Shancheng",74459,34.795278,116.081667 ],
    [ u"cn",u"Shanghai",14608512,31.045556,121.399722 ],
    [ u"cn",u"Shangqiu",181218,34.383333,115.616667 ],
    [ u"cn",u"Shangrao",318769,28.453221,117.968604 ],
    [ u"cn",u"Shangzhi",82419,45.214033,127.950313 ],
    [ u"cn",u"Shanhetun",57550,44.7,127.2 ],
    [ u"cn",u"Shanting",80843,35.075278,117.457778 ],
    [ u"cn",u"Shaoguan",628749,24.8,113.583333 ],
    [ u"cn",u"Shaowu",112585,27.340891,117.483096 ],
    [ u"cn",u"Shaoxing",421283,30.011019,120.571528 ],
    [ u"cn",u"Shaoyang",649452,26.965893,111.241376 ],
    [ u"cn",u"Shaping",107589,22.477547,112.845784 ],
    [ u"cn",u"Shashi",498780,30.307222,112.244722 ],
    [ u"cn",u"Shenjiamen",95433,29.957625,122.298017 ],
    [ u"cn",u"Shenxian",79196,36.241111,115.667222 ],
    [ u"cn",u"Shenyang",3512192,41.792222,123.432778 ],
    [ u"cn",u"Shenzhen",1002592,22.533333,114.133333 ],
    [ u"cn",u"Shihezi",572772,44.3,86.033333 ],
    [ u"cn",u"Shilong",109733,23.112269,113.842476 ],
    [ u"cn",u"Shima",68375,24.447778,117.811111 ],
    [ u"cn",u"Shishou",122411,29.716667,112.4 ],
    [ u"cn",u"Shitanjing",78765,39.234167,106.343889 ],
    [ u"cn",u"Shiyan",408055,32.6475,110.778056 ],
    [ u"cn",u"Shizilu",86749,35.171111,118.828889 ],
    [ u"cn",u"Shizuishan",136570,39.041944,106.395833 ],
    [ u"cn",u"Shouguang",79212,36.88,118.7375 ],
    [ u"cn",u"Shuangcheng",130710,45.35,126.283333 ],
    [ u"cn",u"Shuangyang",62137,43.524167,125.673611 ],
    [ u"cn",u"Shuangyashan",209521,46.636111,131.153889 ],
    [ u"cn",u"Shuiji",75849,36.859167,120.526944 ],
    [ u"cn",u"Shulan",77420,44.35,126.8 ],
    [ u"cn",u"Shunyi",117623,40.125,116.645278 ],
    [ u"cn",u"Simao",71094,22.788627,100.974807 ],
    [ u"cn",u"Sishui",90175,35.648889,117.275833 ],
    [ u"cn",u"Songjianghe",67672,42.185903,127.478946 ],
    [ u"cn",u"Songling",77566,31.193303,120.717577 ],
    [ u"cn",u"Suicheng",61430,33.896298,117.933066 ],
    [ u"cn",u"Suicheng",79141,21.414225,110.236498 ],
    [ u"cn",u"Suifenhe",15183,44.4,131.166667 ],
    [ u"cn",u"Suihua",252245,46.640556,126.996944 ],
    [ u"cn",u"Suileng",57124,47.166667,127.3 ],
    [ u"cn",u"Suining",124924,30.508017,105.573324 ],
    [ u"cn",u"Suixi",74172,33.890673,116.774725 ],
    [ u"cn",u"Sujiatun",148113,41.659167,123.339167 ],
    [ u"cn",u"Suozhen",58766,36.953889,118.104722 ],
    [ u"cn",u"Suzhou",205130,33.636111,116.978889 ],
    [ u"cn",u"Suzhou",1343091,31.311389,120.618056 ],
    [ u"cn",u"Tahe",60874,52.333333,124.733333 ],
    [ u"cn",u"Taian",750340,36.185278,117.12 ],
    [ u"cn",u"Taicheng",145440,22.251347,112.779904 ],
    [ u"cn",u"Taihe",83018,30.871229,105.384542 ],
    [ u"cn",u"Taikang",55316,46.833333,124.416667 ],
    [ u"cn",u"Tailai",66623,46.383333,123.4 ],
    [ u"cn",u"Taixing",79655,32.166667,120.013611 ],
    [ u"cn",u"Taiyuan",2722475,37.726944,112.470833 ],
    [ u"cn",u"Taizhou",612356,32.493333,119.910627 ],
    [ u"cn",u"Tancheng",83467,34.613611,118.339722 ],
    [ u"cn",u"Tanggu",535298,39.021111,117.646944 ],
    [ u"cn",u"Tangjiazhuang",79489,39.733333,118.45 ],
    [ u"cn",u"Tangping",81729,22.026471,111.93229 ],
    [ u"cn",u"Tangshan",2054526,37.3325,114.701389 ],
    [ u"cn",u"Tangzhai",67936,34.432778,116.591111 ],
    [ u"cn",u"Taonan",112819,45.333333,122.783333 ],
    [ u"cn",u"Taozhuang",60137,34.85,117.333333 ],
    [ u"cn",u"Tengzhou",105456,35.077061,117.151758 ],
    [ u"cn",u"Tianjin",3766207,39.142222,117.176667 ],
    [ u"cn",u"Tianmen",224871,30.65,113.1 ],
    [ u"cn",u"Tianpeng",60797,30.986641,103.939333 ],
    [ u"cn",u"Tieling",333907,42.293056,123.841389 ],
    [ u"cn",u"Tieli",109636,46.95,128.05 ],
    [ u"cn",u"Tongchuan",223603,34.898799,108.950562 ],
    [ u"cn",u"Tongchuan",58346,31.094069,105.087312 ],
    [ u"cn",u"Tongliao",261110,43.6125,122.265278 ],
    [ u"cn",u"Tongling",312588,30.933333,117.816667 ],
    [ u"cn",u"Tongren",90593,27.717222,109.185278 ],
    [ u"cn",u"Tongzhou",163326,39.905278,116.599444 ],
    [ u"cn",u"Tongzi",80344,28.1375,106.82 ],
    [ u"cn",u"Tumen",78719,42.966111,129.8425 ],
    [ u"cn",u"Tunxi",77000,29.711389,118.3125 ],
    [ u"cn",u"Ürümqi",1508225,43.800965,87.600459 ],
    [ u"cn",u"Wangkui",69915,46.833333,126.5 ],
    [ u"cn",u"Wangou",65298,42.059722,126.915833 ],
    [ u"cn",u"Wangqing",88732,43.321787,129.763416 ],
    [ u"cn",u"Wanning",64954,18.800278,110.396667 ],
    [ u"cn",u"Wanxian",188980,30.803889,108.389722 ],
    [ u"cn",u"Weifang",394732,36.71,119.101944 ],
    [ u"cn",u"Weihai",152595,37.501667,122.113611 ],
    [ u"cn",u"Weihe",71344,44.966667,128.383333 ],
    [ u"cn",u"Weinan",172321,34.503546,109.508908 ],
    [ u"cn",u"Wencheng",115370,37.193611,122.051111 ],
    [ u"cn",u"Wenling",67433,28.366944,121.36 ],
    [ u"cn",u"Wenshang",59455,35.7275,116.496111 ],
    [ u"cn",u"Wenzhou",865672,27.999416,120.66682 ],
    [ u"cn",u"Wuan",66523,36.694444,114.196389 ],
    [ u"cn",u"Wuchang",94786,44.914282,127.150007 ],
    [ u"cn",u"Wucheng",60212,29.600768,118.174951 ],
    [ u"cn",u"Wuda",129922,39.499444,106.711667 ],
    [ u"cn",u"Wufeng",101728,27.45,104.833333 ],
    [ u"cn",u"Wuhan",4184206,30.580125,114.273405 ],
    [ u"cn",u"Wuhu",507524,31.14607,118.57069 ],
    [ u"cn",u"Wulanhaote",165846,46.083333,122.083333 ],
    [ u"cn",u"Wuning",130387,29.258873,120.231083 ],
    [ u"cn",u"Wuwei",109319,37.928056,102.641389 ],
    [ u"cn",u"Wuxi",1108647,31.568873,120.288573 ],
    [ u"cn",u"Wuxue",220661,29.850578,115.552504 ],
    [ u"cn",u"Wuzhou",265846,23.483333,111.316667 ],
    [ u"cn",u"Xiamen",578337,24.479794,118.081869 ],
    [ u"cn",u"Xiangdong",103815,27.7,113.7 ],
    [ u"cn",u"Xiangfan",462956,32.042203,112.144794 ],
    [ u"cn",u"Xiangxiang",87592,27.733333,112.533333 ],
    [ u"cn",u"Xianshuigu",74028,38.985,117.382778 ],
    [ u"cn",u"Xiantao",239406,30.383333,113.4 ],
    [ u"cn",u"Xian",3953191,34.258333,108.928611 ],
    [ u"cn",u"Xianyang",1034081,34.33778,108.70261 ],
    [ u"cn",u"Xiaolan",187865,22.673811,113.231874 ],
    [ u"cn",u"Xiaolingwei",66031,32.033333,118.85 ],
    [ u"cn",u"Xiaoshan",95234,30.167456,120.258831 ],
    [ u"cn",u"Xiaoshi",68994,41.297111,124.120918 ],
    [ u"cn",u"Xiaoweizhai",58913,26.190278,107.5125 ],
    [ u"cn",u"Xiaoyi",56033,34.76,112.971389 ],
    [ u"cn",u"Xiashi",70171,30.536294,120.686384 ],
    [ u"cn",u"Xiazhen",125667,34.802222,117.111667 ],
    [ u"cn",u"Xichang",126787,27.896422,102.263415 ],
    [ u"cn",u"Xifeng",61087,42.737222,124.722222 ],
    [ u"cn",u"Xihe",90422,31.686355,113.465846 ],
    [ u"cn",u"Xihua",66848,33.783333,114.516667 ],
    [ u"cn",u"Ximei",94326,24.963889,118.379444 ],
    [ u"cn",u"Xinan",61816,34.375833,118.345 ],
    [ u"cn",u"Xingcheng",98968,40.616667,120.716667 ],
    [ u"cn",u"Xinglongshan",58432,43.956111,125.466111 ],
    [ u"cn",u"Xingtai",611739,37.063056,114.494167 ],
    [ u"cn",u"Xingyi",119000,25.05,104.983333 ],
    [ u"cn",u"Xining",767531,36.616667,101.766667 ],
    [ u"cn",u"Xinmin",74139,41.990833,122.825278 ],
    [ u"cn",u"Xinpu",392444,34.599722,119.159444 ],
    [ u"cn",u"Xinqing",55415,48.233333,129.5 ],
    [ u"cn",u"Xintai",222459,35.900556,117.751944 ],
    [ u"cn",u"Xinxiang",743601,35.308889,113.867222 ],
    [ u"cn",u"Xinyang",1590668,32.095833,114.120278 ],
    [ u"cn",u"Xinye",61633,32.518611,112.352222 ],
    [ u"cn",u"Xinyu",97480,27.804294,114.933354 ],
    [ u"cn",u"Xinzhi",72303,36.498889,111.704722 ],
    [ u"cn",u"Xinzhou",78767,30.866667,114.8 ],
    [ u"cn",u"Xinzhou",154003,38.409167,112.733333 ],
    [ u"cn",u"Xiongshi",73732,28.288572,117.213291 ],
    [ u"cn",u"Xiongyue",89887,40.177368,122.122844 ],
    [ u"cn",u"Xiongzhou",79050,25.116667,114.3 ],
    [ u"cn",u"Xiuyan",71614,40.276985,123.282968 ],
    [ u"cn",u"Xixiang",60745,35.162778,112.865 ],
    [ u"cn",u"Xuanhua",373422,40.610278,115.044722 ],
    [ u"cn",u"Xuanwu",56195,33.966667,115.233333 ],
    [ u"cn",u"Xuanzhou",127758,30.9525,118.755278 ],
    [ u"cn",u"Xuchang",449258,34.016667,113.816667 ],
    [ u"cn",u"Xucheng",83267,20.350001,110.128837 ],
    [ u"cn",u"Xunchang",64580,28.454332,104.714984 ],
    [ u"cn",u"Xushan",80299,30.176405,121.245702 ],
    [ u"cn",u"Xuzhou",1199193,34.180454,117.15707 ],
    [ u"cn",u"Yaan",108758,29.989788,103.003694 ],
    [ u"cn",u"Yakeshi",116284,49.283333,120.733333 ],
    [ u"cn",u"Yanan",107960,36.598889,109.491667 ],
    [ u"cn",u"Yancheng",628441,33.385556,120.125278 ],
    [ u"cn",u"Yangcun",63756,39.363889,117.060278 ],
    [ u"cn",u"Yanggu",74725,36.110556,115.775278 ],
    [ u"cn",u"Yangjiang",399735,21.85,111.966667 ],
    [ u"cn",u"Yangliuqing",76387,39.1375,116.999722 ],
    [ u"cn",u"Yangshan",57240,35.183333,116.25 ],
    [ u"cn",u"Yangshe",66039,31.889945,120.605215 ],
    [ u"cn",u"Yangzhou",539715,32.397222,119.435833 ],
    [ u"cn",u"Yanji",326957,42.771389,129.423333 ],
    [ u"cn",u"Yanliang",60891,34.659177,109.22921 ],
    [ u"cn",u"Yantai",719332,37.533333,121.4 ],
    [ u"cn",u"Yantongshan",57515,43.291944,126.009444 ],
    [ u"cn",u"Yanzhou",77276,35.552778,116.828611 ],
    [ u"cn",u"Yashan",56629,22.1975,109.941944 ],
    [ u"cn",u"Yatou",91517,37.15,122.383333 ],
    [ u"cn",u"Yebaishou",65536,41.3975,119.640833 ],
    [ u"cn",u"Yian",73299,47.883333,125.3 ],
    [ u"cn",u"Yibin",242111,28.699702,104.549173 ],
    [ u"cn",u"Yichang",476725,30.77135,111.321458 ],
    [ u"cn",u"Yicheng",61027,31.704722,112.256111 ],
    [ u"cn",u"Yichun",152169,27.833333,114.4 ],
    [ u"cn",u"Yichun",155762,47.7,128.9 ],
    [ u"cn",u"Yidu",117056,36.696667,118.479722 ],
    [ u"cn",u"Yigou",59073,35.811389,114.316667 ],
    [ u"cn",u"Yilan",71180,46.316667,129.566667 ],
    [ u"cn",u"Yima",82509,34.738056,111.883889 ],
    [ u"cn",u"Yinchuan",475101,38.468056,106.273056 ],
    [ u"cn",u"Yingcheng",265886,30.95,113.55 ],
    [ u"cn",u"Yingcheng",115538,24.165876,113.412675 ],
    [ u"cn",u"Yingkou",591159,40.637318,122.502508 ],
    [ u"cn",u"Yingshang",61771,32.629453,116.270135 ],
    [ u"cn",u"Yingzhong",108883,31.166111,112.583056 ],
    [ u"cn",u"Yining",257671,43.881111,81.245833 ],
    [ u"cn",u"Yishui",94115,35.784722,118.628056 ],
    [ u"cn",u"Yiyang",202608,28.589167,112.328333 ],
    [ u"cn",u"Yizheng",176006,32.269167,119.178889 ],
    [ u"cn",u"Yongan",134858,25.98,117.364167 ],
    [ u"cn",u"Yongchang",94465,29.351389,105.894722 ],
    [ u"cn",u"Yongzhou",86095,26.423889,111.613056 ],
    [ u"cn",u"Youhao",78402,47.866667,128.833333 ],
    [ u"cn",u"Yuancheng",93718,23.733333,114.683333 ],
    [ u"cn",u"Yuanping",82883,38.715278,112.7575 ],
    [ u"cn",u"Yuci",235929,37.680278,112.731944 ],
    [ u"cn",u"Yudong",81408,29.385,106.519444 ],
    [ u"cn",u"Yueyang",528140,29.140833,113.111111 ],
    [ u"cn",u"Yulin",148485,22.633333,110.15 ],
    [ u"cn",u"Yumen",84769,39.833333,97.733333 ],
    [ u"cn",u"Yuncheng",201950,35.023056,110.992778 ],
    [ u"cn",u"Yuncheng",64511,35.598333,115.934722 ],
    [ u"cn",u"Yuncheng",96192,22.930558,112.037297 ],
    [ u"cn",u"Yunhe",82641,34.311389,117.950278 ],
    [ u"cn",u"Yunjinghong",62105,21.991015,100.734086 ],
    [ u"cn",u"Yunyang",73922,33.447432,112.714225 ],
    [ u"cn",u"Yushan",140039,31.377623,120.954305 ],
    [ u"cn",u"Yushu",124736,44.8,126.533333 ],
    [ u"cn",u"Yuxia",60206,34.061535,108.629046 ],
    [ u"cn",u"Yuyao",114177,30.05,121.149444 ],
    [ u"cn",u"Yuzhou",87961,34.162778,113.463889 ],
    [ u"cn",u"Zalantun",132224,48,122.716667 ],
    [ u"cn",u"Zaoyang",184509,32.127222,112.754167 ],
    [ u"cn",u"Zaozhuang",183665,34.864722,117.554167 ],
    [ u"cn",u"Zhangdian",669770,36.790556,118.063333 ],
    [ u"cn",u"Zhangjiakou",692602,40.81,114.879444 ],
    [ u"cn",u"Zhangye",96228,38.934167,100.451667 ],
    [ u"cn",u"Zhangzhou",589831,24.513333,117.655556 ],
    [ u"cn",u"Zhanjiang",637790,21.281452,110.342713 ],
    [ u"cn",u"Zhaocheng",100774,37.359167,120.396389 ],
    [ u"cn",u"Zhaodong",154406,46.083333,125.983333 ],
    [ u"cn",u"Zhaoqing",361969,23.051157,112.459722 ],
    [ u"cn",u"Zhaotong",109400,27.316667,103.716667 ],
    [ u"cn",u"Zhaoyang",105918,32.939167,119.834167 ],
    [ u"cn",u"Zhaoyuan",59370,45.5,125.133333 ],
    [ u"cn",u"Zhaozhou",62373,45.683333,125.316667 ],
    [ u"cn",u"Zhengjiatun",93666,43.506389,123.506389 ],
    [ u"cn",u"Zhenhai",61979,29.969497,121.687529 ],
    [ u"cn",u"Zhenjiang",632552,32.209167,119.434167 ],
    [ u"cn",u"Zhenlai",67760,45.849549,123.297296 ],
    [ u"cn",u"Zhicheng",63753,31.006111,119.903611 ],
    [ u"cn",u"Zhicheng",59187,27.046944,118.325278 ],
    [ u"cn",u"Zhicheng",159383,30.295556,111.504722 ],
    [ u"cn",u"Zhifang",76682,30.35,114.316667 ],
    [ u"cn",u"Zhongshan",342306,22.520576,113.382318 ],
    [ u"cn",u"Zhongshu",91750,24.516667,103.766667 ],
    [ u"cn",u"Zhongxing",57338,33.703889,118.679167 ],
    [ u"cn",u"Zhoucheng",72070,35.912222,116.311667 ],
    [ u"cn",u"Zhoucheng",103829,24.355,102.542222 ],
    [ u"cn",u"Zhoucun",122402,36.816667,117.816667 ],
    [ u"cn",u"Zhoukou",377061,33.633333,114.633333 ],
    [ u"cn",u"Zhuanghe",80384,39.700833,122.991111 ],
    [ u"cn",u"Zhucheng",109968,35.994722,119.3975 ],
    [ u"cn",u"Zhuhai",501199,22.276944,113.567778 ],
    [ u"cn",u"Zhuji",110721,29.718765,120.242333 ],
    [ u"cn",u"Zhumadian",253536,32.979444,114.029444 ],
    [ u"cn",u"Zhuozhou",116310,39.481111,115.963333 ],
    [ u"cn",u"Zhuzhou",709358,27.691868,113.152137 ],
    [ u"cn",u"Zigong",689961,29.341622,104.776887 ],
    [ u"cn",u"Ziyang",87400,30.121083,104.648106 ],
    [ u"cn",u"Zouxian",190537,35.400556,116.965556 ],
    [ u"cn",u"Zunyi",466292,27.543056,106.823056 ],
    [ u"co",u"Abejorral",7360,5.789281,-75.427252 ],
    [ u"co",u"Ábrego",10823,8.080647,-73.220543 ],
    [ u"co",u"Abriaquí",1281,6.631477,-76.064437 ],
    [ u"co",u"Acacías",40628,3.986946,-73.757971 ],
    [ u"co",u"Acandí",4840,8.506334,-77.277839 ],
    [ u"co",u"Acaricuará",430,.7,-70.233333 ],
    [ u"co",u"Acevedo",4451,1.836055,-75.854985 ],
    [ u"co",u"Achí",8434,8.568178,-74.554052 ],
    [ u"co",u"Agrado",4531,2.257254,-75.771421 ],
    [ u"co",u"Aguachica",73361,8.308442,-73.6166 ],
    [ u"co",u"Aguadas",19727,5.611612,-75.456235 ],
    [ u"co",u"Agua de Dios",10876,4.376478,-74.669952 ],
    [ u"co",u"Aguazul",15670,5.172819,-72.547058 ],
    [ u"co",u"Agustín Codazzi",51479,10.034087,-73.236111 ],
    [ u"co",u"Aipe",7964,3.222222,-75.236667 ],
    [ u"co",u"Albán",1684,4.876608,-74.437683 ],
    [ u"co",u"Albania",4160,1.328661,-75.878235 ],
    [ u"co",u"Albania",6365,11.160987,-72.592385 ],
    [ u"co",u"Albania",810,5.761389,-73.917778 ],
    [ u"co",u"Alcalá",9135,4.674722,-75.7825 ],
    [ u"co",u"Aldana",1956,.882828,-77.701026 ],
    [ u"co",u"Alejandría",2725,6.377447,-75.140649 ],
    [ u"co",u"Algarrobo",10042,10.1,-74.266667 ],
    [ u"co",u"Algeciras",10792,2.522953,-75.314922 ],
    [ u"co",u"Almaguer",3120,1.917,-76.852331 ],
    [ u"co",u"Almeida",754,4.970833,-73.379722 ],
    [ u"co",u"Altamira",2123,2.062778,-75.787222 ],
    [ u"co",u"Alto Baudó",3242,5.516042,-76.97449 ],
    [ u"co",u"Altos del Rosario",5220,8.794444,-74.165833 ],
    [ u"co",u"Alvarado",2049,4.566124,-74.962294 ],
    [ u"co",u"Amagá",12170,6.040011,-75.703151 ],
    [ u"co",u"Amalfi",9733,6.910163,-75.077644 ],
    [ u"co",u"Ambalema",4892,4.78405,-74.762682 ],
    [ u"co",u"Anapoima",4953,4.520278,-74.539444 ],
    [ u"co",u"Ancuya",5852,1.2703,-77.515749 ],
    [ u"co",u"Andalucía",17432,4.17061,-76.166411 ],
    [ u"co",u"Andes",16420,5.656098,-75.878772 ],
    [ u"co",u"Angelópolis",1917,6.083333,-75.7 ],
    [ u"co",u"Angostura",3640,6.885077,-75.334669 ],
    [ u"co",u"Anolaima",5585,4.765904,-74.465477 ],
    [ u"co",u"Anorí",4762,7.072725,-75.147677 ],
    [ u"co",u"Anserma",25242,5.332778,-75.791111 ],
    [ u"co",u"Ansermanuevo",12332,4.797222,-75.995 ],
    [ u"co",u"Antioquia",11829,6.556867,-75.828056 ],
    [ u"co",u"Anzoátegui",2229,4.629963,-75.09539 ],
    [ u"co",u"Apartadó",86439,7.866667,-76.666667 ],
    [ u"co",u"Apía",6940,5.10645,-75.943177 ],
    [ u"co",u"Aquitania",5718,5.519722,-72.8875 ],
    [ u"co",u"Aracataca",27704,10.591812,-74.189831 ],
    [ u"co",u"Aranzazu",9327,5.271232,-75.490438 ],
    [ u"co",u"Aratoca",2101,6.693532,-73.020826 ],
    [ u"co",u"Arauca",69266,7.084512,-70.755366 ],
    [ u"co",u"Arbeláez",5252,4.272543,-74.415128 ],
    [ u"co",u"Arboleda",1736,1.508584,-77.124435 ],
    [ u"co",u"Arboledas",2702,7.642333,-72.799442 ],
    [ u"co",u"Arboletes",8381,8.85051,-76.426939 ],
    [ u"co",u"Arcabuco",1564,5.754629,-73.436694 ],
    [ u"co",u"Arenal",5346,8.459278,-73.943309 ],
    [ u"co",u"Argelia",3474,5.731269,-75.142573 ],
    [ u"co",u"Argelia",4262,2.25563,-77.248762 ],
    [ u"co",u"Argelia",3419,4.723415,-76.119091 ],
    [ u"co",u"Ariguaní",26246,10.25,-74 ],
    [ u"co",u"Arjona",50406,10.254444,-75.343889 ],
    [ u"co",u"Armenia",2035,6.156389,-75.787222 ],
    [ u"co",u"Armenia",315332,4.533889,-75.681111 ],
    [ u"co",u"Arroyohondo",3622,10.252204,-75.019801 ],
    [ u"co",u"Astrea",8996,9.498276,-73.975914 ],
    [ u"co",u"Ataco",4105,3.591466,-75.381776 ],
    [ u"co",u"Ayapel",22602,8.313721,-75.139822 ],
    [ u"co",u"Bagadó",4561,5.411637,-76.415202 ],
    [ u"co",u"Bajo Baudó",6168,4.953336,-77.365975 ],
    [ u"co",u"Balboa",6272,2.039556,-77.216839 ],
    [ u"co",u"Balboa",2302,4.951667,-75.957222 ],
    [ u"co",u"Baranoa",44079,10.794084,-74.9164 ],
    [ u"co",u"Baraya",4402,3.153333,-75.053056 ],
    [ u"co",u"Barbacoas",7634,1.671536,-78.139782 ],
    [ u"co",u"Barbosa",16707,6.438088,-75.331355 ],
    [ u"co",u"Barbosa",20373,5.931675,-73.615065 ],
    [ u"co",u"Barichara",4150,6.635725,-73.222824 ],
    [ u"co",u"Barrancabermeja",191406,7.065278,-73.854722 ],
    [ u"co",u"Barranca de Upía",1178,4.569634,-72.966758 ],
    [ u"co",u"Barrancas",17350,10.957561,-72.787693 ],
    [ u"co",u"Barranco de Loba",5933,8.945973,-74.10647 ],
    [ u"co",u"Barranquilla",1380437,10.963889,-74.796389 ],
    [ u"co",u"Becerril",9002,9.704134,-73.279298 ],
    [ u"co",u"Belalcázar",6367,4.995278,-75.812778 ],
    [ u"co",u"Belén",3131,1.597871,-77.013993 ],
    [ u"co",u"Belén",5411,5.988921,-72.912544 ],
    [ u"co",u"Belén de Umbría",15698,5.200875,-75.868652 ],
    [ u"co",u"Bello",392945,6.337315,-75.557951 ],
    [ u"co",u"Belmira",1388,6.605082,-75.666193 ],
    [ u"co",u"Beltrán",296,4.801653,-74.741772 ],
    [ u"co",u"Berbeo",266,5.226752,-73.126076 ],
    [ u"co",u"Betania",3800,5.607778,-75.7125 ],
    [ u"co",u"Betéitiva",374,5.911024,-72.809263 ],
    [ u"co",u"Betulia",5216,6.112836,-75.983784 ],
    [ u"co",u"Betulia",1716,6.900694,-73.283472 ],
    [ u"co",u"Bituima",473,4.872516,-74.539255 ],
    [ u"co",u"Boavita",3749,6.33031,-72.58505 ],
    [ u"co",u"Bochalema",2511,7.610955,-72.647735 ],
    [ u"co",u"Bogotá",7102602,4.649178,-74.062827 ],
    [ u"co",u"Bojacá",4399,4.731762,-74.341289 ],
    [ u"co",u"Bojayá",1396,6.521299,-76.972342 ],
    [ u"co",u"Bolívar",15493,1.839944,-76.968889 ],
    [ u"co",u"Bolívar",2230,5.989426,-73.770208 ],
    [ u"co",u"Bolívar",4165,4.3387,-76.183416 ],
    [ u"co",u"Bosconia",24508,9.968889,-73.883611 ],
    [ u"co",u"Boyacá",731,5.453715,-73.362497 ],
    [ u"co",u"Briceño",2214,7.110957,-75.551523 ],
    [ u"co",u"Briceño",632,5.688221,-73.917838 ],
    [ u"co",u"Bucaramanga",571827,7.125393,-73.119804 ],
    [ u"co",u"Bucarasica",783,8.040955,-72.865376 ],
    [ u"co",u"Buenaventura",240391,3.880099,-77.031164 ],
    [ u"co",u"Buenavista",5062,9.049634,-76.002799 ],
    [ u"co",u"Buenavista",2084,4.353898,-75.717821 ],
    [ u"co",u"Buenos Aires",2144,3.015033,-76.642748 ],
    [ u"co",u"Buesaco",4177,1.390167,-77.159815 ],
    [ u"co",u"Buga",118006,3.900889,-76.297829 ],
    [ u"co",u"Bugalagrande",12418,4.212073,-76.155638 ],
    [ u"co",u"Buriticá",2388,6.718732,-75.907344 ],
    [ u"co",u"Busbanzá",164,5.830471,-72.884192 ],
    [ u"co",u"Cabrera",363,6.593261,-73.245453 ],
    [ u"co",u"Cabrera",1397,3.985982,-74.482834 ],
    [ u"co",u"Cabuyaro",1140,4.281704,-72.793994 ],
    [ u"co",u"Cáceres",4987,7.580779,-75.348422 ],
    [ u"co",u"Cachipay",4260,5.266667,-74.566667 ],
    [ u"co",u"Cáchira",2097,7.741035,-73.0483 ],
    [ u"co",u"Cácota",1415,7.267872,-72.641969 ],
    [ u"co",u"Caicedo",1617,6.405108,-75.982548 ],
    [ u"co",u"Caicedonia",32417,4.332396,-75.826654 ],
    [ u"co",u"Caimito",2925,8.812288,-75.410663 ],
    [ u"co",u"Cajamarca",9310,4.441724,-75.426783 ],
    [ u"co",u"Cajibío",3365,2.622712,-76.570388 ],
    [ u"co",u"Cajicá",25000,4.918574,-74.027993 ],
    [ u"co",u"Calamar",3745,1.959598,-72.653147 ],
    [ u"co",u"Calamar",9180,10.251103,-74.914617 ],
    [ u"co",u"Calarcá",62171,4.529486,-75.640914 ],
    [ u"co",u"Caldas",65566,6.091056,-75.63569 ],
    [ u"co",u"Caldas",475,5.554556,-73.865667 ],
    [ u"co",u"Caldono",3518,2.797395,-76.483165 ],
    [ u"co",u"Cali",2392897,3.437222,-76.5225 ],
    [ u"co",u"California",573,7.347089,-72.945185 ],
    [ u"co",u"Caloto",6479,3.035863,-76.407883 ],
    [ u"co",u"Campamento",1870,6.979196,-75.297235 ],
    [ u"co",u"Campoalegre",22569,2.684892,-75.323109 ],
    [ u"co",u"Campo de la Cruz",22804,10.378077,-74.883561 ],
    [ u"co",u"Campohermoso",695,5.031323,-73.103271 ],
    [ u"co",u"Canalete",2620,8.676111,-76.204167 ],
    [ u"co",u"Cañasgordas",6026,6.749891,-76.025393 ],
    [ u"co",u"Candelaria",11427,10.459117,-74.879697 ],
    [ u"co",u"Candelaria",23989,3.406711,-76.348192 ],
    [ u"co",u"Cantagallo",4672,7.375989,-73.919626 ],
    [ u"co",u"Caparrapí",4477,5.346438,-74.491473 ],
    [ u"co",u"Capitanejo",3791,6.528812,-72.695949 ],
    [ u"co",u"Cáqueza",7958,4.405687,-73.946828 ],
    [ u"co",u"Caracolí",3120,6.409196,-74.757153 ],
    [ u"co",u"Caramanta",3044,5.547819,-75.643677 ],
    [ u"co",u"Carcasí",862,6.627114,-72.626249 ],
    [ u"co",u"Carepa",20627,7.758489,-76.652545 ],
    [ u"co",u"Carmen de Apicalá",5640,4.147252,-74.720141 ],
    [ u"co",u"Carmen de Carupa",1928,5.348619,-73.901683 ],
    [ u"co",u"Carmen de Viboral",21152,6.082358,-75.335088 ],
    [ u"co",u"Carolina",3160,6.724393,-75.28168 ],
    [ u"co",u"Cartagena",952036,10.399722,-75.514444 ],
    [ u"co",u"Cartagena del Chairá",7586,1.334884,-74.842886 ],
    [ u"co",u"Cartago",134829,4.746389,-75.911667 ],
    [ u"co",u"Casabianca",1593,5.079586,-75.120591 ],
    [ u"co",u"Caucasia",58035,7.986544,-75.193488 ],
    [ u"co",u"Cepitá",377,6.754266,-72.974395 ],
    [ u"co",u"Cereté",55514,8.884788,-75.790522 ],
    [ u"co",u"Cerinza",1499,5.955676,-72.947826 ],
    [ u"co",u"Cerrito",2435,6.843147,-72.694041 ],
    [ u"co",u"Cerro San Antonio",7058,10.325853,-74.869331 ],
    [ u"co",u"Cértegui",2855,5.370729,-76.604398 ],
    [ u"co",u"Chaguaní",1108,4.948286,-74.593922 ],
    [ u"co",u"Chalán",2897,9.54765,-75.311285 ],
    [ u"co",u"Chámeza",948,5.214209,-72.869481 ],
    [ u"co",u"Chaparral",19982,3.723149,-75.483165 ],
    [ u"co",u"Charalá",5727,5.836474,-73.281049 ],
    [ u"co",u"Charta",650,7.280252,-72.967815 ],
    [ u"co",u"Chía",64570,4.858755,-74.058659 ],
    [ u"co",u"Chigorodó",48444,7.666379,-76.681059 ],
    [ u"co",u"Chimá",2785,9.148927,-75.628406 ],
    [ u"co",u"Chima",786,6.34431,-73.373929 ],
    [ u"co",u"Chimichagua",16746,9.257778,-73.81228 ],
    [ u"co",u"Chinácota",9667,7.607313,-72.601078 ],
    [ u"co",u"Chinavita",1113,5.167231,-73.368231 ],
    [ u"co",u"Chinchiná",68513,4.9825,-75.603611 ],
    [ u"co",u"Chinú",19596,9.10569,-75.398116 ],
    [ u"co",u"Chipaque",2707,4.4425,-74.044167 ],
    [ u"co",u"Chipatá",868,6.061956,-73.637181 ],
    [ u"co",u"Chiquinquirá",45295,5.616373,-73.817484 ],
    [ u"co",u"Chíquiza",730,5.604123,-73.485181 ],
    [ u"co",u"Chiriguaná",15181,9.362379,-73.603135 ],
    [ u"co",u"Chiscas",1356,6.552358,-72.499761 ],
    [ u"co",u"Chita",2914,6.187147,-72.472597 ],
    [ u"co",u"Chitagá",3871,7.137813,-72.664558 ],
    [ u"co",u"Chivatá",664,5.558233,-73.281983 ],
    [ u"co",u"Chivolo",11457,10.025022,-74.622789 ],
    [ u"co",u"Chivor",1622,4.885556,-73.368889 ],
    [ u"co",u"Choachí",4281,4.528969,-73.922727 ],
    [ u"co",u"Chocontá",7592,5.14468,-73.685782 ],
    [ u"co",u"Cicuco",7662,9.263056,-74.656944 ],
    [ u"co",u"Ciénaga",88313,11.007029,-74.247646 ],
    [ u"co",u"Ciénaga de Oro",17623,8.874433,-75.620278 ],
    [ u"co",u"Ciénega",1172,5.408669,-73.295722 ],
    [ u"co",u"Cimitarra",11267,6.314192,-73.949684 ],
    [ u"co",u"Circasia",20113,4.618889,-75.635833 ],
    [ u"co",u"Cisneros",8204,6.538333,-75.088611 ],
    [ u"co",u"Clemencia",8775,10.566455,-75.324986 ],
    [ u"co",u"Cocorná",5257,6.057299,-75.185241 ],
    [ u"co",u"Coello",769,4.289084,-74.898248 ],
    [ u"co",u"Cogua",4755,5.060515,-73.979253 ],
    [ u"co",u"Colombia",2388,3.376064,-74.801495 ],
    [ u"co",u"Colón",1348,1.643222,-77.024333 ],
    [ u"co",u"Colón",3269,1.191167,-76.9685 ],
    [ u"co",u"Colosó",3749,9.491496,-75.361451 ],
    [ u"co",u"Cómbita",1034,5.633118,-73.323981 ],
    [ u"co",u"Concepción",1513,6.394081,-75.258301 ],
    [ u"co",u"Concepción",2520,6.766195,-72.694004 ],
    [ u"co",u"Concordia",9324,6.046392,-75.907055 ],
    [ u"co",u"Concordia",6625,9.835452,-74.455478 ],
    [ u"co",u"Condoto",9898,5.093506,-76.649728 ],
    [ u"co",u"Confines",472,6.363601,-73.243959 ],
    [ u"co",u"Consacá",2239,1.215444,-77.469554 ],
    [ u"co",u"Contadero",1604,.907001,-77.547289 ],
    [ u"co",u"Contratación",3505,6.290053,-73.473536 ],
    [ u"co",u"Convención",9915,8.386944,-73.339722 ],
    [ u"co",u"Copacabana",49170,6.346328,-75.508875 ],
    [ u"co",u"Coper",814,5.476806,-74.044163 ],
    [ u"co",u"Córdoba",4063,4.393185,-75.689353 ],
    [ u"co",u"Córdoba",6597,9.586119,-74.827054 ],
    [ u"co",u"Córdoba",6597,9.633333,-74.783333 ],
    [ u"co",u"Corinto",16579,3.174072,-76.259928 ],
    [ u"co",u"Coromoro",1010,6.294611,-73.040219 ],
    [ u"co",u"Corozal",39801,9.315046,-75.292827 ],
    [ u"co",u"Corrales",1561,5.829683,-72.843321 ],
    [ u"co",u"Cota",7615,4.809384,-74.098001 ],
    [ u"co",u"Cotorra",4880,9.03886,-75.789688 ],
    [ u"co",u"Covarachía",590,6.505634,-72.733095 ],
    [ u"co",u"Coyaima",3893,3.799359,-75.194669 ],
    [ u"co",u"Cravo Norte",4787,6.301735,-70.204154 ],
    [ u"co",u"Cuaspud",2010,.861944,-77.814722 ],
    [ u"co",u"Cubará",1466,7.00078,-72.108524 ],
    [ u"co",u"Cubarral",2280,3.793524,-73.840634 ],
    [ u"co",u"Cucaita",1417,5.543728,-73.454331 ],
    [ u"co",u"Cucunubá",1699,5.249578,-73.766096 ],
    [ u"co",u"Cúcuta",721406,7.893907,-72.507821 ],
    [ u"co",u"Cucutilla",1950,7.539411,-72.772384 ],
    [ u"co",u"Cuítiva",233,5.580067,-72.966871 ],
    [ u"co",u"Cumaral",11264,4.270802,-73.486694 ],
    [ u"co",u"Cumaribo",629,4.445515,-69.798969 ],
    [ u"co",u"Cumbal",7529,.90875,-77.791451 ],
    [ u"co",u"Cumbitara",1091,1.651744,-77.582248 ],
    [ u"co",u"Cunday",2082,4.060035,-74.692117 ],
    [ u"co",u"Curillo",9540,1.033271,-75.919065 ],
    [ u"co",u"Curití",3417,6.60519,-73.068094 ],
    [ u"co",u"Curumaní",22085,9.199918,-73.542738 ],
    [ u"co",u"Dabeiba",11548,7.001719,-76.267225 ],
    [ u"co",u"Dagua",12320,3.656852,-76.68859 ],
    [ u"co",u"Darién",11724,3.930645,-76.484811 ],
    [ u"co",u"Dibulla",4402,11.272506,-73.309107 ],
    [ u"co",u"Distracción",4742,10.896933,-72.886099 ],
    [ u"co",u"Don Matías",10011,6.485685,-75.394959 ],
    [ u"co",u"Dos Quebradas",179586,4.839164,-75.667265 ],
    [ u"co",u"Duitama",92041,5.824499,-73.034083 ],
    [ u"co",u"Durania",3471,7.713073,-72.657591 ],
    [ u"co",u"Ebéjico",2583,6.325983,-75.768348 ],
    [ u"co",u"El Águila",2725,4.91345,-76.040042 ],
    [ u"co",u"El Bagre",40799,7.592724,-74.80858 ],
    [ u"co",u"El Banco",54524,9.001137,-73.975807 ],
    [ u"co",u"El Bordo",12072,2.116958,-76.982137 ],
    [ u"co",u"El Cairo",3268,4.666667,-76.016667 ],
    [ u"co",u"El Calvario",557,4.353424,-73.711467 ],
    [ u"co",u"El Carmen de Bolívar",47958,9.717396,-75.120232 ],
    [ u"co",u"El Carmen",2258,5.887778,-75.164167 ],
    [ u"co",u"El Carmen",5286,8.510637,-73.447755 ],
    [ u"co",u"El Carmen",1602,6.697358,-73.511165 ],
    [ u"co",u"El Castillo",2581,3.563629,-73.794885 ],
    [ u"co",u"El Cerrito",38391,3.685486,-76.313716 ],
    [ u"co",u"El Cocuy",2706,6.407836,-72.444637 ],
    [ u"co",u"El Copey",18137,10.150311,-73.961397 ],
    [ u"co",u"El Doncello",13082,1.678168,-75.284655 ],
    [ u"co",u"El Dorado",1011,2.774106,-72.868341 ],
    [ u"co",u"El Dovio",7943,4.5079,-76.236193 ],
    [ u"co",u"El Espino",1313,6.48277,-72.497181 ],
    [ u"co",u"El Guacamayo",428,6.245179,-73.496553 ],
    [ u"co",u"El Guamo",4732,10.031553,-74.976121 ],
    [ u"co",u"Elías",1117,2.011696,-75.939685 ],
    [ u"co",u"El Molino",5265,10.652246,-72.924046 ],
    [ u"co",u"El Paso",6367,9.660567,-73.747231 ],
    [ u"co",u"El Paujil",7619,1.57006,-75.328629 ],
    [ u"co",u"El Peñol",2294,1.459868,-77.44544 ],
    [ u"co",u"El Peñón",831,6.55,-72.833333 ],
    [ u"co",u"El Peñón",728,5.252638,-74.290689 ],
    [ u"co",u"El Peñón",4204,8.989155,-73.948571 ],
    [ u"co",u"El Piñón",7481,10.402827,-74.824153 ],
    [ u"co",u"El Playón",5334,7.471313,-73.203104 ],
    [ u"co",u"El Retén",15901,10.611353,-74.268237 ],
    [ u"co",u"El Retorno",3362,2.330225,-72.627648 ],
    [ u"co",u"El Roble",3324,9.101935,-75.19508 ],
    [ u"co",u"El Rosal",5552,4.853142,-74.259955 ],
    [ u"co",u"El Rosario",2607,1.741734,-77.3352 ],
    [ u"co",u"El Tambo",6355,2.451994,-76.810288 ],
    [ u"co",u"El Tambo",7279,1.418142,-77.396784 ],
    [ u"co",u"El Tarra",3336,8.575621,-73.094891 ],
    [ u"co",u"El Zulia",13521,7.932478,-72.601252 ],
    [ u"co",u"Encino",412,6.137349,-73.098474 ],
    [ u"co",u"Enciso",698,6.668082,-72.699861 ],
    [ u"co",u"Entrerríos",3462,6.565397,-75.516905 ],
    [ u"co",u"Envigado",163010,6.170643,-75.585307 ],
    [ u"co",u"Espinal",56214,4.149245,-74.884292 ],
    [ u"co",u"Facatativá",94613,4.813668,-74.354529 ],
    [ u"co",u"Falan",5234,5.115636,-74.94894 ],
    [ u"co",u"Filadelfia",5064,5.29606,-75.561197 ],
    [ u"co",u"Filandia",6851,4.674722,-75.658333 ],
    [ u"co",u"Firavitoba",2136,5.668847,-72.99289 ],
    [ u"co",u"Flandes",20919,4.294127,-74.819011 ],
    [ u"co",u"Florencia",130339,1.614382,-75.606229 ],
    [ u"co",u"Florencia",1467,1.68318,-77.073305 ],
    [ u"co",u"Floresta",1127,5.859027,-72.918818 ],
    [ u"co",u"Florián",1227,5.804874,-73.970287 ],
    [ u"co",u"Floridablanca",252271,7.062222,-73.08644 ],
    [ u"co",u"Florida",47173,3.322297,-76.234804 ],
    [ u"co",u"Fómeque",5390,4.487967,-73.897488 ],
    [ u"co",u"Fonseca",23510,10.886063,-72.848696 ],
    [ u"co",u"Fosca",1451,4.339159,-73.938522 ],
    [ u"co",u"Fredonia",8951,5.925833,-75.670556 ],
    [ u"co",u"Fresno",17669,5.152643,-75.036235 ],
    [ u"co",u"Frontino",8603,6.780054,-76.128801 ],
    [ u"co",u"Fuente de Oro",3610,3.459444,-73.612778 ],
    [ u"co",u"Fundación",59177,10.520664,-74.185037 ],
    [ u"co",u"Funes",2508,1.002657,-77.450668 ],
    [ u"co",u"Funza",54422,4.716381,-74.211954 ],
    [ u"co",u"Fúquene",563,5.404253,-73.7964 ],
    [ u"co",u"Fusagasuga",88822,4.336463,-74.363779 ],
    [ u"co",u"Gachalá",1661,4.692441,-73.520421 ],
    [ u"co",u"Gachancipá",3119,4.991109,-73.871538 ],
    [ u"co",u"Gachantiva",534,5.756615,-73.539495 ],
    [ u"co",u"Gachetá",4088,4.818539,-73.636586 ],
    [ u"co",u"Galán",1122,6.637808,-73.288778 ],
    [ u"co",u"Galapa",19733,10.896863,-74.885996 ],
    [ u"co",u"Galeras",9460,9.160948,-75.048108 ],
    [ u"co",u"Gama",584,4.762881,-73.610905 ],
    [ u"co",u"Gamarra",7327,8.322793,-73.742684 ],
    [ u"co",u"Gámbita",742,5.945969,-73.344348 ],
    [ u"co",u"Gámeza",1690,5.80263,-72.805865 ],
    [ u"co",u"Garagoa",11102,5.082356,-73.363342 ],
    [ u"co",u"Garzón",29452,2.19593,-75.627773 ],
    [ u"co",u"Génova",7140,4.316667,-75.766667 ],
    [ u"co",u"Gigante",9829,2.386767,-75.545312 ],
    [ u"co",u"Ginebra",6088,3.724614,-76.266749 ],
    [ u"co",u"Giraldo",1464,6.683056,-75.989167 ],
    [ u"co",u"Girardot",130292,4.298659,-74.804681 ],
    [ u"co",u"Girón",108468,7.068205,-73.169809 ],
    [ u"co",u"Gómez Plata",4097,6.681779,-75.219065 ],
    [ u"co",u"González",5634,8.389442,-73.379893 ],
    [ u"co",u"Gramalote",3577,7.887518,-72.797487 ],
    [ u"co",u"Granada",5661,6.143526,-75.185323 ],
    [ u"co",u"Granada",32366,3.538611,-73.700556 ],
    [ u"co",u"Granada",1100,5.056885,-74.556405 ],
    [ u"co",u"Guaca",1637,6.876209,-72.85594 ],
    [ u"co",u"Guacamayas",772,6.459169,-72.50104 ],
    [ u"co",u"Guacarí",19637,3.763828,-76.332916 ],
    [ u"co",u"Guachetá",4246,5.38425,-73.686172 ],
    [ u"co",u"Guachucal",4014,.960931,-77.731605 ],
    [ u"co",u"Guadalupe",1734,6.81449,-75.240634 ],
    [ u"co",u"Guadalupe",4761,2.024796,-75.755894 ],
    [ u"co",u"Guadalupe",2181,6.246397,-73.418333 ],
    [ u"co",u"Guaduas",14392,5.06692,-74.594986 ],
    [ u"co",u"Guaitarilla",6280,1.138554,-77.553006 ],
    [ u"co",u"Gualmatán",2510,.918884,-77.566507 ],
    [ u"co",u"Guamal",5026,3.880427,-73.765659 ],
    [ u"co",u"Guamal",9016,9.143338,-74.223844 ],
    [ u"co",u"Guamo",14881,4.030782,-74.970097 ],
    [ u"co",u"Guapi",13854,2.570823,-77.885421 ],
    [ u"co",u"Guapotá",564,6.307976,-73.320197 ],
    [ u"co",u"Guarne",14270,6.280456,-75.443537 ],
    [ u"co",u"Guasca",3540,4.86601,-73.877475 ],
    [ u"co",u"Guatapé",5389,6.232741,-75.158638 ],
    [ u"co",u"Guataquí",1139,4.515728,-74.789351 ],
    [ u"co",u"Guatavita",1920,4.936581,-73.833141 ],
    [ u"co",u"Guateque",7069,5.006189,-73.472736 ],
    [ u"co",u"Guática",4369,5.315691,-75.79826 ],
    [ u"co",u"Guavatá",943,5.95502,-73.700182 ],
    [ u"co",u"Guayabal de Síquima",1051,4.877388,-74.467444 ],
    [ u"co",u"Guayabal",5340,5.031034,-74.886825 ],
    [ u"co",u"Guayabetal",2017,4.214724,-73.817192 ],
    [ u"co",u"Guayatá",2857,4.964167,-73.4875 ],
    [ u"co",u"Güepsa",2471,6.02505,-73.573126 ],
    [ u"co",u"Güicán",2101,6.461843,-72.41129 ],
    [ u"co",u"Gutiérrez",772,4.254722,-74.0025 ],
    [ u"co",u"Hacarí",1502,8.323333,-73.148889 ],
    [ u"co",u"Hatillo de Loba",3639,8.95635,-74.078195 ],
    [ u"co",u"Hato",600,6.543016,-73.308264 ],
    [ u"co",u"Heliconia",2403,6.206891,-75.733671 ],
    [ u"co",u"Herrán",1648,7.506108,-72.483321 ],
    [ u"co",u"Herveo",3490,5.080042,-75.175558 ],
    [ u"co",u"Hispania",2468,5.799253,-75.907184 ],
    [ u"co",u"Hobo",4445,2.583333,-75.45 ],
    [ u"co",u"Honda",28158,5.20856,-74.735842 ],
    [ u"co",u"Ibagué",421689,4.438889,-75.232222 ],
    [ u"co",u"Icononzo",3540,4.176977,-74.532538 ],
    [ u"co",u"Iles",1879,.974909,-77.527408 ],
    [ u"co",u"Imués",1736,1.060715,-77.500442 ],
    [ u"co",u"Inírida",7299,3.865278,-67.923889 ],
    [ u"co",u"Inzá",2972,2.551295,-76.065455 ],
    [ u"co",u"Ipiales",77730,.830178,-77.649594 ],
    [ u"co",u"Íquira",3942,2.648673,-75.634573 ],
    [ u"co",u"Isnos",5185,1.928741,-76.211036 ],
    [ u"co",u"Istmina",13788,5.160538,-76.683971 ],
    [ u"co",u"Itagüí",281858,6.171944,-75.611389 ],
    [ u"co",u"Ituango",10770,7.171172,-75.764041 ],
    [ u"co",u"Iza",748,5.612029,-72.9793 ],
    [ u"co",u"Jambalo",1972,2.788333,-76.3225 ],
    [ u"co",u"Jamundí",44834,3.26074,-76.534989 ],
    [ u"co",u"Jardín",7747,5.599018,-75.819758 ],
    [ u"co",u"Jenesano",1200,5.385406,-73.363644 ],
    [ u"co",u"Jericó",7750,5.792106,-75.786012 ],
    [ u"co",u"Jericó",865,6.145921,-72.570804 ],
    [ u"co",u"Jerusalén",697,4.563094,-74.69519 ],
    [ u"co",u"Jesús María",823,5.877153,-73.780968 ],
    [ u"co",u"Jordán",112,6.732996,-73.095885 ],
    [ u"co",u"Juan de Acosta",8655,10.828133,-75.03341 ],
    [ u"co",u"Junín",1499,4.79027,-73.66011 ],
    [ u"co",u"Juradó",2351,7.10534,-77.76413 ],
    [ u"co",u"La Argentina",3082,2.196111,-75.98 ],
    [ u"co",u"Labateca",1639,7.298474,-72.494432 ],
    [ u"co",u"La Belleza",1649,5.790833,-73.848889 ],
    [ u"co",u"Labranzagrande",902,5.56223,-72.574991 ],
    [ u"co",u"La Calera",10175,4.383333,-73.983333 ],
    [ u"co",u"La Capilla",1375,5.704931,-73.475272 ],
    [ u"co",u"La Ceja",36585,6.030823,-75.431501 ],
    [ u"co",u"La Celia",4940,5.043333,-76.016667 ],
    [ u"co",u"La Cruz",8752,1.603013,-76.969008 ],
    [ u"co",u"La Cumbre",2432,3.7225,-76.020833 ],
    [ u"co",u"La Dorada",81951,5.44783,-74.663111 ],
    [ u"co",u"La Esperanza",2718,8.210434,-72.46399 ],
    [ u"co",u"La Estrella",49387,6.15769,-75.643173 ],
    [ u"co",u"La Florida",2882,1.298512,-77.406139 ],
    [ u"co",u"La Gloria",6810,8.618676,-73.802654 ],
    [ u"co",u"La Jagua del Pilar",894,10.516667,-73.083333 ],
    [ u"co",u"La Llanada",2747,1.489973,-77.583474 ],
    [ u"co",u"La Macarena",3466,2.183674,-73.784847 ],
    [ u"co",u"La Merced",3851,5.401944,-75.884722 ],
    [ u"co",u"La Merced",3851,5.086667,-75.8925 ],
    [ u"co",u"La Montañita",3305,1.476602,-75.439796 ],
    [ u"co",u"Landázuri",3483,6.218262,-73.811208 ],
    [ u"co",u"La Palma",8093,5.359201,-74.390467 ],
    [ u"co",u"La Paz",1135,6.178477,-73.589485 ],
    [ u"co",u"La Peña",1667,5.198474,-74.393677 ],
    [ u"co",u"La Pintada",5342,5.748673,-75.606261 ],
    [ u"co",u"La Plata",19276,2.393406,-75.892319 ],
    [ u"co",u"La Playa",1215,8.216389,-73.241389 ],
    [ u"co",u"La Primavera",3920,5.490556,-70.409167 ],
    [ u"co",u"La Salina",360,6.1,-72.35 ],
    [ u"co",u"La Sierra",2129,2.178346,-76.762648 ],
    [ u"co",u"La Tebaida",27099,4.452649,-75.787463 ],
    [ u"co",u"La Unión",8361,5.974309,-75.361954 ],
    [ u"co",u"La Unión",15061,1.604496,-77.131523 ],
    [ u"co",u"La Unión",4427,8.860556,-75.280556 ],
    [ u"co",u"La Unión",23459,4.532819,-76.103177 ],
    [ u"co",u"La Uribe",2103,3.240549,-74.354159 ],
    [ u"co",u"La Uvita",1708,6.316839,-72.560321 ],
    [ u"co",u"La Vega",3469,2.006277,-76.780276 ],
    [ u"co",u"La Vega",5706,4.968915,-74.609452 ],
    [ u"co",u"La Victoria",11064,4.522711,-76.03738 ],
    [ u"co",u"La Victoria",314,5.522778,-74.232778 ],
    [ u"co",u"La Virginia",33836,4.899722,-75.8825 ],
    [ u"co",u"Lebrija",8950,7.113168,-73.2178 ],
    [ u"co",u"Leiva",3668,1.933891,-77.302531 ],
    [ u"co",u"Leiva",5103,5.645,-73.566667 ],
    [ u"co",u"Lejanías",5157,3.525104,-74.021561 ],
    [ u"co",u"Lenguazaque",2555,5.307108,-73.711525 ],
    [ u"co",u"Lérida",20069,4.862417,-74.909768 ],
    [ u"co",u"Leticia",29666,-4.215278,-69.940556 ],
    [ u"co",u"Líbano",28212,4.921795,-75.062317 ],
    [ u"co",u"Liborina",2373,6.677901,-75.812185 ],
    [ u"co",u"Linares",3512,1.35783,-77.527246 ],
    [ u"co",u"Litoral del San Juan",1448,4.258748,-77.365164 ],
    [ u"co",u"Lloró",2651,5.496047,-76.549448 ],
    [ u"co",u"López",3700,2.1177,-76.775248 ],
    [ u"co",u"Lorica",40606,9.236484,-75.813499 ],
    [ u"co",u"Los Andes",4839,1.514686,-77.504435 ],
    [ u"co",u"Los Córdobas",2007,8.894026,-76.354551 ],
    [ u"co",u"Los Palmitos",14385,9.378988,-75.267692 ],
    [ u"co",u"Los Patios",58663,7.837931,-72.503696 ],
    [ u"co",u"Los Santos",1310,7.17,-73.093056 ],
    [ u"co",u"Lourdes",1500,7.944111,-72.83253 ],
    [ u"co",u"Luruaco",13237,10.609214,-75.143091 ],
    [ u"co",u"Macanal",734,4.972141,-73.319588 ],
    [ u"co",u"Macaravita",538,6.505669,-72.592988 ],
    [ u"co",u"Maceo",3109,6.551958,-74.787415 ],
    [ u"co",u"Machetá",1742,5.081541,-73.607613 ],
    [ u"co",u"Madrid",50438,4.732445,-74.264192 ],
    [ u"co",u"Magangué",100315,9.242024,-74.754671 ],
    [ u"co",u"Magüí",2892,1.935,-78.205 ],
    [ u"co",u"Mahates",9224,10.232927,-75.189849 ],
    [ u"co",u"Maicao",130351,11.383208,-72.243208 ],
    [ u"co",u"Majagual",11139,8.538865,-74.62038 ],
    [ u"co",u"Málaga",18740,6.699027,-72.732327 ],
    [ u"co",u"Malambo",101536,10.859533,-74.773861 ],
    [ u"co",u"Mallama",1788,1.137396,-77.848901 ],
    [ u"co",u"Manatí",14141,10.445893,-74.958694 ],
    [ u"co",u"Manaure",9703,11.775047,-72.444472 ],
    [ u"co",u"Maní",7031,4.817222,-72.288611 ],
    [ u"co",u"Manizales",357819,5.06889,-75.517383 ],
    [ u"co",u"Manta",1410,5.008643,-73.54115 ],
    [ u"co",u"Manzanares",16278,5.324722,-75.156944 ],
    [ u"co",u"Mapiripán",1993,2.889155,-72.125591 ],
    [ u"co",u"Margarita",1939,9.155957,-74.266183 ],
    [ u"co",u"María la Baja",23401,9.983205,-75.30155 ],
    [ u"co",u"Marinilla",24172,6.173579,-75.336208 ],
    [ u"co",u"Maripí",1143,5.551944,-74.008611 ],
    [ u"co",u"Mariquita",23104,5.198894,-74.89295 ],
    [ u"co",u"Marmato",1456,5.478427,-75.592667 ],
    [ u"co",u"Marquetalia",6224,5.296591,-75.054962 ],
    [ u"co",u"Marsella",11158,4.937222,-75.737778 ],
    [ u"co",u"Marulanda",1256,5.28393,-75.26016 ],
    [ u"co",u"Matanza",1669,7.322333,-73.015161 ],
    [ u"co",u"Medellín",2000001,6.25184,-75.563591 ],
    [ u"co",u"Medina",3098,4.510053,-73.349816 ],
    [ u"co",u"Melgar",25980,4.204748,-74.640746 ],
    [ u"co",u"Mercaderes",4684,1.800937,-77.165963 ],
    [ u"co",u"Mesetas",4163,3.384635,-74.044242 ],
    [ u"co",u"Milán",2618,1.292047,-75.511666 ],
    [ u"co",u"Miraflores",4864,1.336667,-71.951111 ],
    [ u"co",u"Miraflores",2766,5.196077,-73.14504 ],
    [ u"co",u"Miranda",13223,3.249907,-76.228145 ],
    [ u"co",u"Mistrató",6263,5.297302,-75.883217 ],
    [ u"co",u"Mitú",5917,1.198333,-70.173333 ],
    [ u"co",u"Mocoa",22035,1.149327,-76.64661 ],
    [ u"co",u"Mogotes",3438,6.475588,-72.970459 ],
    [ u"co",u"Molagavita",1205,6.673153,-72.808749 ],
    [ u"co",u"Momil",6441,9.237675,-75.674889 ],
    [ u"co",u"Mompos",30862,9.237864,-74.425329 ],
    [ u"co",u"Mongua",2322,5.750835,-72.803387 ],
    [ u"co",u"Monguí",2299,5.721507,-72.84908 ],
    [ u"co",u"Moniquirá",9785,5.876376,-73.572843 ],
    [ u"co",u"Moñitos",5385,8.25,-76.05 ],
    [ u"co",u"Montebello",2007,5.9449,-75.524279 ],
    [ u"co",u"Montecristo",5608,8.297102,-74.473298 ],
    [ u"co",u"Montelíbano",34162,9.58265,-74.103108 ],
    [ u"co",u"Montenegro",36500,4.566389,-75.751111 ],
    [ u"co",u"Montería",272424,8.747984,-75.881428 ],
    [ u"co",u"Monterrey",7759,4.872057,-72.898791 ],
    [ u"co",u"Morales",4074,2.757011,-76.617231 ],
    [ u"co",u"Morales",4773,8.270276,-73.868267 ],
    [ u"co",u"Morelia",2257,1.487474,-75.725807 ],
    [ u"co",u"Morroa",4949,9.333479,-75.305423 ],
    [ u"co",u"Mosquera",3471,2.50861,-78.451102 ],
    [ u"co",u"Mosquera",27006,4.705921,-74.230208 ],
    [ u"co",u"Motavita",392,5.576547,-73.366963 ],
    [ u"co",u"Murillo",1860,4.87393,-75.17151 ],
    [ u"co",u"Murindó",2372,6.984806,-76.754394 ],
    [ u"co",u"Mutatá",4811,7.244074,-76.435645 ],
    [ u"co",u"Mutiscua",918,7.300606,-72.746675 ],
    [ u"co",u"Mutis",3079,6.22622,-77.404393 ],
    [ u"co",u"Muzo",7977,5.535278,-74.107778 ],
    [ u"co",u"Nariño",3186,5.60893,-75.176561 ],
    [ u"co",u"Nariño",2933,1.295456,-77.360496 ],
    [ u"co",u"Nariño",1213,4.397808,-74.827313 ],
    [ u"co",u"Natagaima",11217,3.620569,-75.094148 ],
    [ u"co",u"Nátaga",2232,2.543593,-75.80852 ],
    [ u"co",u"Nechí",6694,8.094189,-74.775733 ],
    [ u"co",u"Necoclí",10835,8.423417,-76.785967 ],
    [ u"co",u"Neira",11755,5.166498,-75.520008 ],
    [ u"co",u"Neiva",352859,2.927299,-75.281885 ],
    [ u"co",u"Nemocón",5467,5.05,-73.883333 ],
    [ u"co",u"Nilo",1117,4.306041,-74.620833 ],
    [ u"co",u"Nimaima",604,5.126143,-74.384945 ],
    [ u"co",u"Nobsa",3360,5.769779,-72.940991 ],
    [ u"co",u"Nocaima",2475,5.069831,-74.377999 ],
    [ u"co",u"Norcasia",5976,5.577815,-74.885206 ],
    [ u"co",u"Nóvita",1898,4.955112,-76.605258 ],
    [ u"co",u"Nueva Granada",2714,9.801677,-74.393036 ],
    [ u"co",u"Nuevo Colón",863,5.353681,-73.456605 ],
    [ u"co",u"Nunchía",1282,5.640556,-72.198611 ],
    [ u"co",u"Nuquí",2741,5.7125,-77.270833 ],
    [ u"co",u"Obando",7298,4.575833,-75.973889 ],
    [ u"co",u"Ocamonte",883,6.340007,-73.122053 ],
    [ u"co",u"Ocaña",83513,8.237727,-73.356038 ],
    [ u"co",u"Oiba",3959,6.263875,-73.298764 ],
    [ u"co",u"Oicatá",327,5.595478,-73.3082 ],
    [ u"co",u"Olaya Herrera",9821,1.256086,-77.496649 ],
    [ u"co",u"Olaya",710,6.629881,-75.802985 ],
    [ u"co",u"Onzaga",1393,6.344336,-72.817258 ],
    [ u"co",u"Oporapa",2310,2.050146,-75.976749 ],
    [ u"co",u"Orito",13708,.676558,-76.877116 ],
    [ u"co",u"Orocué",2835,4.791175,-71.335423 ],
    [ u"co",u"Ortega",6871,3.936105,-75.221692 ],
    [ u"co",u"Ospina",2747,1.059503,-77.565539 ],
    [ u"co",u"Ospina Pérez",1307,4.088081,-74.477463 ],
    [ u"co",u"Otanche",3589,5.656721,-74.182491 ],
    [ u"co",u"Ovejas",13284,9.532482,-75.22382 ],
    [ u"co",u"Pachavita",959,5.139686,-73.397393 ],
    [ u"co",u"Pacho",16698,5.132778,-74.159771 ],
    [ u"co",u"Pácora",8218,5.527084,-75.459301 ],
    [ u"co",u"Padilla",4472,3.220376,-76.313851 ],
    [ u"co",u"Páez",5179,2.654722,-75.992778 ],
    [ u"co",u"Páez",1220,5.101123,-73.051225 ],
    [ u"co",u"Paicol",1681,2.449623,-75.775003 ],
    [ u"co",u"Pailitas",10481,8.956518,-73.625485 ],
    [ u"co",u"Paime",799,5.363596,-74.145788 ],
    [ u"co",u"Paipa",13554,5.78013,-73.117082 ],
    [ u"co",u"Pajarito",1258,5.292903,-72.70277 ],
    [ u"co",u"Palermo",9896,2.891667,-75.4375 ],
    [ u"co",u"Palestina",2028,1.723624,-76.134028 ],
    [ u"co",u"Palestina",7865,5.019405,-75.622424 ],
    [ u"co",u"Palmar de Varela",28085,10.740548,-74.754429 ],
    [ u"co",u"Palmar",360,6.537727,-73.292339 ],
    [ u"co",u"Palmas del Socorro",657,6.406667,-73.286944 ],
    [ u"co",u"Palmira",247991,3.539444,-76.303611 ],
    [ u"co",u"Palmito",3993,9.331894,-75.541704 ],
    [ u"co",u"Palocabildo",3534,5.11705,-75.017323 ],
    [ u"co",u"Pamplona",53588,7.375647,-72.647949 ],
    [ u"co",u"Pamplonita",941,7.436366,-72.638082 ],
    [ u"co",u"Pandi",1336,4.191111,-74.4875 ],
    [ u"co",u"Panqueba",668,6.442553,-72.458821 ],
    [ u"co",u"Páramo",843,6.416389,-73.17 ],
    [ u"co",u"Paratebueno",2027,4.375754,-73.215472 ],
    [ u"co",u"Pasca",3169,4.307222,-74.300556 ],
    [ u"co",u"Pasto",382242,1.213611,-77.281111 ],
    [ u"co",u"Pauna",2663,5.658611,-73.9825 ],
    [ u"co",u"Paya",336,5.624923,-72.423454 ],
    [ u"co",u"Paz de Ariporo",16666,5.880556,-71.891944 ],
    [ u"co",u"Pedraza",3677,10.187386,-74.915036 ],
    [ u"co",u"Pelaya",11306,8.688187,-73.664515 ],
    [ u"co",u"Peñol",7698,6.218293,-75.24298 ],
    [ u"co",u"Pensilvania",8173,5.383456,-75.161219 ],
    [ u"co",u"Peque",1793,7.021225,-75.909262 ],
    [ u"co",u"Pereira",440123,4.813333,-75.696111 ],
    [ u"co",u"Pesca",5113,5.55,-73.05 ],
    [ u"co",u"Piedecuesta",86388,6.987892,-73.049533 ],
    [ u"co",u"Piedras",1173,4.538328,-74.881747 ],
    [ u"co",u"Pijao",5668,4.334189,-75.703479 ],
    [ u"co",u"Pijiño",5390,9.329079,-74.45302 ],
    [ u"co",u"Pinchote",674,6.532258,-73.173088 ],
    [ u"co",u"Pinillos",6218,8.919248,-74.467711 ],
    [ u"co",u"Piojó",3388,10.748462,-75.107756 ],
    [ u"co",u"Pisba",307,5.723962,-72.486462 ],
    [ u"co",u"Pitalito",53686,1.849656,-76.047849 ],
    [ u"co",u"Pital",3957,2.266503,-75.804422 ],
    [ u"co",u"Pivijay",33493,10.461675,-74.616208 ],
    [ u"co",u"Pizarro",6105,2.101944,-78.721667 ],
    [ u"co",u"Planadas",9710,3.196977,-75.645061 ],
    [ u"co",u"Planeta Rica",37298,8.414722,-75.588333 ],
    [ u"co",u"Plato",48607,9.790289,-74.782442 ],
    [ u"co",u"Policarpa",2377,1.632313,-77.461988 ],
    [ u"co",u"Ponedera",11222,10.641035,-74.750257 ],
    [ u"co",u"Pore",4134,5.727222,-71.994722 ],
    [ u"co",u"Potosí",3980,.807392,-77.572165 ],
    [ u"co",u"Pradera",44631,3.421111,-76.244722 ],
    [ u"co",u"Prado",3556,3.750243,-74.929325 ],
    [ u"co",u"Providencia",3326,1.555713,-77.550121 ],
    [ u"co",u"Pueblo Bello",6295,10.417065,-73.580404 ],
    [ u"co",u"Pueblo Nuevo",9076,8.241098,-74.958147 ],
    [ u"co",u"Pueblo Rico",4165,5.238333,-76.036389 ],
    [ u"co",u"Pueblorrico",5327,5.791756,-75.841012 ],
    [ u"co",u"Puebloviejo",13524,10.993761,-74.284385 ],
    [ u"co",u"Puente Nacional",5775,5.877395,-73.6781 ],
    [ u"co",u"Puerres",3812,1.193738,-77.266613 ],
    [ u"co",u"Puerto Asís",29783,.513278,-76.500748 ],
    [ u"co",u"Puerto Berrío",33983,6.491565,-74.403264 ],
    [ u"co",u"Puerto Boyacá",27311,5.975838,-74.588455 ],
    [ u"co",u"Puerto Carreño",10216,6.189031,-67.485879 ],
    [ u"co",u"Puerto Colombia",26228,10.987778,-74.954722 ],
    [ u"co",u"Puerto Concordia",4313,2.622059,-72.757242 ],
    [ u"co",u"Puerto Escondido",3020,9.018105,-76.26413 ],
    [ u"co",u"Puerto Gaitán",5928,4.313279,-72.08157 ],
    [ u"co",u"Puerto Guzmán",4094,.964538,-76.407953 ],
    [ u"co",u"Puerto Leguízamo",9098,-.193368,-74.781886 ],
    [ u"co",u"Puerto Lleras",5076,3.022247,-73.404402 ],
    [ u"co",u"Puerto López",16678,4.084514,-72.955974 ],
    [ u"co",u"Puerto Nariño",2113,-3.770278,-70.383056 ],
    [ u"co",u"Puerto Parra",1448,6.651493,-74.057343 ],
    [ u"co",u"Puerto Rico",12306,1.905743,-75.154059 ],
    [ u"co",u"Puerto Rico",5029,2.938333,-73.208333 ],
    [ u"co",u"Puerto Rondón",3724,6.280477,-71.1 ],
    [ u"co",u"Puerto Salgar",9864,5.463041,-74.654363 ],
    [ u"co",u"Puerto Santander",16275,8.363611,-72.406295 ],
    [ u"co",u"Puerto Tejada",53675,3.231136,-76.416684 ],
    [ u"co",u"Puerto Triunfo",4056,5.872619,-74.640286 ],
    [ u"co",u"Puerto Wilches",13705,7.348285,-73.896011 ],
    [ u"co",u"Pulí",596,4.681159,-74.714056 ],
    [ u"co",u"Pupiales",6760,.87136,-77.640269 ],
    [ u"co",u"Puracé",4837,2.342491,-76.495809 ],
    [ u"co",u"Purificación",10847,3.858705,-74.931288 ],
    [ u"co",u"Purísima",7043,9.23657,-75.721905 ],
    [ u"co",u"Quebradanegra",753,5.117369,-74.479443 ],
    [ u"co",u"Quetame",1374,4.332342,-73.861415 ],
    [ u"co",u"Quibdó",75105,5.694722,-76.661111 ],
    [ u"co",u"Quimbaya",31392,4.623056,-75.762778 ],
    [ u"co",u"Quinchía",10896,5.339573,-75.730184 ],
    [ u"co",u"Quípama",3571,5.519404,-74.177653 ],
    [ u"co",u"Quipile",1896,4.748056,-74.563056 ],
    [ u"co",u"Rafael Reyes",4084,4.519521,-74.59293 ],
    [ u"co",u"Ragonvalia",3543,7.577487,-72.475738 ],
    [ u"co",u"Ramiriquí",5039,5.400205,-73.335437 ],
    [ u"co",u"Ráquira",2120,5.537932,-73.632006 ],
    [ u"co",u"Recetor",205,5.231836,-72.760369 ],
    [ u"co",u"Regidor",3386,8.665653,-73.821506 ],
    [ u"co",u"Remedios",6415,7.030833,-74.533333 ],
    [ u"co",u"Remolino",8308,10.701985,-74.716019 ],
    [ u"co",u"Repelón",18686,10.491944,-75.129167 ],
    [ u"co",u"Restrepo",7511,4.258334,-73.561423 ],
    [ u"co",u"Restrepo",9545,3.822034,-76.522423 ],
    [ u"co",u"Retiro",7941,6.058611,-75.503056 ],
    [ u"co",u"Ricaurte",2682,4.280754,-74.764687 ],
    [ u"co",u"Rioblanco",6210,3.530833,-75.680556 ],
    [ u"co",u"Río de Oro",6122,8.291901,-73.384853 ],
    [ u"co",u"Riofrío",9236,4.157104,-76.288518 ],
    [ u"co",u"Ríohacha",92433,11.544444,-72.907222 ],
    [ u"co",u"Rionegro",62292,6.155149,-75.373708 ],
    [ u"co",u"Rionegro",9515,7.153611,-73.153611 ],
    [ u"co",u"Riosucio",7163,7.44027,-77.1167 ],
    [ u"co",u"Riosucio",18950,5.42164,-75.703177 ],
    [ u"co",u"Río Viejo",6963,8.587399,-73.839013 ],
    [ u"co",u"Risaralda",5421,5.16647,-75.765954 ],
    [ u"co",u"Rivera",8044,2.77717,-75.256415 ],
    [ u"co",u"Roberto Payán",1772,1.696594,-78.244817 ],
    [ u"co",u"Roldanillo",27562,4.412557,-76.154567 ],
    [ u"co",u"Roncesvalles",3918,4.010796,-75.60493 ],
    [ u"co",u"Rondón",504,5.356415,-73.209178 ],
    [ u"co",u"Rosas",1830,2.260928,-76.739863 ],
    [ u"co",u"Rovira",6950,4.239221,-75.239963 ],
    [ u"co",u"Sabana de Torres",11292,7.391498,-73.495739 ],
    [ u"co",u"Sabanagrande",21167,10.789605,-74.755254 ],
    [ u"co",u"Sabanagrande",21167,10.719722,-74.682778 ],
    [ u"co",u"Sabanalarga",2517,6.848931,-75.817106 ],
    [ u"co",u"Sabanalarga",68536,10.629617,-74.92063 ],
    [ u"co",u"Sabanalarga",1419,4.854299,-73.040032 ],
    [ u"co",u"Sabaneta",34173,6.15,-75.6 ],
    [ u"co",u"Saboyá",1375,5.696357,-73.769316 ],
    [ u"co",u"Sácama",744,6.098915,-72.248082 ],
    [ u"co",u"Sáchica",1774,5.584528,-73.54184 ],
    [ u"co",u"Sahagún",59189,8.946165,-75.442749 ],
    [ u"co",u"Saladoblanco",1662,1.992439,-76.043353 ],
    [ u"co",u"Salamina",18076,5.407328,-75.487487 ],
    [ u"co",u"Salamina",6166,10.490274,-74.79463 ],
    [ u"co",u"Saldaña",9237,3.929225,-75.015174 ],
    [ u"co",u"Salento",4136,4.6375,-75.570278 ],
    [ u"co",u"Salgar",6429,5.965025,-75.965407 ],
    [ u"co",u"Samacá",3689,5.492735,-73.485368 ],
    [ u"co",u"Samana",7781,5.412581,-74.992189 ],
    [ u"co",u"Samaniego",13515,1.338495,-77.595695 ],
    [ u"co",u"Sampués",21204,9.183611,-75.381667 ],
    [ u"co",u"San Agustín",9481,1.878629,-76.275566 ],
    [ u"co",u"San Alberto",10628,7.761066,-73.392201 ],
    [ u"co",u"San Andrés",3154,6.903333,-75.6825 ],
    [ u"co",u"San Andrés",58258,12.584722,-81.700556 ],
    [ u"co",u"San Andrés",3032,6.811478,-72.849292 ],
    [ u"co",u"San Antero",11610,9.374101,-75.758909 ],
    [ u"co",u"San Antonio del Tequendama",1577,4.618889,-74.353889 ],
    [ u"co",u"San Antonio",5185,3.653056,-75.632778 ],
    [ u"co",u"San Benito Abad",18181,8.929007,-75.02709 ],
    [ u"co",u"San Benito",426,6.132694,-73.490651 ],
    [ u"co",u"San Bernardo",2988,1.521189,-77.03091 ],
    [ u"co",u"San Bernardo",7625,4.178642,-74.423112 ],
    [ u"co",u"San Calixto",2080,8.402096,-73.207374 ],
    [ u"co",u"San Carlos",7742,6.18789,-74.993149 ],
    [ u"co",u"San Carlos",3447,8.74372,-75.713306 ],
    [ u"co",u"San Cayetano",1430,7.877066,-72.624298 ],
    [ u"co",u"San Cayetano",699,5.301532,-74.069542 ],
    [ u"co",u"San Cristóbal",4738,9.878093,-75.252482 ],
    [ u"co",u"San Diego",8014,10.334271,-73.180045 ],
    [ u"co",u"Sandoná",10402,1.291512,-77.474094 ],
    [ u"co",u"San Eduardo",524,5.226752,-73.126076 ],
    [ u"co",u"San Estanislao",12596,10.398333,-75.151111 ],
    [ u"co",u"San Fernando",1615,9.268325,-74.530213 ],
    [ u"co",u"San Francisco",2779,6.116667,-75.983333 ],
    [ u"co",u"San Francisco",4350,1.178666,-76.878501 ],
    [ u"co",u"San Francisco",2785,4.973721,-74.290055 ],
    [ u"co",u"San Gil",33592,6.555734,-73.133088 ],
    [ u"co",u"San Jacinto",20265,9.827668,-75.121701 ],
    [ u"co",u"San Jerónimo",3356,6.443442,-75.728147 ],
    [ u"co",u"San Joaquín",844,6.430037,-72.86768 ],
    [ u"co",u"San José del Guaviare",22136,2.572858,-72.645914 ],
    [ u"co",u"San José del Palmar",2392,4.974167,-76.228333 ],
    [ u"co",u"San José de Miranda",1096,6.658701,-72.73344 ],
    [ u"co",u"San José de Pare",941,6.017465,-73.547035 ],
    [ u"co",u"San José",1724,5.001667,-75.752222 ],
    [ u"co",u"San Juan de Arama",2636,3.346389,-73.889444 ],
    [ u"co",u"San Juan de Betulia",9092,9.27345,-75.241032 ],
    [ u"co",u"San Juan del Cesar",26849,10.771075,-73.00314 ],
    [ u"co",u"San Juan de Urabá",10825,8.759241,-76.529689 ],
    [ u"co",u"San Juanito",396,4.509815,-72.968486 ],
    [ u"co",u"San Juan Nepomuceno",29619,9.951565,-75.081979 ],
    [ u"co",u"San Lorenzo",2394,1.506278,-77.218979 ],
    [ u"co",u"San Luis de Gaceno",2579,4.820522,-73.168507 ],
    [ u"co",u"San Luis de Palenque",2032,5.421389,-71.731667 ],
    [ u"co",u"San Luis",6448,6.041667,-74.992778 ],
    [ u"co",u"San Luis",4184,4.132578,-75.094994 ],
    [ u"co",u"San Marcos",36549,8.659723,-75.12809 ],
    [ u"co",u"San Martín",7029,8.00151,-73.511263 ],
    [ u"co",u"San Martín",16274,3.696373,-73.699575 ],
    [ u"co",u"San Mateo",1634,6.401106,-72.555629 ],
    [ u"co",u"San Miguel de Sema",647,5.518472,-73.722383 ],
    [ u"co",u"San Miguel",7186,.343144,-76.911243 ],
    [ u"co",u"San Miguel",624,6.575828,-72.645909 ],
    [ u"co",u"San Onofre",32958,9.735863,-75.526261 ],
    [ u"co",u"San Pablo de Borbur",1519,5.660339,-74.062116 ],
    [ u"co",u"San Pablo",6522,1.67145,-77.014082 ],
    [ u"co",u"San Pablo",13984,10.051537,-75.267746 ],
    [ u"co",u"San Pedro de Cartago",1524,1.563054,-77.117602 ],
    [ u"co",u"San Pedro de Urabá",11095,8.275147,-76.376407 ],
    [ u"co",u"San Pedro",8801,6.462213,-75.556556 ],
    [ u"co",u"San Pedro",11489,9.395603,-75.064758 ],
    [ u"co",u"San Pedro",5473,3.992185,-76.239261 ],
    [ u"co",u"San Pelayo",5637,8.958328,-75.836272 ],
    [ u"co",u"San Rafael",7245,6.294359,-75.025892 ],
    [ u"co",u"San Roque",5576,6.485112,-75.019605 ],
    [ u"co",u"San Sebastián",931,1.838611,-76.771889 ],
    [ u"co",u"San Sebastian",6520,9.242169,-74.500369 ],
    [ u"co",u"San Sebastián",6520,9.237779,-74.351658 ],
    [ u"co",u"Santa Ana",13951,9.321247,-74.568478 ],
    [ u"co",u"Santa Bárbara",12743,5.874583,-75.567056 ],
    [ u"co",u"Santá Barbara",4875,2.450069,-77.979357 ],
    [ u"co",u"Santa Barbará",291,6.990221,-72.907004 ],
    [ u"co",u"Santa Catalina",6084,10.603607,-75.288235 ],
    [ u"co",u"Santacruz",2469,1.520896,-77.262058 ],
    [ u"co",u"Santa Helena",865,6.3,-73.583333 ],
    [ u"co",u"Santa Isabel",2035,4.71418,-75.097986 ],
    [ u"co",u"Santa Lucía",15760,10.324198,-74.960169 ],
    [ u"co",u"Santa María",2761,2.861389,-75.597778 ],
    [ u"co",u"Santa María",2238,4.860483,-73.262338 ],
    [ u"co",u"Santa Marta",431788,11.240791,-74.19904 ],
    [ u"co",u"Santana",2091,6.057497,-73.481123 ],
    [ u"co",u"Santander de Quilichao",40799,3.009452,-76.484937 ],
    [ u"co",u"Santa Rosa de Cabal",57929,4.868056,-75.621389 ],
    [ u"co",u"Santa Rosa del Sur",8905,7.964444,-74.054444 ],
    [ u"co",u"Santa Rosa de Osos",10191,6.647375,-75.460305 ],
    [ u"co",u"Santa Rosa de Viterbo",6924,5.874008,-72.982166 ],
    [ u"co",u"Santa Rosa",2385,1.702666,-76.573891 ],
    [ u"co",u"Santa Rosa",10604,10.444722,-75.369722 ],
    [ u"co",u"Santa Sofía",1058,5.709077,-73.604037 ],
    [ u"co",u"Santiago",1032,7.864318,-72.716202 ],
    [ u"co",u"Santiago",2716,1.148444,-77.0045 ],
    [ u"co",u"Santo Domingo",2873,6.471423,-75.16395 ],
    [ u"co",u"Santo Tomás",25847,10.75773,-74.754509 ],
    [ u"co",u"Santuario",17722,6.138333,-75.264167 ],
    [ u"co",u"Santuario",6815,5.072367,-75.963407 ],
    [ u"co",u"San Vicente de Chucurí",11265,6.881,-73.409766 ],
    [ u"co",u"San Vicente",5021,6.232778,-75.336111 ],
    [ u"co",u"San Zenón",4340,9.214331,-74.313634 ],
    [ u"co",u"Sapúyes",2628,1.033333,-77.6 ],
    [ u"co",u"Saravena",33817,6.953758,-71.87523 ],
    [ u"co",u"Sardinata",7872,8.082888,-72.800707 ],
    [ u"co",u"Sasaima",2948,4.898056,-74.436944 ],
    [ u"co",u"Sativanorte",792,6.131564,-72.708947 ],
    [ u"co",u"Sativasur",579,6.089589,-72.724316 ],
    [ u"co",u"Segovia",39938,7.07993,-74.6989 ],
    [ u"co",u"Sesquilé",1876,5.044628,-73.797243 ],
    [ u"co",u"Sevilla",41613,4.264249,-75.930852 ],
    [ u"co",u"Siachoque",1375,5.512376,-73.244358 ],
    [ u"co",u"Sibaté",23208,4.484249,-74.24499 ],
    [ u"co",u"Sibundoy",9458,1.204777,-76.923664 ],
    [ u"co",u"Silos",1300,7.205245,-72.756386 ],
    [ u"co",u"Silvania",8237,4.403671,-74.3867 ],
    [ u"co",u"Silvia",7474,2.611029,-76.378533 ],
    [ u"co",u"Simacota",2157,6.442898,-73.336882 ],
    [ u"co",u"Simijaca",4767,5.50291,-73.852267 ],
    [ u"co",u"Simití",6670,7.9579,-73.9436 ],
    [ u"co",u"Sincelejo",261190,9.304722,-75.397778 ],
    [ u"co",u"Sincé",30769,9.243913,-75.146748 ],
    [ u"co",u"Sipí",332,4.658056,-76.476667 ],
    [ u"co",u"Sitionuevo",11817,10.777367,-74.720491 ],
    [ u"co",u"Soacha",313950,4.579368,-74.216819 ],
    [ u"co",u"Soatá",10945,6.333691,-72.682826 ],
    [ u"co",u"Socha",3353,5.981701,-72.715027 ],
    [ u"co",u"Socorro",17752,6.468382,-73.260224 ],
    [ u"co",u"Socotá",2194,6.040285,-72.635094 ],
    [ u"co",u"Sogamoso",126553,5.714344,-72.933908 ],
    [ u"co",u"Solano",2973,.69937,-75.253526 ],
    [ u"co",u"Soledad",342562,10.918433,-74.76459 ],
    [ u"co",u"Somondoco",1029,4.985437,-73.432703 ],
    [ u"co",u"Sonsón",17232,5.71062,-75.310685 ],
    [ u"co",u"Sopetrán",4902,6.670278,-75.7475 ],
    [ u"co",u"Soplaviento",8067,10.3875,-75.135556 ],
    [ u"co",u"Sopó",8396,4.907499,-73.938398 ],
    [ u"co",u"Soracá",827,5.500548,-73.332992 ],
    [ u"co",u"Sora",508,5.565142,-73.450173 ],
    [ u"co",u"Sotaquirá",1352,5.764828,-73.247583 ],
    [ u"co",u"Sotará",1390,2.254617,-76.610856 ],
    [ u"co",u"Suaita",2691,6.101404,-73.440412 ],
    [ u"co",u"Suan",10382,10.333471,-74.880161 ],
    [ u"co",u"Suárez",9986,2.953951,-76.696436 ],
    [ u"co",u"Suárez",1243,4.049058,-74.83198 ],
    [ u"co",u"Suaza",2481,1.976108,-75.79454 ],
    [ u"co",u"Subachoque",4088,4.926139,-74.17299 ],
    [ u"co",u"Sucre",2552,2.038049,-76.924461 ],
    [ u"co",u"Sucre",1095,5.918328,-73.79109 ],
    [ u"co",u"Sucre",23210,8.81136,-74.720839 ],
    [ u"co",u"Suesca",4877,5.102891,-73.798453 ],
    [ u"co",u"Supatá",1907,5.060967,-74.237205 ],
    [ u"co",u"Supía",12784,5.45303,-75.650717 ],
    [ u"co",u"Suratá",806,7.366332,-72.983608 ],
    [ u"co",u"Susacón",1207,6.229783,-72.690099 ],
    [ u"co",u"Susa",1609,5.451899,-73.814362 ],
    [ u"co",u"Sutamarchán",1432,5.615375,-73.617006 ],
    [ u"co",u"Sutatausa",1332,5.247794,-73.852378 ],
    [ u"co",u"Sutatenza",827,5.024027,-73.440502 ],
    [ u"co",u"Tabio",4180,4.917264,-74.093635 ],
    [ u"co",u"Tadó",10095,5.265977,-76.564874 ],
    [ u"co",u"Talaigua",6217,9.303472,-74.56477 ],
    [ u"co",u"Tamalameque",4972,8.852212,-73.812289 ],
    [ u"co",u"Tamara",2007,5.829722,-72.163333 ],
    [ u"co",u"Támesis",6407,5.664622,-75.713389 ],
    [ u"co",u"Tame",29100,6.460995,-71.730043 ],
    [ u"co",u"Taminango",2919,1.574908,-77.286658 ],
    [ u"co",u"Tangua",3348,1.094727,-77.394821 ],
    [ u"co",u"Taraira",341,.493889,-69.666944 ],
    [ u"co",u"Tarazá",13639,7.583583,-75.400684 ],
    [ u"co",u"Tarqui",4144,2.112485,-75.82419 ],
    [ u"co",u"Tarso",2700,5.864672,-75.821916 ],
    [ u"co",u"Tasco",1811,5.910443,-72.780012 ],
    [ u"co",u"Tauramena",4805,5.01831,-72.749187 ],
    [ u"co",u"Tausa",895,5.199029,-73.891282 ],
    [ u"co",u"Tello",4868,3.066944,-75.137778 ],
    [ u"co",u"Tena",696,4.660006,-74.392584 ],
    [ u"co",u"Tenerife",8476,9.900932,-74.859852 ],
    [ u"co",u"Tenjo",3858,4.872701,-74.144351 ],
    [ u"co",u"Tenza",1312,5.076644,-73.420767 ],
    [ u"co",u"Teruel",3921,2.741933,-75.567381 ],
    [ u"co",u"Tesalia",3981,2.485866,-75.729209 ],
    [ u"co",u"Tibacuy",1028,4.351111,-72.456389 ],
    [ u"co",u"Tibaná",1802,5.317284,-73.396548 ],
    [ u"co",u"Tibasosa",3535,5.746306,-72.998329 ],
    [ u"co",u"Tibirita",920,5.052274,-73.504585 ],
    [ u"co",u"Tibú",13566,8.638955,-72.73583 ],
    [ u"co",u"Tierralta",26242,8.173611,-76.059167 ],
    [ u"co",u"Timaná",8203,1.971357,-75.931233 ],
    [ u"co",u"Timbío",9606,2.350169,-76.683413 ],
    [ u"co",u"Timbiquí",6267,2.771697,-77.665359 ],
    [ u"co",u"Tinjacá",400,5.579163,-73.644855 ],
    [ u"co",u"Tipacoque",1036,6.42031,-72.691842 ],
    [ u"co",u"Tiquisio",4255,8.559722,-74.266944 ],
    [ u"co",u"Titiribí",3787,6.062765,-75.793703 ],
    [ u"co",u"Tocaima",10235,4.458201,-74.634343 ],
    [ u"co",u"Tocancipá",6027,4.965313,-73.913013 ],
    [ u"co",u"Toca",3946,5.563925,-73.18398 ],
    [ u"co",u"Togüí",829,5.390556,-73.516667 ],
    [ u"co",u"Toledo",4480,7.013056,-75.695278 ],
    [ u"co",u"Toledo",5911,7.309844,-72.482949 ],
    [ u"co",u"Tolú",27390,9.523919,-75.581392 ],
    [ u"co",u"Toluviejo",8260,9.450819,-75.438641 ],
    [ u"co",u"Tona",627,7.20221,-72.965018 ],
    [ u"co",u"Tópaga",1014,5.759792,-72.82583 ],
    [ u"co",u"Topaipí",1099,5.334567,-74.302917 ],
    [ u"co",u"Toribío",3912,2.954813,-76.268389 ],
    [ u"co",u"Toro",13764,4.611667,-76.081389 ],
    [ u"co",u"Tota",774,5.558327,-72.987567 ],
    [ u"co",u"Totoró",1888,2.512044,-76.40124 ],
    [ u"co",u"Trinidad",4752,5.407377,-71.661397 ],
    [ u"co",u"Trujillo",5874,4.212168,-76.319454 ],
    [ u"co",u"Tubará",8181,10.874444,-74.978889 ],
    [ u"co",u"Tuluá",165504,4.084656,-76.19536 ],
    [ u"co",u"Tumaco",86714,1.798611,-78.815556 ],
    [ u"co",u"Tunja",117480,5.535278,-73.367778 ],
    [ u"co",u"Tununguá",178,5.729673,-73.94137 ],
    [ u"co",u"Túquerres",20185,1.092341,-77.620852 ],
    [ u"co",u"Turbaco",56173,10.329444,-75.411367 ],
    [ u"co",u"Turbaná",10236,10.271695,-75.44222 ],
    [ u"co",u"Turbo",50509,8.093678,-76.726908 ],
    [ u"co",u"Turmequé",2901,5.323605,-73.490669 ],
    [ u"co",u"Tutasá",292,6.032282,-72.856387 ],
    [ u"co",u"Tuta",1639,5.689655,-73.227789 ],
    [ u"co",u"Ubalá",1886,4.747778,-72.536944 ],
    [ u"co",u"Ubaque",1009,4.486675,-73.937477 ],
    [ u"co",u"Ubaté",20486,5.309326,-73.815745 ],
    [ u"co",u"Ulloa",2621,4.704444,-75.740278 ],
    [ u"co",u"Umbita",1295,5.220408,-73.456953 ],
    [ u"co",u"Une",3208,4.403056,-74.025278 ],
    [ u"co",u"Unguía",4179,8.043346,-77.094527 ],
    [ u"co",u"Uramita",2292,6.899444,-76.174167 ],
    [ u"co",u"Uribia",7519,11.713897,-72.266035 ],
    [ u"co",u"Urrao",18846,6.315197,-76.134201 ],
    [ u"co",u"Urumita",8509,10.558938,-73.012319 ],
    [ u"co",u"Usiacurí",9147,10.75,-74.983333 ],
    [ u"co",u"Utica",2945,5.187271,-74.481047 ],
    [ u"co",u"Valdivia",3398,7.288889,-75.397778 ],
    [ u"co",u"Valencia",10653,8.258014,-76.149275 ],
    [ u"co",u"Valle del Guamuez",9969,.4525,-76.919167 ],
    [ u"co",u"Valle de San Juan",1486,4.198688,-75.117332 ],
    [ u"co",u"Valledupar",308242,10.46314,-73.253224 ],
    [ u"co",u"Valparaíso",3626,5.615003,-75.624218 ],
    [ u"co",u"Valparaíso",3767,1.19512,-75.707053 ],
    [ u"co",u"Vegachí",9618,6.761409,-74.794731 ],
    [ u"co",u"Vélez",10905,6.013351,-73.673521 ],
    [ u"co",u"Venadillo",11311,4.719295,-74.929181 ],
    [ u"co",u"Venecia",5462,5.962778,-75.738056 ],
    [ u"co",u"Ventaquemada",1680,5.367531,-73.520746 ],
    [ u"co",u"Vergara",2267,5.118412,-74.345492 ],
    [ u"co",u"Versalles",3543,4.30003,-76.302927 ],
    [ u"co",u"Vetas",1210,7.309107,-72.871218 ],
    [ u"co",u"Vianí",1586,4.87384,-74.562439 ],
    [ u"co",u"Victoria",4723,5.316481,-74.911006 ],
    [ u"co",u"Vigía del Fuerte",4638,6.578911,-76.886278 ],
    [ u"co",u"Vijes",4071,3.699335,-76.442304 ],
    [ u"co",u"Villa del Rosario",64952,7.833889,-72.474167 ],
    [ u"co",u"Villagarzon",7015,1.029049,-76.62022 ],
    [ u"co",u"Villagómez",779,5.273718,-74.196143 ],
    [ u"co",u"Villahermosa",4156,5.030673,-75.116068 ],
    [ u"co",u"Villamaría",35303,5.044923,-75.514604 ],
    [ u"co",u"Villanueva",18700,10.605278,-72.98 ],
    [ u"co",u"Villanueva",3707,6.671693,-73.174205 ],
    [ u"co",u"Villanueva",20033,5.283333,-71.966667 ],
    [ u"co",u"Villanueva",12792,10.443611,-75.273056 ],
    [ u"co",u"Villapinzón",5874,5.216171,-73.5949 ],
    [ u"co",u"Villa Rica",9070,2.509491,-76.844185 ],
    [ u"co",u"Villarrica",3081,3.935024,-74.600359 ],
    [ u"co",u"Villavicencio",321721,4.142002,-73.626645 ],
    [ u"co",u"Villavieja",2730,3.220523,-75.218643 ],
    [ u"co",u"Villeta",20689,5.008856,-74.472264 ],
    [ u"co",u"Viotá",5840,4.437129,-74.521573 ],
    [ u"co",u"Viracachá",541,5.436373,-73.296059 ],
    [ u"co",u"Vista Hermosa",4282,3.124283,-73.751561 ],
    [ u"co",u"Viterbo",15216,5.062421,-75.87159 ],
    [ u"co",u"Yacopí",3202,5.459477,-74.338226 ],
    [ u"co",u"Yacuanquer",2643,1.115772,-77.401687 ],
    [ u"co",u"Yaguará",5724,2.663548,-75.517532 ],
    [ u"co",u"Yalí",3908,6.674565,-74.834296 ],
    [ u"co",u"Yarumal",22368,6.890278,-75.670833 ],
    [ u"co",u"Yavaraté",38,.615,-69.208056 ],
    [ u"co",u"Yolombó",6033,6.598411,-75.011402 ],
    [ u"co",u"Yondó",7516,7.006208,-73.909717 ],
    [ u"co",u"Yopal",61031,5.337752,-72.395859 ],
    [ u"co",u"Yotoco",8362,3.860478,-76.383644 ],
    [ u"co",u"Yumbo",71438,3.582335,-76.491455 ],
    [ u"co",u"Zambrano",9565,9.747238,-74.815298 ],
    [ u"co",u"Zapatoca",6052,6.815319,-73.267684 ],
    [ u"co",u"Zaragoza",18795,7.489707,-74.869189 ],
    [ u"co",u"Zarzal",28761,4.394621,-76.071499 ],
    [ u"co",u"Zetaquira",1047,5.282152,-73.168956 ],
    [ u"co",u"Zipacón",1480,4.758807,-74.380167 ],
    [ u"co",u"Zipaquirá",91237,5.022079,-74.004812 ],
    [ u"cr",u"Alajuela",47503,10.016247,-84.211628 ],
    [ u"cr",u"Alajuelita",13848,9.901627,-84.10042 ],
    [ u"cr",u"Aserrí",25874,9.858758,-84.092301 ],
    [ u"cr",u"Atenas",7014,9.978058,-84.380319 ],
    [ u"cr",u"Bagaces",4108,10.527091,-85.254825 ],
    [ u"cr",u"Batán",4584,10.084435,-83.340997 ],
    [ u"cr",u"Buenos Aires",11680,8.859576,-83.502242 ],
    [ u"cr",u"Calle Blancos",20714,9.95,-84.066667 ],
    [ u"cr",u"Cañas",20309,10.429397,-85.093113 ],
    [ u"cr",u"Carmen",15920,10.200948,-83.477775 ],
    [ u"cr",u"Cartago",26615,9.853281,-83.902296 ],
    [ u"cr",u"Chacarita",26354,9.982886,-84.772319 ],
    [ u"cr",u"Cinco Esquinas",7158,10.10374,-84.167815 ],
    [ u"cr",u"Colón",9687,9.916362,-84.241832 ],
    [ u"cr",u"Concepción",22036,9.933333,-84 ],
    [ u"cr",u"Corredor",7084,8.640016,-82.945997 ],
    [ u"cr",u"Curridabat",34592,9.911785,-84.034068 ],
    [ u"cr",u"Daniel Flores",10028,9.335538,-83.669397 ],
    [ u"cr",u"Desamparados",39276,9.896798,-84.06294 ],
    [ u"cr",u"Escazú",12073,9.918872,-84.139895 ],
    [ u"cr",u"Esparta",15575,9.994468,-84.664658 ],
    [ u"cr",u"Florencia",888,10.361309,-84.474961 ],
    [ u"cr",u"Golfito",6778,8.639011,-83.166029 ],
    [ u"cr",u"Grecia",12677,10.072427,-84.311242 ],
    [ u"cr",u"Guácimo",7022,10.21044,-83.680666 ],
    [ u"cr",u"Guácimo",11720,8.948405,-83.109585 ],
    [ u"cr",u"Guadalupe",13754,9.860578,-83.935301 ],
    [ u"cr",u"Guadalupe",13754,9.652861,-84.007966 ],
    [ u"cr",u"Guápiles",19097,10.215878,-83.786609 ],
    [ u"cr",u"Heredia",21968,10.002362,-84.11651 ],
    [ u"cr",u"Ipís",26674,9.967455,-84.013255 ],
    [ u"cr",u"Juntas",4737,10.280895,-84.959506 ],
    [ u"cr",u"La Cruz",4319,11.073771,-85.632716 ],
    [ u"cr",u"La Suiza",2434,9.85238,-83.613307 ],
    [ u"cr",u"Liberia",45405,10.635039,-85.43772 ],
    [ u"cr",u"Limón",63094,9.992861,-83.030533 ],
    [ u"cr",u"Los Chiles",3342,11.033333,-84.716667 ],
    [ u"cr",u"Matina",2315,10.076088,-83.289527 ],
    [ u"cr",u"Mercedes",26013,10.006955,-84.133963 ],
    [ u"cr",u"Miramar",6540,10.092499,-84.729783 ],
    [ u"cr",u"Naranjo",11856,10.09866,-84.378243 ],
    [ u"cr",u"Nicoya",15315,10.148275,-85.452013 ],
    [ u"cr",u"Orotina",6135,9.911972,-84.52337 ],
    [ u"cr",u"Pacayas",1556,9.807087,-84.047638 ],
    [ u"cr",u"Palmares",4645,9.324647,-83.666597 ],
    [ u"cr",u"Palmar",4657,10.021289,-84.773365 ],
    [ u"cr",u"Palmar",4657,9.872758,-84.455337 ],
    [ u"cr",u"Paraíso",39709,9.83832,-83.865565 ],
    [ u"cr",u"Parrita",3734,9.52012,-84.322487 ],
    [ u"cr",u"Pital",2046,10.450558,-84.274065 ],
    [ u"cr",u"Pocosol",2947,10.366667,-84.616667 ],
    [ u"cr",u"Puerto Cortés",3850,8.959878,-83.523813 ],
    [ u"cr",u"Puntarenas",35655,9.976149,-84.838754 ],
    [ u"cr",u"Purral",30034,9.958084,-84.030498 ],
    [ u"cr",u"Quepos",7810,9.423574,-84.165224 ],
    [ u"cr",u"Quesada",27316,10.323807,-84.427141 ],
    [ u"cr",u"Río Segundo",9853,10.002992,-84.190393 ],
    [ u"cr",u"Roxana",2351,10.275277,-83.75133 ],
    [ u"cr",u"Sabanilla",13253,9.945223,-84.039265 ],
    [ u"cr",u"San Antonio",12965,10.068342,-84.325441 ],
    [ u"cr",u"San Antonio",12965,9.983333,-84.183333 ],
    [ u"cr",u"San Diego",16991,9.898985,-84.00287 ],
    [ u"cr",u"San Felipe",24985,9.904882,-84.105512 ],
    [ u"cr",u"San Francisco",55933,10.0035,-84.072127 ],
    [ u"cr",u"San Francisco",55933,9.95,-84.066667 ],
    [ u"cr",u"San Ignacio",3072,9.79853,-84.161733 ],
    [ u"cr",u"San Isidro",17617,10.017035,-84.055565 ],
    [ u"cr",u"San Isidro",17617,9.977033,-84.007743 ],
    [ u"cr",u"San Josecito",12195,10.016667,-84.1 ],
    [ u"cr",u"San José",31430,10.951731,-85.136096 ],
    [ u"cr",u"San José",335056,9.933333,-84.083333 ],
    [ u"cr",u"San Juan",7729,10.099047,-84.242856 ],
    [ u"cr",u"San Juan",26051,9.959738,-84.081653 ],
    [ u"cr",u"San Marcos de Tarrazú",4255,9.660105,-84.020261 ],
    [ u"cr",u"San Miguel",28827,9.871206,-84.06084 ],
    [ u"cr",u"San Pablo",21666,10.030131,-84.122144 ],
    [ u"cr",u"San Pedro",27482,9.928293,-84.050735 ],
    [ u"cr",u"San Rafael Abajo",27424,9.831002,-84.290079 ],
    [ u"cr",u"San Rafael Arriba",15054,9.875563,-84.076613 ],
    [ u"cr",u"San Rafael",3624,10.046182,-84.247053 ],
    [ u"cr",u"San Rafael",9951,9.764961,-83.827298 ],
    [ u"cr",u"San Rafael",8889,10.013202,-84.100157 ],
    [ u"cr",u"San Rafael",25415,9.875563,-84.076613 ],
    [ u"cr",u"San Ramón",10774,10.088021,-84.470217 ],
    [ u"cr",u"Santa Ana",8031,9.932598,-84.182545 ],
    [ u"cr",u"Santa Cruz",12283,10.26053,-85.585097 ],
    [ u"cr",u"Santiago",8292,9.846358,-84.314281 ],
    [ u"cr",u"Santo Domingo",5750,10.063885,-84.154987 ],
    [ u"cr",u"San Vicente",34453,9.98433,-84.08223 ],
    [ u"cr",u"San Vicente",34453,9.960158,-84.04762 ],
    [ u"cr",u"San Vito",3981,8.820786,-82.970919 ],
    [ u"cr",u"Siquirres",18235,10.09748,-83.506588 ],
    [ u"cr",u"Tilarán",7301,10.470292,-84.967094 ],
    [ u"cr",u"Tres Ríos",10432,9.90644,-83.987602 ],
    [ u"cr",u"Turrialba",28960,9.904666,-83.683519 ],
    [ u"cr",u"Upala",4185,10.897918,-85.014536 ],
    [ u"cr",u"Zarcero",3559,10.18561,-84.390757 ],
    [ u"cu",u"Abreus",16711,22.2775,-80.5675 ],
    [ u"cu",u"Agramonte",5376,22.6761111,-81.1163889 ],
    [ u"cu",u"Aguada de Pasajeros",23606,22.385,-80.8508333 ],
    [ u"cu",u"Alacranes",5843,22.7675,-81.5675 ],
    [ u"cu",u"Alquízar",15275,22.8058333,-82.5841667 ],
    [ u"cu",u"Amancio",26914,20.8225,-77.5786111 ],
    [ u"cu",u"Artemisa",68076,22.8130556,-82.7619444 ],
    [ u"cu",u"Báguanos",15176,20.7488889,-76.0258333 ],
    [ u"cu",u"Bahía Honda",19834,22.9036111,-83.1591667 ],
    [ u"cu",u"Banes",53107,20.9625,-75.7186111 ],
    [ u"cu",u"Baracoa",48365,20.3466667,-74.4958333 ],
    [ u"cu",u"Baraguá",15268,21.6966667,-78.6327778 ],
    [ u"cu",u"Batabanó",13832,22.6869444,-82.2927778 ],
    [ u"cu",u"Bauta",45771,22.9827778,-82.5463889 ],
    [ u"cu",u"Bayamo",192641,20.3791667,-76.6433333 ],
    [ u"cu",u"Bejucal",18123,22.9286111,-82.3886111 ],
    [ u"cu",u"Bolondrón",6778,22.7633333,-81.4469444 ],
    [ u"cu",u"Cabaiguán",44516,22.0788889,-79.4991667 ],
    [ u"cu",u"Cabañas",5894,22.9758333,-82.9219444 ],
    [ u"cu",u"Caibarién",39142,22.5205556,-79.4669444 ],
    [ u"cu",u"Calabazar de Sagua",10455,22.6447222,-79.8961111 ],
    [ u"cu",u"Calimete",23255,22.5333333,-80.9061111 ],
    [ u"cu",u"Camagüey",347572,21.3808333,-77.9169444 ],
    [ u"cu",u"Camajuaní",35517,22.465,-79.7244444 ],
    [ u"cu",u"Campechuela",25069,20.2341667,-77.2788889 ],
    [ u"cu",u"Candelaria",12675,22.7405556,-82.9611111 ],
    [ u"cu",u"Cárdenas",98519,23.0375,-81.2047222 ],
    [ u"cu",u"Chambas",24113,22.1927778,-78.9136111 ],
    [ u"cu",u"Ciego de Ávila",142032,21.84,-78.7619444 ],
    [ u"cu",u"Cienfuegos",186648,22.1461111,-80.4355556 ],
    [ u"cu",u"Cifuentes",40142,22.645,-80.0461111 ],
    [ u"cu",u"Colombia",20096,20.9880556,-77.4297222 ],
    [ u"cu",u"Colón",63885,22.7191667,-80.9058333 ],
    [ u"cu",u"Condado",38249,21.8766667,-79.8402778 ],
    [ u"cu",u"Consolación del Sur",69859,22.5047222,-83.5136111 ],
    [ u"cu",u"Contramaestre",70441,20.2977778,-76.2413889 ],
    [ u"cu",u"Corralillo",51900,22.9819444,-80.5855556 ],
    [ u"cu",u"Cruces",24907,22.3411111,-80.2666667 ],
    [ u"cu",u"Cueto",26527,20.6438889,-75.9355556 ],
    [ u"cu",u"Cumanayagua",38689,22.1494444,-80.2022222 ],
    [ u"cu",u"El Cobre",4768,20.0488889,-75.9469444 ],
    [ u"cu",u"Encrucijada",26155,22.6169444,-79.8711111 ],
    [ u"cu",u"Esmeralda",20274,21.8525,-78.1169444 ],
    [ u"cu",u"Esperanza",10462,22.3333333,-80.05 ],
    [ u"cu",u"Florida",63009,21.5247222,-78.2258333 ],
    [ u"cu",u"Fomento",19991,22.1038889,-79.7216667 ],
    [ u"cu",u"Gibara",27603,21.1097222,-76.1316667 ],
    [ u"cu",u"Guáimaro",39360,21.05,-77.35 ],
    [ u"cu",u"Guanajay",25258,22.9263889,-82.6875 ],
    [ u"cu",u"Guane",16548,22.2025,-84.0875 ],
    [ u"cu",u"Guantánamo",272808,20.1444444,-75.2091667 ],
    [ u"cu",u"Güines",68938,22.8361111,-82.0280556 ],
    [ u"cu",u"Güira de Melena",69897,22.7905556,-82.5052778 ],
    [ u"cu",u"Guisa",18408,20.255,-76.5386111 ],
    [ u"cu",u"Holguín",319114,20.8872222,-76.2630556 ],
    [ u"cu",u"Jagüey Grande",54365,22.5269444,-81.1286111 ],
    [ u"cu",u"Jaruco",20207,23.0430556,-82.0108333 ],
    [ u"cu",u"Jatibonico",19644,21.9419444,-79.17 ],
    [ u"cu",u"Jiguaní",41109,20.3666667,-76.4272222 ],
    [ u"cu",u"Jobabo",17804,20.9691667,-76.2994444 ],
    [ u"cu",u"Jovellanos",47166,22.8044444,-81.1944444 ],
    [ u"cu",u"Las Tunas",203690,20.9616667,-76.9511111 ],
    [ u"cu",u"Los Arabos",12504,22.7280556,-80.7213889 ],
    [ u"cu",u"Los Palacios",25703,22.5872222,-83.2486111 ],
    [ u"cu",u"Madruga",33798,22.9113889,-81.8561111 ],
    [ u"cu",u"Manati",13278,21.3047222,-76.8402778 ],
    [ u"cu",u"Manguito",3155,22.5880556,-80.9144444 ],
    [ u"cu",u"Manicaragua",41532,22.1494444,-79.9736111 ],
    [ u"cu",u"Mantua",10797,22.2888889,-84.2844444 ],
    [ u"cu",u"Manzanillo",128194,20.3433333,-77.1166667 ],
    [ u"cu",u"Mariel",28987,22.9875,-82.7536111 ],
    [ u"cu",u"Martí",13439,22.9475,-80.9202778 ],
    [ u"cu",u"Matanzas",146738,23.0411111,-81.5775 ],
    [ u"cu",u"Mayarí",83631,20.6541667,-75.6819444 ],
    [ u"cu",u"Media Luna",16713,20.1419444,-77.435 ],
    [ u"cu",u"Minas",20863,21.4833333,-77.6166667 ],
    [ u"cu",u"Moa",92885,20.6569444,-74.9402778 ],
    [ u"cu",u"Morón",66062,22.1094444,-78.6275 ],
    [ u"cu",u"Niquero",18771,20.0430556,-77.5827778 ],
    [ u"cu",u"Nueva Gerona",20264,21.8833333,-82.8 ],
    [ u"cu",u"Nuevitas",54024,21.5452778,-77.2644444 ],
    [ u"cu",u"Palma Soriano",102830,20.2172222,-75.9988889 ],
    [ u"cu",u"Palmira",23078,22.2416667,-80.3902778 ],
    [ u"cu",u"Pedro Betancourt",26761,22.7272222,-81.29 ],
    [ u"cu",u"Perico",24073,22.7691667,-81.0188889 ],
    [ u"cu",u"Pinar del Río",186997,22.4175,-83.6980556 ],
    [ u"cu",u"Placetas",55410,22.3119444,-79.6533333 ],
    [ u"cu",u"Primero de Enero",17934,21.9469444,-78.4283333 ],
    [ u"cu",u"Puerto Padre",76841,21.195,-76.6027778 ],
    [ u"cu",u"Quemado de Güines",12736,22.7852778,-80.2536111 ],
    [ u"cu",u"Rancho Veloz",4549,22.8805556,-80.3916667 ],
    [ u"cu",u"Ranchuelo",43696,22.3772222,-80.1488889 ],
    [ u"cu",u"Remedios",34109,22.4947222,-79.5458333 ],
    [ u"cu",u"Río Cauto",23737,20.5602778,-76.9161111 ],
    [ u"cu",u"Rodas",19212,22.3408333,-80.5572222 ],
    [ u"cu",u"Sagua de Tánamo",18282,20.5819444,-75.2413889 ],
    [ u"cu",u"Sagua la Grande",62075,22.8066667,-80.0755556 ],
    [ u"cu",u"San Antonio de los Baños",42726,22.8911111,-82.4991667 ],
    [ u"cu",u"San Cristóbal",59582,22.7141667,-83.0480556 ],
    [ u"cu",u"Sancti Spíritus",127073,21.9297222,-79.4425 ],
    [ u"cu",u"San Diego de los Baños",1643,22.6466667,-83.3697222 ],
    [ u"cu",u"San José de las Lajas",54850,22.9613889,-82.1511111 ],
    [ u"cu",u"San Luis",6690,22.2786111,-83.7611111 ],
    [ u"cu",u"San Luis",67296,20.0997222,-75.7472222 ],
    [ u"cu",u"San Nicolás",14914,22.7844444,-81.9133333 ],
    [ u"cu",u"Santa Clara",250518,22.1666667,-79.7666667 ],
    [ u"cu",u"Santa Cruz del Norte",18403,23.1538889,-81.9236111 ],
    [ u"cu",u"Santa Cruz del Sur",34602,20.7147222,-77.9955556 ],
    [ u"cu",u"Santa Fe",4595,21.7422222,-82.755 ],
    [ u"cu",u"Santiago de Cuba",555878,20.0247222,-75.8219444 ],
    [ u"cu",u"Santiago de las Vegas",35241,22.97,-82.3869444 ],
    [ u"cu",u"Santo Domingo",45477,22.5866667,-80.2436111 ],
    [ u"cu",u"Sibanicú",16856,21.235,-77.5263889 ],
    [ u"cu",u"Trinidad",60208,21.8019444,-79.9841667 ],
    [ u"cu",u"Unión de Reyes",33647,22.7952778,-81.5375 ],
    [ u"cu",u"Varadero",17178,23.1536111,-81.2513889 ],
    [ u"cu",u"Venezuela",16601,21.7352778,-78.7963889 ],
    [ u"cu",u"Vertientes",29704,21.2594444,-78.1463889 ],
    [ u"cu",u"Yaguajay",42220,22.3272222,-79.2377778 ],
    [ u"cu",u"Yara",28944,20.2752778,-76.9533333 ],
    [ u"cu",u"Zaza del Medio",8667,21.9961111,-79.3669444 ],
    [ u"cu",u"Zulueta",6141,22.3669444,-79.5691667 ],
    [ u"cv",u"Assomada",7808,15.1,-23.6833333 ],
    [ u"cv",u"Mindelo",69441,16.8833333,-25.0 ],
    [ u"cv",u"Pombas",1790,17.15,-25.0166667 ],
    [ u"cv",u"Ponta do Sol",4001,17.2,-25.1 ],
    [ u"cv",u"Porto Novo",5494,17.0333333,-25.0666667 ],
    [ u"cv",u"Praia",111611,14.9166667,-23.5166667 ],
    [ u"cv",u"Ribeira Brava",5242,16.6166667,-24.3 ],
    [ u"cv",u"Sal Rei",2089,16.1833333,-22.9166667 ],
    [ u"cv",u"Santa Maria",16967,16.6,-22.9 ],
    [ u"cv",u"São Filipe",8063,14.9,-24.5166667 ],
    [ u"cv",u"Tarrafal",6366,15.2833333,-23.7666667 ],
    [ u"cv",u"Vila do Maio",2962,15.1333333,-23.2166667 ],
    [ u"cy",u"Aradippou",13351,34.95,33.5916667 ],
    [ u"cy",u"Chlorakas",3619,34.8041667,32.4083333 ],
    [ u"cy",u"Dipkarpaz",5215,35.6,34.375 ],
    [ u"cy",u"Dromolaxia",5241,34.8791667,33.5833333 ],
    [ u"cy",u"Empa",4520,34.8083333,32.425 ],
    [ u"cy",u"Gazimagusa",42532,35.125,33.95 ],
    [ u"cy",u"Geri",7640,35.1,33.4166667 ],
    [ u"cy",u"Girne",26720,35.3416667,33.3166667 ],
    [ u"cy",u"Güzelyurt",14836,35.1980556,32.9913889 ],
    [ u"cy",u"Iskele",4491,35.2875,33.8916667 ],
    [ u"cy",u"Lapithos",5215,35.3125,33.1416667 ],
    [ u"cy",u"Larnaca",48954,34.9166667,33.6291667 ],
    [ u"cy",u"Lefka",7836,35.1105556,32.8505556 ],
    [ u"cy",u"Lemesos",154018,34.675,33.0333333 ],
    [ u"cy",u"Livadia",5329,34.9541667,33.6291667 ],
    [ u"cy",u"Nicosia",42342,35.1666667,33.3666667 ],
    [ u"cy",u"Páfos",35966,34.7666667,32.4166667 ],
    [ u"cy",u"Pano Polemidia",3781,34.7,33.0 ],
    [ u"cy",u"Paralimni",11838,35.0375,33.9833333 ],
    [ u"cy",u"Polis",1975,35.0366667,32.4263889 ],
    [ u"cy",u"Ypsonas",7349,34.6833333,32.9583333 ],
    [ u"cy",u"Ziyamet",1593,35.4708333,34.1416667 ],
    [ u"cz",u"Adamov",4951,49.301409,16.655487 ],
    [ u"cz",u"Albrechtice",4055,50.857945,15.033725 ],
    [ u"cz",u"Bakov nad Jizerou",4684,50.478355,14.939416 ],
    [ u"cz",u"Banov",2072,48.988364,17.721403 ],
    [ u"cz",u"Baska",3145,49.64417,18.371902 ],
    [ u"cz",u"Batelov",2383,49.313905,15.396317 ],
    [ u"cz",u"Bechyne",5900,49.299118,14.469875 ],
    [ u"cz",u"Becov",2069,50.44922,13.717491 ],
    [ u"cz",u"Bela pod Bezdezem",4937,50.503175,14.799517 ],
    [ u"cz",u"Benatky nad Jizerou",6853,50.28619,14.834337 ],
    [ u"cz",u"Benesov",16321,49.782377,14.686569 ],
    [ u"cz",u"Benesov nad Ploucnici",4042,50.738658,14.311497 ],
    [ u"cz",u"Beroun",17422,49.966171,14.060086 ],
    [ u"cz",u"Bilina",15866,50.548752,13.775444 ],
    [ u"cz",u"Bilovec",7465,49.75703,18.016558 ],
    [ u"cz",u"Bilovice nad Svitavou",2293,49.245536,16.671772 ],
    [ u"cz",u"Blansko",20643,49.363931,16.647513 ],
    [ u"cz",u"Blatna",6609,49.427165,13.884526 ],
    [ u"cz",u"Blovice",3852,49.583231,13.533991 ],
    [ u"cz",u"Blucina",1998,49.055618,16.647764 ],
    [ u"cz",u"Bludov",3177,49.942862,16.926266 ],
    [ u"cz",u"Bochov",1940,50.150569,13.046016 ],
    [ u"cz",u"Bohumin",23310,49.901831,18.360679 ],
    [ u"cz",u"Bohunovice",2354,49.66286,17.289043 ],
    [ u"cz",u"Bohusovice nad Ohri",2523,50.494477,14.149776 ],
    [ u"cz",u"Bojkovice",4747,49.037279,17.816865 ],
    [ u"cz",u"Bolatice",4118,49.953699,18.082143 ],
    [ u"cz",u"Bor",3944,49.713098,12.776297 ],
    [ u"cz",u"Borohradek",2127,50.096142,16.092833 ],
    [ u"cz",u"Borovany",3565,48.899809,14.642921 ],
    [ u"cz",u"Borsice",2273,49.061597,17.350058 ],
    [ u"cz",u"Boskovice",11356,49.490899,16.659172 ],
    [ u"cz",u"Brandys nad Labem-Stara Boleslav",15375,50.183608,14.659499 ],
    [ u"cz",u"Brasy",2024,49.832415,13.568605 ],
    [ u"cz",u"Breclav",26905,48.757723,16.890041 ],
    [ u"cz",u"Breznice",3772,49.558764,13.950916 ],
    [ u"cz",u"Brezova",2767,50.196603,12.87048 ],
    [ u"cz",u"Bridlicna",3796,49.911432,17.365002 ],
    [ u"cz",u"Brno",377407,49.2,16.633333 ],
    [ u"cz",u"Brodek u Prerova",1908,49.484523,17.336783 ],
    [ u"cz",u"Broumov",8325,50.585292,16.331815 ],
    [ u"cz",u"Brtnice",3641,49.310551,15.674454 ],
    [ u"cz",u"Bruntal",17610,49.989638,17.463217 ],
    [ u"cz",u"Brusperk",3573,49.699167,18.222021 ],
    [ u"cz",u"Buchlovice",2437,49.088463,17.340304 ],
    [ u"cz",u"Bucovice",6297,49.150789,17.002631 ],
    [ u"cz",u"Budisov nad Budisovkou",3220,49.794289,17.628931 ],
    [ u"cz",u"Bustehrad",2343,50.154904,14.187483 ],
    [ u"cz",u"Bystrice",4972,49.641899,18.730349 ],
    [ u"cz",u"Bystrice",3991,49.731793,14.667197 ],
    [ u"cz",u"Bystrice nad Pernstejnem",9030,49.52333,16.25941 ],
    [ u"cz",u"Bystrice pod Hostynem",8748,49.399643,17.674172 ],
    [ u"cz",u"Bzenec",4184,48.970968,17.269298 ],
    [ u"cz",u"Caslav",10209,49.912041,15.39483 ],
    [ u"cz",u"Cejkovice",2554,48.883333,16.283333 ],
    [ u"cz",u"Celadna",2027,49.552926,18.346749 ],
    [ u"cz",u"Celakovice",10086,50.163545,14.755924 ],
    [ u"cz",u"Cercany",2689,49.849118,14.706445 ],
    [ u"cz",u"Cerna Hora",1906,49.41309,16.581007 ],
    [ u"cz",u"Cernilov",2160,50.263472,15.914827 ],
    [ u"cz",u"Cernosice",4774,49.958377,14.319865 ],
    [ u"cz",u"Cervena Voda",3214,50.042613,16.742237 ],
    [ u"cz",u"Cerveny Kostelec",8431,50.476607,16.093114 ],
    [ u"cz",u"Ceska Kamenice",5468,50.800341,14.418459 ],
    [ u"cz",u"Ceska Lipa",39398,50.686736,14.538125 ],
    [ u"cz",u"Ceska Skalice",5384,50.394014,16.049184 ],
    [ u"cz",u"Ceska Trebova",17103,49.901115,16.445046 ],
    [ u"cz",u"Ceska Ves",2475,50.257388,17.228514 ],
    [ u"cz",u"Ceske Budejovice",97530,48.983333,14.466667 ],
    [ u"cz",u"Ceske Velenice",3504,48.764608,14.95924 ],
    [ u"cz",u"Cesky Brod",6875,50.07358,14.858163 ],
    [ u"cz",u"Cesky Dub",2835,50.660313,14.995326 ],
    [ u"cz",u"Cesky Krumlov",14404,48.81264,14.318207 ],
    [ u"cz",u"Cesky Tesin",26478,49.745479,18.621783 ],
    [ u"cz",u"Chabarovice",2223,50.67493,13.939411 ],
    [ u"cz",u"Cheb",32778,50.075777,12.374676 ],
    [ u"cz",u"Chlumcany",2371,49.631497,13.310957 ],
    [ u"cz",u"Chlumec",4090,50.699732,13.936998 ],
    [ u"cz",u"Chlumec nad Cidlinou",5229,50.156747,15.45845 ],
    [ u"cz",u"Chlum u Trebone",2253,48.961325,14.92961 ],
    [ u"cz",u"Chocen",9002,50.004354,16.22068 ],
    [ u"cz",u"Chodov",14661,50.239093,12.748613 ],
    [ u"cz",u"Chomutov",51054,50.463532,13.41365 ],
    [ u"cz",u"Chotebor",9829,49.717964,15.672295 ],
    [ u"cz",u"Chotesov",2592,49.655302,13.201168 ],
    [ u"cz",u"Chrastava",5918,50.816043,14.968178 ],
    [ u"cz",u"Chropyne",5232,49.361302,17.367619 ],
    [ u"cz",u"Chrudim",23909,49.95,15.8 ],
    [ u"cz",u"Chvaletice",3308,50.027712,15.445573 ],
    [ u"cz",u"Chynov",2059,49.408237,14.811225 ],
    [ u"cz",u"Cvikov",4430,50.777624,14.632985 ],
    [ u"cz",u"Dacice",7895,49.079485,15.4357 ],
    [ u"cz",u"Decin",52521,50.77137,14.198248 ],
    [ u"cz",u"Desna",3534,50.757871,15.311269 ],
    [ u"cz",u"Detmarovice",3768,49.894051,18.462384 ],
    [ u"cz",u"Dobra",2920,49.672268,18.414883 ],
    [ u"cz",u"Dobrany",5642,49.653671,13.29378 ],
    [ u"cz",u"Dobrichovice",2863,49.930846,14.27753 ],
    [ u"cz",u"Dobris",8066,49.780879,14.170542 ],
    [ u"cz",u"Dobronin",1897,49.48208,15.679466 ],
    [ u"cz",u"Dobrovice",3027,50.366759,14.961847 ],
    [ u"cz",u"Dobruska",7150,50.291973,16.161633 ],
    [ u"cz",u"Dobsice",2333,48.85,16.083333 ],
    [ u"cz",u"Doksy",5041,50.565654,14.654607 ],
    [ u"cz",u"Dolany",1932,49.64881,17.322268 ],
    [ u"cz",u"Dolni Benesov",4353,49.922199,18.113812 ],
    [ u"cz",u"Dolni Bojanovice",2870,48.857761,17.028111 ],
    [ u"cz",u"Dolni Bousov",2362,50.437513,15.127006 ],
    [ u"cz",u"Dolni Dobrouc",2553,49.992745,16.498762 ],
    [ u"cz",u"Dolni Kounice",2297,49.07548,16.458775 ],
    [ u"cz",u"Dolni Lutyne",4752,49.902974,18.423696 ],
    [ u"cz",u"Dolni Nemci",3002,48.968436,17.584023 ],
    [ u"cz",u"Dolni Poustevna",1938,50.991419,14.293227 ],
    [ u"cz",u"Domazlice",11036,49.441403,12.925536 ],
    [ u"cz",u"Doudleby nad Orlici",1927,50.107118,16.258362 ],
    [ u"cz",u"Drnovice",2178,49.274783,16.950789 ],
    [ u"cz",u"Dubi",7592,50.674556,13.79464 ],
    [ u"cz",u"Dubnany",6635,48.922718,17.104341 ],
    [ u"cz",u"Duchcov",8737,50.608973,13.744816 ],
    [ u"cz",u"Dvur Kralove",16364,50.429766,15.813812 ],
    [ u"cz",u"Frantiskovy Lazne",5234,50.12425,12.348123 ],
    [ u"cz",u"Frenstat",11348,49.544884,18.210243 ],
    [ u"cz",u"Frycovice",2114,49.674995,18.228693 ],
    [ u"cz",u"Frydek-Mistek",61584,49.683333,18.35 ],
    [ u"cz",u"Frydlant",7481,50.923446,15.077856 ],
    [ u"cz",u"Frydlant nad Ostravici",9753,49.591096,18.359548 ],
    [ u"cz",u"Frystak",3457,49.291023,17.693884 ],
    [ u"cz",u"Fulnek",6030,49.713098,17.900844 ],
    [ u"cz",u"Golcuv Jenikov",2593,49.816395,15.477346 ],
    [ u"cz",u"Habartov",5367,50.193493,12.574425 ],
    [ u"cz",u"Haj ve Slezsku",3299,49.898602,18.098483 ],
    [ u"cz",u"Halenkov",2349,49.319523,18.146193 ],
    [ u"cz",u"Hanusovice",3585,50.079228,16.93492 ],
    [ u"cz",u"Havirov",85829,49.8,18.4 ],
    [ u"cz",u"Havlickuv Brod",24373,49.614082,15.564558 ],
    [ u"cz",u"Hejnice",2692,50.878539,15.181515 ],
    [ u"cz",u"Hermanuv Mestec",4865,49.936342,15.678921 ],
    [ u"cz",u"Hlinsko",10538,49.763832,15.909317 ],
    [ u"cz",u"Hlubocky",4556,49.628217,17.403569 ],
    [ u"cz",u"Hluboka nad Vltavou",4514,49.05379,14.454533 ],
    [ u"cz",u"Hlucin",14341,49.896907,18.191661 ],
    [ u"cz",u"Hluk",4340,48.987772,17.526427 ],
    [ u"cz",u"Hodkovice nad Mohelkou",2588,50.665805,15.090202 ],
    [ u"cz",u"Hodonin",27600,48.856013,17.123073 ],
    [ u"cz",u"Holesov",12455,49.329979,17.577216 ],
    [ u"cz",u"Holice",6192,50.069729,15.992836 ],
    [ u"cz",u"Holysov",4562,49.592964,13.100612 ],
    [ u"cz",u"Horice",9052,50.369111,15.630551 ],
    [ u"cz",u"Horka nad Moravou",2048,49.638936,17.207852 ],
    [ u"cz",u"Horni Becva",2408,49.433333,18.283333 ],
    [ u"cz",u"Horni Benesov",2473,49.967143,17.603331 ],
    [ u"cz",u"Horni Briza",4468,49.842714,13.361977 ],
    [ u"cz",u"Horni Jiretin",1908,50.566667,13.566667 ],
    [ u"cz",u"Horni Plana",2281,48.768088,14.043873 ],
    [ u"cz",u"Horni Slavkov",5942,50.139647,12.806378 ],
    [ u"cz",u"Horni Sucha",4353,49.804997,18.476979 ],
    [ u"cz",u"Horomerice",2105,50.133877,14.334353 ],
    [ u"cz",u"Horovice",6570,49.836564,13.902058 ],
    [ u"cz",u"Hostinne",4865,50.540171,15.730411 ],
    [ u"cz",u"Hostivice",4727,50.080782,14.255397 ],
    [ u"cz",u"Hovezi",2302,49.304997,18.06167 ],
    [ u"cz",u"Hovorany",2212,48.95513,16.990661 ],
    [ u"cz",u"Hradec Kralove",97427,50.207744,15.829455 ],
    [ u"cz",u"Hradek",2888,49.26142,13.495013 ],
    [ u"cz",u"Hranice",2254,50.303473,12.17667 ],
    [ u"cz",u"Hranice",19666,49.556306,17.735236 ],
    [ u"cz",u"Hrob",1979,50.656467,13.724949 ],
    [ u"cz",u"Hronov",6491,50.476002,16.182718 ],
    [ u"cz",u"Hrusovany nad Jevisovkou",3261,48.833333,16.4 ],
    [ u"cz",u"Hrusovany u Brna",2881,49.036583,16.591713 ],
    [ u"cz",u"Hukvaldy",1897,49.624767,18.22096 ],
    [ u"cz",u"Hulin",7576,49.314891,17.471896 ],
    [ u"cz",u"Humpolec",10915,49.541739,15.35586 ],
    [ u"cz",u"Hustopece",5858,48.941028,16.73353 ],
    [ u"cz",u"Ivancice",9314,49.101315,16.37623 ],
    [ u"cz",u"Ivanovice na Hane",2893,49.304928,17.093292 ],
    [ u"cz",u"Jablonec",45289,50.720474,15.171128 ],
    [ u"cz",u"Jablonec nad Jizerou",1967,50.704428,15.42863 ],
    [ u"cz",u"Jablonne nad Orlici",3106,50.030388,16.603926 ],
    [ u"cz",u"Jablonne v Podjestedi",3674,50.763952,14.761264 ],
    [ u"cz",u"Jablunka",1965,49.38369,17.950487 ],
    [ u"cz",u"Jablunkov",5911,49.574677,18.769523 ],
    [ u"cz",u"Jachymov",2816,50.365752,12.922539 ],
    [ u"cz",u"Janovice nad Uhlavou",2025,49.344417,13.217585 ],
    [ u"cz",u"Jaromerice nad Rokytnou",4089,49.095265,15.891582 ],
    [ u"cz",u"Jaromer",12911,50.349199,15.920442 ],
    [ u"cz",u"Javornik",2935,50.395669,17.01267 ],
    [ u"cz",u"Jedovnice",2477,49.344289,16.755841 ],
    [ u"cz",u"Jemnice",4289,49.017549,15.576795 ],
    [ u"cz",u"Jesenice",2551,49.969168,14.514608 ],
    [ u"cz",u"Jesenik",12693,50.229906,17.203426 ],
    [ u"cz",u"Jevicko",2817,49.632619,16.711918 ],
    [ u"cz",u"Jicin",16516,50.435841,15.355569 ],
    [ u"cz",u"Jihlava",50818,49.4,15.583333 ],
    [ u"cz",u"Jilemnice",5728,50.605466,15.50996 ],
    [ u"cz",u"Jilove",5233,50.751482,14.109192 ],
    [ u"cz",u"Jilove u Prahy",3427,49.898235,14.496985 ],
    [ u"cz",u"Jince",2296,49.788652,13.976619 ],
    [ u"cz",u"Jindrichuv Hradec",22646,49.144852,15.0025 ],
    [ u"cz",u"Jirikov",3901,50.993215,14.572155 ],
    [ u"cz",u"Jirkov",20648,50.5,13.45 ],
    [ u"cz",u"Jistebnice",2035,49.485539,14.527817 ],
    [ u"cz",u"Kadan",17559,50.384339,13.267338 ],
    [ u"cz",u"Kamenice",2901,49.901177,14.5812 ],
    [ u"cz",u"Kamenice nad Lipou",4202,49.302353,15.076126 ],
    [ u"cz",u"Kamenicky Senov",4055,50.773234,14.472826 ],
    [ u"cz",u"Kaplice",7087,48.739407,14.493856 ],
    [ u"cz",u"Kardasova Recice",2022,49.184224,14.853137 ],
    [ u"cz",u"Karlovy Vary",53585,50.237003,12.875042 ],
    [ u"cz",u"Karolinka",2881,49.351904,18.24642 ],
    [ u"cz",u"Karvina",65441,49.856792,18.546907 ],
    [ u"cz",u"Kaznejov",2986,49.893351,13.381569 ],
    [ u"cz",u"Kdyne",4879,49.392123,13.039451 ],
    [ u"cz",u"Kelc",2569,49.478455,17.819404 ],
    [ u"cz",u"Kladno",71262,50.142037,14.096549 ],
    [ u"cz",u"Klasterec nad Ohri",15724,50.388821,13.182397 ],
    [ u"cz",u"Klatovy",23059,49.39717,13.289064 ],
    [ u"cz",u"Klecany",2018,50.176478,14.412374 ],
    [ u"cz",u"Klimkovice",3755,49.788341,18.127265 ],
    [ u"cz",u"Koberice",3198,49.984879,18.056068 ],
    [ u"cz",u"Kobyli",2084,48.931754,16.888425 ],
    [ u"cz",u"Kojetin",6407,49.350476,17.302747 ],
    [ u"cz",u"Kolin",30351,50.026904,15.202311 ],
    [ u"cz",u"Komarov",2542,49.807361,13.858013 ],
    [ u"cz",u"Konice",3019,49.592494,16.888092 ],
    [ u"cz",u"Kopidlno",2195,50.333198,15.26877 ],
    [ u"cz",u"Koprivnice",23798,49.598453,18.145241 ],
    [ u"cz",u"Korycany",2827,49.109827,17.166496 ],
    [ u"cz",u"Kosmonosy",4005,50.436676,14.928258 ],
    [ u"cz",u"Kostelec nad Cernymi Lesy",3345,49.995688,14.861005 ],
    [ u"cz",u"Kostelec nad Labem",3029,50.226468,14.58672 ],
    [ u"cz",u"Kostelec nad Orlici",6153,50.123826,16.211445 ],
    [ u"cz",u"Kostelec na Hane",2713,49.514288,17.058101 ],
    [ u"cz",u"Kozlovice",2811,49.600238,18.257268 ],
    [ u"cz",u"Kraliky",4806,50.084047,16.759172 ],
    [ u"cz",u"Kralovice",3475,49.98058,13.485576 ],
    [ u"cz",u"Kralupy nad Vltavou",17493,50.239486,14.300742 ],
    [ u"cz",u"Kraluv Dvur",5509,49.947837,14.038397 ],
    [ u"cz",u"Kraslice",7236,50.327579,12.511121 ],
    [ u"cz",u"Krasna Lipa",3621,50.48378,13.357497 ],
    [ u"cz",u"Kravare",6667,49.932857,18.017489 ],
    [ u"cz",u"Kremze",2475,48.905005,14.309279 ],
    [ u"cz",u"Krnov",25769,50.089054,17.698012 ],
    [ u"cz",u"Kromeriz",29211,49.295955,17.395659 ],
    [ u"cz",u"Krupka",13281,50.681912,13.864749 ],
    [ u"cz",u"Kryry",2434,50.17508,13.42508 ],
    [ u"cz",u"Kuncice pod Ondrejnikem",1954,49.56047,18.255484 ],
    [ u"cz",u"Kunovice",5129,49.040529,17.466141 ],
    [ u"cz",u"Kunstat",2532,49.506871,16.521307 ],
    [ u"cz",u"Kurim",8896,49.302631,16.532675 ],
    [ u"cz",u"Kutna Hora",21474,49.95,15.266667 ],
    [ u"cz",u"Kvasice",2275,49.23974,17.471008 ],
    [ u"cz",u"Kynsperk nad Ohri",5134,50.11917,12.531531 ],
    [ u"cz",u"Lanskroun",9980,49.911432,16.612503 ],
    [ u"cz",u"Lanzhot",3756,48.723731,16.96522 ],
    [ u"cz",u"Lazne Belohrad",3780,50.428875,15.582745 ],
    [ u"cz",u"Lazne Bohdanec",3083,50.076389,15.682222 ],
    [ u"cz",u"Ledec",6101,49.696295,15.274891 ],
    [ u"cz",u"Ledenice",2135,48.933078,14.621598 ],
    [ u"cz",u"Lednice",2347,48.797895,16.803683 ],
    [ u"cz",u"Lesna",1951,49.519404,17.93131 ],
    [ u"cz",u"Letohrad",6257,50.035969,16.496683 ],
    [ u"cz",u"Letovice",6614,49.547591,16.576105 ],
    [ u"cz",u"Libcice nad Vltavou",3404,50.197949,14.354321 ],
    [ u"cz",u"Liberec",99416,50.763889,15.065278 ],
    [ u"cz",u"Libochovice",3659,50.4097,14.069006 ],
    [ u"cz",u"Libusin",2539,50.167322,14.054582 ],
    [ u"cz",u"Line",2230,49.69531,13.257388 ],
    [ u"cz",u"Lisov",3897,49.016476,14.6081 ],
    [ u"cz",u"Litomerice",24930,50.538408,14.130347 ],
    [ u"cz",u"Litomysl",10351,49.86898,16.313674 ],
    [ u"cz",u"Litovel",10026,49.706317,17.076908 ],
    [ u"cz",u"Litvinov",27424,50.601105,13.612673 ],
    [ u"cz",u"Loket",3186,50.185921,12.754252 ],
    [ u"cz",u"Lom",3603,50.59408,13.660254 ],
    [ u"cz",u"Lomnice nad Popelkou",6108,50.532459,15.370539 ],
    [ u"cz",u"Lostice",3051,49.745003,16.930656 ],
    [ u"cz",u"Loucna nad Desnou",1925,50.073687,17.091196 ],
    [ u"cz",u"Loucovice",1960,48.620897,14.249763 ],
    [ u"cz",u"Louny",19720,50.355707,13.809376 ],
    [ u"cz",u"Lovosice",9266,50.514231,14.052128 ],
    [ u"cz",u"Luby",2465,50.253328,12.404506 ],
    [ u"cz",u"Ludgerovice",4577,49.884296,18.249405 ],
    [ u"cz",u"Luhacovice",5596,49.097632,17.749896 ],
    [ u"cz",u"Luka nad Jihlavou",2470,49.375568,15.700632 ],
    [ u"cz",u"Lutin",3198,49.556673,17.139519 ],
    [ u"cz",u"Luze",2601,49.893878,16.029931 ],
    [ u"cz",u"Luzice",2731,48.83974,17.07035 ],
    [ u"cz",u"Lysa nad Labem",8461,50.201139,14.841773 ],
    [ u"cz",u"Marianske Lazne",14709,49.960197,12.700682 ],
    [ u"cz",u"Melnik",19318,50.361082,14.472342 ],
    [ u"cz",u"Merin",1901,49.391768,15.88687 ],
    [ u"cz",u"Mestec Kralove",3010,50.205726,15.296462 ],
    [ u"cz",u"Mesto Albrechtice",3612,50.16305,17.572759 ],
    [ u"cz",u"Mezibori",4945,50.621852,13.60102 ],
    [ u"cz",u"Mezimesti",2840,50.626582,16.242148 ],
    [ u"cz",u"Mikulasovice",2385,50.965381,14.364363 ],
    [ u"cz",u"Mikulcice",1899,48.817654,17.05 ],
    [ u"cz",u"Mikulovice",2771,50.300642,17.324338 ],
    [ u"cz",u"Mikulov",7653,48.806314,16.637074 ],
    [ u"cz",u"Milevsko",9436,49.451895,14.361574 ],
    [ u"cz",u"Milin",2107,49.633333,14.046329 ],
    [ u"cz",u"Milotice",1940,48.955224,17.142277 ],
    [ u"cz",u"Milovice",4342,50.228034,14.889739 ],
    [ u"cz",u"Mimon",6708,50.65575,14.729251 ],
    [ u"cz",u"Miroslav",2998,48.95,16.316667 ],
    [ u"cz",u"Mirosov",2228,49.690165,13.66891 ],
    [ u"cz",u"Mlada Boleslav",44417,50.42311,14.919316 ],
    [ u"cz",u"Mlada Vozice",2721,49.538113,14.813137 ],
    [ u"cz",u"Mlade Buky",2199,50.604513,15.84315 ],
    [ u"cz",u"Mnichovice",2204,49.936421,14.708604 ],
    [ u"cz",u"Mnichovo Hradiste",8652,50.522981,14.974758 ],
    [ u"cz",u"Mnisek pod Brdy",4208,49.865009,14.264299 ],
    [ u"cz",u"Modrice",3491,49.130176,16.611011 ],
    [ u"cz",u"Mohelnice",9808,49.777384,16.918452 ],
    [ u"cz",u"Moravska Nova Ves",2518,48.804341,17.012853 ],
    [ u"cz",u"Moravska Trebova",11564,49.755711,16.657149 ],
    [ u"cz",u"Moravske Budejovice",7970,49.052105,15.810128 ],
    [ u"cz",u"Moravsky Beroun",3418,49.796431,17.444735 ],
    [ u"cz",u"Moravsky Krumlov",6079,49.046745,16.30917 ],
    [ u"cz",u"Moravsky Pisek",2140,48.988068,17.329189 ],
    [ u"cz",u"Morkovice-Slizany",2799,49.247255,17.21128 ],
    [ u"cz",u"Morkov",2365,49.536277,18.06176 ],
    [ u"cz",u"Most",68254,50.509611,13.639121 ],
    [ u"cz",u"Mosty u Jablunkova",3981,49.534671,18.753926 ],
    [ u"cz",u"Mutenice",3655,48.902988,17.026664 ],
    [ u"cz",u"Nachod",21196,50.416667,16.166667 ],
    [ u"cz",u"Napajedla",7573,49.177848,17.517417 ],
    [ u"cz",u"Navsi",3750,49.589936,18.754532 ],
    [ u"cz",u"Nechanice",2186,50.237115,15.635234 ],
    [ u"cz",u"Nejdek",8556,50.32224,12.730727 ],
    [ u"cz",u"Nemcice nad Hanou",2102,49.342743,17.209161 ],
    [ u"cz",u"Nepomuk",3531,49.487615,13.583583 ],
    [ u"cz",u"Neratovice",16285,50.262281,14.508592 ],
    [ u"cz",u"Netolice",2606,49.050948,14.198223 ],
    [ u"cz",u"Neveklov",2432,49.751765,14.544805 ],
    [ u"cz",u"Nivnice",3221,48.97692,17.64596 ],
    [ u"cz",u"Nova Bystrice",3389,49.019462,15.104118 ],
    [ u"cz",u"Nova Paka",9259,50.489941,15.516498 ],
    [ u"cz",u"Nova Role",4027,50.271955,12.786849 ],
    [ u"cz",u"Nova Vcelnice",2463,49.239363,15.072403 ],
    [ u"cz",u"Nove Hrady",2588,48.790466,14.778111 ],
    [ u"cz",u"Nove Mesto nad Metuji",10074,50.354135,16.139448 ],
    [ u"cz",u"Nove Mesto na Morave",10459,49.562994,16.074353 ],
    [ u"cz",u"Nove Mesto pod Smrkem",4001,50.92634,15.22973 ],
    [ u"cz",u"Nove Sedlo",2626,50.210998,12.739372 ],
    [ u"cz",u"Nove Straseci",5210,50.153997,13.90082 ],
    [ u"cz",u"Novosedlice",2143,50.65795,13.822201 ],
    [ u"cz",u"Novy Bor",12325,50.757126,14.556747 ],
    [ u"cz",u"Novy Bydzov",7170,50.2411,15.491409 ],
    [ u"cz",u"Novy Hrozenkov",2738,49.339768,18.205008 ],
    [ u"cz",u"Novy Jicin",27043,49.598334,18.012384 ],
    [ u"cz",u"Novy Malin",2303,49.95,17.033333 ],
    [ u"cz",u"Nydek",1944,49.659767,18.763336 ],
    [ u"cz",u"Nymburk",14498,50.190375,15.03947 ],
    [ u"cz",u"Nyrany",6884,49.714397,13.207057 ],
    [ u"cz",u"Nyrsko",5088,49.292258,13.142736 ],
    [ u"cz",u"Obrnice",2610,50.503511,13.697048 ],
    [ u"cz",u"Odolena Voda",4478,50.232887,14.411094 ],
    [ u"cz",u"Odry",7415,49.666667,17.833333 ],
    [ u"cz",u"Okrisky",2014,49.24487,15.768936 ],
    [ u"cz",u"Olomouc",102792,49.59404,17.25119 ],
    [ u"cz",u"Olovi",1891,50.244662,12.55825 ],
    [ u"cz",u"Opatovice nad Labem",2171,50.151404,15.791597 ],
    [ u"cz",u"Opava",61514,49.93846,17.902628 ],
    [ u"cz",u"Opocno",3124,50.269932,16.110817 ],
    [ u"cz",u"Orechov",2344,49.11351,16.517417 ],
    [ u"cz",u"Orlova",34938,49.860351,18.444873 ],
    [ u"cz",u"Osek",5005,50.624513,13.694421 ],
    [ u"cz",u"Oslavany",4527,49.121758,16.338463 ],
    [ u"cz",u"Ostrava",317136,49.811852,18.255282 ],
    [ u"cz",u"Ostrov",17453,50.307349,12.94792 ],
    [ u"cz",u"Ostrozska Nova Ves",3333,49.004698,17.437016 ],
    [ u"cz",u"Otrokovice",19303,49.207366,17.523862 ],
    [ u"cz",u"Pacov",5210,49.471272,15.004092 ],
    [ u"cz",u"Palkovice",2590,49.628455,18.302271 ],
    [ u"cz",u"Pardubice",90853,50.027778,15.775833 ],
    [ u"cz",u"Paskov",3704,49.733452,18.290601 ],
    [ u"cz",u"Pecky",4386,50.090851,15.030752 ],
    [ u"cz",u"Pelhrimov",16590,49.428201,15.223368 ],
    [ u"cz",u"Peruc",2058,50.342619,13.960352 ],
    [ u"cz",u"Petrovice u Karvine",4499,49.898572,18.532976 ],
    [ u"cz",u"Petrvald",6785,49.828425,18.390542 ],
    [ u"cz",u"Pisek",29756,49.308408,14.149171 ],
    [ u"cz",u"Plana nad Luznici",3027,49.344926,14.713605 ],
    [ u"cz",u"Plana",5377,49.867527,12.74151 ],
    [ u"cz",u"Plasy",2610,49.931803,13.382054 ],
    [ u"cz",u"Plesna",1972,50.217447,12.349792 ],
    [ u"cz",u"Plumlov",2259,49.466667,17.016667 ],
    [ u"cz",u"Plzen",165531,49.75,13.366667 ],
    [ u"cz",u"Pocatky",2743,49.261044,15.238458 ],
    [ u"cz",u"Podborany",6082,50.226883,13.409585 ],
    [ u"cz",u"Podebrady",13445,50.147421,15.118661 ],
    [ u"cz",u"Podivin",2876,48.829387,16.849737 ],
    [ u"cz",u"Pohorelice",4345,48.983333,16.516667 ],
    [ u"cz",u"Polesovice",1980,49.033464,17.342672 ],
    [ u"cz",u"Police nad Metuji",4377,50.538067,16.234725 ],
    [ u"cz",u"Policka",9149,49.715579,16.268436 ],
    [ u"cz",u"Polna",4849,49.487442,15.716744 ],
    [ u"cz",u"Postoloprty",4812,50.359982,13.696013 ],
    [ u"cz",u"Postrelmov",3222,49.910957,16.916429 ],
    [ u"cz",u"Povrly",2099,50.673057,14.160202 ],
    [ u"cz",u"Pozorice",1968,49.210654,16.791883 ],
    [ u"cz",u"Prachatice",11825,49.014417,13.999526 ],
    [ u"cz",u"Prague",1154508,50.083333,14.466667 ],
    [ u"cz",u"Prelouc",9106,50.038042,15.560284 ],
    [ u"cz",u"Prerov",48513,49.453926,17.452379 ],
    [ u"cz",u"Prestice",6426,49.574825,13.328597 ],
    [ u"cz",u"Pribor",8720,49.640482,18.150476 ],
    [ u"cz",u"Pribram",35963,49.691355,14.020575 ],
    [ u"cz",u"Pribyslav",3965,49.57721,15.738639 ],
    [ u"cz",u"Probostov",2229,50.666667,13.833333 ],
    [ u"cz",u"Prosec",2089,49.807075,16.116531 ],
    [ u"cz",u"Prostejov",48258,49.47333,17.113455 ],
    [ u"cz",u"Protivin",4926,49.201066,14.214535 ],
    [ u"cz",u"Pruhonice",2008,50.001471,14.559534 ],
    [ u"cz",u"Prusanky",2087,48.828992,16.983727 ],
    [ u"cz",u"Rajec-Jestrebi",3548,49.416667,16.633333 ],
    [ u"cz",u"Rajhrad",2703,49.087673,16.604472 ],
    [ u"cz",u"Rakovnik",16725,50.10257,13.728775 ],
    [ u"cz",u"Rakvice",2066,48.856971,16.814168 ],
    [ u"cz",u"Rapotin",2887,49.983333,17.016667 ],
    [ u"cz",u"Raspenava",2835,50.899712,15.133397 ],
    [ u"cz",u"Ratiskovice",4032,48.918075,17.162063 ],
    [ u"cz",u"Revnice",3047,49.913114,14.240644 ],
    [ u"cz",u"Ricany",10928,49.992672,14.658531 ],
    [ u"cz",u"Rohatec",3358,48.933333,17.166667 ],
    [ u"cz",u"Rokycany",14295,49.74047,13.592556 ],
    [ u"cz",u"Rokytnice nad Jizerou",3373,50.72763,15.445253 ],
    [ u"cz",u"Rosice",5276,49.181825,16.393079 ],
    [ u"cz",u"Rotava",3431,50.297435,12.573072 ],
    [ u"cz",u"Roudnice",13114,50.421241,14.257235 ],
    [ u"cz",u"Rousinov",4903,49.82358,14.813137 ],
    [ u"cz",u"Rozmital pod Tremsinem",4491,49.607461,13.8706 ],
    [ u"cz",u"Roznov",17964,49.4606,18.136664 ],
    [ u"cz",u"Roztoky",5910,50.161771,14.392392 ],
    [ u"cz",u"Rtyne v Podkrkonosi",3040,50.506405,16.069229 ],
    [ u"cz",u"Ruda nad Moravou",2464,49.981072,16.877622 ],
    [ u"cz",u"Rudna",3170,50.032859,14.225905 ],
    [ u"cz",u"Rudnik",2178,50.608353,15.737229 ],
    [ u"cz",u"Rudolfov",2377,48.989583,14.542241 ],
    [ u"cz",u"Rumburk",11000,50.953564,14.553788 ],
    [ u"cz",u"Rychnov nad Kneznou",11721,50.166667,16.283333 ],
    [ u"cz",u"Rychvald",6743,49.868333,18.375828 ],
    [ u"cz",u"Sadska",3153,50.136909,14.985015 ],
    [ u"cz",u"Sardice",2189,48.963116,17.03136 ],
    [ u"cz",u"Sazava",3843,49.870565,14.895367 ],
    [ u"cz",u"Sedlcany",8088,49.65885,14.423418 ],
    [ u"cz",u"Semily",9247,50.602889,15.33768 ],
    [ u"cz",u"Senov",5385,49.790917,18.375858 ],
    [ u"cz",u"Sezemice",2995,50.066321,15.850651 ],
    [ u"cz",u"Sezimovo Usti",7455,49.377523,14.702868 ],
    [ u"cz",u"Sitborice",1940,49.014957,16.777808 ],
    [ u"cz",u"Skutec",5322,49.842468,15.994781 ],
    [ u"cz",u"Slany",15330,50.232504,14.074934 ],
    [ u"cz",u"Slapanice",6190,49.165352,16.725835 ],
    [ u"cz",u"Slatinany",3957,49.918333,15.815192 ],
    [ u"cz",u"Slavicin",7127,49.087973,17.879764 ],
    [ u"cz",u"Slavkov u Brna",5858,49.153157,16.879558 ],
    [ u"cz",u"Slavonice",2703,48.998229,15.350296 ],
    [ u"cz",u"Sluknov",5630,51.004656,14.453761 ],
    [ u"cz",u"Slusovice",2972,49.250592,17.79852 ],
    [ u"cz",u"Smirice",3131,50.300086,15.865792 ],
    [ u"cz",u"Smrzovka",3415,50.735331,15.244694 ],
    [ u"cz",u"Sobeslav",7252,49.259093,14.718653 ],
    [ u"cz",u"Sobotin",2502,50.016667,17.1 ],
    [ u"cz",u"Sobotka",2279,50.467115,15.175501 ],
    [ u"cz",u"Sokolov",25079,50.178428,12.647147 ],
    [ u"cz",u"Solnice",2076,50.203468,16.238854 ],
    [ u"cz",u"Spalene Porici",2501,49.612487,13.605553 ],
    [ u"cz",u"Stankov",3053,49.552243,13.06993 ],
    [ u"cz",u"Stara Paka",2015,50.510833,15.49 ],
    [ u"cz",u"Stara Ves nad Ondrejnici",2439,49.726075,18.19404 ],
    [ u"cz",u"Stare Mesto",2137,50.161224,16.946342 ],
    [ u"cz",u"Stare Mesto",6661,49.076493,17.437993 ],
    [ u"cz",u"Stary Jicin",2400,49.577494,17.961908 ],
    [ u"cz",u"Stary Plzenec",4225,49.694596,13.474666 ],
    [ u"cz",u"Stepankovice",3030,49.957387,18.03714 ],
    [ u"cz",u"Stepanov",3316,50.162384,16.917024 ],
    [ u"cz",u"Sternberk",14130,49.726551,17.292981 ],
    [ u"cz",u"Steti",9152,50.453141,14.378383 ],
    [ u"cz",u"Stity",2021,49.961908,16.763931 ],
    [ u"cz",u"Stochov",5563,50.139507,13.965953 ],
    [ u"cz",u"Stod",3429,49.639961,13.16422 ],
    [ u"cz",u"Strakonice",23863,49.260997,13.905073 ],
    [ u"cz",u"Stramberk",3395,49.590958,18.117846 ],
    [ u"cz",u"Strani",3831,48.905327,17.705316 ],
    [ u"cz",u"Strasice",2456,49.735474,13.757592 ],
    [ u"cz",u"Straznice",5960,48.898948,17.311932 ],
    [ u"cz",u"Straz pod Ralskem",4010,50.698886,14.794952 ],
    [ u"cz",u"Strelice",2527,49.15342,16.500263 ],
    [ u"cz",u"Stribro",7748,49.754845,12.995478 ],
    [ u"cz",u"Studena",2482,49.187082,15.28649 ],
    [ u"cz",u"Studenka",10503,49.719889,18.074529 ],
    [ u"cz",u"Suchdol nad Luznici",3628,48.89419,14.878038 ],
    [ u"cz",u"Sumperk",29604,49.965811,16.978874 ],
    [ u"cz",u"Susice",11452,49.237292,13.523972 ],
    [ u"cz",u"Svetla nad Sazavou",7158,49.667892,15.402449 ],
    [ u"cz",u"Svitavy",17625,49.755945,16.466791 ],
    [ u"cz",u"Svoboda nad Upou",2249,50.623117,15.817125 ],
    [ u"cz",u"Tabor",36546,49.411005,14.672771 ],
    [ u"cz",u"Tachov",12684,49.798116,12.635752 ],
    [ u"cz",u"Tanvald",6971,50.740333,15.274131 ],
    [ u"cz",u"Telc",6028,49.18228,15.458117 ],
    [ u"cz",u"Tepla",3085,49.979968,12.864322 ],
    [ u"cz",u"Teplice",50972,50.646569,13.840138 ],
    [ u"cz",u"Terezin",2916,50.510696,14.149776 ],
    [ u"cz",u"Terlicko",4110,49.752945,18.482957 ],
    [ u"cz",u"Tisnov",8279,49.347502,16.425956 ],
    [ u"cz",u"Tlucna",2307,49.724768,13.239043 ],
    [ u"cz",u"Tlumacov",2393,49.252762,17.500987 ],
    [ u"cz",u"Touzim",3779,50.055655,12.990823 ],
    [ u"cz",u"Tovacov",2656,49.430834,17.287735 ],
    [ u"cz",u"Trebechovice pod Orebem",5406,50.201595,15.988212 ],
    [ u"cz",u"Trebic",39038,49.210649,15.881458 ],
    [ u"cz",u"Trebon",8968,49.005636,14.763256 ],
    [ u"cz",u"Tremosna",4605,49.82666,13.391741 ],
    [ u"cz",u"Tremosnice",3390,49.870259,15.577777 ],
    [ u"cz",u"Trhove Sviny",4596,48.841687,14.638371 ],
    [ u"cz",u"Trinec",39054,49.680358,18.665348 ],
    [ u"cz",u"Trmice",2678,50.642224,14.001877 ],
    [ u"cz",u"Trojanovice",2054,49.515596,18.233463 ],
    [ u"cz",u"Troubky",1980,49.429764,17.347977 ],
    [ u"cz",u"Trutnov",32085,50.565612,15.914355 ],
    [ u"cz",u"Tuchlovice",2211,50.136983,13.990812 ],
    [ u"cz",u"Turnov",14500,50.592134,15.164575 ],
    [ u"cz",u"Tvrdonice",2059,48.76088,16.992502 ],
    [ u"cz",u"Tynec nad Sazavou",5374,49.827817,14.598529 ],
    [ u"cz",u"Tyniste nad Orlici",6259,50.152992,16.076118 ],
    [ u"cz",u"Tyn nad Vltavou",8100,49.225516,14.418562 ],
    [ u"cz",u"Uherske Hradiste",26954,49.066667,17.463943 ],
    [ u"cz",u"Uhersky Brod",17625,49.025539,17.646646 ],
    [ u"cz",u"Uhersky Ostroh",4499,48.98866,17.394875 ],
    [ u"cz",u"Uhlirske Janovice",3172,49.881494,15.064461 ],
    [ u"cz",u"Unicov",12474,49.772259,17.122268 ],
    [ u"cz",u"Upice",5906,50.512965,16.016914 ],
    [ u"cz",u"Ustek",2649,50.58494,14.345113 ],
    [ u"cz",u"Usti nad Orlici",15194,49.975283,16.397151 ],
    [ u"cz",u"Usti",95556,50.666667,14.033333 ],
    [ u"cz",u"Uvaly",4834,50.073111,14.725905 ],
    [ u"cz",u"Vacenovice",2075,48.948027,17.174783 ],
    [ u"cz",u"Valasska Bystrice",2172,49.414654,18.109637 ],
    [ u"cz",u"Valasske Klobouky",5168,49.143456,18.01618 ],
    [ u"cz",u"Valasske Mezirici",27562,49.473211,17.972378 ],
    [ u"cz",u"Valtice",3616,48.741812,16.757793 ],
    [ u"cz",u"Vamberk",4794,50.117637,16.293932 ],
    [ u"cz",u"Varnsdorf",16018,50.915389,14.617839 ],
    [ u"cz",u"Vejprnice",2509,49.73007,13.277113 ],
    [ u"cz",u"Vejprty",3320,50.49575,13.033892 ],
    [ u"cz",u"Velesin",4006,48.83049,14.463114 ],
    [ u"cz",u"Velim",2046,50.061389,15.101479 ],
    [ u"cz",u"Velka Bites",4868,49.28905,16.227124 ],
    [ u"cz",u"Velka Bystrice",2857,49.594408,17.360232 ],
    [ u"cz",u"Velka nad Velickou",3216,48.883333,17.533333 ],
    [ u"cz",u"Velke Bilovice",3785,48.849474,16.89145 ],
    [ u"cz",u"Velke Hamry",2709,50.717417,15.296648 ],
    [ u"cz",u"Velke Karlovice",2664,49.36405,18.3069 ],
    [ u"cz",u"Velke Losiny",2878,50.043327,17.053093 ],
    [ u"cz",u"Velke Mezirici",11795,49.355442,16.01449 ],
    [ u"cz",u"Velke Opatovice",4176,49.613217,16.676185 ],
    [ u"cz",u"Velke Pavlovice",3089,48.902269,16.814891 ],
    [ u"cz",u"Velke Porici",2272,50.458755,16.192494 ],
    [ u"cz",u"Velky Osek",2188,50.100358,15.192194 ],
    [ u"cz",u"Velky Senov",2004,50.992377,14.382757 ],
    [ u"cz",u"Velky Tynec",2114,49.551547,17.335117 ],
    [ u"cz",u"Velvary",3001,50.281733,14.24153 ],
    [ u"cz",u"Vendryne",3827,49.655127,18.699643 ],
    [ u"cz",u"Verovice",1934,49.538936,18.119879 ],
    [ u"cz",u"Veseli nad Luznici",6606,49.184951,14.698235 ],
    [ u"cz",u"Veseli nad Moravou",12245,48.950888,17.382144 ],
    [ u"cz",u"Vetrni",3756,48.77493,14.287545 ],
    [ u"cz",u"Veverska Bityska",2779,49.275743,16.436621 ],
    [ u"cz",u"Vikyrovice",2014,49.983333,17.016667 ],
    [ u"cz",u"Vimperk",8237,49.056271,13.785015 ],
    [ u"cz",u"Vitkov",6312,49.775114,17.752379 ],
    [ u"cz",u"Vizovice",4481,49.221403,17.853332 ],
    [ u"cz",u"Vlasim",12350,49.703603,14.899412 ],
    [ u"cz",u"Vlcnov",3016,49.580239,17.952866 ],
    [ u"cz",u"Vnorovy",3065,48.929189,17.350493 ],
    [ u"cz",u"Vodnany",6546,49.147394,14.170186 ],
    [ u"cz",u"Volary",4047,48.91039,13.889017 ],
    [ u"cz",u"Volyne",3177,50.448742,13.211491 ],
    [ u"cz",u"Votice",4599,49.639484,14.640219 ],
    [ u"cz",u"Vracov",4514,48.974388,17.21088 ],
    [ u"cz",u"Vranovice",1918,48.966667,16.6 ],
    [ u"cz",u"Vratimov",6431,49.768571,18.315002 ],
    [ u"cz",u"Vrbno pod Pradedem",6220,50.121807,17.379478 ],
    [ u"cz",u"Vrchlabi",13155,50.624091,15.61315 ],
    [ u"cz",u"Vrdy",3049,49.920754,15.471089 ],
    [ u"cz",u"Vresina",2328,49.946431,18.191672 ],
    [ u"cz",u"Vsetaty",2001,50.28187,14.592122 ],
    [ u"cz",u"Vsetin",29302,49.341899,17.983582 ],
    [ u"cz",u"Vyskov",22549,49.278302,17.002565 ],
    [ u"cz",u"Vysoke Myto",12173,49.953254,16.154723 ],
    [ u"cz",u"Vyssi Brod",2547,48.617733,14.31264 ],
    [ u"cz",u"Zabreh",14574,49.884404,16.873092 ],
    [ u"cz",u"Zacler",3617,50.65811,15.908241 ],
    [ u"cz",u"Zakupy",2582,50.68491,14.646469 ],
    [ u"cz",u"Zamberk",6128,50.086091,16.463802 ],
    [ u"cz",u"Zasova",2738,49.476432,18.044408 ],
    [ u"cz",u"Zastavka",2350,49.2,16.366667 ],
    [ u"cz",u"Zatec",19961,50.326309,13.544673 ],
    [ u"cz",u"Zbiroh",2582,49.8565,13.769114 ],
    [ u"cz",u"Zbysov",3925,49.130834,16.806276 ],
    [ u"cz",u"Zdanice",2731,49.067259,17.0284 ],
    [ u"cz",u"Zdice",3936,49.914201,13.976926 ],
    [ u"cz",u"Zdounky",2018,49.229255,17.314168 ],
    [ u"cz",u"Zelezna Ruda",2009,49.137768,13.232492 ],
    [ u"cz",u"Zelezny Brod",6516,50.645106,15.255259 ],
    [ u"cz",u"Zidlochovice",3075,49.038068,16.614826 ],
    [ u"cz",u"Zirovnice",3043,49.252133,15.188454 ],
    [ u"cz",u"Zlate Hory",4489,50.260746,17.395136 ],
    [ u"cz",u"Zlin",81066,49.216667,17.666667 ],
    [ u"cz",u"Zliv",3679,49.066667,14.366667 ],
    [ u"cz",u"Zlonice",2261,50.286003,14.091592 ],
    [ u"cz",u"Zlutice",2854,50.090704,13.162844 ],
    [ u"cz",u"Znojmo",35791,48.856116,16.056412 ],
    [ u"cz",u"Zruc nad Sazavou",5175,49.744364,15.103751 ],
    [ u"de",u"Aachen",251104,50.770833,6.105278 ],
    [ u"de",u"Aalen",67593,48.833333,10.1 ],
    [ u"de",u"Abensberg",12543,48.816667,11.85 ],
    [ u"de",u"Achern",24272,48.633333,8.066667 ],
    [ u"de",u"Achim",30117,53.033333,9.016667 ],
    [ u"de",u"Adendorf",9917,53.283333,10.45 ],
    [ u"de",u"Aerzen",12114,52.033333,9.266667 ],
    [ u"de",u"Ahaus",38932,52.066667,7 ],
    [ u"de",u"Ahlen",55112,51.75,7.916667 ],
    [ u"de",u"Ahrensburg",30797,53.683333,10.25 ],
    [ u"de",u"Aichach",20935,48.466667,11.133333 ],
    [ u"de",u"Ainring",9852,47.816667,12.95 ],
    [ u"de",u"Aken",9350,51.85,12.05 ],
    [ u"de",u"Albstadt",47064,48.25,9.016667 ],
    [ u"de",u"Aldenhoven",14335,50.9,6.283333 ],
    [ u"de",u"Alfeld",21258,51.983333,9.833333 ],
    [ u"de",u"Alfter",22028,50.733333,7.016667 ],
    [ u"de",u"Alpen",12970,51.583333,6.516667 ],
    [ u"de",u"Alsdorf",46558,50.883333,6.166667 ],
    [ u"de",u"Alsfeld",17968,50.75,9.266667 ],
    [ u"de",u"Altdorf",11709,48.15,12.183333 ],
    [ u"de",u"Altena",20641,51.3,7.666667 ],
    [ u"de",u"Altenburg",38338,50.983333,12.45 ],
    [ u"de",u"Altenholz",9721,54.4,10.133333 ],
    [ u"de",u"Altenstadt",12388,50.283333,8.95 ],
    [ u"de",u"Altensteig",11122,48.583333,8.6 ],
    [ u"de",u"Altötting",12998,48.233333,12.683333 ],
    [ u"de",u"Altusried",10084,47.8,10.216667 ],
    [ u"de",u"Alzenau",19083,50.083333,9.066667 ],
    [ u"de",u"Alzey",17945,49.751667,8.116111 ],
    [ u"de",u"Amberg",44873,49.441389,11.862222 ],
    [ u"de",u"Andernach",29089,50.433333,7.4 ],
    [ u"de",u"Angermünde",18200,53.033333,14 ],
    [ u"de",u"Anklam",14533,53.866667,13.7 ],
    [ u"de",u"Annaberg-Buchholz",22849,50.566667,13 ],
    [ u"de",u"Anröchte",10981,51.566667,8.333333 ],
    [ u"de",u"Ansbach",40822,49.3,10.583333 ],
    [ u"de",u"Apen",11093,53.216667,7.8 ],
    [ u"de",u"Apolda",24380,51.016667,11.5 ],
    [ u"de",u"Arnsberg",77415,51.383333,8.083333 ],
    [ u"de",u"Arnstadt",25995,50.833333,10.95 ],
    [ u"de",u"Aschaffenburg",69248,49.973889,9.149167 ],
    [ u"de",u"Ascheberg",15327,51.783333,7.616667 ],
    [ u"de",u"Aschersleben",24569,51.75,11.466667 ],
    [ u"de",u"Asperg",12627,48.9,9.116667 ],
    [ u"de",u"Attendorn",25014,51.116667,7.9 ],
    [ u"de",u"Aue",18630,50.583333,12.7 ],
    [ u"de",u"Auerbach",25430,50.516667,12.4 ],
    [ u"de",u"Augsburg",261842,48.366667,10.883333 ],
    [ u"de",u"Augustdorf",10275,51.9,8.733333 ],
    [ u"de",u"Aurich",40987,53.466667,7.483333 ],
    [ u"de",u"Babenhausen",16551,49.966667,8.957778 ],
    [ u"de",u"Backnang",36477,48.95,9.433333 ],
    [ u"de",u"Bad Aibling",17926,47.866667,12 ],
    [ u"de",u"Bad Bentheim",15436,52.316667,7.166667 ],
    [ u"de",u"Bad Berleburg",20830,51.05,8.4 ],
    [ u"de",u"Bad Bevensen",8808,53.083333,10.583333 ],
    [ u"de",u"Bad Bramstedt",13303,53.916667,9.883333 ],
    [ u"de",u"Bad Camberg",13920,50.3,8.266667 ],
    [ u"de",u"Bad Doberan",11373,54.1,11.9 ],
    [ u"de",u"Bad Driburg",19743,51.733333,9.016667 ],
    [ u"de",u"Bad Dürkheim",18751,49.468611,8.166389 ],
    [ u"de",u"Bad Dürrenberg",11587,51.3,12.066667 ],
    [ u"de",u"Bad Dürrheim",12668,48.016667,8.533333 ],
    [ u"de",u"Bad Ems",9468,50.333333,7.716667 ],
    [ u"de",u"Baden-Baden",54802,48.75,8.25 ],
    [ u"de",u"Bad Essen",15858,52.316667,8.333333 ],
    [ u"de",u"Bad Frankenhausen",9102,51.35,11.1 ],
    [ u"de",u"Bad Freienwalde",15108,52.783333,14.033333 ],
    [ u"de",u"Bad Gandersheim",11100,51.866667,10.033333 ],
    [ u"de",u"Bad Harzburg",22670,51.883333,10.566667 ],
    [ u"de",u"Bad Hersfeld",30630,50.866667,9.7 ],
    [ u"de",u"Bad Homburg",51923,50.216667,8.616667 ],
    [ u"de",u"Bad Iburg",11790,52.15,8.05 ],
    [ u"de",u"Bad Kissingen",21527,50.2,10.083333 ],
    [ u"de",u"Bad Kreuznach",43317,49.833333,7.866667 ],
    [ u"de",u"Bad Krozingen",16051,47.916272,7.700622 ],
    [ u"de",u"Bad Laasphe",15268,50.933333,8.4 ],
    [ u"de",u"Bad Laer",9514,52.1,8.083333 ],
    [ u"de",u"Bad Langensalza",20144,51.1,10.65 ],
    [ u"de",u"Bad Lauterberg",11813,51.65,10.466667 ],
    [ u"de",u"Bad Liebenwerda",10880,51.516667,13.4 ],
    [ u"de",u"Bad Liebenzell",9665,48.766667,8.733333 ],
    [ u"de",u"Bad Lippspringe",15054,51.783333,8.816667 ],
    [ u"de",u"Bad Mergentheim",22072,49.4925,9.773611 ],
    [ u"de",u"Bad Münder",18692,52.2,9.466667 ],
    [ u"de",u"Bad Münstereifel",19166,50.55,6.766667 ],
    [ u"de",u"Bad Nauheim",30369,50.366667,8.75 ],
    [ u"de",u"Bad Nenndorf",10323,52.333333,9.366667 ],
    [ u"de",u"Bad Neuenahr-Ahrweiler",27972,50.55,7.1 ],
    [ u"de",u"Bad Neustadt",16268,50.333333,10.216667 ],
    [ u"de",u"Bad Oeynhausen",49698,52.2,8.8 ],
    [ u"de",u"Bad Oldesloe",23982,53.816667,10.383333 ],
    [ u"de",u"Bad Orb",10051,50.216667,9.35 ],
    [ u"de",u"Bad Pyrmont",21741,51.983333,9.25 ],
    [ u"de",u"Bad Rappenau",20868,49.240556,9.1025 ],
    [ u"de",u"Bad Reichenhall",16823,47.733333,12.883333 ],
    [ u"de",u"Bad Sachsa",8245,51.6,10.55 ],
    [ u"de",u"Bad Säckingen",16483,47.55,7.95 ],
    [ u"de",u"Bad Salzdetfurth",14590,52.05,10 ],
    [ u"de",u"Bad Salzuflen",55348,52.083333,8.766667 ],
    [ u"de",u"Bad Salzungen",16610,50.816667,10.233333 ],
    [ u"de",u"Bad Sassendorf",11552,51.583333,8.166667 ],
    [ u"de",u"Bad Schwalbach",11259,50.133333,8.066667 ],
    [ u"de",u"Bad Schwartau",20052,53.916667,10.7 ],
    [ u"de",u"Bad Segeberg",16097,53.933333,10.316667 ],
    [ u"de",u"Bad Soden",21418,50.133333,8.5 ],
    [ u"de",u"Bad Soden-Salmünster",13960,50.283333,9.366667 ],
    [ u"de",u"Bad Sooden-Allendorf",8955,51.283333,9.983333 ],
    [ u"de",u"Bad Tölz",17378,47.766667,11.566667 ],
    [ u"de",u"Bad Urach",13007,48.5,9.4 ],
    [ u"de",u"Bad Vilbel",30933,50.183333,8.75 ],
    [ u"de",u"Bad Waldsee",19749,47.916667,9.766667 ],
    [ u"de",u"Bad Wildbad",11411,48.75,8.55 ],
    [ u"de",u"Bad Wildungen",18078,51.116667,9.116667 ],
    [ u"de",u"Bad Windsheim",12033,49.5,10.416667 ],
    [ u"de",u"Bad Wörishofen",13922,48.016667,10.6 ],
    [ u"de",u"Bad Wurzach",14288,47.9,9.9 ],
    [ u"de",u"Bad Zwischenahn",26641,53.183333,8 ],
    [ u"de",u"Baesweiler",27865,50.9,6.183333 ],
    [ u"de",u"Baiersbronn",16156,48.5,8.383333 ],
    [ u"de",u"Balingen",34680,48.283333,8.85 ],
    [ u"de",u"Balve",12288,51.333333,7.866667 ],
    [ u"de",u"Bamberg",70471,49.866667,10.866667 ],
    [ u"de",u"Bargteheide",14123,53.733333,10.266667 ],
    [ u"de",u"Barmstedt",9558,53.783333,9.766667 ],
    [ u"de",u"Barntrup",9666,51.983333,9.116667 ],
    [ u"de",u"Barsbüttel",12395,53.566667,10.166667 ],
    [ u"de",u"Barsinghausen",34322,52.3,9.45 ],
    [ u"de",u"Barth",9344,54.366667,12.733333 ],
    [ u"de",u"Bassum",16204,52.85,8.733333 ],
    [ u"de",u"Baunatal",28338,51.25,9.416667 ],
    [ u"de",u"Bautzen",41606,51.183333,14.433333 ],
    [ u"de",u"Bayreuth",74840,49.948056,11.578333 ],
    [ u"de",u"Bebra",14798,50.966667,9.8 ],
    [ u"de",u"Beckingen",15959,49.4,6.7 ],
    [ u"de",u"Beckum",37914,51.75,8.033333 ],
    [ u"de",u"Bedburg",25224,51,6.583333 ],
    [ u"de",u"Beeskow",8547,52.166667,14.25 ],
    [ u"de",u"Belm",14073,52.3,8.133333 ],
    [ u"de",u"Bendorf",17224,50.433333,7.566667 ],
    [ u"de",u"Bensheim",39450,49.680278,8.616111 ],
    [ u"de",u"Bergen",13586,52.816667,9.966667 ],
    [ u"de",u"Bergen",14621,54.416667,13.433333 ],
    [ u"de",u"Bergheim",64082,50.966667,6.65 ],
    [ u"de",u"Bergisch Gladbach",106611,50.983333,7.133333 ],
    [ u"de",u"Bergkamen",52670,51.633333,7.633333 ],
    [ u"de",u"Bergneustadt",20865,51.033333,7.65 ],
    [ u"de",u"Berlin",3398362,52.516667,13.4 ],
    [ u"de",u"Bernau",33481,52.666667,13.583333 ],
    [ u"de",u"Bernburg",32859,51.8,11.733333 ],
    [ u"de",u"Besigheim",11667,48.983333,9.133333 ],
    [ u"de",u"Bestwig",11819,51.366667,8.4 ],
    [ u"de",u"Betzdorf",10615,50.783333,7.883333 ],
    [ u"de",u"Beverungen",15230,51.666667,9.366667 ],
    [ u"de",u"Bexbach",19372,49.333333,7.266667 ],
    [ u"de",u"Biberach",32501,48.1,9.8 ],
    [ u"de",u"Biblis",8824,49.691667,8.458611 ],
    [ u"de",u"Biedenkopf",13736,50.916667,8.533333 ],
    [ u"de",u"Bielefeld",327198,52.033333,8.533333 ],
    [ u"de",u"Bietigheim-Bissingen",41979,48.966667,9.133333 ],
    [ u"de",u"Billerbeck",11578,51.966667,7.3 ],
    [ u"de",u"Bingen",24844,49.966667,7.9 ],
    [ u"de",u"Birkenau",10406,49.5625,8.706944 ],
    [ u"de",u"Birkenfeld",10444,48.866667,8.633333 ],
    [ u"de",u"Bischofsheim",12114,49.993889,8.367222 ],
    [ u"de",u"Bischofswerda",13577,51.116667,14.183333 ],
    [ u"de",u"Bissendorf",14431,52.233333,8.166667 ],
    [ u"de",u"Bitburg",13154,49.966667,6.533333 ],
    [ u"de",u"Bitterfeld",15486,51.616667,12.316667 ],
    [ u"de",u"Blankenburg",15887,51.783333,10.95 ],
    [ u"de",u"Blaubeuren",11900,48.4,9.783333 ],
    [ u"de",u"Blieskastel",22938,49.233333,7.25 ],
    [ u"de",u"Blomberg",17295,51.933333,9.083333 ],
    [ u"de",u"Blumberg",10666,47.833333,8.533333 ],
    [ u"de",u"Bobenheim-Roxheim",10129,49.5875,8.357778 ],
    [ u"de",u"Bobingen",16595,48.266667,10.833333 ],
    [ u"de",u"Böblingen",46830,48.683333,9.016667 ],
    [ u"de",u"Bocholt",73872,51.833333,6.6 ],
    [ u"de",u"Bochum",387061,51.483333,7.216667 ],
    [ u"de",u"Bockenem",11328,52.016667,10.133333 ],
    [ u"de",u"Bogen",10458,48.916667,12.683333 ],
    [ u"de",u"Böhl-Iggelheim",10694,49.380556,8.303889 ],
    [ u"de",u"Bohmte",13432,52.366667,8.316667 ],
    [ u"de",u"Boizenburg",10634,53.383333,10.716667 ],
    [ u"de",u"Bönen",18950,51.6,7.766667 ],
    [ u"de",u"Bonn",314081,50.733333,7.1 ],
    [ u"de",u"Bopfingen",12669,48.85,10.35 ],
    [ u"de",u"Boppard",16606,50.233333,7.6 ],
    [ u"de",u"Borgentreich",9813,51.566667,9.25 ],
    [ u"de",u"Borken",13656,51.05,9.283333 ],
    [ u"de",u"Borken",41179,51.85,6.866667 ],
    [ u"de",u"Borna",18504,51.116667,12.5 ],
    [ u"de",u"Bornheim",49126,50.766667,7 ],
    [ u"de",u"Bottrop",120829,51.516667,6.916667 ],
    [ u"de",u"Bovenden",13376,51.583333,9.933333 ],
    [ u"de",u"Brackenheim",15031,49.079722,9.065 ],
    [ u"de",u"Brake",16199,53.333333,8.483333 ],
    [ u"de",u"Brakel",17782,51.716667,9.183333 ],
    [ u"de",u"Bramsche",28773,52.4,7.983333 ],
    [ u"de",u"Brandenburg",75507,52.416667,12.55 ],
    [ u"de",u"Brand-Erbisdorf",12098,50.866667,13.333333 ],
    [ u"de",u"Braunfels",11398,50.516667,8.4 ],
    [ u"de",u"Breisach",14083,48.032791,7.582937 ],
    [ u"de",u"Bremen",546429,53.083333,8.8 ],
    [ u"de",u"Bremerhaven",119688,53.55,8.583333 ],
    [ u"de",u"Bremervörde",18983,53.483333,9.133333 ],
    [ u"de",u"Bretten",28774,49.039167,8.702778 ],
    [ u"de",u"Bretzfeld",12223,49.179444,9.438333 ],
    [ u"de",u"Brilon",27186,51.4,8.583333 ],
    [ u"de",u"Bruchköbel",20820,50.183333,8.916667 ],
    [ u"de",u"Bruchsal",43615,49.128056,8.583611 ],
    [ u"de",u"Bruckmühl",16178,47.883333,11.916667 ],
    [ u"de",u"Brüggen",16224,51.25,6.183333 ],
    [ u"de",u"Brühl",14344,49.397222,8.533611 ],
    [ u"de",u"Brühl",44588,50.833333,6.9 ],
    [ u"de",u"Brunsbüttel",13840,53.9,9.15 ],
    [ u"de",u"Brunswick",245259,52.266667,10.533333 ],
    [ u"de",u"Buchen",19276,49.523889,9.323056 ],
    [ u"de",u"Buchloe",11997,48.033333,10.733333 ],
    [ u"de",u"Bückeburg",21077,52.266667,9.05 ],
    [ u"de",u"Büdelsdorf",10060,54.316667,9.683333 ],
    [ u"de",u"Büdingen",22157,50.3,9.116667 ],
    [ u"de",u"Bühl",29434,48.7,8.15 ],
    [ u"de",u"Bünde",45389,52.2,8.583333 ],
    [ u"de",u"Burbach",14984,50.75,8.083333 ],
    [ u"de",u"Büren",22703,51.55,8.566667 ],
    [ u"de",u"Burg",28602,52.266667,11.85 ],
    [ u"de",u"Burgdorf",30288,52.45,10.016667 ],
    [ u"de",u"Burghausen",18376,48.166667,12.833333 ],
    [ u"de",u"Burgkirchen",10795,48.166667,12.733333 ],
    [ u"de",u"Burglengenfeld",12098,49.205556,12.041389 ],
    [ u"de",u"Burgstädt",12506,50.916667,12.816667 ],
    [ u"de",u"Burgthann",11615,49.35,11.3 ],
    [ u"de",u"Burladingen",13249,48.283333,9.116667 ],
    [ u"de",u"Burscheid",19579,51.1,7.116667 ],
    [ u"de",u"Bürstadt",15365,49.643611,8.46 ],
    [ u"de",u"Büttelborn",13326,49.903333,8.523333 ],
    [ u"de",u"Butzbach",25804,50.433333,8.683333 ],
    [ u"de",u"Bützow",8163,53.85,11.983333 ],
    [ u"de",u"Buxtehude",38236,53.45,9.7 ],
    [ u"de",u"Cadolzburg",10188,49.45,10.866667 ],
    [ u"de",u"Calbe",11666,51.9,11.766667 ],
    [ u"de",u"Calw",24220,48.716667,8.733333 ],
    [ u"de",u"Castrop-Rauxel",78587,51.55,7.316667 ],
    [ u"de",u"Celle",71106,52.616667,10.083333 ],
    [ u"de",u"Cham",17393,49.225556,12.663611 ],
    [ u"de",u"Chemnitz",246654,50.833333,12.916667 ],
    [ u"de",u"Clausthal-Zellerfeld",15082,51.8,10.333333 ],
    [ u"de",u"Cleves",49448,51.783333,6.15 ],
    [ u"de",u"Cloppenburg",31030,52.85,8.033333 ],
    [ u"de",u"Coburg",42413,50.25,10.966667 ],
    [ u"de",u"Coesfeld",36929,51.933333,7.15 ],
    [ u"de",u"Cologne",968823,50.933333,6.95 ],
    [ u"de",u"Coswig",21965,51.133333,13.583333 ],
    [ u"de",u"Coswig",8729,51.883333,12.45 ],
    [ u"de",u"Cottbus",115246,51.766667,14.333333 ],
    [ u"de",u"Crailsheim",32666,49.15,10.083333 ],
    [ u"de",u"Cremlingen",12811,52.25,10.65 ],
    [ u"de",u"Crimmitschau",22410,50.816667,12.383333 ],
    [ u"de",u"Cuxhaven",52873,53.883333,8.7 ],
    [ u"de",u"Dachau",39815,48.266667,11.433333 ],
    [ u"de",u"Damme",16236,52.516667,8.2 ],
    [ u"de",u"Dannenberg",8612,53.1,11.1 ],
    [ u"de",u"Darmstadt",139757,49.870556,8.649444 ],
    [ u"de",u"Dassel",11319,51.8,9.683333 ],
    [ u"de",u"Datteln",37130,51.666667,7.383333 ],
    [ u"de",u"Deggendorf",31146,48.833333,12.966667 ],
    [ u"de",u"Delbrück",30699,51.766667,8.566667 ],
    [ u"de",u"Delitzsch",25160,51.533333,12.35 ],
    [ u"de",u"Delmenhorst",75740,53.05,8.616667 ],
    [ u"de",u"Demmin",12263,53.9,13.033333 ],
    [ u"de",u"Denkendorf",10096,48.683333,9.316667 ],
    [ u"de",u"Denzlingen",13388,48.066667,7.883333 ],
    [ u"de",u"Dessau",76628,51.833333,12.25 ],
    [ u"de",u"Detmold",74853,51.933333,8.883333 ],
    [ u"de",u"Dettingen",9282,48.533333,9.35 ],
    [ u"de",u"Dieburg",15452,49.898889,8.844444 ],
    [ u"de",u"Diedorf",10348,48.35,10.766667 ],
    [ u"de",u"Diepholz",16874,52.6,8.366667 ],
    [ u"de",u"Dietzenbach",32975,50.016667,8.783333 ],
    [ u"de",u"Diez",11065,50.366667,8.016667 ],
    [ u"de",u"Dillenburg",24772,50.733333,8.283333 ],
    [ u"de",u"Dillingen",19013,48.566667,10.483333 ],
    [ u"de",u"Dillingen",21451,49.35,6.733333 ],
    [ u"de",u"Dingolfing",18733,48.633333,12.5 ],
    [ u"de",u"Dinkelsbühl",11581,49.066667,10.316667 ],
    [ u"de",u"Dinklage",12802,52.65,8.116667 ],
    [ u"de",u"Dinslaken",71632,51.566667,6.733333 ],
    [ u"de",u"Ditzingen",24255,48.833333,9.066667 ],
    [ u"de",u"Döbeln",21318,51.116667,13.116667 ],
    [ u"de",u"Donaueschingen",21699,47.95,8.5 ],
    [ u"de",u"Donauwörth",18550,48.7,10.8 ],
    [ u"de",u"Donzdorf",11038,48.683333,9.816667 ],
    [ u"de",u"Dorfen",13425,48.266667,12.15 ],
    [ u"de",u"Dormagen",64129,51.1,6.833333 ],
    [ u"de",u"Dornstadt",8374,48.466667,9.95 ],
    [ u"de",u"Dorsten",80180,51.666667,6.966667 ],
    [ u"de",u"Dortmund",594255,51.516667,7.45 ],
    [ u"de",u"Dörverden",9805,52.85,9.233333 ],
    [ u"de",u"Dossenheim",11794,49.450278,8.674722 ],
    [ u"de",u"Dreieich",41054,50,8.7 ],
    [ u"de",u"Drensteinfurt",15234,51.8,7.75 ],
    [ u"de",u"Dresden",480801,51.05,13.75 ],
    [ u"de",u"Drochtersen",12404,53.7,9.383333 ],
    [ u"de",u"Drolshagen",12438,51.016667,7.766667 ],
    [ u"de",u"Duderstadt",22842,51.516667,10.266667 ],
    [ u"de",u"Duisburg",505271,51.433333,6.75 ],
    [ u"de",u"Dülmen",47899,51.833333,7.3 ],
    [ u"de",u"Düren",92956,50.8,6.483333 ],
    [ u"de",u"Durmersheim",11742,48.933333,8.266667 ],
    [ u"de",u"Düsseldorf",577139,51.216667,6.766667 ],
    [ u"de",u"Eberbach",15526,49.469444,8.992778 ],
    [ u"de",u"Ebersbach",16143,48.716667,9.533333 ],
    [ u"de",u"Ebersbach",9056,51.016667,14.583333 ],
    [ u"de",u"Ebersberg",11082,48.083333,11.966667 ],
    [ u"de",u"Eberswalde",41384,52.833333,13.833333 ],
    [ u"de",u"Eching",13247,48.3,11.616667 ],
    [ u"de",u"Eckernförde",23184,54.466667,9.833333 ],
    [ u"de",u"Edemissen",12838,52.383333,10.266667 ],
    [ u"de",u"Edewecht",20519,53.133333,7.983333 ],
    [ u"de",u"Edingen-Neckarhausen",13935,49.457222,8.606389 ],
    [ u"de",u"Egelsbach",9703,49.971111,8.670278 ],
    [ u"de",u"Eggenfelden",12988,48.4,12.766667 ],
    [ u"de",u"Eggenstein-Leopoldshafen",15222,49.095278,8.390556 ],
    [ u"de",u"Ehingen",26154,48.283333,9.733333 ],
    [ u"de",u"Eichenau",11614,48.166667,11.316667 ],
    [ u"de",u"Eichenzell",10708,50.483333,9.7 ],
    [ u"de",u"Eichstätt",13166,48.883333,11.183333 ],
    [ u"de",u"Eilenburg",17120,51.466667,12.616667 ],
    [ u"de",u"Einbeck",28179,51.816667,9.866667 ],
    [ u"de",u"Eisenach",44399,50.983333,10.316667 ],
    [ u"de",u"Eisenberg",9970,49.565833,8.07 ],
    [ u"de",u"Eisenberg",11616,50.966667,11.9 ],
    [ u"de",u"Eisenhüttenstadt",35839,52.15,14.65 ],
    [ u"de",u"Eislingen",20343,48.7,9.7 ],
    [ u"de",u"Eitorf",19867,50.766667,7.45 ],
    [ u"de",u"Ellwangen",25396,48.966667,10.133333 ],
    [ u"de",u"Elmshorn",48744,53.75,9.65 ],
    [ u"de",u"Elsdorf",21901,50.933333,6.566667 ],
    [ u"de",u"Elsfleth",9286,53.233333,8.466667 ],
    [ u"de",u"Elsterwerda",9714,51.45,13.533333 ],
    [ u"de",u"Eltville",16858,50.033333,8.116667 ],
    [ u"de",u"Elze",9686,52.116667,9.733333 ],
    [ u"de",u"Emden",51639,53.366667,7.216667 ],
    [ u"de",u"Emmendingen",26820,48.133333,7.85 ],
    [ u"de",u"Emmerich",29753,51.833333,6.25 ],
    [ u"de",u"Emsdetten",35383,52.183333,7.533333 ],
    [ u"de",u"Engelskirchen",20883,50.983333,7.4 ],
    [ u"de",u"Engen",10195,47.85,8.766667 ],
    [ u"de",u"Enger",20417,52.133333,8.566667 ],
    [ u"de",u"Eningen",10715,48.483333,9.25 ],
    [ u"de",u"Ennepetal",32426,51.3,7.35 ],
    [ u"de",u"Ennigerloh",20678,51.833333,8.016667 ],
    [ u"de",u"Eppelborn",18400,49.4,6.966667 ],
    [ u"de",u"Eppelheim",14647,49.4025,8.633056 ],
    [ u"de",u"Eppingen",21457,49.136944,8.910278 ],
    [ u"de",u"Eppstein",13512,50.133333,8.4 ],
    [ u"de",u"Erbach",13238,48.333333,9.883333 ],
    [ u"de",u"Erbach",13501,49.656111,8.996389 ],
    [ u"de",u"Erding",32377,48.3,11.933333 ],
    [ u"de",u"Erftstadt",51606,50.816667,6.766667 ],
    [ u"de",u"Erfurt",196719,50.983333,11.033333 ],
    [ u"de",u"Ergolding",11513,48.583333,12.166667 ],
    [ u"de",u"Erkelenz",44479,51.083333,6.316667 ],
    [ u"de",u"Erkner",11866,52.416667,13.75 ],
    [ u"de",u"Erkrath",47908,51.216667,6.9 ],
    [ u"de",u"Erlangen",102781,49.589722,11.003889 ],
    [ u"de",u"Erlenbach",10095,49.803889,9.163889 ],
    [ u"de",u"Erlensee",12407,50.15,8.95 ],
    [ u"de",u"Erwitte",16097,51.616667,8.35 ],
    [ u"de",u"Eschborn",20438,50.133333,8.55 ],
    [ u"de",u"Eschwege",21546,51.183333,10.066667 ],
    [ u"de",u"Eschweiler",55888,50.816667,6.283333 ],
    [ u"de",u"Espelkamp",26684,52.383333,8.616667 ],
    [ u"de",u"Essenbach",11013,48.616667,12.216667 ],
    [ u"de",u"Essen",576914,51.45,7.016667 ],
    [ u"de",u"Esslingen",92710,48.75,9.3 ],
    [ u"de",u"Ettenheim",11956,48.25,7.816667 ],
    [ u"de",u"Ettlingen",39635,48.95,8.4 ],
    [ u"de",u"Euskirchen",54855,50.666667,6.783333 ],
    [ u"de",u"Eutin",17258,54.133333,10.616667 ],
    [ u"de",u"Falkensee",37916,52.566667,13.083333 ],
    [ u"de",u"Falkenstein",9859,50.483333,12.366667 ],
    [ u"de",u"Fallingbostel",13639,52.866667,9.7 ],
    [ u"de",u"Feldkirchen-Westerham",10177,47.9,11.85 ],
    [ u"de",u"Fellbach",44142,48.8,9.283333 ],
    [ u"de",u"Felsberg",11244,51.133333,9.416667 ],
    [ u"de",u"Feucht",13585,49.376667,11.213889 ],
    [ u"de",u"Feuchtwangen",12207,49.166667,10.333333 ],
    [ u"de",u"Filderstadt",43580,48.666667,9.216667 ],
    [ u"de",u"Finnentrop",18466,51.166667,7.966667 ],
    [ u"de",u"Finsterwalde",18733,51.633333,13.716667 ],
    [ u"de",u"Flensburg",85158,54.783333,9.433333 ],
    [ u"de",u"Flöha",11427,50.866667,13.066667 ],
    [ u"de",u"Flörsheim",19936,50.016667,8.433333 ],
    [ u"de",u"Forchheim",30838,49.723056,11.066944 ],
    [ u"de",u"Forst",22521,51.733333,14.633333 ],
    [ u"de",u"Frankenberg",19366,51.066667,8.8 ],
    [ u"de",u"Frankenberg",16819,50.916667,13.033333 ],
    [ u"de",u"Frankenthal",47523,49.537222,8.355 ],
    [ u"de",u"Frankfurt",648034,50.116667,8.683333 ],
    [ u"de",u"Frankfurt",64399,52.35,14.55 ],
    [ u"de",u"Frechen",48198,50.916667,6.816667 ],
    [ u"de",u"Freiberg",15517,48.933333,9.2 ],
    [ u"de",u"Freiberg",43160,50.916667,13.366667 ],
    [ u"de",u"Freiburg",213920,48,7.85 ],
    [ u"de",u"Freilassing",16033,47.85,12.983333 ],
    [ u"de",u"Freising",42322,48.4,11.733333 ],
    [ u"de",u"Freital",38815,51.016667,13.65 ],
    [ u"de",u"Freudenberg",18440,50.9,7.866667 ],
    [ u"de",u"Freudenstadt",24384,48.433333,8.416667 ],
    [ u"de",u"Frickenhausen",8917,48.6,9.366667 ],
    [ u"de",u"Friedberg",29581,48.35,10.983333 ],
    [ u"de",u"Friedberg",28164,50.35,8.766667 ],
    [ u"de",u"Friedeburg",10822,53.45,7.833333 ],
    [ u"de",u"Friedland",10472,51.416667,9.933333 ],
    [ u"de",u"Friedrichsdorf",24897,50.266667,8.65 ],
    [ u"de",u"Friedrichshafen",58005,47.65,9.483333 ],
    [ u"de",u"Friedrichsthal",11425,49.316667,7.1 ],
    [ u"de",u"Friesenheim",12616,49.498333,8.422778 ],
    [ u"de",u"Friesoythe",20178,53.016667,7.85 ],
    [ u"de",u"Fritzlar",14798,51.133333,9.283333 ],
    [ u"de",u"Fröndenberg",23499,51.466667,7.766667 ],
    [ u"de",u"Fuldabrück",9098,51.266667,9.483333 ],
    [ u"de",u"Fulda",63851,50.55,9.666667 ],
    [ u"de",u"Fuldatal",12102,51.383333,9.566667 ],
    [ u"de",u"Fürstenfeldbruck",34194,48.183333,11.25 ],
    [ u"de",u"Fürstenwalde",33199,52.366667,14.066667 ],
    [ u"de",u"Fürth",112959,49.466667,10.966667 ],
    [ u"de",u"Furth im Wald",9400,49.309722,12.84 ],
    [ u"de",u"Furtwangen",9763,48.05,8.2 ],
    [ u"de",u"Füssen",14002,47.566667,10.7 ],
    [ u"de",u"Gaggenau",29800,48.8,8.333333 ],
    [ u"de",u"Gaildorf",12683,49.003889,9.771111 ],
    [ u"de",u"Gaimersheim",10998,48.816667,11.366667 ],
    [ u"de",u"Ganderkesee",31262,53.033333,8.533333 ],
    [ u"de",u"Gangelt",11647,50.983333,6 ],
    [ u"de",u"Garbsen",63354,52.416667,9.6 ],
    [ u"de",u"Garching",15380,48.25,11.65 ],
    [ u"de",u"Gardelegen",11771,52.533333,11.366667 ],
    [ u"de",u"Garmisch-Partenkirchen",26346,47.5,11.1 ],
    [ u"de",u"Garrel",12515,52.95,8.016667 ],
    [ u"de",u"Gärtringen",11438,48.65,8.9 ],
    [ u"de",u"Gauting",19381,48.066667,11.366667 ],
    [ u"de",u"Geeste",11456,52.6,7.266667 ],
    [ u"de",u"Geesthacht",29853,53.433333,10.366667 ],
    [ u"de",u"Gehrden",15139,52.316667,9.6 ],
    [ u"de",u"Geilenkirchen",28587,50.966667,6.116667 ],
    [ u"de",u"Geisenheim",11959,49.983333,7.966667 ],
    [ u"de",u"Geldern",34291,51.516667,6.333333 ],
    [ u"de",u"Gelnhausen",21417,50.2,9.183333 ],
    [ u"de",u"Gelsenkirchen",271647,51.516667,7.05 ],
    [ u"de",u"Gemünden",11560,50.05,9.7 ],
    [ u"de",u"Gengenbach",11035,48.4,8.016667 ],
    [ u"de",u"Genthin",14573,52.4,12.166667 ],
    [ u"de",u"Georgsmarienhütte",32945,52.2,8.05 ],
    [ u"de",u"Gera",104463,50.866667,12.083333 ],
    [ u"de",u"Geretsried",23377,47.866667,11.466667 ],
    [ u"de",u"Gerlingen",18977,48.8,9.066667 ],
    [ u"de",u"Germering",36905,48.133333,11.366667 ],
    [ u"de",u"Germersheim",20706,49.223056,8.363889 ],
    [ u"de",u"Gernsbach",14548,48.766667,8.333333 ],
    [ u"de",u"Gernsheim",9435,49.76,8.495833 ],
    [ u"de",u"Gerstetten",12407,48.633333,10.033333 ],
    [ u"de",u"Gersthofen",20322,48.416667,10.883333 ],
    [ u"de",u"Gescher",16937,51.95,7.016667 ],
    [ u"de",u"Geseke",20790,51.65,8.516667 ],
    [ u"de",u"Gevelsberg",32978,51.316667,7.333333 ],
    [ u"de",u"Giengen",20211,48.616667,10.25 ],
    [ u"de",u"Gifhorn",42699,52.483333,10.55 ],
    [ u"de",u"Gilching",17204,48.116667,11.3 ],
    [ u"de",u"Ginsheim-Gustavsburg",16283,49.985833,8.3425 ],
    [ u"de",u"Gladbeck",77264,51.566667,6.983333 ],
    [ u"de",u"Gladenbach",12613,50.766667,8.566667 ],
    [ u"de",u"Glauchau",26260,50.816667,12.533333 ],
    [ u"de",u"Glinde",16106,53.55,10.2 ],
    [ u"de",u"Glückstadt",11976,53.783333,9.416667 ],
    [ u"de",u"Goch",34045,51.666667,6.166667 ],
    [ u"de",u"Goldbach",10038,49.988889,9.186389 ],
    [ u"de",u"Göppingen",58021,48.7,9.666667 ],
    [ u"de",u"Görlitz",57097,51.166667,15 ],
    [ u"de",u"Goslar",43461,51.9,10.433333 ],
    [ u"de",u"Gotha",47214,50.95,10.716667 ],
    [ u"de",u"Göttingen",123570,51.533333,9.933333 ],
    [ u"de",u"Gottmadingen",10242,47.733333,8.783333 ],
    [ u"de",u"Graben-Neudorf",11683,49.170278,8.487778 ],
    [ u"de",u"Gräfelfing",12992,48.1,11.45 ],
    [ u"de",u"Grafenau",9180,48.85,13.4 ],
    [ u"de",u"Gräfenhainichen",8026,51.733333,12.45 ],
    [ u"de",u"Grafing",12469,48.05,11.966667 ],
    [ u"de",u"Grefrath",16167,51.3,6.316667 ],
    [ u"de",u"Greifswald",51935,54.1,13.383333 ],
    [ u"de",u"Greiz",23931,50.65,12.2 ],
    [ u"de",u"Grenzach-Wyhlen",13994,47.552573,7.660567 ],
    [ u"de",u"Grevenbroich",64851,51.083333,6.583333 ],
    [ u"de",u"Greven",35732,52.1,7.616667 ],
    [ u"de",u"Grevesmühlen",10993,53.866667,11.183333 ],
    [ u"de",u"Griesheim",25432,49.862778,8.575278 ],
    [ u"de",u"Grimma",17780,51.233333,12.716667 ],
    [ u"de",u"Grimmen",10764,54.1,13.05 ],
    [ u"de",u"Gröbenzell",19181,48.2,11.366667 ],
    [ u"de",u"Gröditz",8086,51.416667,13.45 ],
    [ u"de",u"Gronau",46061,52.2,7.033333 ],
    [ u"de",u"Grünberg",14360,50.6,8.95 ],
    [ u"de",u"Grünstadt",13219,49.569167,8.168056 ],
    [ u"de",u"Grünwald",11173,48.05,11.516667 ],
    [ u"de",u"Guben",21602,51.95,14.716667 ],
    [ u"de",u"Gummersbach",53244,51.033333,7.55 ],
    [ u"de",u"Gundelfingen",11475,48.05,7.866667 ],
    [ u"de",u"Günzburg",19507,48.45,10.266667 ],
    [ u"de",u"Gunzenhausen",16666,49.1,10.75 ],
    [ u"de",u"Güstrow",30869,53.8,12.166667 ],
    [ u"de",u"Gütersloh",96332,51.9,8.383333 ],
    [ u"de",u"Haan",29369,51.2,7 ],
    [ u"de",u"Haar",17810,48.1,11.733333 ],
    [ u"de",u"Hagen",14349,52.2,7.983333 ],
    [ u"de",u"Hagen",199497,51.35,7.466667 ],
    [ u"de",u"Hagenow",12253,53.433333,11.183333 ],
    [ u"de",u"Haiger",20134,50.75,8.216667 ],
    [ u"de",u"Haigerloch",11066,48.366667,8.8 ],
    [ u"de",u"Hainichen",9628,50.966667,13.116667 ],
    [ u"de",u"Halberstadt",39391,51.9,11.05 ],
    [ u"de",u"Haldensleben",20131,52.3,11.416667 ],
    [ u"de",u"Halle",20921,52.066667,8.366667 ],
    [ u"de",u"Halle",232452,51.5,12 ],
    [ u"de",u"Halstenbek",16074,53.633333,9.85 ],
    [ u"de",u"Haltern",38212,51.733333,7.183333 ],
    [ u"de",u"Halver",17660,51.2,7.483333 ],
    [ u"de",u"Hamburg",1733846,53.55,10 ],
    [ u"de",u"Hameln",59349,52.1,9.35 ],
    [ u"de",u"Hammelburg",11798,50.116667,9.9 ],
    [ u"de",u"Hamm",186289,51.683333,7.8 ],
    [ u"de",u"Hamminkeln",27755,51.733333,6.583333 ],
    [ u"de",u"Hanau",89938,50.133333,8.916667 ],
    [ u"de",u"Hannoversch Münden",25612,51.416667,9.683333 ],
    [ u"de",u"Hanover",519144,52.366667,9.716667 ],
    [ u"de",u"Haren",23038,52.783333,7.233333 ],
    [ u"de",u"Harrislee",11600,54.8,9.383333 ],
    [ u"de",u"Harsewinkel",23910,51.966667,8.233333 ],
    [ u"de",u"Harsum",12401,52.216667,9.966667 ],
    [ u"de",u"Hasbergen",10863,52.233333,7.933333 ],
    [ u"de",u"Haselünne",12748,52.666667,7.483333 ],
    [ u"de",u"Hatten",13342,53.016667,8.35 ],
    [ u"de",u"Hattersheim",25544,50.066667,8.466667 ],
    [ u"de",u"Hattingen",58076,51.4,7.166667 ],
    [ u"de",u"Hauzenberg",12471,48.65,13.633333 ],
    [ u"de",u"Havixbeck",12249,51.983333,7.416667 ],
    [ u"de",u"Hechingen",19671,48.35,8.983333 ],
    [ u"de",u"Heddesheim",11673,49.505556,8.603611 ],
    [ u"de",u"Heide",20309,54.2,9.1 ],
    [ u"de",u"Heidelberg",144703,49.416667,8.7 ],
    [ u"de",u"Heidenau",16719,50.983333,13.866667 ],
    [ u"de",u"Heidenheim",50684,48.683333,10.15 ],
    [ u"de",u"Heilbad Heiligenstadt",17056,51.383333,10.133333 ],
    [ u"de",u"Heilbronn",121822,49.140278,9.22 ],
    [ u"de",u"Heiligenhafen",9328,54.366667,10.983333 ],
    [ u"de",u"Heiligenhaus",28312,51.316667,6.966667 ],
    [ u"de",u"Heinsberg",42409,51.066667,6.083333 ],
    [ u"de",u"Helmbrechts",9539,50.233333,11.7 ],
    [ u"de",u"Helmstedt",25686,52.233333,11 ],
    [ u"de",u"Hemer",39288,51.383333,7.766667 ],
    [ u"de",u"Hemmingen",18956,52.316667,9.75 ],
    [ u"de",u"Hemsbach",12442,49.591667,8.646389 ],
    [ u"de",u"Hennef",45829,50.783333,7.283333 ],
    [ u"de",u"Hennigsdorf",26498,52.633333,13.2 ],
    [ u"de",u"Henstedt-Ulzburg",26062,53.783333,10 ],
    [ u"de",u"Heppenheim",25580,49.640833,8.637222 ],
    [ u"de",u"Herborn",21404,50.683333,8.316667 ],
    [ u"de",u"Herbrechtingen",13244,48.616667,10.183333 ],
    [ u"de",u"Herdecke",25954,51.4,7.433333 ],
    [ u"de",u"Herford",65834,52.133333,8.683333 ],
    [ u"de",u"Hermsdorf",8728,50.9,11.866667 ],
    [ u"de",u"Herne",173121,51.55,7.216667 ],
    [ u"de",u"Herrenberg",31401,48.6,8.866667 ],
    [ u"de",u"Hersbruck",12506,49.5125,11.433889 ],
    [ u"de",u"Herten",65367,51.6,7.133333 ],
    [ u"de",u"Herxheim",10443,49.509167,8.179167 ],
    [ u"de",u"Herzberg",14832,51.65,10.333333 ],
    [ u"de",u"Herzberg",12188,51.683333,13.233333 ],
    [ u"de",u"Herzogenaurach",23229,49.55,10.883333 ],
    [ u"de",u"Herzogenrath",47425,50.866667,6.1 ],
    [ u"de",u"Hessisch Lichtenau",13394,51.2,9.716667 ],
    [ u"de",u"Hessisch Oldendorf",19871,52.166667,9.25 ],
    [ u"de",u"Hettstedt",15876,51.65,11.5 ],
    [ u"de",u"Heubach",10164,48.783333,9.933333 ],
    [ u"de",u"Heusenstamm",19257,50.066667,8.8 ],
    [ u"de",u"Heusweiler",20094,49.35,6.933333 ],
    [ u"de",u"Hiddenhausen",20742,52.166667,8.616667 ],
    [ u"de",u"Hilchenbach",16784,50.983333,8.1 ],
    [ u"de",u"Hildburghausen",12422,50.416667,10.75 ],
    [ u"de",u"Hilden",57036,51.166667,6.933333 ],
    [ u"de",u"Hildesheim",102958,52.15,9.966667 ],
    [ u"de",u"Hille",16620,52.333333,8.75 ],
    [ u"de",u"Hilpoltstein",12968,49.19,11.188611 ],
    [ u"de",u"Hilter",10312,52.15,8.15 ],
    [ u"de",u"Hirschaid",11514,49.819444,10.990833 ],
    [ u"de",u"Hochheim",17203,50.016667,8.35 ],
    [ u"de",u"Höchstadt",13470,49.7,10.8 ],
    [ u"de",u"Höchst",10143,49.799722,8.999444 ],
    [ u"de",u"Hockenheim",20814,49.322778,8.545833 ],
    [ u"de",u"Hofgeismar",16199,51.483333,9.4 ],
    [ u"de",u"Hofheim",38482,50.083333,8.45 ],
    [ u"de",u"Hof",49353,50.316667,11.916667 ],
    [ u"de",u"Hohen Neuendorf",22687,52.666667,13.283333 ],
    [ u"de",u"Hohenstein-Ernstthal",16416,50.8,12.716667 ],
    [ u"de",u"Höhr-Grenzhausen",9906,50.433333,7.666667 ],
    [ u"de",u"Holzgerlingen",11567,48.633333,9.016667 ],
    [ u"de",u"Holzkirchen",15459,47.883333,11.7 ],
    [ u"de",u"Holzminden",21028,51.816667,9.45 ],
    [ u"de",u"Holzwickede",17867,51.5,7.633333 ],
    [ u"de",u"Homberg",14893,51.033333,9.4 ],
    [ u"de",u"Homburg",45010,49.316667,7.333333 ],
    [ u"de",u"Horb",26287,48.433333,8.683333 ],
    [ u"de",u"Hörstel",19979,52.316667,7.583333 ],
    [ u"de",u"Hösbach",13258,50,9.2 ],
    [ u"de",u"Hövelhof",16349,51.816667,8.65 ],
    [ u"de",u"Höxter",32962,51.766667,9.383333 ],
    [ u"de",u"Hoyerswerda",43267,51.433333,14.25 ],
    [ u"de",u"Hückelhoven",39765,51.05,6.216667 ],
    [ u"de",u"Hückeswagen",16499,51.15,7.35 ],
    [ u"de",u"Hude",15858,53.116667,8.466667 ],
    [ u"de",u"Hüllhorst",13913,52.283333,8.666667 ],
    [ u"de",u"Hünfeld",16454,50.666667,9.766667 ],
    [ u"de",u"Hungen",12844,50.466667,8.9 ],
    [ u"de",u"Hünxe",13707,51.65,6.783333 ],
    [ u"de",u"Hürth",55217,50.866667,6.866667 ],
    [ u"de",u"Husum",20753,54.466667,9.05 ],
    [ u"de",u"Ibbenbüren",51305,52.266667,7.733333 ],
    [ u"de",u"Idar-Oberstein",32876,49.7,7.3 ],
    [ u"de",u"Idstein",23432,50.233333,8.266667 ],
    [ u"de",u"Ihlow",12757,51.883333,13.333333 ],
    [ u"de",u"Illertissen",16623,48.216667,10.1 ],
    [ u"de",u"Illingen",18312,49.366667,7.05 ],
    [ u"de",u"Ilmenau",27471,50.683333,10.9 ],
    [ u"de",u"Ilsede",12326,52.266667,10.2 ],
    [ u"de",u"Immenstadt",14282,47.566667,10.216667 ],
    [ u"de",u"Ingelheim",25296,49.980556,8.073611 ],
    [ u"de",u"Ingolstadt",120598,48.766667,11.433333 ],
    [ u"de",u"Iserlohn",98190,51.366667,7.7 ],
    [ u"de",u"Ismaning",14722,48.233333,11.633333 ],
    [ u"de",u"Isny",14461,47.7,10.033333 ],
    [ u"de",u"Isselburg",11274,51.833333,6.466667 ],
    [ u"de",u"Issum",12257,51.533333,6.433333 ],
    [ u"de",u"Itzehoe",33415,53.916667,9.516667 ],
    [ u"de",u"Jena",99269,50.933333,11.583333 ],
    [ u"de",u"Jever",14079,53.583333,7.9 ],
    [ u"de",u"Jork",11878,53.533333,9.683333 ],
    [ u"de",u"Jüchen",22333,51.1,6.5 ],
    [ u"de",u"Jülich",34888,50.933333,6.366667 ],
    [ u"de",u"Jüterbog",13483,51.983333,13.083333 ],
    [ u"de",u"Kaarst",42876,51.233333,6.616667 ],
    [ u"de",u"Kaiserslautern",98947,49.45,7.75 ],
    [ u"de",u"Kalkar",14405,51.733333,6.3 ],
    [ u"de",u"Kall",12074,50.55,6.55 ],
    [ u"de",u"Kaltenkirchen",19161,53.833333,9.966667 ],
    [ u"de",u"Kamen",46076,51.6,7.666667 ],
    [ u"de",u"Kamenz",18122,51.266667,14.1 ],
    [ u"de",u"Kamp-Lintfort",39949,51.5,6.533333 ],
    [ u"de",u"Kappeln",9801,54.666667,9.933333 ],
    [ u"de",u"Karben",21718,50.233333,8.75 ],
    [ u"de",u"Karlsfeld",17958,48.216667,11.466667 ],
    [ u"de",u"Karlsruhe",284786,49.004722,8.385833 ],
    [ u"de",u"Karlstadt",15247,49.960278,9.772222 ],
    [ u"de",u"Kassel",193117,51.316667,9.5 ],
    [ u"de",u"Kaufbeuren",43454,47.883333,10.616667 ],
    [ u"de",u"Kaufungen",12804,51.281111,9.618611 ],
    [ u"de",u"Kehl",34493,48.583333,7.816667 ],
    [ u"de",u"Kelheim",16227,48.916667,11.866667 ],
    [ u"de",u"Kelkheim",26823,50.133333,8.45 ],
    [ u"de",u"Kelsterbach",14146,50.066667,8.533333 ],
    [ u"de",u"Kempen",36506,51.366667,6.416667 ],
    [ u"de",u"Kempten",61800,47.716667,10.316667 ],
    [ u"de",u"Kerpen",64729,50.866667,6.7 ],
    [ u"de",u"Ketsch",12960,49.367778,8.531111 ],
    [ u"de",u"Kevelaer",28148,51.583333,6.25 ],
    [ u"de",u"Kiel",235264,54.333333,10.133333 ],
    [ u"de",u"Kierspe",18281,51.133333,7.583333 ],
    [ u"de",u"Kirchen",9354,50.8,7.883333 ],
    [ u"de",u"Kirchhain",16432,50.816667,8.966667 ],
    [ u"de",u"Kirchheim",40144,48.65,9.45 ],
    [ u"de",u"Kirchheim",11982,48.183333,11.75 ],
    [ u"de",u"Kirchhundem",13059,51.1,8.1 ],
    [ u"de",u"Kirchlengern",16557,52.2,8.633333 ],
    [ u"de",u"Kirchlinteln",10644,52.95,9.316667 ],
    [ u"de",u"Kirchzarten",9575,47.966667,7.95 ],
    [ u"de",u"Kirkel",10509,49.283333,7.233333 ],
    [ u"de",u"Kirn",8879,49.783333,7.45 ],
    [ u"de",u"Kissing",11072,48.3,10.983333 ],
    [ u"de",u"Kitzingen",21705,49.733333,10.166667 ],
    [ u"de",u"Kleinblittersdorf",12940,49.15,7.033333 ],
    [ u"de",u"Kleinmachnow",18306,52.4,13.25 ],
    [ u"de",u"Klingenthal",8984,50.366667,12.466667 ],
    [ u"de",u"Koblenz",108146,50.35,7.6 ],
    [ u"de",u"Kolbermoor",18488,47.85,12.066667 ],
    [ u"de",u"Kolkwitz",10336,51.75,14.25 ],
    [ u"de",u"Köngen",9879,48.683333,9.366667 ],
    [ u"de",u"Königslutter",16614,52.25,10.816667 ],
    [ u"de",u"Königstein",15767,50.183333,8.466667 ],
    [ u"de",u"Königswinter",41248,50.683333,7.183333 ],
    [ u"de",u"Königs Wusterhausen",33872,52.283333,13.616667 ],
    [ u"de",u"Konstanz",81951,47.666667,9.183333 ],
    [ u"de",u"Korbach",24657,51.283333,8.866667 ],
    [ u"de",u"Korb",10305,48.85,9.366667 ],
    [ u"de",u"Korntal-Münchingen",18358,48.816667,9.116667 ],
    [ u"de",u"Kornwestheim",30756,48.866667,9.183333 ],
    [ u"de",u"Korschenbroich",33588,51.183333,6.516667 ],
    [ u"de",u"Köthen",28700,51.75,11.966667 ],
    [ u"de",u"Krefeld",239908,51.333333,6.566667 ],
    [ u"de",u"Kreuzau",18670,50.75,6.483333 ],
    [ u"de",u"Kreuztal",31720,50.966667,7.983333 ],
    [ u"de",u"Kriftel",10590,50.083333,8.483333 ],
    [ u"de",u"Kronach",18349,50.233333,11.316667 ],
    [ u"de",u"Kronberg",17649,50.183333,8.5 ],
    [ u"de",u"Kronshagen",11826,54.333333,10.083333 ],
    [ u"de",u"Krumbach",12518,48.25,10.366667 ],
    [ u"de",u"Kulmbach",27346,50.1,11.45 ],
    [ u"de",u"Kümmersbruck",10458,49.419167,11.888333 ],
    [ u"de",u"Künzell",16356,50.55,9.716667 ],
    [ u"de",u"Künzelsau",15128,49.281944,9.688889 ],
    [ u"de",u"Kürten",20588,51.05,7.266667 ],
    [ u"de",u"Kyritz",11321,52.95,12.4 ],
    [ u"de",u"Laatzen",40245,52.316667,9.8 ],
    [ u"de",u"Ladenburg",11621,49.475,8.606944 ],
    [ u"de",u"Lage",36709,51.983333,8.8 ],
    [ u"de",u"Lahnstein",18572,50.3,7.616667 ],
    [ u"de",u"Lahr",43676,48.35,7.866667 ],
    [ u"de",u"Lahstedt",10882,52.25,10.216667 ],
    [ u"de",u"Laichingen",11063,48.5,9.683333 ],
    [ u"de",u"Lampertheim",31873,49.601944,8.471944 ],
    [ u"de",u"Landau",13026,48.683333,12.683333 ],
    [ u"de",u"Landau",42031,49.2075,8.113333 ],
    [ u"de",u"Landsberg",26624,48.05,10.866667 ],
    [ u"de",u"Landshut",61131,48.533333,12.15 ],
    [ u"de",u"Langelsheim",13234,51.933333,10.333333 ],
    [ u"de",u"Langenau",14411,48.5,10.1 ],
    [ u"de",u"Langenfeld",58803,51.1,6.95 ],
    [ u"de",u"Langenhagen",49958,52.45,9.75 ],
    [ u"de",u"Langen",35755,49.993333,8.672778 ],
    [ u"de",u"Langen",18685,53.616667,8.6 ],
    [ u"de",u"Langenselbold",12652,50.183333,9.033333 ],
    [ u"de",u"Langenzenn",10767,49.5,10.8 ],
    [ u"de",u"Langerwehe",14222,50.816667,6.35 ],
    [ u"de",u"Langgöns",12251,50.5,8.666667 ],
    [ u"de",u"Langwedel",15200,52.966667,9.216667 ],
    [ u"de",u"Lappersdorf",12817,49.056944,12.09 ],
    [ u"de",u"Laubach",10262,50.55,8.983333 ],
    [ u"de",u"Lauchhammer",18948,51.5,13.8 ],
    [ u"de",u"Lauda-Königshofen",15138,49.565278,9.704167 ],
    [ u"de",u"Lauenburg",11796,53.366667,10.566667 ],
    [ u"de",u"Lauffen",11191,49.074444,9.146944 ],
    [ u"de",u"Lauf",26181,49.510278,11.2775 ],
    [ u"de",u"Lauingen",10991,48.566667,10.433333 ],
    [ u"de",u"Laupheim",19111,48.233333,9.883333 ],
    [ u"de",u"Lauterbach",14665,50.633333,9.4 ],
    [ u"de",u"Lebach",21665,49.4,6.916667 ],
    [ u"de",u"Leer",34081,53.233333,7.433333 ],
    [ u"de",u"Lehre",11664,52.333333,10.666667 ],
    [ u"de",u"Lehrte",44495,52.383333,9.966667 ],
    [ u"de",u"Leichlingen",27532,51.116667,7.016667 ],
    [ u"de",u"Leimen",27323,49.351111,8.689444 ],
    [ u"de",u"Leinefelde",13794,51.383333,10.333333 ],
    [ u"de",u"Leinfelden-Echterdingen",37210,48.7,9.15 ],
    [ u"de",u"Leipzig",492637,51.3,12.333333 ],
    [ u"de",u"Lemgo",42036,52.033333,8.9 ],
    [ u"de",u"Lengede",13196,52.2,10.3 ],
    [ u"de",u"Lengerich",22642,52.183333,7.866667 ],
    [ u"de",u"Lenggries",9409,47.683333,11.566667 ],
    [ u"de",u"Lennestadt",28142,51.116667,8.066667 ],
    [ u"de",u"Leonberg",46276,48.8,9.016667 ],
    [ u"de",u"Leopoldshöhe",16324,52.016667,8.7 ],
    [ u"de",u"Leuna",7100,51.316667,12.016667 ],
    [ u"de",u"Leutenbach",10718,48.883333,9.4 ],
    [ u"de",u"Leutkirch",22645,47.825,10.016667 ],
    [ u"de",u"Leverkusen",159088,51.016667,6.983333 ],
    [ u"de",u"Lich",13410,50.516667,8.833333 ],
    [ u"de",u"Lichtenau",11350,51.616667,8.9 ],
    [ u"de",u"Lichtenfels",21586,50.15,11.066667 ],
    [ u"de",u"Lichtenstein",13583,50.75,12.65 ],
    [ u"de",u"Liebenburg",9649,52.016667,10.45 ],
    [ u"de",u"Lilienthal",17851,53.133333,8.916667 ],
    [ u"de",u"Limbach-Oberfrohna",26721,50.866667,12.75 ],
    [ u"de",u"Limburgerhof",10750,49.424444,8.391944 ],
    [ u"de",u"Limburg",33955,50.383333,8.05 ],
    [ u"de",u"Lindau",24161,47.55,9.683333 ],
    [ u"de",u"Lindenberg",11614,47.6,9.9 ],
    [ u"de",u"Lindlar",22752,51.016667,7.383333 ],
    [ u"de",u"Lingen",51577,52.516667,7.316667 ],
    [ u"de",u"Linkenheim-Hochstetten",11783,49.137222,8.403333 ],
    [ u"de",u"Linnich",13983,50.983333,6.266667 ],
    [ u"de",u"Lippstadt",67638,51.666667,8.35 ],
    [ u"de",u"Löbau",21398,51.1,14.666667 ],
    [ u"de",u"Lohfelden",13910,51.266667,9.533333 ],
    [ u"de",u"Lohmar",31802,50.833333,7.216667 ],
    [ u"de",u"Lohne",25332,52.666667,8.233333 ],
    [ u"de",u"Löhne",41805,52.183333,8.666667 ],
    [ u"de",u"Lohr",16297,49.993611,9.578333 ],
    [ u"de",u"Lollar",10206,50.65,8.7 ],
    [ u"de",u"Löningen",13315,52.733333,7.766667 ],
    [ u"de",u"Lorch",11503,48.8,9.683333 ],
    [ u"de",u"Lörrach",47666,47.616288,7.664842 ],
    [ u"de",u"Lorsch",12829,49.654722,8.568611 ],
    [ u"de",u"Losheim",16418,49.516667,6.75 ],
    [ u"de",u"Lotte",13564,52.283333,7.916667 ],
    [ u"de",u"Loxstedt",16783,53.466667,8.65 ],
    [ u"de",u"Lübbecke",27131,52.3,8.616667 ],
    [ u"de",u"Lübbenau",21356,51.866667,13.966667 ],
    [ u"de",u"Lübben",14985,51.95,13.9 ],
    [ u"de",u"Lübeck",213171,53.866667,10.7 ],
    [ u"de",u"Lüchow",9763,52.966667,11.15 ],
    [ u"de",u"Luckenwalde",21217,52.083333,13.166667 ],
    [ u"de",u"Lüdenscheid",80045,51.216667,7.616667 ],
    [ u"de",u"Lüdinghausen",24218,51.766667,7.466667 ],
    [ u"de",u"Ludwigsburg",87855,48.9,9.183333 ],
    [ u"de",u"Ludwigsfelde",24823,52.3,13.266667 ],
    [ u"de",u"Ludwigshafen",162514,49.481111,8.435278 ],
    [ u"de",u"Ludwigslust",12209,53.316667,11.5 ],
    [ u"de",u"Lugau",7779,50.733333,12.75 ],
    [ u"de",u"Lügde",11448,51.95,9.25 ],
    [ u"de",u"Lüneburg",73252,53.25,10.4 ],
    [ u"de",u"Lünen",91912,51.616667,7.516667 ],
    [ u"de",u"Magdeburg",224428,52.166667,11.666667 ],
    [ u"de",u"Mainburg",13944,48.65,11.783333 ],
    [ u"de",u"Maintal",38656,50.15,8.833333 ],
    [ u"de",u"Mainz",187940,50,8.271111 ],
    [ u"de",u"Maisach",12623,48.216667,11.266667 ],
    [ u"de",u"Malchin",8413,53.733333,12.783333 ],
    [ u"de",u"Malente",10731,54.183333,10.566667 ],
    [ u"de",u"Malsch",14364,48.883333,8.333333 ],
    [ u"de",u"Manching",11297,48.716667,11.5 ],
    [ u"de",u"Mannheim",309626,49.488333,8.464722 ],
    [ u"de",u"Marbach",15353,48.933333,9.25 ],
    [ u"de",u"Marburg",79300,50.816667,8.766667 ],
    [ u"de",u"Marienberg",15600,50.65,13.166667 ],
    [ u"de",u"Marienheide",13645,51.083333,7.533333 ],
    [ u"de",u"Markdorf",12701,47.716667,9.4 ],
    [ u"de",u"Markgröningen",14766,48.9,9.066667 ],
    [ u"de",u"Markkleeberg",23220,51.283333,12.4 ],
    [ u"de",u"Marktheidenfeld",11023,49.844167,9.603889 ],
    [ u"de",u"Marktoberdorf",18701,47.783333,10.616667 ],
    [ u"de",u"Marktredwitz",18359,50.005,12.081111 ],
    [ u"de",u"Markt Schwaben",11251,48.2,11.883333 ],
    [ u"de",u"Marl",91262,51.65,7.083333 ],
    [ u"de",u"Marpingen",11439,49.45,7.05 ],
    [ u"de",u"Marsberg",22361,51.45,8.85 ],
    [ u"de",u"Maxhütte-Haidhof",10610,49.2025,12.098056 ],
    [ u"de",u"Mayen",19372,50.333333,7.216667 ],
    [ u"de",u"Mechernich",27551,50.6,6.65 ],
    [ u"de",u"Meckenbeuren",13121,47.7,9.566667 ],
    [ u"de",u"Meckenheim",25491,50.633333,7.016667 ],
    [ u"de",u"Meerane",17646,50.85,12.466667 ],
    [ u"de",u"Meerbusch",55053,51.283333,6.666667 ],
    [ u"de",u"Meinerzhagen",21907,51.116667,7.65 ],
    [ u"de",u"Meiningen",21570,50.55,10.416667 ],
    [ u"de",u"Meitingen",11245,48.55,10.85 ],
    [ u"de",u"Melle",46745,52.2,8.35 ],
    [ u"de",u"Melsungen",14122,51.133333,9.55 ],
    [ u"de",u"Memmingen",41210,47.983333,10.166667 ],
    [ u"de",u"Menden",58939,51.433333,7.8 ],
    [ u"de",u"Mengen",10155,48.05,9.333333 ],
    [ u"de",u"Meppen",34205,52.683333,7.316667 ],
    [ u"de",u"Merchweiler",10795,49.35,7.05 ],
    [ u"de",u"Mering",12437,48.266667,10.983333 ],
    [ u"de",u"Merseburg",34440,51.366667,12 ],
    [ u"de",u"Merzig",31141,49.45,6.633333 ],
    [ u"de",u"Meschede",32593,51.35,8.283333 ],
    [ u"de",u"Mettingen",12869,52.316667,7.783333 ],
    [ u"de",u"Mettlach",12705,49.5,6.6 ],
    [ u"de",u"Mettmann",39371,51.25,6.966667 ],
    [ u"de",u"Metzingen",22034,48.533333,9.266667 ],
    [ u"de",u"Meuselwitz",9953,51.05,12.3 ],
    [ u"de",u"Michelstadt",17363,49.673611,9.0025 ],
    [ u"de",u"Miesbach",11394,47.783333,11.833333 ],
    [ u"de",u"Miltenberg",9706,49.703889,9.264444 ],
    [ u"de",u"Mindelheim",14221,48.05,10.483333 ],
    [ u"de",u"Minden",83402,52.283333,8.916667 ],
    [ u"de",u"Mittweida",16494,50.983333,12.983333 ],
    [ u"de",u"Moers",109167,51.45,6.65 ],
    [ u"de",u"Möglingen",10460,48.883333,9.133333 ],
    [ u"de",u"Möhnesee",11612,51.5,8.133333 ],
    [ u"de",u"Mölln",18396,53.633333,10.683333 ],
    [ u"de",u"Mömbris",12393,50.066667,9.166667 ],
    [ u"de",u"Mönchengladbach",264969,51.2,6.433333 ],
    [ u"de",u"Monheim",43905,51.083333,6.883333 ],
    [ u"de",u"Monschau",13167,50.55,6.25 ],
    [ u"de",u"Montabaur",12518,50.433333,7.833333 ],
    [ u"de",u"Moosburg",17394,48.466667,11.933333 ],
    [ u"de",u"Morbach",11184,49.816667,7.116667 ],
    [ u"de",u"Mörfelden-Walldorf",34194,49.994722,8.583611 ],
    [ u"de",u"Mörlenbach",10566,49.599167,8.734722 ],
    [ u"de",u"Morsbach",11743,50.866667,7.75 ],
    [ u"de",u"Mosbach",25474,49.353889,9.142778 ],
    [ u"de",u"Mössingen",20197,48.4,9.066667 ],
    [ u"de",u"Much",15327,50.916667,7.4 ],
    [ u"de",u"Mühlacker",26674,48.95,8.833333 ],
    [ u"de",u"Mühldorf",17940,48.25,12.533333 ],
    [ u"de",u"Mühlhausen",36287,51.216667,10.45 ],
    [ u"de",u"Mühlheim",26753,50.116667,8.833333 ],
    [ u"de",u"Mülheim-Kärlich",10414,50.383333,7.5 ],
    [ u"de",u"Mülheim",172779,51.433333,6.883333 ],
    [ u"de",u"Müllheim",18518,47.811248,7.6285 ],
    [ u"de",u"Münchberg",11646,50.2,11.783333 ],
    [ u"de",u"Munich",1246133,48.1500,11.5833 ],
    [ u"de",u"Münsingen",14466,48.416667,9.5 ],
    [ u"de",u"Münster",13957,49.922778,8.867778 ],
    [ u"de",u"Munster",18090,52.983333,10.083333 ],
    [ u"de",u"Münster",272452,51.966667,7.633333 ],
    [ u"de",u"Murnau",12223,47.683333,11.2 ],
    [ u"de",u"Murrhardt",14381,48.966667,9.566667 ],
    [ u"de",u"Mutterstadt",12565,49.441389,8.356111 ],
    [ u"de",u"Nagold",23486,48.55,8.716667 ],
    [ u"de",u"Naila",8349,50.316667,11.7 ],
    [ u"de",u"Nalbach",9616,49.383333,6.783333 ],
    [ u"de",u"Nauen",19203,52.6,12.883333 ],
    [ u"de",u"Naumburg",30040,51.15,11.816667 ],
    [ u"de",u"Neckargemünd",14111,49.392222,8.794167 ],
    [ u"de",u"Neckarsulm",27530,49.192778,9.226111 ],
    [ u"de",u"Netphen",25187,50.916667,8.1 ],
    [ u"de",u"Nettetal",42959,51.316667,6.283333 ],
    [ u"de",u"Neu-Anspach",15609,50.316667,8.5 ],
    [ u"de",u"Neubiberg",13057,48.083333,11.683333 ],
    [ u"de",u"Neubrandenburg",67393,53.566667,13.266667 ],
    [ u"de",u"Neuenburg",11538,47.813418,7.563494 ],
    [ u"de",u"Neuenhagen",16111,52.533333,13.683333 ],
    [ u"de",u"Neuenkirchen",14068,52.25,7.366667 ],
    [ u"de",u"Neuenrade",12505,51.283333,7.783333 ],
    [ u"de",u"Neufahrn",18487,48.316667,11.666667 ],
    [ u"de",u"Neuhausen",11566,48.683333,9.283333 ],
    [ u"de",u"Neuhof",11437,50.433333,9.616667 ],
    [ u"de",u"Neumünster",79429,54.066667,9.983333 ],
    [ u"de",u"Neunkirchen",14295,50.8,8 ],
    [ u"de",u"Neunkirchen",50432,49.35,7.183333 ],
    [ u"de",u"Neuruppin",32173,52.933333,12.8 ],
    [ u"de",u"Neuss",152975,51.2,6.683333 ],
    [ u"de",u"Neustadt",12470,49.583333,10.6 ],
    [ u"de",u"Neustadt",45661,52.5,9.466667 ],
    [ u"de",u"Neustadt",16680,54.1,10.816667 ],
    [ u"de",u"Neustadt",10649,51.033333,14.216667 ],
    [ u"de",u"Neustadt",9142,50.733333,11.75 ],
    [ u"de",u"Neustrelitz",22312,53.366667,13.083333 ],
    [ u"de",u"Neutraubling",12645,48.983333,12.2 ],
    [ u"de",u"Neu-Ulm",51654,48.4,10.016667 ],
    [ u"de",u"Neuwied",66901,50.433333,7.466667 ],
    [ u"de",u"Neu Wulmstorf",20988,53.466667,9.8 ],
    [ u"de",u"Nidda",18335,50.416667,9 ],
    [ u"de",u"Nidderau",20274,50.25,8.9 ],
    [ u"de",u"Nideggen",11075,50.7,6.483333 ],
    [ u"de",u"Niederkassel",36426,50.816667,7.033333 ],
    [ u"de",u"Niederkrüchten",15697,51.2,6.216667 ],
    [ u"de",u"Niedernhausen",14703,50.15,8.316667 ],
    [ u"de",u"Niederzier",14648,50.883333,6.466667 ],
    [ u"de",u"Niefern-Öschelbronn",12299,48.916667,8.783333 ],
    [ u"de",u"Nienburg",32512,52.633333,9.216667 ],
    [ u"de",u"Niesky",11260,51.3,14.816667 ],
    [ u"de",u"Nohfelden",10666,49.583333,7.15 ],
    [ u"de",u"Nordenham",27783,53.5,8.483333 ],
    [ u"de",u"Norden",24686,53.6,7.2 ],
    [ u"de",u"Norderstedt",72011,53.7,10.016667 ],
    [ u"de",u"Nordhausen",43709,51.516667,10.8 ],
    [ u"de",u"Nordhorn",52906,52.433333,7.083333 ],
    [ u"de",u"Nördlingen",19646,48.85,10.5 ],
    [ u"de",u"Nordstemmen",13436,52.166667,9.783333 ],
    [ u"de",u"Northeim",30751,51.7,10 ],
    [ u"de",u"Nörvenich",11778,50.8,6.65 ],
    [ u"de",u"Nottuln",20256,51.933333,7.35 ],
    [ u"de",u"Nümbrecht",17492,50.9,7.55 ],
    [ u"de",u"Nuremberg",497593,49.447778,11.068333 ],
    [ u"de",u"Nürtingen",41002,48.633333,9.35 ],
    [ u"de",u"Oberasbach",17343,49.433333,10.95 ],
    [ u"de",u"Oberhaching",12416,48.033333,11.6 ],
    [ u"de",u"Oberhausen",220916,51.466667,6.85 ],
    [ u"de",u"Oberhausen-Rheinhausen",9580,49.273889,8.471667 ],
    [ u"de",u"Oberkirch",20264,48.533333,8.083333 ],
    [ u"de",u"Oberndorf",14890,48.283333,8.566667 ],
    [ u"de",u"Obernkirchen",10155,52.266667,9.133333 ],
    [ u"de",u"Ober-Ramstadt",15695,49.833611,8.751944 ],
    [ u"de",u"Oberstdorf",9895,47.4,10.283333 ],
    [ u"de",u"Obertshausen",24280,50.083333,8.85 ],
    [ u"de",u"Oberursel",42880,50.2,8.583333 ],
    [ u"de",u"Ochsenfurt",11531,49.65,10.083333 ],
    [ u"de",u"Ochtrup",19543,52.216667,7.183333 ],
    [ u"de",u"Odenthal",15537,51.033333,7.116667 ],
    [ u"de",u"Oelde",29608,51.816667,8.15 ],
    [ u"de",u"Oer-Erkenschwick",30474,51.633333,7.25 ],
    [ u"de",u"Oerlinghausen",17555,51.966667,8.666667 ],
    [ u"de",u"Offenbach",120641,50.1,8.766667 ],
    [ u"de",u"Offenburg",59109,48.483333,7.933333 ],
    [ u"de",u"Oftersheim",10228,49.365278,8.583056 ],
    [ u"de",u"Öhringen",23068,49.201667,9.503889 ],
    [ u"de",u"Olbernhau",11206,50.666667,13.333333 ],
    [ u"de",u"Olching",24526,48.2,11.333333 ],
    [ u"de",u"Oldenburg",160347,53.166667,8.2 ],
    [ u"de",u"Olfen",12450,51.7,7.4 ],
    [ u"de",u"Olpe",25939,51.033333,7.85 ],
    [ u"de",u"Olsberg",15923,51.35,8.5 ],
    [ u"de",u"Oranienburg",43275,52.75,13.233333 ],
    [ u"de",u"Oschatz",16348,51.3,13.116667 ],
    [ u"de",u"Oschersleben",19929,52.033333,11.25 ],
    [ u"de",u"Osnabrück",165372,52.266667,8.05 ],
    [ u"de",u"Osterburg",7255,52.783333,11.766667 ],
    [ u"de",u"Ostercappeln",9677,52.35,8.233333 ],
    [ u"de",u"Osterhofen",12010,48.7,13.016667 ],
    [ u"de",u"Osterholz-Scharmbeck",31469,53.233333,8.8 ],
    [ u"de",u"Ostfildern",34162,48.716667,9.266667 ],
    [ u"de",u"Östringen",12887,49.22,8.712222 ],
    [ u"de",u"Ottersberg",12392,53.1,9.15 ],
    [ u"de",u"Ottobrunn",19254,48.066667,11.683333 ],
    [ u"de",u"Ottweiler",15692,49.383333,7.166667 ],
    [ u"de",u"Overath",27073,50.95,7.3 ],
    [ u"de",u"Oyten",15694,53.05,9.016667 ],
    [ u"de",u"Paderborn",143096,51.716667,8.766667 ],
    [ u"de",u"Papenburg",34715,53.066667,7.4 ],
    [ u"de",u"Parchim",19146,53.433333,11.85 ],
    [ u"de",u"Pasewalk",12059,53.516667,13.983333 ],
    [ u"de",u"Passau",51091,48.583333,13.483333 ],
    [ u"de",u"Pattensen",13496,52.266667,9.766667 ],
    [ u"de",u"Pegnitz",14337,49.756389,11.545 ],
    [ u"de",u"Peine",49776,52.316667,10.233333 ],
    [ u"de",u"Peiting",12048,47.8,10.933333 ],
    [ u"de",u"Penzberg",16243,47.75,11.383333 ],
    [ u"de",u"Perleberg",13394,53.066667,11.866667 ],
    [ u"de",u"Petersberg",14350,50.566667,9.716667 ],
    [ u"de",u"Petershagen",27148,52.383333,8.966667 ],
    [ u"de",u"Pfarrkirchen",12029,48.433333,12.933333 ],
    [ u"de",u"Pforzheim",120366,48.883333,8.7 ],
    [ u"de",u"Pfullendorf",13278,47.916667,9.25 ],
    [ u"de",u"Pfullingen",18426,48.45,9.233333 ],
    [ u"de",u"Pfungstadt",25151,49.806389,8.606944 ],
    [ u"de",u"Philippsburg",12403,49.235833,8.456389 ],
    [ u"de",u"Pinneberg",40679,53.65,9.8 ],
    [ u"de",u"Pirmasens",43539,49.2,7.6 ],
    [ u"de",u"Pirna",39701,50.966667,13.933333 ],
    [ u"de",u"Planegg",10669,48.1,11.416667 ],
    [ u"de",u"Plankstadt",9300,49.394444,8.596111 ],
    [ u"de",u"Plattling",12590,48.783333,12.866667 ],
    [ u"de",u"Plauen",69378,50.5,12.133333 ],
    [ u"de",u"Plettenberg",28247,51.216667,7.883333 ],
    [ u"de",u"Plochingen",14627,48.716667,9.416667 ],
    [ u"de",u"Plön",12876,54.166667,10.416667 ],
    [ u"de",u"Plüderhausen",9697,48.8,9.6 ],
    [ u"de",u"Pocking",14816,48.4,13.316667 ],
    [ u"de",u"Poing",11498,48.166667,11.816667 ],
    [ u"de",u"Porta Westfalica",36419,52.216667,8.933333 ],
    [ u"de",u"Potsdam",145291,52.4,13.066667 ],
    [ u"de",u"Preetz",15540,54.233333,10.283333 ],
    [ u"de",u"Premnitz",11176,52.533333,12.333333 ],
    [ u"de",u"Prenzlau",20922,53.316667,13.866667 ],
    [ u"de",u"Prien",10264,47.866667,12.333333 ],
    [ u"de",u"Pritzwalk",15286,53.15,12.183333 ],
    [ u"de",u"Puchheim",19278,48.15,11.35 ],
    [ u"de",u"Pulheim",54209,51,6.8 ],
    [ u"de",u"Püttlingen",21142,49.283333,6.883333 ],
    [ u"de",u"Quakenbrück",13170,52.683333,7.95 ],
    [ u"de",u"Quedlinburg",23057,51.783333,11.15 ],
    [ u"de",u"Querfurt",9436,51.383333,11.6 ],
    [ u"de",u"Quickborn",20281,53.733333,9.9 ],
    [ u"de",u"Quierschied",14626,49.316667,7.05 ],
    [ u"de",u"Radeberg",18529,51.116667,13.916667 ],
    [ u"de",u"Radebeul",32698,51.1,13.65 ],
    [ u"de",u"Radevormwald",24298,51.2,7.35 ],
    [ u"de",u"Radolfzell",30385,47.733333,8.966667 ],
    [ u"de",u"Raesfeld",11430,51.766667,6.85 ],
    [ u"de",u"Rahden",16218,52.433333,8.616667 ],
    [ u"de",u"Rastatt",48452,48.85,8.2 ],
    [ u"de",u"Rastede",20358,53.25,8.2 ],
    [ u"de",u"Ratekau",16031,53.95,10.733333 ],
    [ u"de",u"Rathenow",27058,52.6,12.333333 ],
    [ u"de",u"Ratingen",92306,51.3,6.85 ],
    [ u"de",u"Ratisbon",129643,49.015,12.095556 ],
    [ u"de",u"Ratzeburg",13719,53.7,10.766667 ],
    [ u"de",u"Raubling",11403,47.783333,12.1 ],
    [ u"de",u"Raunheim",13993,50.016667,8.45 ],
    [ u"de",u"Ravensburg",48441,47.783333,9.616667 ],
    [ u"de",u"Recke",11867,52.383333,7.716667 ],
    [ u"de",u"Recklinghausen",122727,51.616667,7.2 ],
    [ u"de",u"Rees",22654,51.766667,6.4 ],
    [ u"de",u"Regen",12591,48.966667,13.133333 ],
    [ u"de",u"Regenstauf",15078,49.121667,12.129167 ],
    [ u"de",u"Rehau",10279,50.25,12.033333 ],
    [ u"de",u"Rehburg-Loccum",11180,52.466667,9.2 ],
    [ u"de",u"Rehlingen-Siersburg",16121,49.366667,6.683333 ],
    [ u"de",u"Reichenbach",22569,50.616667,12.3 ],
    [ u"de",u"Reinbek",25357,53.516667,10.25 ],
    [ u"de",u"Reinheim",17839,49.826944,8.836111 ],
    [ u"de",u"Reiskirchen",10771,50.6,8.833333 ],
    [ u"de",u"Rellingen",13856,53.65,9.816667 ],
    [ u"de",u"Remagen",16360,50.566667,7.233333 ],
    [ u"de",u"Remscheid",118230,51.183333,7.2 ],
    [ u"de",u"Rendsburg",28814,54.3,9.666667 ],
    [ u"de",u"Renningen",17725,48.766667,8.933333 ],
    [ u"de",u"Reutlingen",113625,48.483333,9.216667 ],
    [ u"de",u"Rheda-Wiedenbrück",46378,51.833333,8.316667 ],
    [ u"de",u"Rhede",18774,51.833333,6.7 ],
    [ u"de",u"Rheinau",10885,48.866667,8.2 ],
    [ u"de",u"Rheinbach",26195,50.633333,6.95 ],
    [ u"de",u"Rheinberg",32178,51.55,6.6 ],
    [ u"de",u"Rheine",76474,52.283333,7.45 ],
    [ u"de",u"Rheinfelden",32538,47.566667,7.8 ],
    [ u"de",u"Ribnitz-Damgarten",17176,54.25,12.466667 ],
    [ u"de",u"Riedlingen",10466,48.15,9.466667 ],
    [ u"de",u"Riegelsberg",15476,49.3,6.933333 ],
    [ u"de",u"Rielasingen-Worblingen",12006,47.733333,8.833333 ],
    [ u"de",u"Riesa",36788,51.3,13.3 ],
    [ u"de",u"Rietberg",28683,51.783333,8.433333 ],
    [ u"de",u"Rinteln",28048,52.183333,9.083333 ],
    [ u"de",u"Ritterhude",14143,53.183333,8.75 ],
    [ u"de",u"Rodenbach",11455,50.15,9.033333 ],
    [ u"de",u"Rödental",13973,50.283333,11.066667 ],
    [ u"de",u"Rodgau",43760,50.016667,8.833333 ],
    [ u"de",u"Roding",11428,49.196389,12.518611 ],
    [ u"de",u"Rommerskirchen",12554,51.033333,6.683333 ],
    [ u"de",u"Ronnenberg",23604,52.316667,9.65 ],
    [ u"de",u"Rosbach",11674,50.8,7.616667 ],
    [ u"de",u"Rosdorf",11844,51.5,9.9 ],
    [ u"de",u"Rosendahl",11132,51.766667,7.95 ],
    [ u"de",u"Rosenheim",60768,47.85,12.133333 ],
    [ u"de",u"Rösrath",27353,50.9,7.2 ],
    [ u"de",u"Rostock",196833,54.083333,12.133333 ],
    [ u"de",u"Rotenburg",14346,50.983333,9.716667 ],
    [ u"de",u"Rotenburg",22108,53.116667,9.4 ],
    [ u"de",u"Röthenbach",12084,49.485,11.2475 ],
    [ u"de",u"Roth",24959,49.245,11.091111 ],
    [ u"de",u"Rottenburg",43117,48.466667,8.933333 ],
    [ u"de",u"Rottweil",25783,48.166667,8.616667 ],
    [ u"de",u"Rudersberg",11651,48.883333,9.533333 ],
    [ u"de",u"Rüdersdorf",17943,52.45,13.783333 ],
    [ u"de",u"Rüdesheim",9811,49.983333,7.916667 ],
    [ u"de",u"Rudolstadt",25773,50.716667,11.333333 ],
    [ u"de",u"Runkel",9794,50.4,8.166667 ],
    [ u"de",u"Rüsselsheim",59911,49.9925,8.435 ],
    [ u"de",u"Rutesheim",10175,48.8,8.95 ],
    [ u"de",u"Rüthen",11453,51.483333,8.45 ],
    [ u"de",u"Saalfeld",28152,50.65,11.366667 ],
    [ u"de",u"Saarbrücken",181779,49.233333,7 ],
    [ u"de",u"Saarlouis",37663,49.316667,6.75 ],
    [ u"de",u"Saarwellingen",13882,49.35,6.816667 ],
    [ u"de",u"Salzgitter",111622,52.083333,10.333333 ],
    [ u"de",u"Salzhemmendorf",10709,52.066667,9.616667 ],
    [ u"de",u"Salzkotten",24369,51.666667,8.6 ],
    [ u"de",u"Salzwedel",24144,52.85,11.15 ],
    [ u"de",u"Sandhausen",14329,49.342778,8.659167 ],
    [ u"de",u"Sangerhausen",23301,51.466667,11.3 ],
    [ u"de",u"Sankt Augustin",56258,50.766667,7.183333 ],
    [ u"de",u"Sankt Georgen",13825,48.133333,8.333333 ],
    [ u"de",u"Sankt Ingbert",38654,49.283333,7.116667 ],
    [ u"de",u"Sankt Leon-Rot",12143,49.266389,8.616667 ],
    [ u"de",u"Sankt Wendel",27162,49.466667,7.166667 ],
    [ u"de",u"Sarstedt",18555,52.233333,9.85 ],
    [ u"de",u"Sassenberg",14507,52,8.05 ],
    [ u"de",u"Schalksmühle",11859,51.233333,7.533333 ],
    [ u"de",u"Scharbeutz",11973,54.033333,10.75 ],
    [ u"de",u"Schenefeld",17887,53.6,9.816667 ],
    [ u"de",u"Schermbeck",13758,51.683333,6.866667 ],
    [ u"de",u"Schieder-Schwalenberg",9382,51.883333,9.183333 ],
    [ u"de",u"Schiffdorf",14424,53.533333,8.65 ],
    [ u"de",u"Schifferstadt",18933,49.387222,8.374722 ],
    [ u"de",u"Schiffweiler",17356,49.366667,7.133333 ],
    [ u"de",u"Schkeuditz",19337,51.4,12.216667 ],
    [ u"de",u"Schleiden",13972,50.533333,6.466667 ],
    [ u"de",u"Schleswig",24061,54.516667,9.55 ],
    [ u"de",u"Schlitz",10248,50.666667,9.566667 ],
    [ u"de",u"Schlüchtern",17362,50.35,9.516667 ],
    [ u"de",u"Schmalkalden",17963,50.716667,10.45 ],
    [ u"de",u"Schmallenberg",26218,51.15,8.3 ],
    [ u"de",u"Schmelz",17494,49.433333,6.85 ],
    [ u"de",u"Schmölln",13118,50.9,12.366667 ],
    [ u"de",u"Schneeberg",16833,50.6,12.633333 ],
    [ u"de",u"Schneverdingen",19537,53.116667,9.8 ],
    [ u"de",u"Schönaich",10145,48.65,9.066667 ],
    [ u"de",u"Schönebeck",34358,52.016667,11.75 ],
    [ u"de",u"Schöneiche",11812,52.216667,13.516667 ],
    [ u"de",u"Schongau",12634,47.816667,10.9 ],
    [ u"de",u"Schöningen",13313,52.133333,10.95 ],
    [ u"de",u"Schopfheim",19919,47.65,7.816667 ],
    [ u"de",u"Schorndorf",39919,48.8,9.533333 ],
    [ u"de",u"Schortens",21251,53.533333,7.95 ],
    [ u"de",u"Schotten",11570,50.5,9.133333 ],
    [ u"de",u"Schramberg",18637,48.233333,8.383333 ],
    [ u"de",u"Schriesheim",14448,49.477778,8.672778 ],
    [ u"de",u"Schrobenhausen",16177,48.55,11.266667 ],
    [ u"de",u"Schüttorf",11762,52.316667,7.233333 ],
    [ u"de",u"Schwabach",38921,49.329167,11.025556 ],
    [ u"de",u"Schwäbisch Gmünd",61379,48.8,9.783333 ],
    [ u"de",u"Schwäbisch Hall",36590,49.105833,9.734167 ],
    [ u"de",u"Schwabmünchen",13209,48.183333,10.75 ],
    [ u"de",u"Schwaigern",11032,49.143889,9.055 ],
    [ u"de",u"Schwalbach",14074,50.15,8.533333 ],
    [ u"de",u"Schwalbach",18801,49.3,6.816667 ],
    [ u"de",u"Schwalmstadt",20002,50.933333,9.216667 ],
    [ u"de",u"Schwalmtal",19510,51.216667,6.266667 ],
    [ u"de",u"Schwandorf",28124,49.326389,12.109722 ],
    [ u"de",u"Schwanewede",19985,53.233333,8.6 ],
    [ u"de",u"Schwarzenbach",5074,50.216667,11.933333 ],
    [ u"de",u"Schwarzenbek",15310,53.5,10.483333 ],
    [ u"de",u"Schwarzenberg",18406,50.55,12.783333 ],
    [ u"de",u"Schwedt",40005,53.066667,14.3 ],
    [ u"de",u"Schweinfurt",54801,50.05,10.233333 ],
    [ u"de",u"Schwelm",30470,51.283333,7.283333 ],
    [ u"de",u"Schwerin",96329,53.633333,11.383333 ],
    [ u"de",u"Schwerte",50757,51.45,7.566667 ],
    [ u"de",u"Schwetzingen",23270,49.378056,8.581944 ],
    [ u"de",u"Schwieberdingen",10308,48.883333,9.066667 ],
    [ u"de",u"Sebnitz",9359,50.966667,14.283333 ],
    [ u"de",u"Seeheim-Jugenheim",16776,49.765,8.651944 ],
    [ u"de",u"Seelze",33224,52.4,9.6 ],
    [ u"de",u"Seesen",21976,51.9,10.183333 ],
    [ u"de",u"Seevetal",41557,53.4,9.966667 ],
    [ u"de",u"Sehnde",22400,52.316667,9.95 ],
    [ u"de",u"Selb",17172,50.166667,12.133333 ],
    [ u"de",u"Seligenstadt",19711,50.05,8.983333 ],
    [ u"de",u"Selm",27596,51.7,7.466667 ],
    [ u"de",u"Sendenhorst",13469,51.833333,7.833333 ],
    [ u"de",u"Senden",22199,48.316667,10.066667 ],
    [ u"de",u"Senden",19880,51.85,7.5 ],
    [ u"de",u"Senftenberg",28812,51.516667,14.016667 ],
    [ u"de",u"Siegburg",38818,50.8,7.2 ],
    [ u"de",u"Siegen",108228,50.866667,8.033333 ],
    [ u"de",u"Sigmaringen",17023,48.083333,9.216667 ],
    [ u"de",u"Simbach",10015,48.266667,13.016667 ],
    [ u"de",u"Simmerath",15981,50.6,6.3 ],
    [ u"de",u"Sindelfingen",61686,48.7,9.016667 ],
    [ u"de",u"Singen",46386,47.766667,8.833333 ],
    [ u"de",u"Sinsheim",35740,49.255278,8.877222 ],
    [ u"de",u"Sinzheim",11131,48.766667,8.166667 ],
    [ u"de",u"Sinzig",17708,50.55,7.25 ],
    [ u"de",u"Soest",48720,51.583333,8.116667 ],
    [ u"de",u"Solingen",165192,51.183333,7.083333 ],
    [ u"de",u"Solms",13982,50.766667,9.6 ],
    [ u"de",u"Soltau",22108,52.983333,9.833333 ],
    [ u"de",u"Sömmerda",20872,51.15,11.1 ],
    [ u"de",u"Sondershausen",21954,51.366667,10.866667 ],
    [ u"de",u"Sonneberg",24351,50.35,11.166667 ],
    [ u"de",u"Sonthofen",21512,47.516667,10.283333 ],
    [ u"de",u"Sontra",8618,51.066667,9.933333 ],
    [ u"de",u"Spaichingen",12258,48.083333,8.716667 ],
    [ u"de",u"Spenge",15569,52.133333,8.483333 ],
    [ u"de",u"Spiesen-Elversberg",14633,49.316667,7.133333 ],
    [ u"de",u"Spremberg",28444,51.55,14.366667 ],
    [ u"de",u"Springe",30284,52.216667,9.55 ],
    [ u"de",u"Sprockhövel",26125,51.35,7.25 ],
    [ u"de",u"Stade",45419,53.6,9.483333 ],
    [ u"de",u"Stadtallendorf",21789,50.833333,9.016667 ],
    [ u"de",u"Stadtbergen",14837,48.366667,10.85 ],
    [ u"de",u"Stadthagen",23474,52.316667,9.2 ],
    [ u"de",u"Stadtlohn",20726,51.983333,6.933333 ],
    [ u"de",u"Starnberg",22827,48,11.35 ],
    [ u"de",u"Steinau",11199,50.316667,9.466667 ],
    [ u"de",u"Steinbach",10223,50.166667,8.566667 ],
    [ u"de",u"Steinen",10038,47.647177,7.741135 ],
    [ u"de",u"Steinfurt",34478,52.15,7.35 ],
    [ u"de",u"Steinhagen",20143,52,8.4 ],
    [ u"de",u"Steinheim",11493,48.966667,9.283333 ],
    [ u"de",u"Steinheim",14059,51.85,9.1 ],
    [ u"de",u"Stein",13885,49.416667,11.016667 ],
    [ u"de",u"Stelle",11396,53.383333,10.116667 ],
    [ u"de",u"Stendal",37402,52.6,11.85 ],
    [ u"de",u"Stephanskirchen",9812,47.85,12.183333 ],
    [ u"de",u"Stockach",16800,47.85,9.016667 ],
    [ u"de",u"Stockelsdorf",16449,53.9,10.65 ],
    [ u"de",u"Stolberg",58900,50.766667,6.233333 ],
    [ u"de",u"Stollberg",13304,50.716667,12.8 ],
    [ u"de",u"Straelen",15531,51.45,6.266667 ],
    [ u"de",u"Stralsund",57959,54.3,13.1 ],
    [ u"de",u"Straubing",44504,48.883333,12.566667 ],
    [ u"de",u"Strausberg",26835,52.583333,13.883333 ],
    [ u"de",u"Stuhr",33110,53.033333,8.75 ],
    [ u"de",u"Stuttgart",591688,48.766667,9.183333 ],
    [ u"de",u"Suhl",43269,50.6,10.7 ],
    [ u"de",u"Sulingen",12905,52.683333,8.8 ],
    [ u"de",u"Sulzbach-Rosenberg",20511,49.498333,11.751667 ],
    [ u"de",u"Sulzbach",18802,49.3,7.066667 ],
    [ u"de",u"Sulz",12834,48.366667,8.65 ],
    [ u"de",u"Sundern",29648,51.333333,8 ],
    [ u"de",u"Syke",24084,52.9,8.833333 ],
    [ u"de",u"Tamm",12327,48.916667,9.116667 ],
    [ u"de",u"Tangermünde",9686,52.55,11.95 ],
    [ u"de",u"Tauberbischofsheim",13276,49.624722,9.662778 ],
    [ u"de",u"Taucha",14669,51.383333,12.483333 ],
    [ u"de",u"Taufkirchen",17922,48.05,11.616667 ],
    [ u"de",u"Taunusstein",29461,50.15,8.15 ],
    [ u"de",u"Tecklenburg",9510,52.216667,7.833333 ],
    [ u"de",u"Telgte",19739,51.983333,7.783333 ],
    [ u"de",u"Teltow",19624,52.4,13.266667 ],
    [ u"de",u"Templin",19764,53.116667,13.5 ],
    [ u"de",u"Teningen",11939,48.133333,7.816667 ],
    [ u"de",u"Teterow",9683,53.783333,12.566667 ],
    [ u"de",u"Tettnang",18365,47.666667,9.6 ],
    [ u"de",u"Thale",13544,51.75,11.05 ],
    [ u"de",u"Thalheim",7622,50.7,12.85 ],
    [ u"de",u"Tholey",13266,49.483333,7.066667 ],
    [ u"de",u"Timmendorfer Strand",9090,54,10.783333 ],
    [ u"de",u"Tirschenreuth",9379,49.8825,12.333056 ],
    [ u"de",u"Titisee-Neustadt",12092,47.9,8.166667 ],
    [ u"de",u"Töging",9830,48.25,12.583333 ],
    [ u"de",u"Tönisvorst",30579,51.316667,6.45 ],
    [ u"de",u"Torgau",18883,51.566667,13 ],
    [ u"de",u"Torgelow",10551,53.633333,14.016667 ],
    [ u"de",u"Tornesch",13045,53.7,9.716667 ],
    [ u"de",u"Tostedt",13695,53.283333,9.716667 ],
    [ u"de",u"Traunreut",21535,47.966667,12.6 ],
    [ u"de",u"Traunstein",18275,47.883333,12.65 ],
    [ u"de",u"Trebur",13016,49.931111,8.416111 ],
    [ u"de",u"Treuchtlingen",13208,48.95,10.916667 ],
    [ u"de",u"Trier",100649,49.75,6.633333 ],
    [ u"de",u"Troisdorf",75641,50.816667,7.166667 ],
    [ u"de",u"Trossingen",15123,48.066667,8.65 ],
    [ u"de",u"Trostberg",11640,48.033333,12.55 ],
    [ u"de",u"Tübingen",83815,48.533333,9.05 ],
    [ u"de",u"Tuttlingen",35133,47.983333,8.816667 ],
    [ u"de",u"Tutzing",9411,47.916667,11.283333 ],
    [ u"de",u"Twistringen",12675,52.8,8.65 ],
    [ u"de",u"Übach-Palenberg",25957,50.933333,6.116667 ],
    [ u"de",u"Überherrn",12145,49.25,6.7 ],
    [ u"de",u"Überlingen",21613,47.766667,9.166667 ],
    [ u"de",u"Ubstadt-Weiher",12939,49.170833,8.618889 ],
    [ u"de",u"Ueckermünde",10951,53.733333,14.05 ],
    [ u"de",u"Uelzen",35096,52.966667,10.566667 ],
    [ u"de",u"Uetersen",18155,53.683333,9.666667 ],
    [ u"de",u"Uetze",20477,52.466667,10.2 ],
    [ u"de",u"Uhingen",14220,48.7,9.583333 ],
    [ u"de",u"Ulm",120745,48.4,10 ],
    [ u"de",u"Unna",69138,51.533333,7.683333 ],
    [ u"de",u"Unterhaching",20751,48.05,11.633333 ],
    [ u"de",u"Usingen",13469,50.333333,8.533333 ],
    [ u"de",u"Uslar",15982,51.666667,9.65 ],
    [ u"de",u"Vaihingen",29284,48.933333,8.966667 ],
    [ u"de",u"Vallendar",9055,50.4,7.616667 ],
    [ u"de",u"Varel",25303,53.4,8.133333 ],
    [ u"de",u"Vaterstetten",20962,48.116667,11.783333 ],
    [ u"de",u"Vechelde",16165,52.266667,10.383333 ],
    [ u"de",u"Vechta",30178,52.716667,8.283333 ],
    [ u"de",u"Velbert",88876,51.333333,7.05 ],
    [ u"de",u"Velen",13236,51.9,6.983333 ],
    [ u"de",u"Vellmar",18464,51.35,9.466667 ],
    [ u"de",u"Velten",11697,52.683333,13.183333 ],
    [ u"de",u"Verden",26364,52.916667,9.233333 ],
    [ u"de",u"Verl",24532,51.883333,8.516667 ],
    [ u"de",u"Versmold",21227,52.05,8.15 ],
    [ u"de",u"Vienenburg",11518,51.95,10.566667 ],
    [ u"de",u"Viernheim",32921,49.541667,8.578611 ],
    [ u"de",u"Viersen",76771,51.25,6.383333 ],
    [ u"de",u"Villingen-Schwenningen",82286,48.066667,8.45 ],
    [ u"de",u"Vilsbiburg",11538,48.45,12.35 ],
    [ u"de",u"Vilshofen",16800,48.633333,13.183333 ],
    [ u"de",u"Visselhövede",10757,52.983333,9.6 ],
    [ u"de",u"Vlotho",20219,52.166667,8.85 ],
    [ u"de",u"Voerde",39052,51.6,6.683333 ],
    [ u"de",u"Vöhringen",13092,48.283333,10.083333 ],
    [ u"de",u"Volkach",9424,49.866667,10.233333 ],
    [ u"de",u"Völklingen",41799,49.25,6.85 ],
    [ u"de",u"Vreden",22250,52.033333,6.833333 ],
    [ u"de",u"Wachtberg",20004,50.633333,7.1 ],
    [ u"de",u"Wächtersbach",12497,50.266667,9.3 ],
    [ u"de",u"Wadern",17236,49.533333,6.883333 ],
    [ u"de",u"Wadersloh",13212,51.733333,8.25 ],
    [ u"de",u"Wadgassen",18787,49.266667,6.783333 ],
    [ u"de",u"Waghäusel",19373,49.256389,8.507222 ],
    [ u"de",u"Wahlstedt",9462,53.95,10.216667 ],
    [ u"de",u"Waiblingen",53515,48.833333,9.3 ],
    [ u"de",u"Waldbröl",19660,50.883333,7.616667 ],
    [ u"de",u"Waldheim",9150,51.066667,13.016667 ],
    [ u"de",u"Waldkirchen",10716,48.733333,13.6 ],
    [ u"de",u"Waldkirch",20193,48.1,7.966667 ],
    [ u"de",u"Waldkraiburg",24939,48.216667,12.4 ],
    [ u"de",u"Wald-Michelbach",11447,49.57,8.831667 ],
    [ u"de",u"Waldshut-Tiengen",22648,47.616667,8.216667 ],
    [ u"de",u"Walldorf",14488,49.306389,8.645278 ],
    [ u"de",u"Walldürn",11960,49.583333,9.366667 ],
    [ u"de",u"Wallenhorst",24279,52.35,8.016667 ],
    [ u"de",u"Wallerfangen",9880,49.333333,6.716667 ],
    [ u"de",u"Walsrode",24439,52.866667,9.6 ],
    [ u"de",u"Waltershausen",11345,50.9,10.566667 ],
    [ u"de",u"Waltrop",30150,51.633333,7.4 ],
    [ u"de",u"Warburg",24399,51.5,9.166667 ],
    [ u"de",u"Wardenburg",16019,53.066667,8.2 ],
    [ u"de",u"Warendorf",39281,51.95,7.983333 ],
    [ u"de",u"Waren",21504,53.516667,12.683333 ],
    [ u"de",u"Warstein",29029,51.45,8.366667 ],
    [ u"de",u"Wassenberg",16603,51.1,6.15 ],
    [ u"de",u"Wasserburg",12539,48.066667,12.233333 ],
    [ u"de",u"Wedel",32619,53.583333,9.716667 ],
    [ u"de",u"Weener",15794,53.166667,7.35 ],
    [ u"de",u"Weeze",10371,51.633333,6.2 ],
    [ u"de",u"Wegberg",29931,51.15,6.266667 ],
    [ u"de",u"Wehr",13042,47.633333,7.9 ],
    [ u"de",u"Weida",8355,50.766667,12.066667 ],
    [ u"de",u"Weiden",42387,49.6775,12.156667 ],
    [ u"de",u"Weilburg",13833,50.483333,8.25 ],
    [ u"de",u"Weil der Stadt",19310,48.75,8.866667 ],
    [ u"de",u"Weilerswist",16515,50.766667,6.833333 ],
    [ u"de",u"Weilheim",21635,47.833333,11.15 ],
    [ u"de",u"Weil im Schönbuch",10245,48.616667,9.066667 ],
    [ u"de",u"Weilmünster",9637,50.433333,8.366667 ],
    [ u"de",u"Weimar",65113,50.983333,11.316667 ],
    [ u"de",u"Weingarten",23928,47.8,9.633333 ],
    [ u"de",u"Weinheim",43217,49.548333,8.666111 ],
    [ u"de",u"Weinsberg",11910,49.150278,9.288333 ],
    [ u"de",u"Weiterstadt",24499,49.907778,8.595278 ],
    [ u"de",u"Welver",13142,51.616667,7.966667 ],
    [ u"de",u"Welzheim",11286,48.883333,9.65 ],
    [ u"de",u"Wendelstein",16108,49.353611,11.148333 ],
    [ u"de",u"Wenden",19977,50.966667,7.866667 ],
    [ u"de",u"Wendlingen",16199,48.683333,9.383333 ],
    [ u"de",u"Wennigsen",14122,52.266667,9.583333 ],
    [ u"de",u"Werdau",24299,50.733333,12.383333 ],
    [ u"de",u"Werder",25913,52.383333,12.95 ],
    [ u"de",u"Werdohl",20481,51.266667,7.766667 ],
    [ u"de",u"Werl",32304,51.55,7.916667 ],
    [ u"de",u"Wermelskirchen",36952,51.15,7.216667 ],
    [ u"de",u"Wernau",12668,48.7,9.416667 ],
    [ u"de",u"Werneck",10764,49.983333,10.1 ],
    [ u"de",u"Wernigerode",34674,51.833333,10.783333 ],
    [ u"de",u"Wertheim",24920,49.7575,9.509444 ],
    [ u"de",u"Werther",11910,52.066667,8.416667 ],
    [ u"de",u"Wesel",61768,51.666667,6.616667 ],
    [ u"de",u"Wesseling",36296,50.833333,6.983333 ],
    [ u"de",u"Westerkappeln",11443,52.316667,7.883333 ],
    [ u"de",u"Westerland",8927,54.9,8.3 ],
    [ u"de",u"Westerstede",22209,53.25,7.933333 ],
    [ u"de",u"Wetter",9430,50.9,8.716667 ],
    [ u"de",u"Wetter",29328,51.383333,7.4 ],
    [ u"de",u"Wetzlar",52869,50.55,8.5 ],
    [ u"de",u"Wickede",12681,51.483333,7.866667 ],
    [ u"de",u"Wiefelstede",14816,53.25,8.116667 ],
    [ u"de",u"Wiehl",26784,50.95,7.533333 ],
    [ u"de",u"Wiesbaden",272337,50.083333,8.25 ],
    [ u"de",u"Wiesloch",26642,49.297778,8.701389 ],
    [ u"de",u"Wiesmoor",13180,53.416667,7.733333 ],
    [ u"de",u"Wildberg",10186,48.633333,8.75 ],
    [ u"de",u"Wildeshausen",18276,52.9,8.433333 ],
    [ u"de",u"Wilhelmshaven",84209,53.516667,8.133333 ],
    [ u"de",u"Willich",52100,51.266667,6.55 ],
    [ u"de",u"Wilnsdorf",21498,50.816667,8.1 ],
    [ u"de",u"Winnenden",28230,48.883333,9.4 ],
    [ u"de",u"Winterberg",14603,51.2,8.533333 ],
    [ u"de",u"Wipperfürth",23507,51.116667,7.4 ],
    [ u"de",u"Wismar",45432,53.9,11.466667 ],
    [ u"de",u"Wittenberge",20322,53,11.75 ],
    [ u"de",u"Witten",101122,51.433333,7.333333 ],
    [ u"de",u"Wittingen",12401,52.733333,10.716667 ],
    [ u"de",u"Wittlich",17902,49.983333,6.883333 ],
    [ u"de",u"Wittmund",21417,53.566667,7.783333 ],
    [ u"de",u"Wittstock",19811,53.15,12.5 ],
    [ u"de",u"Witzenhausen",16001,51.333333,9.866667 ],
    [ u"de",u"Wolfenbüttel",54911,52.166667,10.55 ],
    [ u"de",u"Wolfen",25144,51.666667,12.283333 ],
    [ u"de",u"Wolfhagen",13265,51.316667,9.166667 ],
    [ u"de",u"Wolfratshausen",17190,47.916667,11.416667 ],
    [ u"de",u"Wolfsburg",123184,52.433333,10.8 ],
    [ u"de",u"Wolgast",12539,54.05,13.766667 ],
    [ u"de",u"Wolmirstedt",10589,52.25,11.633333 ],
    [ u"de",u"Wolnzach",11071,48.6,11.616667 ],
    [ u"de",u"Worms",82104,49.635556,8.359722 ],
    [ u"de",u"Worpswede",9580,53.216667,8.933333 ],
    [ u"de",u"Wörth",17507,49.058056,8.248611 ],
    [ u"de",u"Wülfrath",22549,51.283333,7.05 ],
    [ u"de",u"Wunsiedel",10319,50.033333,12.016667 ],
    [ u"de",u"Wunstorf",42145,52.433333,9.416667 ],
    [ u"de",u"Wuppertal",363240,51.266667,7.183333 ],
    [ u"de",u"Würselen",37594,50.816667,6.133333 ],
    [ u"de",u"Würzburg",134499,49.787778,9.936111 ],
    [ u"de",u"Wurzen",15066,51.366667,12.733333 ],
    [ u"de",u"Xanten",21294,51.666667,6.45 ],
    [ u"de",u"Zehdenick",16310,52.983333,13.333333 ],
    [ u"de",u"Zeitz",29582,51.05,12.15 ],
    [ u"de",u"Zella-Mehlis",12664,50.65,10.65 ],
    [ u"de",u"Zerbst",16054,51.966667,12.083333 ],
    [ u"de",u"Zetel",12037,53.416667,7.983333 ],
    [ u"de",u"Zeulenroda",13760,50.65,11.983333 ],
    [ u"de",u"Zeven",12577,53.3,9.283333 ],
    [ u"de",u"Zirndorf",25237,49.45,10.95 ],
    [ u"de",u"Zittau",25527,50.9,14.833333 ],
    [ u"de",u"Zschopau",12016,50.75,13.066667 ],
    [ u"de",u"Zülpich",20010,50.7,6.65 ],
    [ u"de",u"Zweibrücken",35970,49.25,7.366667 ],
    [ u"de",u"Zwickau",99343,50.733333,12.5 ],
    [ u"de",u"Zwiesel",10484,49.016667,13.233333 ],
    [ u"de",u"Zwönitz",12424,50.633333,12.8 ],
    [ u"dj",u"Jibuti",623891,11.595,43.1480556 ],
    [ u"dk",u"Aabenraa",16344,55.036217,9.417999 ],
    [ u"dk",u"Aabybro",4849,57.15,9.75 ],
    [ u"dk",u"Aakirkeby",2195,55.068666,14.925412 ],
    [ u"dk",u"Aalborg",122219,57.035498,9.941163 ],
    [ u"dk",u"Aalestrup",2787,56.694701,9.493357 ],
    [ u"dk",u"Aars",7247,56.803809,9.515814 ],
    [ u"dk",u"Aarup",2592,55.37315,10.041314 ],
    [ u"dk",u"Allingåbro",1842,56.464948,10.334087 ],
    [ u"dk",u"Arden",2516,56.768987,9.861842 ],
    [ u"dk",u"Århus",226716,56.153423,10.22553 ],
    [ u"dk",u"Årslev",3228,55.303526,10.46428 ],
    [ u"dk",u"Asnæs",2441,55.812292,11.501293 ],
    [ u"dk",u"Assens",5913,55.271213,9.905333 ],
    [ u"dk",u"Assentoft",2432,56.442095,10.151695 ],
    [ u"dk",u"Augustenborg",3132,54.952008,9.872163 ],
    [ u"dk",u"Aulum",2875,56.26539,8.79256 ],
    [ u"dk",u"Auning",2509,56.430791,10.378184 ],
    [ u"dk",u"Beder",4214,56.056426,10.217645 ],
    [ u"dk",u"Bellinge",4129,55.33535,10.320446 ],
    [ u"dk",u"Billund",6160,55.731157,9.113309 ],
    [ u"dk",u"Birkerød",18901,55.842331,12.433477 ],
    [ u"dk",u"Bjæverskov",2619,55.457556,12.036508 ],
    [ u"dk",u"Bjerringbro",7390,56.377973,9.66065 ],
    [ u"dk",u"Blovstrød",2137,55.870377,12.386399 ],
    [ u"dk",u"Bogense",3410,55.565192,10.092923 ],
    [ u"dk",u"Bording",2104,56.144141,9.276501 ],
    [ u"dk",u"Børkop",3561,55.637935,9.648225 ],
    [ u"dk",u"Borup",3120,55.494716,11.975843 ],
    [ u"dk",u"Brædstrup",3130,55.970793,9.608549 ],
    [ u"dk",u"Bramming",6726,55.469456,8.700074 ],
    [ u"dk",u"Brande",6357,55.938142,9.121783 ],
    [ u"dk",u"Brejning",2220,55.6613,9.677034 ],
    [ u"dk",u"Broager",3376,54.887358,9.680958 ],
    [ u"dk",u"Brønderslev",11671,57.265112,9.959859 ],
    [ u"dk",u"Brørup",4233,55.481936,9.017558 ],
    [ u"dk",u"Brovst",2710,57.095615,9.528007 ],
    [ u"dk",u"Bullerup",2982,55.426861,10.47137 ],
    [ u"dk",u"Christiansfeld",2709,55.358172,9.487014 ],
    [ u"dk",u"Copenhagen",1089958,55.666667,12.583333 ],
    [ u"dk",u"Dianalund",3605,55.531326,11.492499 ],
    [ u"dk",u"Dragør",11045,55.594566,12.668952 ],
    [ u"dk",u"Dronninglund",3084,57.160353,10.29287 ],
    [ u"dk",u"Dybbøl",2303,54.910792,9.736011 ],
    [ u"dk",u"Ebeltoft",5888,56.201801,10.682258 ],
    [ u"dk",u"Egtved",2151,55.617955,9.301021 ],
    [ u"dk",u"Ejby",1987,55.68923,11.847246 ],
    [ u"dk",u"Ejby",1996,55.430102,9.929729 ],
    [ u"dk",u"Esbjerg",72206,55.470276,8.451869 ],
    [ u"dk",u"Espergærde",11358,56,12.566667 ],
    [ u"dk",u"Faaborg",7239,55.09671,10.240669 ],
    [ u"dk",u"Fakse",3747,55.246862,12.117637 ],
    [ u"dk",u"Fakse Ladeplads",2837,55.219805,12.170133 ],
    [ u"dk",u"Farsø",3271,56.772758,9.339255 ],
    [ u"dk",u"Farum",11552,55.809873,12.362286 ],
    [ u"dk",u"Fensmark",4203,55.277637,11.808131 ],
    [ u"dk",u"Fjerritslev",3441,57.081343,9.266428 ],
    [ u"dk",u"Fløng",11108,55.662115,12.186975 ],
    [ u"dk",u"Forlev",2058,55.367176,11.260613 ],
    [ u"dk",u"Framlev",3067,56.148796,10.004024 ],
    [ u"dk",u"Fredensborg",8249,55.973475,12.40386 ],
    [ u"dk",u"Fredericia",36946,55.575781,9.761693 ],
    [ u"dk",u"Frederiksberg",3142,55.416182,11.569336 ],
    [ u"dk",u"Frederikshavn",24103,57.443803,10.547177 ],
    [ u"dk",u"Frederikssund",14564,55.838923,12.067612 ],
    [ u"dk",u"Frederiksværk",12176,55.967671,12.021482 ],
    [ u"dk",u"Frejlev",2286,57.006234,9.81711 ],
    [ u"dk",u"Fuglebjerg",1985,55.303365,11.549197 ],
    [ u"dk",u"Ganløse",2843,55.791236,12.264206 ],
    [ u"dk",u"Gilleleje",5799,56.121959,12.310561 ],
    [ u"dk",u"Gistrup",3622,56.994302,9.990851 ],
    [ u"dk",u"Give",4240,55.839773,9.249978 ],
    [ u"dk",u"Gjellerup Kirkeby",3627,56.143407,9.049882 ],
    [ u"dk",u"Glamsbjerg",3099,55.27237,10.104829 ],
    [ u"dk",u"Gørlev",2269,55.540585,11.228593 ],
    [ u"dk",u"Græsted",3310,56.065579,12.285119 ],
    [ u"dk",u"Gram",2548,55.291189,9.049695 ],
    [ u"dk",u"Gråsten",4022,54.919179,9.595232 ],
    [ u"dk",u"Grenaa",14317,56.41285,10.895649 ],
    [ u"dk",u"Greve Strand",41560,55.583333,12.3 ],
    [ u"dk",u"Grindsted",9414,55.754,8.912307 ],
    [ u"dk",u"Guderup",2424,54.989785,9.871742 ],
    [ u"dk",u"Gundsømagle",2149,55.735649,12.151579 ],
    [ u"dk",u"Haarby",2400,55.215019,10.122624 ],
    [ u"dk",u"Haderslev",20825,55.252434,9.489315 ],
    [ u"dk",u"Hadsten",7020,56.328528,10.048493 ],
    [ u"dk",u"Hadsund",5066,56.720861,10.11403 ],
    [ u"dk",u"Hals",2388,56.996091,10.308066 ],
    [ u"dk",u"Hammel",6138,56.257615,9.863157 ],
    [ u"dk",u"Hammerum",3025,56.133613,9.061214 ],
    [ u"dk",u"Hanstholm",2418,57.116667,8.616667 ],
    [ u"dk",u"Harboøre",1745,56.617356,8.182675 ],
    [ u"dk",u"Hårlev",2423,55.349357,12.233823 ],
    [ u"dk",u"Haslev",10588,55.317917,11.974003 ],
    [ u"dk",u"Havdrup",3828,55.544811,12.123917 ],
    [ u"dk",u"Hedensted",10048,55.770131,9.696694 ],
    [ u"dk",u"Hellebæk",5243,56.068234,12.557821 ],
    [ u"dk",u"Helsinge",7354,56.019659,12.198974 ],
    [ u"dk",u"Helsingør",35048,56.029377,12.586267 ],
    [ u"dk",u"Herning",30329,56.133333,8.983333 ],
    [ u"dk",u"Hillerød",28313,55.933333,12.316667 ],
    [ u"dk",u"Hinnerup",7055,56.266078,10.062993 ],
    [ u"dk",u"Hirtshals",6653,57.588135,9.951498 ],
    [ u"dk",u"Hjallerup",3320,57.164661,10.145708 ],
    [ u"dk",u"Hjørring",24634,57.466323,9.988917 ],
    [ u"dk",u"Hjortshøj",2515,56.24811,10.265325 ],
    [ u"dk",u"Hobro",11064,56.638115,9.795317 ],
    [ u"dk",u"Højby",4406,55.342179,10.436844 ],
    [ u"dk",u"Højslev",1857,56.585648,9.136366 ],
    [ u"dk",u"Holbæk",24544,55.713537,11.716903 ],
    [ u"dk",u"Holeby",1844,54.711475,11.464165 ],
    [ u"dk",u"Holstebro",32072,56.359471,8.620799 ],
    [ u"dk",u"Holsted",3096,55.510864,8.918721 ],
    [ u"dk",u"Høng",3789,55.51027,11.290181 ],
    [ u"dk",u"Hornbæk",3223,56.08541,12.450485 ],
    [ u"dk",u"Hørning",6085,56.087014,10.037162 ],
    [ u"dk",u"Hornslet",4906,56.315496,10.320412 ],
    [ u"dk",u"Horsens",50074,55.865675,9.873531 ],
    [ u"dk",u"Hørsholm",36670,55.88098,12.501106 ],
    [ u"dk",u"Høruphav",2514,54.910167,9.89872 ],
    [ u"dk",u"Hørve",2382,55.75292,11.452976 ],
    [ u"dk",u"Humlebæk",8965,55.961269,12.532432 ],
    [ u"dk",u"Hundested",8615,55.966667,11.866667 ],
    [ u"dk",u"Hurup",2770,56.749436,8.419525 ],
    [ u"dk",u"Hvalsø",3930,55.59575,11.861583 ],
    [ u"dk",u"Hvide Sande",3291,55.996387,8.127307 ],
    [ u"dk",u"Ikast",14692,56.136747,9.160023 ],
    [ u"dk",u"Ishøj",19453,55.618404,12.328128 ],
    [ u"dk",u"Jægerspris",3805,55.855443,11.967863 ],
    [ u"dk",u"Jelling",3059,55.755883,9.425798 ],
    [ u"dk",u"Juelsminde",3667,55.708759,10.016679 ],
    [ u"dk",u"Jyderup",3984,55.663991,11.420289 ],
    [ u"dk",u"Jyllinge",9981,55.758426,12.112271 ],
    [ u"dk",u"Kalundborg",15939,55.681984,11.100426 ],
    [ u"dk",u"Karup",2176,56.309808,9.170866 ],
    [ u"dk",u"Kås",1990,57.197744,9.671734 ],
    [ u"dk",u"Kerteminde",5748,55.450484,10.658433 ],
    [ u"dk",u"Kibæk",2656,56.031701,8.856974 ],
    [ u"dk",u"Kjellerup",4514,56.285809,9.435276 ],
    [ u"dk",u"Klarup",3352,57.011935,10.056171 ],
    [ u"dk",u"Køge",33885,55.460008,12.183415 ],
    [ u"dk",u"Kolding",55363,55.494131,9.458997 ],
    [ u"dk",u"Kolt",5061,56.108448,10.069856 ],
    [ u"dk",u"Korsør",15029,55.326574,11.150012 ],
    [ u"dk",u"Kruså",1694,54.85097,9.40129 ],
    [ u"dk",u"Langå",2710,56.390257,9.89486 ],
    [ u"dk",u"Langeskov",3713,55.356547,10.58447 ],
    [ u"dk",u"Lejre",2036,55.604318,11.974851 ],
    [ u"dk",u"Lillerød",15359,55.868749,12.345809 ],
    [ u"dk",u"Lind",3777,56.1,8.983333 ],
    [ u"dk",u"Liseleje",2906,56.005313,11.948266 ],
    [ u"dk",u"Løgstør",4469,56.962451,9.258304 ],
    [ u"dk",u"Løgten",5048,56.274591,10.31181 ],
    [ u"dk",u"Løgumkloster",3056,55.059411,8.955079 ],
    [ u"dk",u"Løjt Kirkeby",1975,55.083333,9.466667 ],
    [ u"dk",u"Lunderskov",2687,55.48375,9.299174 ],
    [ u"dk",u"Lynge",4284,55.839412,12.277248 ],
    [ u"dk",u"Lystrup",9107,56.237504,10.237777 ],
    [ u"dk",u"Malling",3339,56.036323,10.19632 ],
    [ u"dk",u"Måløv",8513,55.755283,12.323269 ],
    [ u"dk",u"Mariager",2433,56.649851,9.975148 ],
    [ u"dk",u"Maribo",5349,54.775198,11.502437 ],
    [ u"dk",u"Mårslet",2698,56.063605,10.162305 ],
    [ u"dk",u"Marstal",2265,54.856205,10.517255 ],
    [ u"dk",u"Middelfart",13596,55.499223,9.744498 ],
    [ u"dk",u"Munkebo",5225,55.461837,10.555769 ],
    [ u"dk",u"Næstved",40660,55.224898,11.784213 ],
    [ u"dk",u"Nakskov",14081,54.837343,11.12839 ],
    [ u"dk",u"Neder Holluf",5612,55.364514,10.448243 ],
    [ u"dk",u"Neder Vindinge",1900,55.032107,11.883556 ],
    [ u"dk",u"Nexø",3841,55.058981,15.132815 ],
    [ u"dk",u"Nibe",4376,56.981502,9.639167 ],
    [ u"dk",u"Nivå",8035,55.934052,12.50485 ],
    [ u"dk",u"Nødebo",1875,55.978767,12.34685 ],
    [ u"dk",u"Nordborg",7406,55.057319,9.740799 ],
    [ u"dk",u"Nordby",2512,55.446031,8.39786 ],
    [ u"dk",u"Nørre Aaby",2678,55.461074,9.8794 ],
    [ u"dk",u"Nørre Alslev",2128,54.897835,11.884136 ],
    [ u"dk",u"Nyborg",15826,55.305846,10.803394 ],
    [ u"dk",u"Nykøbing",9326,56.791688,8.849895 ],
    [ u"dk",u"Nykøbing",16807,54.7655,11.875085 ],
    [ u"dk",u"Nyråd",2224,55.00511,11.960597 ],
    [ u"dk",u"Odder",11009,55.977212,10.168293 ],
    [ u"dk",u"Odense",145931,55.393475,10.394935 ],
    [ u"dk",u"Oksbøl",2845,55.626805,8.28757 ],
    [ u"dk",u"Ølgod",3891,55.806823,8.628588 ],
    [ u"dk",u"Ølstykke",5348,55.791587,12.145033 ],
    [ u"dk",u"Ørslev",1801,55.043558,11.967918 ],
    [ u"dk",u"Osted",2122,55.562283,11.957861 ],
    [ u"dk",u"Otterup",4522,55.51527,10.397562 ],
    [ u"dk",u"Padborg",4684,54.826572,9.362473 ],
    [ u"dk",u"Pandrup",2942,57.221197,9.67273 ],
    [ u"dk",u"Præstø",3695,55.117772,12.057272 ],
    [ u"dk",u"Randers",55780,56.460704,10.03639 ],
    [ u"dk",u"Ribe",7983,55.329462,8.781352 ],
    [ u"dk",u"Ringe",4849,55.245059,10.470646 ],
    [ u"dk",u"Ringkøbing",9315,56.08642,8.248684 ],
    [ u"dk",u"Ringsted",18794,55.441121,11.809437 ],
    [ u"dk",u"Rødbyhavn",2145,54.654424,11.352033 ],
    [ u"dk",u"Rødby",2379,54.694952,11.38885 ],
    [ u"dk",u"Rødding",2769,55.365691,9.063161 ],
    [ u"dk",u"Rødekro",5452,55.070155,9.31641 ],
    [ u"dk",u"Rønde",2213,56.301453,10.475055 ],
    [ u"dk",u"Rønnede",2395,55.257102,12.021245 ],
    [ u"dk",u"Rønne",13889,55.100907,14.706636 ],
    [ u"dk",u"Roskilde",44285,55.640094,12.08054 ],
    [ u"dk",u"Rudkøbing",4666,54.937994,10.721368 ],
    [ u"dk",u"Ryomgård",1952,56.384305,10.502952 ],
    [ u"dk",u"Ry",4909,56.090375,9.765053 ],
    [ u"dk",u"Sabro",1977,56.213327,10.034414 ],
    [ u"dk",u"Sæby",8435,57.331881,10.52251 ],
    [ u"dk",u"Sakskøbing",4928,54.798046,11.630404 ],
    [ u"dk",u"Seden",3350,55.426479,10.44265 ],
    [ u"dk",u"Silkeborg",38760,56.170146,9.565162 ],
    [ u"dk",u"Sindal",2898,57.476296,10.200914 ],
    [ u"dk",u"Skælskør",6455,55.250578,11.293522 ],
    [ u"dk",u"Skærbæk",3174,55.157353,8.769011 ],
    [ u"dk",u"Skagen",9747,57.726972,10.589686 ],
    [ u"dk",u"Skanderborg",13543,56.031296,9.931704 ],
    [ u"dk",u"Skibby",2661,55.751225,11.960827 ],
    [ u"dk",u"Skive",20815,56.563814,9.040245 ],
    [ u"dk",u"Skjern",7145,55.95,8.5 ],
    [ u"dk",u"Skørping",2722,56.83626,9.892549 ],
    [ u"dk",u"Skovby",2489,56.153396,9.956951 ],
    [ u"dk",u"Slagelse",31896,55.402719,11.354142 ],
    [ u"dk",u"Slangerup",6829,55.85,12.183333 ],
    [ u"dk",u"Smørumnedre",8968,55.742322,12.302763 ],
    [ u"dk",u"Snejbjerg",3513,56.138752,8.898956 ],
    [ u"dk",u"Snoghøj",2371,55.522527,9.721248 ],
    [ u"dk",u"Søften",2030,56.23801,10.085101 ],
    [ u"dk",u"Solbjerg",2964,56.04009,10.093077 ],
    [ u"dk",u"Solrød",14634,55.536009,12.182229 ],
    [ u"dk",u"Sønder Bjert",1815,55.452724,9.56741 ],
    [ u"dk",u"Sønderborg",27033,54.910634,9.792843 ],
    [ u"dk",u"Søndersø",2850,55.485263,10.255404 ],
    [ u"dk",u"Sorø",7167,55.438715,11.560856 ],
    [ u"dk",u"Spentrup",2155,56.537031,10.037917 ],
    [ u"dk",u"Starup",2091,55.24097,9.535032 ],
    [ u"dk",u"Stavnsholt",5658,55.814788,12.405454 ],
    [ u"dk",u"Stavtrup",3519,56.13124,10.119871 ],
    [ u"dk",u"Stege",3881,54.987043,12.284609 ],
    [ u"dk",u"Stenlille",1905,55.540225,11.591458 ],
    [ u"dk",u"Stenløse",13302,55.767676,12.196011 ],
    [ u"dk",u"Stige",2182,55.439413,10.409399 ],
    [ u"dk",u"Stilling",3655,56.062239,9.988215 ],
    [ u"dk",u"Stoholm",2202,56.484541,9.146167 ],
    [ u"dk",u"Store Heddinge",3679,55.309962,12.389795 ],
    [ u"dk",u"Storvorde",2796,57.003916,10.101252 ],
    [ u"dk",u"Støvring",6239,56.890869,9.830965 ],
    [ u"dk",u"Strandby",2518,57.491501,10.496085 ],
    [ u"dk",u"Strib",4339,55.540213,9.767479 ],
    [ u"dk",u"Strøby Egede",2700,55.413822,12.245015 ],
    [ u"dk",u"Struer",11317,56.486241,8.60442 ],
    [ u"dk",u"Stubbekøbing",2301,54.88942,12.040204 ],
    [ u"dk",u"Sundby",2922,54.863996,11.79302 ],
    [ u"dk",u"Sunds",3525,56.204169,9.012656 ],
    [ u"dk",u"Svebölle",2186,55.636785,11.317163 ],
    [ u"dk",u"Svejbæk",3743,56.132548,9.632894 ],
    [ u"dk",u"Svendborg",27553,55.058732,10.591346 ],
    [ u"dk",u"Svenstrup",4550,56.972304,9.848058 ],
    [ u"dk",u"Svinninge",2376,55.721114,11.465466 ],
    [ u"dk",u"Svogerslev",4355,55.634232,12.014654 ],
    [ u"dk",u"Taastrup",30977,55.647521,12.312019 ],
    [ u"dk",u"Tarm",4080,55.908615,8.530412 ],
    [ u"dk",u"Tårs",1856,57.383333,10.116667 ],
    [ u"dk",u"Taulov",2898,55.536919,9.609314 ],
    [ u"dk",u"Thisted",13020,56.958788,8.696409 ],
    [ u"dk",u"Thurø",3350,55.047398,10.663847 ],
    [ u"dk",u"Thyborøn",2587,56.698459,8.21238 ],
    [ u"dk",u"Tinglev",2829,54.93099,9.252433 ],
    [ u"dk",u"Tjæreborg",2146,55.464574,8.579683 ],
    [ u"dk",u"Toftlund",3438,55.18858,9.069251 ],
    [ u"dk",u"Tølløse",3457,55.612505,11.770344 ],
    [ u"dk",u"Tommerup",2072,55.319521,10.206589 ],
    [ u"dk",u"Tønder",7841,54.943118,8.869335 ],
    [ u"dk",u"Tørring",2370,55.853926,9.484182 ],
    [ u"dk",u"Tranbjerg",7307,56.090105,10.11937 ],
    [ u"dk",u"Trige",2475,56.252906,10.148399 ],
    [ u"dk",u"Trørød",8576,55.839465,12.544316 ],
    [ u"dk",u"Tune",5168,55.595283,12.183192 ],
    [ u"dk",u"Ulfborg",1994,56.267253,8.321668 ],
    [ u"dk",u"Ullerslev",2962,55.361722,10.651905 ],
    [ u"dk",u"Ulstrup",1963,56.389942,9.793545 ],
    [ u"dk",u"Vadum",1978,57.117904,9.857 ],
    [ u"dk",u"Værløse",12842,55.725,12.375 ],
    [ u"dk",u"Vamdrup",4685,55.427637,9.284347 ],
    [ u"dk",u"Varde",12735,55.62157,8.48073 ],
    [ u"dk",u"Vejen",8525,55.48117,9.137948 ],
    [ u"dk",u"Vejle",51177,55.708391,9.542763 ],
    [ u"dk",u"Veksø",1921,55.754734,12.238366 ],
    [ u"dk",u"Vestbjerg",2251,57.131656,9.959421 ],
    [ u"dk",u"Vester Hassing",2298,57.067674,10.125581 ],
    [ u"dk",u"Viborg",33844,56.45282,9.404291 ],
    [ u"dk",u"Viby",4505,55.548724,12.023912 ],
    [ u"dk",u"Videbæk",4052,56.087595,8.628517 ],
    [ u"dk",u"Vildbjerg",3773,56.2,8.766667 ],
    [ u"dk",u"Vindeby",2144,55.044891,10.613089 ],
    [ u"dk",u"Vinderup",2991,56.475147,8.790811 ],
    [ u"dk",u"Vindinge",2045,55.622977,12.138696 ],
    [ u"dk",u"Vipperød",2345,55.667675,11.739673 ],
    [ u"dk",u"Virklund",3113,56.132181,9.555824 ],
    [ u"dk",u"Vissenbjerg",3055,55.384825,10.137836 ],
    [ u"dk",u"Vodskov",4406,57.108539,10.022151 ],
    [ u"dk",u"Vojens",8019,55.246393,9.306035 ],
    [ u"dk",u"Vordingborg",8960,54.983333,11.9 ],
    [ u"dk",u"Vrå",2273,57.347626,9.951537 ],
    [ u"dm",u"Atkinson",2506,15.5166667,-61.2666667 ],
    [ u"dm",u"Barroui",1498,15.4333333,-61.45 ],
    [ u"dm",u"Berekua",3195,15.2333333,-61.3166667 ],
    [ u"dm",u"Castle Bruce",1997,15.4333333,-61.2666667 ],
    [ u"dm",u"Coulihaut",1604,15.4833333,-61.4833333 ],
    [ u"dm",u"La Plaine",2504,15.3333333,-61.25 ],
    [ u"dm",u"Mahaut",2405,15.35,-61.4 ],
    [ u"dm",u"Marigot",2907,15.5333333,-61.3 ],
    [ u"dm",u"Pointe Michel",1202,15.25,-61.3833333 ],
    [ u"dm",u"Pont Cassé",702,15.3666667,-61.35 ],
    [ u"dm",u"Portsmouth",3608,15.5833333,-61.4666667 ],
    [ u"dm",u"Roseau",16571,15.3,-61.4 ],
    [ u"dm",u"Wesley",1997,15.5666667,-61.3166667 ],
    [ u"do",u"Azua",59141,18.45,-70.7333333 ],
    [ u"do",u"Bajos de Haina",66810,18.4166667,-70.0333333 ],
    [ u"do",u"Baní",66712,18.2833333,-70.3333333 ],
    [ u"do",u"Barahona",77161,18.2,-71.1 ],
    [ u"do",u"Bayaguana",21059,18.75,-69.6333333 ],
    [ u"do",u"Bonao",73273,18.9333333,-70.4166667 ],
    [ u"do",u"Cabral",12303,18.25,-71.2166667 ],
    [ u"do",u"Comendador",12072,18.8775,-71.7027778 ],
    [ u"do",u"Constanza",29485,18.9166667,-70.75 ],
    [ u"do",u"Cotuí",41643,19.05,-70.15 ],
    [ u"do",u"Dajabón",16402,19.55,-71.7 ],
    [ u"do",u"Duvergé",13405,18.3666667,-71.5166667 ],
    [ u"do",u"El Peñón",4088,18.3,-71.1833333 ],
    [ u"do",u"El Seibo",23554,18.7666667,-69.0333333 ],
    [ u"do",u"Esperanza",42173,19.5833333,-71.0 ],
    [ u"do",u"Fantino",10025,19.1166667,-70.3 ],
    [ u"do",u"Hato Mayor",36002,18.7666667,-69.25 ],
    [ u"do",u"Higüey",123803,18.6166667,-68.7 ],
    [ u"do",u"Jarabacoa",29991,19.1166667,-70.6333333 ],
    [ u"do",u"Jimaní",6567,18.4908333,-71.8508333 ],
    [ u"do",u"La Mata",10295,19.15,-70.65 ],
    [ u"do",u"La Romana",208439,18.4166667,-68.9666667 ],
    [ u"do",u"Las Guáranas",9588,19.2,-70.2166667 ],
    [ u"do",u"Las Matas de Farfán",21803,18.8736111,-71.5213889 ],
    [ u"do",u"La Vega",102431,19.2166667,-70.5166667 ],
    [ u"do",u"Maimón",15297,19.8,-70.7833333 ],
    [ u"do",u"Mao",48297,19.5666667,-71.0833333 ],
    [ u"do",u"Moca",61838,19.4166667,-70.5666667 ],
    [ u"do",u"Monte Cristi",17001,19.8666667,-71.65 ],
    [ u"do",u"Monte Plata",15533,18.8,-69.7833333 ],
    [ u"do",u"Nagua",33863,19.3833333,-69.8333333 ],
    [ u"do",u"Neiba",18675,18.4666667,-71.4166667 ],
    [ u"do",u"Pedernales",11071,18.0333333,-71.75 ],
    [ u"do",u"Pimentel",9550,19.1833333,-70.1 ],
    [ u"do",u"Puerto Plata",119908,19.8,-70.6833333 ],
    [ u"do",u"Quisqueya",17697,18.55,-69.4166667 ],
    [ u"do",u"Sabana Grande de Boyá",16835,18.95,-69.8 ],
    [ u"do",u"Salcedo",11676,19.3833333,-70.4166667 ],
    [ u"do",u"Samaná",11433,19.2166667,-69.3166667 ],
    [ u"do",u"Sánchez",11368,19.2333333,-69.6 ],
    [ u"do",u"San Cristóbal",154045,18.4166667,-70.1 ],
    [ u"do",u"San Francisco de Macorís",124772,19.3,-70.25 ],
    [ u"do",u"San Ignacio de Sabaneta",16381,19.4666667,-71.3333333 ],
    [ u"do",u"San José de Ocoa",21149,18.55,-70.5 ],
    [ u"do",u"San Juan de la Maguana",72952,18.8,-71.2333333 ],
    [ u"do",u"San Pedro de Macorís",217901,18.45,-69.3 ],
    [ u"do",u"Santiago",555911,19.45,-70.7 ],
    [ u"do",u"Santo Domingo",2202016,18.4666667,-69.9 ],
    [ u"do",u"Sosúa",9483,19.75,-70.5166667 ],
    [ u"do",u"Tamayo",6431,18.4,-71.2 ],
    [ u"do",u"Tamboril",23305,19.4833333,-70.6 ],
    [ u"do",u"Villa Altagracia",40029,18.6666667,-70.1666667 ],
    [ u"do",u"Villa Bisonó",33141,19.5666667,-70.8666667 ],
    [ u"do",u"Villa Vázquez",11645,19.75,-71.45 ],
    [ u"dz",u"Adrar",89441,27.9,-0.2833333 ],
    [ u"dz",u"Aflu",84998,34.1088889,2.1019444 ],
    [ u"dz",u"Algiers",1980242,36.7630556,3.0505556 ],
    [ u"dz",u"Birin",51460,35.635,3.225 ],
    [ u"dz",u"Constantine",450126,36.365,6.6147222 ],
    [ u"dz",u"Médéa",147710,36.2675,2.75 ],
    [ u"dz",u"Sidi Ali",25309,36.1005556,0.42 ],
    [ u"dz",u"Tazmalt",21497,36.3872222,4.4016667 ],
    [ u"dz",u"Tigzirt",19748,36.8938889,4.1225 ],
    [ u"dz",u"Timizart",41398,36.8,4.2666667 ],
    [ u"dz",u"Tuggurt",49051,33.1,6.0666667 ],
    [ u"dz",u"Wahran",646025,35.6911111,-0.6416667 ],
    [ u"dz",u"Warqla",150611,31.9575,5.3277778 ],
    [ u"ec",u"Alamor",6391,-4.0333333,-80.0333333 ],
    [ u"ec",u"Alausí",14294,-2.2,-78.8333333 ],
    [ u"ec",u"Alfredo Baquerizo Moreno",12617,-1.9166667,-79.5166667 ],
    [ u"ec",u"Ambato",154369,-1.25,-78.6166667 ],
    [ u"ec",u"Archidona",7309,-0.9166667,-77.8 ],
    [ u"ec",u"Arenillas",15852,-3.55,-80.0666667 ],
    [ u"ec",u"Atuntaqui",17456,0.3333333,-78.2166667 ],
    [ u"ec",u"Azogues",34877,-2.7333333,-78.8333333 ],
    [ u"ec",u"Babahoyo",76279,-1.8166667,-79.5166667 ],
    [ u"ec",u"Bahía de Caráquez",37056,-0.6,-80.4166667 ],
    [ u"ec",u"Balao",12205,-2.7333333,-79.75 ],
    [ u"ec",u"Baños",9501,-1.4,-78.4166667 ],
    [ u"ec",u"Calceta",17286,-0.85,-80.1666667 ],
    [ u"ec",u"Cañar",9900,-2.55,-78.9333333 ],
    [ u"ec",u"Cariamanga",16862,-4.3333333,-79.55 ],
    [ u"ec",u"Catacocha",10872,-4.0666667,-79.6333333 ],
    [ u"ec",u"Catamayo",18565,-3.9833333,-79.35 ],
    [ u"ec",u"Catarama",9723,-1.5833333,-79.4666667 ],
    [ u"ec",u"Cayambe",26582,0.05,-78.1333333 ],
    [ u"ec",u"Celica",5499,-4.1166667,-79.95 ],
    [ u"ec",u"Chone",44751,-0.6833333,-80.1 ],
    [ u"ec",u"Colimes",9384,-1.55,-80.0166667 ],
    [ u"ec",u"Coronel Maridueña",7303,-2.2,-79.4166667 ],
    [ u"ec",u"Cotacachi",8238,0.3,-78.2666667 ],
    [ u"ec",u"Cuenca",276964,-2.8833333,-78.9833333 ],
    [ u"ec",u"Daule",48505,-1.8666667,-79.9333333 ],
    [ u"ec",u"El Ángel",3983,0.6166667,-77.9333333 ],
    [ u"ec",u"El Carmen",63371,-1.3166667,-80.0166667 ],
    [ u"ec",u"El Triunfo",32282,-1.9333333,-79.9666667 ],
    [ u"ec",u"Esmeraldas",95630,0.9833333,-79.7 ],
    [ u"ec",u"Gualaceo",17122,-2.9,-78.7833333 ],
    [ u"ec",u"Gualaquiza",4611,-3.4,-78.55 ],
    [ u"ec",u"Guano",12659,-1.5833333,-78.6333333 ],
    [ u"ec",u"Guaranda",22199,-1.6,-79.0 ],
    [ u"ec",u"Guayaquil",1952029,-2.1666667,-79.9 ],
    [ u"ec",u"Huaquillas",39757,-3.4833333,-80.2333333 ],
    [ u"ec",u"Ibarra",108666,0.35,-78.1166667 ],
    [ u"ec",u"Jipijapa",35901,-1.3333333,-80.5833333 ],
    [ u"ec",u"Junín",9128,-0.9333333,-80.2166667 ],
    [ u"ec",u"La Libertad",75881,-2.2333333,-80.9 ],
    [ u"ec",u"La Maná",16450,-0.9333333,-79.2166667 ],
    [ u"ec",u"Latacunga",51717,-0.9333333,-78.6166667 ],
    [ u"ec",u"La Troncal",36353,-2.4,-79.3333333 ],
    [ u"ec",u"Loja",117796,-4.0,-79.2166667 ],
    [ u"ec",u"Lomas de Sargentillo",7542,-1.8833333,-80.0833333 ],
    [ u"ec",u"Macará",13035,-4.3833333,-79.95 ],
    [ u"ec",u"Macas",23687,-2.3166667,-78.1166667 ],
    [ u"ec",u"Machachi",25742,-0.5,-78.5666667 ],
    [ u"ec",u"Machala",198123,-3.2666667,-79.9666667 ],
    [ u"ec",u"Manta",183166,-0.95,-80.7333333 ],
    [ u"ec",u"Milagro",110093,-2.0666667,-79.5333333 ],
    [ u"ec",u"Montalvo",15547,-1.8,-79.3333333 ],
    [ u"ec",u"Montecristi",18351,-1.05,-80.6666667 ],
    [ u"ec",u"Muisne",13393,0.6080556,-80.0441667 ],
    [ u"ec",u"Naranjal",32045,-2.6666667,-79.6166667 ],
    [ u"ec",u"Naranjito",34206,-2.2166667,-79.4833333 ],
    [ u"ec",u"Nueva Loja",24211,0.0847222,-76.8827778 ],
    [ u"ec",u"Otavalo",32330,0.2333333,-78.2666667 ],
    [ u"ec",u"Paján",9183,-1.5666667,-80.4166667 ],
    [ u"ec",u"Palenque",9083,-1.45,-79.7333333 ],
    [ u"ec",u"Palestina",9364,-1.9333333,-79.7333333 ],
    [ u"ec",u"Palora",6472,-1.7,-77.9333333 ],
    [ u"ec",u"Pasaje",44860,-3.3333333,-79.8166667 ],
    [ u"ec",u"Pedernales",5983,0.0833333,-80.05 ],
    [ u"ec",u"Pedro Carbo",23372,-1.8333333,-80.2333333 ],
    [ u"ec",u"Pelileo",16572,-1.3166667,-78.5333333 ],
    [ u"ec",u"Píllaro",7462,-1.1666667,-78.5333333 ],
    [ u"ec",u"Pimampiro",7408,0.4,-77.9666667 ],
    [ u"ec",u"Piñas",16981,-3.6666667,-79.65 ],
    [ u"ec",u"Playas",30564,-2.6333333,-80.3833333 ],
    [ u"ec",u"Portovelo",9708,-3.7166667,-79.6166667 ],
    [ u"ec",u"Portoviejo",170326,-1.05,-80.45 ],
    [ u"ec",u"Puebloviejo",10335,-3.7333333,-79.2833333 ],
    [ u"ec",u"Puerto Ayora",8996,-0.75,-90.3166667 ],
    [ u"ec",u"Puerto Baquerizo Moreno",4214,-0.9,-89.6 ],
    [ u"ec",u"Pujilí",16168,-0.95,-78.6833333 ],
    [ u"ec",u"Puyo",24881,-1.4666667,-77.9833333 ],
    [ u"ec",u"Quevedo",119436,-1.0333333,-79.45 ],
    [ u"ec",u"Quito",1399814,-0.2166667,-78.5 ],
    [ u"ec",u"Riobamba",124478,-1.6666667,-78.6333333 ],
    [ u"ec",u"Rocafuerte",10274,-0.9166667,-80.4333333 ],
    [ u"ec",u"Rosa Zárate",42121,0.3333333,-79.4666667 ],
    [ u"ec",u"Salinas",43862,-2.2166667,-80.9666667 ],
    [ u"ec",u"Samborondón",24118,-1.95,-79.7333333 ],
    [ u"ec",u"San Cristóbal",6164,-0.9166667,-89.5666667 ],
    [ u"ec",u"San Gabriel",15112,0.6,-77.8166667 ],
    [ u"ec",u"Sangolquí",5114,-0.3166667,-78.45 ],
    [ u"ec",u"San Lorenzo",20209,1.2883333,-78.8369444 ],
    [ u"ec",u"San Miguel",12575,-1.7,-79.0333333 ],
    [ u"ec",u"San Miguel",10838,-1.0333333,-78.5666667 ],
    [ u"ec",u"Santa Ana",12833,-1.2166667,-80.3833333 ],
    [ u"ec",u"Santa Elena",42214,-2.2333333,-80.85 ],
    [ u"ec",u"Santa Lucía",12523,-2.1833333,-80.0 ],
    [ u"ec",u"Santa Rosa",41816,-3.45,-79.9666667 ],
    [ u"ec",u"Santo Domingo",200421,-0.25,-79.15 ],
    [ u"ec",u"Saquisilí",3778,-0.8333333,-78.6666667 ],
    [ u"ec",u"Sucre",15286,-1.2666667,-80.4333333 ],
    [ u"ec",u"Sucúa",7413,-2.4666667,-78.1666667 ],
    [ u"ec",u"Tena",17172,-0.9833333,-77.8166667 ],
    [ u"ec",u"Tosagua",14680,-0.7833333,-80.25 ],
    [ u"ec",u"Valdez",11441,1.2491667,-78.9830556 ],
    [ u"ec",u"Velasco Ibarra",48754,-1.05,-79.6166667 ],
    [ u"ec",u"Ventanas",46708,-1.45,-79.4666667 ],
    [ u"ec",u"Vinces",32497,-1.55,-79.7333333 ],
    [ u"ec",u"Yaguachi",27947,-2.1166667,-79.6833333 ],
    [ u"ec",u"Yantzaza",9970,-3.8277778,-78.7594444 ],
    [ u"ec",u"Zamora",15276,-4.0691667,-78.9566667 ],
    [ u"ec",u"Zaruma",12505,-3.6833333,-79.6166667 ],
    [ u"ee",u"Aakre",295,58.1013889,26.1944444 ],
    [ u"ee",u"Ääsmäe",638,59.2380556,24.5086111 ],
    [ u"ee",u"Aaspere",315,59.4169444,26.1172222 ],
    [ u"ee",u"Abja-Paluoja",1372,58.1252778,25.3497222 ],
    [ u"ee",u"Adavere",646,58.7061111,25.8991667 ],
    [ u"ee",u"Aegviidu",910,59.2858333,25.6141667 ],
    [ u"ee",u"Ahja",616,58.2038889,27.0733333 ],
    [ u"ee",u"Ahula",329,59.1091667,25.7388889 ],
    [ u"ee",u"Äksi",453,58.5269444,26.6441667 ],
    [ u"ee",u"Alatskivi",430,58.5980556,27.1336111 ],
    [ u"ee",u"Alavere",427,59.2433333,25.3244444 ],
    [ u"ee",u"Albu",349,59.1505556,25.6669444 ],
    [ u"ee",u"Alliku",220,59.3538889,24.55 ],
    [ u"ee",u"Ämari",579,59.3666667,24.5833333 ],
    [ u"ee",u"Ambla",352,59.1911111,25.8455556 ],
    [ u"ee",u"Annikoru",329,58.2672222,26.3005556 ],
    [ u"ee",u"Antsla",1468,57.8255556,26.5405556 ],
    [ u"ee",u"Aravete",955,59.1416667,25.7613889 ],
    [ u"ee",u"Aravu",144,58.2313889,27.3858333 ],
    [ u"ee",u"Ardu",559,59.1005556,25.3708333 ],
    [ u"ee",u"Are",408,58.5216667,24.5675 ],
    [ u"ee",u"Aruküla",1829,59.3644444,25.0772222 ],
    [ u"ee",u"Aseri",1831,59.4505556,26.8675 ],
    [ u"ee",u"Assaku",402,59.3775,24.8447222 ],
    [ u"ee",u"Aste",546,58.3436111,22.4588889 ],
    [ u"ee",u"Audru",1430,58.4086111,24.3738889 ],
    [ u"ee",u"Avinurme",779,58.9822222,26.8641667 ],
    [ u"ee",u"Eidapere",325,58.7513889,24.9427778 ],
    [ u"ee",u"Elva",5820,58.2225,26.4211111 ],
    [ u"ee",u"Erastvere",311,57.9697222,26.7938889 ],
    [ u"ee",u"Esku",413,58.6475,25.8830556 ],
    [ u"ee",u"Essu",302,59.4325,26.365 ],
    [ u"ee",u"Haabneeme",2077,59.5113889,24.8211111 ],
    [ u"ee",u"Häädemeeste",851,58.0813889,24.5102778 ],
    [ u"ee",u"Haage",370,58.365,26.6272222 ],
    [ u"ee",u"Haapsalu",11805,58.9430556,23.5413889 ],
    [ u"ee",u"Habaja",345,59.0994444,25.1752778 ],
    [ u"ee",u"Haiba",395,59.1266667,24.4672222 ],
    [ u"ee",u"Haljala",1233,59.4336111,26.2613889 ],
    [ u"ee",u"Halliste",362,58.3366667,25.0983333 ],
    [ u"ee",u"Harju-Risti",387,59.2341667,24.0183333 ],
    [ u"ee",u"Harku",781,59.1325,24.3711111 ],
    [ u"ee",u"Harkujärve",453,59.4172222,24.5872222 ],
    [ u"ee",u"Helme",407,58.0119444,25.8972222 ],
    [ u"ee",u"Himmaste",545,58.0769444,27.0741667 ],
    [ u"ee",u"Hulja",569,59.3522222,26.2141667 ],
    [ u"ee",u"Hummuli",404,57.9036111,26.0583333 ],
    [ u"ee",u"Hüüru",349,59.3819444,24.5297222 ],
    [ u"ee",u"Ignase",106,58.2611111,26.8469444 ],
    [ u"ee",u"Iisaku",916,59.1013889,27.3080556 ],
    [ u"ee",u"Ilmatsalu",512,58.3863889,26.5466667 ],
    [ u"ee",u"Imavere",486,58.7330556,25.7725 ],
    [ u"ee",u"Jämejala",294,58.3894444,25.5661111 ],
    [ u"ee",u"Jäneda",448,59.2458333,25.7044444 ],
    [ u"ee",u"Järva-Jaani",1051,59.0386111,25.8863889 ],
    [ u"ee",u"Järvakandi",1471,58.7788889,24.8258333 ],
    [ u"ee",u"Jarve",682,59.3986111,27.2730556 ],
    [ u"ee",u"Jõesuu",393,58.4927778,24.9113889 ],
    [ u"ee",u"Jõgeva",6396,58.7466667,26.3938889 ],
    [ u"ee",u"Jõhvi",11469,59.3591667,27.4211111 ],
    [ u"ee",u"Jõõpre",448,58.4733333,24.3241667 ],
    [ u"ee",u"Jüri",2581,59.3541667,24.8941667 ],
    [ u"ee",u"Juuru",571,59.0647222,24.9502778 ],
    [ u"ee",u"Kaagjärve",317,57.7672222,26.1772222 ],
    [ u"ee",u"Kääpa",306,57.8708333,27.1063889 ],
    [ u"ee",u"Käärdi",573,58.2080556,26.4113889 ],
    [ u"ee",u"Kaarepere",334,58.6633333,26.5269444 ],
    [ u"ee",u"Kabala",366,58.6897222,25.6272222 ],
    [ u"ee",u"Kabli",365,58.3358333,24.7361111 ],
    [ u"ee",u"Kadrina",2406,59.3347222,26.145 ],
    [ u"ee",u"Kaerepere",544,58.9655556,24.8436111 ],
    [ u"ee",u"Käina",854,58.8255556,22.7897222 ],
    [ u"ee",u"Kaiu",595,59.0105556,25.0597222 ],
    [ u"ee",u"Kallaste",1171,58.655,27.1591667 ],
    [ u"ee",u"Kambja",722,58.2305556,26.7005556 ],
    [ u"ee",u"Kanepi",638,57.9830556,26.7563889 ],
    [ u"ee",u"Käravete",295,59.1911111,25.7541667 ],
    [ u"ee",u"Kärdla",3763,58.9977778,22.7491667 ],
    [ u"ee",u"Karjaküla",362,59.3402778,24.3855556 ],
    [ u"ee",u"Karksi",528,58.1033333,25.5627778 ],
    [ u"ee",u"Karksi-Nuia",1986,58.1033333,25.5627778 ],
    [ u"ee",u"Kärla",988,58.3358333,22.2597222 ],
    [ u"ee",u"Kärstna",300,58.145,25.81 ],
    [ u"ee",u"Käru",460,58.8338889,25.1480556 ],
    [ u"ee",u"Kauksi",317,58.0883333,27.2205556 ],
    [ u"ee",u"Keava",294,58.9463889,24.9033333 ],
    [ u"ee",u"Keeni",351,57.9538889,26.2797222 ],
    [ u"ee",u"Kehra",3183,59.3361111,25.3211111 ],
    [ u"ee",u"Kehtna",1579,58.9302778,24.8780556 ],
    [ u"ee",u"Keila-Joa",378,59.3997222,24.3044444 ],
    [ u"ee",u"Keila",9411,59.3036111,24.4130556 ],
    [ u"ee",u"Kihelkonna",476,58.3522222,22.0469444 ],
    [ u"ee",u"Kiili",942,59.3069444,24.8377778 ],
    [ u"ee",u"Kiisa",551,59.2369444,24.6888889 ],
    [ u"ee",u"Kiiu",833,59.4477778,25.3794444 ],
    [ u"ee",u"Kilingi-Nõmme",2175,58.1502778,24.9641667 ],
    [ u"ee",u"Kiviõli",6953,59.3530556,26.9711111 ],
    [ u"ee",u"Kivi-Vigala",293,58.7152778,24.3769444 ],
    [ u"ee",u"Klooga",983,59.3197222,24.2113889 ],
    [ u"ee",u"Kobela",468,57.8419444,26.4638889 ],
    [ u"ee",u"Kodila",336,59.0425,24.6683333 ],
    [ u"ee",u"Koeru",1300,58.9630556,26.0308333 ],
    [ u"ee",u"Kohila",3355,59.1680556,24.7575 ],
    [ u"ee",u"Kohtla-Järve",46060,59.3986111,27.2730556 ],
    [ u"ee",u"Kohtla-Nõmme",1075,59.3516667,27.175 ],
    [ u"ee",u"Koigi",448,59.1716667,25.9730556 ],
    [ u"ee",u"Kolga-Jaani",420,58.5330556,25.9458333 ],
    [ u"ee",u"Kolga",520,59.4866667,25.6191667 ],
    [ u"ee",u"Kolkja",397,58.5455556,27.215 ],
    [ u"ee",u"Kollino",301,57.8158333,26.5588889 ],
    [ u"ee",u"Koluvere",494,58.9052778,24.1083333 ],
    [ u"ee",u"Kõo",318,58.6291667,25.7211111 ],
    [ u"ee",u"Koonga",303,58.5825,24.1541667 ],
    [ u"ee",u"Koosa",548,58.52,27.0741667 ],
    [ u"ee",u"Kõpu",363,58.3269444,25.3116667 ],
    [ u"ee",u"Kõrveküla",571,58.4241667,26.7822222 ],
    [ u"ee",u"Kose",2232,59.4580556,24.8783333 ],
    [ u"ee",u"Kose",549,57.8127778,27.0369444 ],
    [ u"ee",u"Kose-Uuemõisa",980,59.2,25.1052778 ],
    [ u"ee",u"Kostivere",790,59.4255556,25.1036111 ],
    [ u"ee",u"Krootuse",417,58.0711111,26.835 ],
    [ u"ee",u"Kudjape",450,58.2552778,22.5491667 ],
    [ u"ee",u"Kuimetsa",385,59.0433333,25.1252778 ],
    [ u"ee",u"Külitse",361,58.3230556,26.6122222 ],
    [ u"ee",u"Kullamaa",332,58.8788889,24.0816667 ],
    [ u"ee",u"Kumna",315,59.325,24.4388889 ],
    [ u"ee",u"Kunda",3764,59.4833333,26.5333333 ],
    [ u"ee",u"Kuremaa",594,58.7366667,26.5225 ],
    [ u"ee",u"Kuremäe",369,59.2025,27.5363889 ],
    [ u"ee",u"Kuressaare",14922,58.2480556,22.5038889 ],
    [ u"ee",u"Kurtna",331,59.2313889,24.7183333 ],
    [ u"ee",u"Kuusalu",1238,59.4438889,25.4413889 ],
    [ u"ee",u"Laagri",4135,59.3513889,24.5988889 ],
    [ u"ee",u"Laekvere",472,59.0655556,26.5655556 ],
    [ u"ee",u"Laeva",468,58.4919444,26.3616667 ],
    [ u"ee",u"Lagedi",939,59.4055556,24.9422222 ],
    [ u"ee",u"Lähte",487,58.4891667,26.6702778 ],
    [ u"ee",u"Laiuse",461,58.7880556,26.4841667 ],
    [ u"ee",u"Lasva",309,57.8627778,27.1841667 ],
    [ u"ee",u"Lavassaare",548,58.5113889,24.3888889 ],
    [ u"ee",u"Lehola",530,59.2925,24.3113889 ],
    [ u"ee",u"Lehtmetsa",789,59.32,25.3569444 ],
    [ u"ee",u"Lehtse",493,59.2494444,25.8230556 ],
    [ u"ee",u"Leie",284,58.42,26.0258333 ],
    [ u"ee",u"Leisi",329,58.5705556,22.6969444 ],
    [ u"ee",u"Lelle",431,58.8636111,25.0044444 ],
    [ u"ee",u"Libatse",488,58.6588889,24.4830556 ],
    [ u"ee",u"Lihula",1457,58.6813889,23.8452778 ],
    [ u"ee",u"Linna",456,58.0316667,25.8525 ],
    [ u"ee",u"Linnamäe",460,58.9961111,23.7069444 ],
    [ u"ee",u"Linte",286,58.1552778,27.4591667 ],
    [ u"ee",u"Lohkva",776,58.3691667,26.7980556 ],
    [ u"ee",u"Lohusuu",394,58.9436111,27.045 ],
    [ u"ee",u"Loksa",3463,59.5763889,25.7213889 ],
    [ u"ee",u"Loo",2175,59.4363889,24.9483333 ],
    [ u"ee",u"Lüganuse",454,59.3805556,27.0302778 ],
    [ u"ee",u"Luige",562,59.3388889,24.7616667 ],
    [ u"ee",u"Luke",335,58.2402778,26.5366667 ],
    [ u"ee",u"Lüllemäe",290,57.7511111,26.3838889 ],
    [ u"ee",u"Lustivere",477,58.6669444,26.0836111 ],
    [ u"ee",u"Luua",432,58.6513889,26.5972222 ],
    [ u"ee",u"Luunja",579,58.3558333,26.8808333 ],
    [ u"ee",u"Maardu",16630,59.4280556,25.025 ],
    [ u"ee",u"Mäetaguse",542,59.2297222,27.2722222 ],
    [ u"ee",u"Mammaste",616,58.0666667,27.0452778 ],
    [ u"ee",u"Märjamaa",3063,58.9038889,24.4305556 ],
    [ u"ee",u"Melliste",484,58.3288889,26.9813889 ],
    [ u"ee",u"Miiduranna",399,59.5002778,24.8208333 ],
    [ u"ee",u"Mikitamäe",345,58.0008333,27.5480556 ],
    [ u"ee",u"Misso",324,57.6022222,27.2377778 ],
    [ u"ee",u"Mõisaküla",1090,58.0922222,25.1863889 ],
    [ u"ee",u"Mooste",450,58.1561111,27.1927778 ],
    [ u"ee",u"Muraste",337,59.4572222,24.4308333 ],
    [ u"ee",u"Mustjala",295,58.4613889,22.2416667 ],
    [ u"ee",u"Mustla",928,58.1341667,25.1002778 ],
    [ u"ee",u"Mustvee",1662,58.8486111,26.9397222 ],
    [ u"ee",u"Näpi",404,59.3647222,26.4025 ],
    [ u"ee",u"Narva-Jõesuu",2802,59.4588889,28.0408333 ],
    [ u"ee",u"Narva",66980,59.3772222,28.1902778 ],
    [ u"ee",u"Nasva",330,58.2294444,22.385 ],
    [ u"ee",u"Nõo",1476,58.2755556,26.5375 ],
    [ u"ee",u"Oisu",418,58.7536111,25.565 ],
    [ u"ee",u"Õisu",351,58.1972222,25.5502778 ],
    [ u"ee",u"Olgina",504,59.3952778,28.1252778 ],
    [ u"ee",u"Olustvere",647,58.5536111,25.5627778 ],
    [ u"ee",u"Orava",300,57.8966667,27.4591667 ],
    [ u"ee",u"Orgita",540,58.9286111,24.4288889 ],
    [ u"ee",u"Orissaare",1065,58.5597222,23.0930556 ],
    [ u"ee",u"Oru",394,59.1877778,24.9805556 ],
    [ u"ee",u"Osula",335,57.8858333,26.8197222 ],
    [ u"ee",u"Otepää",351,58.0583333,26.4966667 ],
    [ u"ee",u"Padise",392,59.2311111,24.1405556 ],
    [ u"ee",u"Paide",9735,58.8855556,25.5572222 ],
    [ u"ee",u"Paikuse",1996,58.3791667,24.6344444 ],
    [ u"ee",u"Paistu",346,58.2705556,25.6227778 ],
    [ u"ee",u"Pajusti",756,59.2744444,26.4233333 ],
    [ u"ee",u"Palamuse",541,58.685,26.5788889 ],
    [ u"ee",u"Paldiski",4202,59.3566667,24.0530556 ],
    [ u"ee",u"Palivere",968,58.9702778,23.9033333 ],
    [ u"ee",u"Panga",290,58.8166667,23.55 ],
    [ u"ee",u"Papsaare",497,58.4047222,24.4069444 ],
    [ u"ee",u"Päri",475,58.3452778,25.5033333 ],
    [ u"ee",u"Parksepa",737,57.9097222,26.9830556 ],
    [ u"ee",u"Pärnu-Jaagupi",1341,58.6058333,24.5152778 ],
    [ u"ee",u"Pärnu",44193,58.3747222,24.5136111 ],
    [ u"ee",u"Peetri",824,59.3941667,24.8133333 ],
    [ u"ee",u"Peetri",307,58.95,25.8333333 ],
    [ u"ee",u"Piira",371,59.3102778,26.3938889 ],
    [ u"ee",u"Pisisaare",300,58.7238889,25.9683333 ],
    [ u"ee",u"Põlgaste",372,57.9802778,26.88 ],
    [ u"ee",u"Põltsamaa",4764,58.6525,25.9705556 ],
    [ u"ee",u"Põlva",6504,58.0602778,27.0694444 ],
    [ u"ee",u"Prillimäe",406,59.1883333,24.805 ],
    [ u"ee",u"Pringi",603,59.5394444,24.7938889 ],
    [ u"ee",u"Puhja",1072,58.3419444,26.3147222 ],
    [ u"ee",u"Puiatu",291,58.3616667,25.4205556 ],
    [ u"ee",u"Puiga",332,57.7961111,27.0388889 ],
    [ u"ee",u"Puka",748,58.0497222,26.2263889 ],
    [ u"ee",u"Purtse",298,59.4188889,27.0163889 ],
    [ u"ee",u"Püssi",1840,59.36,27.0497222 ],
    [ u"ee",u"Püünsi",729,59.5508333,24.7958333 ],
    [ u"ee",u"Puurmani",646,58.5783333,26.2752778 ],
    [ u"ee",u"Raasiku",1317,59.3663889,25.1830556 ],
    [ u"ee",u"Rahinge",346,58.3844444,26.6105556 ],
    [ u"ee",u"Raikküla",301,58.9386111,24.7613889 ],
    [ u"ee",u"Raja",469,58.7963889,26.9497222 ],
    [ u"ee",u"Rakke",1045,58.9816667,26.2544444 ],
    [ u"ee",u"Rakvere",16736,59.3463889,26.3558333 ],
    [ u"ee",u"Ramsi",732,58.3058333,25.5352778 ],
    [ u"ee",u"Randvere",513,59.5088889,24.8997222 ],
    [ u"ee",u"Räni",498,58.3575,26.6505556 ],
    [ u"ee",u"Rannu",439,58.2366667,26.2180556 ],
    [ u"ee",u"Räpina",2901,58.0980556,27.4636111 ],
    [ u"ee",u"Rapla",5684,59.0072222,24.7927778 ],
    [ u"ee",u"Ravila",377,59.1786111,25.2163889 ],
    [ u"ee",u"Reiu",376,58.2930556,24.5891667 ],
    [ u"ee",u"Riisipere",1058,59.1141667,24.3105556 ],
    [ u"ee",u"Risti",597,58.5605556,23.8394444 ],
    [ u"ee",u"Roela",596,59.1702778,26.6002778 ],
    [ u"ee",u"Rohuneeme",316,59.5569444,24.7972222 ],
    [ u"ee",u"Roiu",485,58.3,26.8713889 ],
    [ u"ee",u"Rõngu",738,58.1452778,26.2480556 ],
    [ u"ee",u"Roosna-Alliku",488,59.0272222,25.7083333 ],
    [ u"ee",u"Rosma",377,58.0361111,27.0719444 ],
    [ u"ee",u"Rõuge",442,57.7277778,26.9097222 ],
    [ u"ee",u"Rummu",3488,59.5352778,24.7997222 ],
    [ u"ee",u"Saarepeedi",330,58.4305556,25.6905556 ],
    [ u"ee",u"Sääse",495,59.1586111,26.1538889 ],
    [ u"ee",u"Sadala",306,58.8652778,26.6019444 ],
    [ u"ee",u"Saku",4548,59.3022222,24.6577778 ],
    [ u"ee",u"Salme",576,58.1613889,22.2622222 ],
    [ u"ee",u"Särevere",1035,58.79,25.4280556 ],
    [ u"ee",u"Saru",299,57.6047222,26.5386111 ],
    [ u"ee",u"Saue",5022,59.3202778,24.5525 ],
    [ u"ee",u"Sauga",1062,58.4166667,24.4333333 ],
    [ u"ee",u"Saverna",398,58.0688889,26.7247222 ],
    [ u"ee",u"Seljametsa",318,58.3608333,24.6658333 ],
    [ u"ee",u"Selja",405,58.5136111,24.8088889 ],
    [ u"ee",u"Sihva",362,58.0194444,26.4347222 ],
    [ u"ee",u"Siimusti",797,58.7297222,26.3394444 ],
    [ u"ee",u"Sillamäe",16672,59.3997222,27.7547222 ],
    [ u"ee",u"Simuna",474,59.0430556,26.4038889 ],
    [ u"ee",u"Sindi",4036,58.4005556,24.6675 ],
    [ u"ee",u"Sinimäe",352,59.3722222,27.8747222 ],
    [ u"ee",u"Sipa",338,58.9227778,24.3155556 ],
    [ u"ee",u"Soe",307,58.2133333,25.9280556 ],
    [ u"ee",u"Soinaste",336,58.3388889,26.6897222 ],
    [ u"ee",u"Sõmerpalu",413,57.85,26.8252778 ],
    [ u"ee",u"Sõmeru",1350,59.3611111,26.4375 ],
    [ u"ee",u"Sonda",594,59.3436111,26.8363889 ],
    [ u"ee",u"Sooru",294,57.8533333,26.1158333 ],
    [ u"ee",u"Suigu",295,58.5286111,24.6966667 ],
    [ u"ee",u"Suislepa",305,58.1497222,25.9569444 ],
    [ u"ee",u"Sürgavere",423,58.4925,25.4841667 ],
    [ u"ee",u"Surju",320,58.235,24.7175 ],
    [ u"ee",u"Suure-Jaani",1254,58.5361111,25.4705556 ],
    [ u"ee",u"Suuremõisa",316,58.865,22.9522222 ],
    [ u"ee",u"Tabasalu",2166,59.4302778,24.5330556 ],
    [ u"ee",u"Tabivere",1062,58.5541667,26.5955556 ],
    [ u"ee",u"Taebla",990,58.9538889,23.7522222 ],
    [ u"ee",u"Tali",345,58.0591667,24.7888889 ],
    [ u"ee",u"Tallinn",394023,59.4338889,24.7280556 ],
    [ u"ee",u"Tamme",349,58.9283333,24.6438889 ],
    [ u"ee",u"Tammiku",376,59.3294444,27.3816667 ],
    [ u"ee",u"Tammiste",354,58.3886111,24.5819444 ],
    [ u"ee",u"Tamsalu",2594,59.1586111,26.1152778 ],
    [ u"ee",u"Tapa",6551,59.2247222,25.9188889 ],
    [ u"ee",u"Tapa",6551,59.2605556,25.9586111 ],
    [ u"ee",u"Tarbja",355,58.9297222,25.5880556 ],
    [ u"ee",u"Tartu",101092,58.3661111,26.7361111 ],
    [ u"ee",u"Tihemetsa",894,58.1452778,25.0441667 ],
    [ u"ee",u"Tilsi",430,57.975,27.0122222 ],
    [ u"ee",u"Toila",750,59.4236111,27.5025 ],
    [ u"ee",u"Tootsi",1010,58.5780556,24.7925 ],
    [ u"ee",u"Tõravere",311,58.2694444,26.4586111 ],
    [ u"ee",u"Tori",526,58.4788889,24.8241667 ],
    [ u"ee",u"Torma",533,58.8127778,26.7383333 ],
    [ u"ee",u"Tõrva",3112,58.0027778,25.935 ],
    [ u"ee",u"Tõstamaa",639,58.3325,23.9997222 ],
    [ u"ee",u"Triigi",291,59.1138889,26.34 ],
    [ u"ee",u"Tsirguliina",515,57.86,26.1969444 ],
    [ u"ee",u"Tsooru",313,57.7402778,26.6555556 ],
    [ u"ee",u"Tudulinna",295,59.0372222,27.0852778 ],
    [ u"ee",u"Tudu",441,59.1772222,26.8580556 ],
    [ u"ee",u"Turba",1096,59.0830556,24.225 ],
    [ u"ee",u"Türi-Alliku",507,58.8158333,25.4538889 ],
    [ u"ee",u"Türi",6138,58.8086111,25.4325 ],
    [ u"ee",u"Ubja",311,59.4122222,26.4272222 ],
    [ u"ee",u"Uhti",327,58.2786111,26.73 ],
    [ u"ee",u"Uhtna",355,59.3916667,26.5622222 ],
    [ u"ee",u"Ülenurme",1047,58.3158333,26.7241667 ],
    [ u"ee",u"Ulila",349,58.3633333,26.4261111 ],
    [ u"ee",u"Ulvi",290,59.3241667,26.6361111 ],
    [ u"ee",u"Uuemõisa",1068,58.9394444,23.5894444 ],
    [ u"ee",u"Uulu",524,58.2836111,24.5872222 ],
    [ u"ee",u"Uusna",368,58.3891667,25.7283333 ],
    [ u"ee",u"Väätsa",679,58.8855556,25.4463889 ],
    [ u"ee",u"Vaida",1016,59.2905556,24.9658333 ],
    [ u"ee",u"Väike-Kamari",489,58.6111111,25.9841667 ],
    [ u"ee",u"Väike-Maarja",2155,59.1263889,26.25 ],
    [ u"ee",u"Vaimastvere",346,58.8127778,26.2916667 ],
    [ u"ee",u"Väimela",799,57.8908333,27.0188889 ],
    [ u"ee",u"Vajangu",401,59.0975,26.0333333 ],
    [ u"ee",u"Valga",13946,57.7744444,26.0452778 ],
    [ u"ee",u"Valjala",503,58.4061111,22.8011111 ],
    [ u"ee",u"Valkla",663,59.4744444,25.3186111 ],
    [ u"ee",u"Vana-Antsla",313,57.8661111,26.5322222 ],
    [ u"ee",u"Vanamõisa",353,59.3244444,24.5347222 ],
    [ u"ee",u"Vana-Vigala",572,58.7697222,24.2736111 ],
    [ u"ee",u"Vana-Võidu",517,58.3905556,25.6541667 ],
    [ u"ee",u"Vändra",2544,58.6158333,25.0969444 ],
    [ u"ee",u"Vao",431,59.1058333,26.1902778 ],
    [ u"ee",u"Vara",406,58.5208333,26.8816667 ],
    [ u"ee",u"Varbola",323,59.0433333,24.4491667 ],
    [ u"ee",u"Värska",563,57.9580556,27.6380556 ],
    [ u"ee",u"Varstu",437,57.6391667,26.6597222 ],
    [ u"ee",u"Vasalemma",856,59.2441667,24.29 ],
    [ u"ee",u"Vaskjala",325,59.3608333,24.9436111 ],
    [ u"ee",u"Vastemõisa",450,58.4422222,25.4330556 ],
    [ u"ee",u"Vastse-Kuuste",510,58.1677778,26.9286111 ],
    [ u"ee",u"Vastseliina",773,57.7263889,27.3583333 ],
    [ u"ee",u"Veltsi",293,59.3986111,26.2652778 ],
    [ u"ee",u"Veriora",549,58.0041667,27.3519444 ],
    [ u"ee",u"Vihtra",309,58.5875,25.0152778 ],
    [ u"ee",u"Viimsi",1740,59.4966667,24.8422222 ],
    [ u"ee",u"Viiratsi",1338,58.36,25.6372222 ],
    [ u"ee",u"Viljandi",20310,58.3638889,25.59 ],
    [ u"ee",u"Vinni",1032,59.2894444,26.3969444 ],
    [ u"ee",u"Virtsu",731,58.57,23.5238889 ],
    [ u"ee",u"Viru-Jaagupi",376,59.2425,26.4758333 ],
    [ u"ee",u"Viru-Nigula",364,59.4441667,26.6875 ],
    [ u"ee",u"Võhma",1551,58.6283333,25.5483333 ],
    [ u"ee",u"Võisiku",516,58.6283333,25.9205556 ],
    [ u"ee",u"Võiste",520,58.4666667,24.4833333 ],
    [ u"ee",u"Voka",1046,59.3997222,27.5816667 ],
    [ u"ee",u"Võnnu",630,58.2783333,27.0480556 ],
    [ u"ee",u"Voore",321,58.7152778,26.7513889 ],
    [ u"ee",u"Võru",14630,57.8338889,27.0194444 ],
    [ u"ee",u"Võsu",481,59.5725,25.9752778 ],
    [ u"eg",u"Abnub",68756,27.2666667,31.1502778 ],
    [ u"eg",u"Aja",34692,30.9416667,31.2922222 ],
    [ u"eg",u"Akhmim",99459,26.5666667,31.7333333 ],
    [ u"eg",u"Alexandria",3811512,31.1980556,29.9191667 ],
    [ u"eg",u"Aswan",241282,24.0875,32.8988889 ],
    [ u"eg",u"Asyut",420614,27.1827778,31.1827778 ],
    [ u"eg",u"Beba",59937,28.925,30.9833333 ],
    [ u"eg",u"Benha",167070,30.4608333,31.1875 ],
    [ u"eg",u"Beni Mazâr",58158,28.5036111,30.7991667 ],
    [ u"eg",u"Beni Suef",189637,29.0638889,31.0888889 ],
    [ u"eg",u"Cairo",7734602,30.05,31.25 ],
    [ u"eg",u"Damietta",76906,31.4194444,31.815 ],
    [ u"eg",u"Dekernes",137559,31.0883333,31.5969444 ],
    [ u"eg",u"Deshna",54197,26.1211111,32.4652778 ],
    [ u"eg",u"Diyarb Najm",51841,30.7541667,31.4405556 ],
    [ u"eg",u"El Badâri",44132,26.9922222,31.4152778 ],
    [ u"eg",u"El Balyana",48801,26.2386111,32.0030556 ],
    [ u"eg",u"El Faiyûm",306421,29.3077778,30.84 ],
    [ u"eg",u"El Mahalla el Kubra",431088,30.9761111,31.1669444 ],
    [ u"eg",u"El Wasta",37453,29.3377778,31.2055556 ],
    [ u"eg",u"Esna",69335,25.2930556,32.5527778 ],
    [ u"eg",u"Fowa",63310,31.2025,30.5472222 ],
    [ u"eg",u"Gizeh",2443490,30.0086111,31.2122222 ],
    [ u"eg",u"Hihya",43432,30.67,31.5872222 ],
    [ u"eg",u"Hurghada",95689,27.2388889,33.8361111 ],
    [ u"eg",u"Ismailia",284851,30.5833333,32.2666667 ],
    [ u"eg",u"Luxor",422408,25.6833333,32.65 ],
    [ u"eg",u"Madinat Sittah Uktubar",41930,29.8166667,31.05 ],
    [ u"eg",u"Marsa Matruh",62049,31.35,27.2333333 ],
    [ u"eg",u"Matay",45215,28.4222222,30.7555556 ],
    [ u"eg",u"Port Said",538377,31.2666667,32.3 ],
    [ u"eg",u"Qalyub",100521,30.1830556,31.2052778 ],
    [ u"eg",u"Qena",235390,26.17,32.7272222 ],
    [ u"eg",u"Rosetta",64489,31.4044444,30.4163889 ],
    [ u"eg",u"Safaga",32944,26.7333333,33.9333333 ],
    [ u"eg",u"Sohag",209440,26.55,31.7 ],
    [ u"eg",u"Suez",488124,29.9666667,32.55 ],
    [ u"eg",u"Tahta",90604,26.7680556,31.4938889 ],
    [ u"eg",u"Tala",51498,30.6819444,30.9475 ],
    [ u"eg",u"Talkha",157756,31.0530556,31.3738889 ],
    [ u"eg",u"Tanta",404934,30.7911111,30.9980556 ],
    [ u"er",u"Addi Ugri",17784,14.8855556,38.8163889 ],
    [ u"er",u"Asmara",563948,15.3333333,38.9333333 ],
    [ u"er",u"Barentu",15891,15.1138889,37.5927778 ],
    [ u"er",u"Edd",11259,13.9297222,41.6925 ],
    [ u"er",u"Ginda",11560,15.4491667,39.0886111 ],
    [ u"er",u"Teseney",3753,15.11,36.6575 ],
    [ u"es",u"Abarán",13850,38.205507,-1.399072 ],
    [ u"es",u"A Coruña",236010,43.366609,-8.406812 ],
    [ u"es",u"Adeje",22245,28.11984,-16.725581 ],
    [ u"es",u"Adra",23988,36.747398,-3.015989 ],
    [ u"es",u"Aguilar de la Frontera",13557,37.514454,-4.656173 ],
    [ u"es",u"Águilas",30739,37.405983,-1.5853 ],
    [ u"es",u"Agüimes",21908,27.905052,-15.445395 ],
    [ u"es",u"Albacete",155083,38.995845,-1.857773 ],
    [ u"es",u"Albal",13507,39.4,-.416667 ],
    [ u"es",u"Albolote",14355,37.230062,-3.655454 ],
    [ u"es",u"Alboraya",19431,39.5,-.35 ],
    [ u"es",u"Albox",10688,37.388557,-2.149495 ],
    [ u"es",u"Alcalá de Guadaira",58934,37.337906,-5.839506 ],
    [ u"es",u"Alcalá de Henares",195152,40.482048,-3.359957 ],
    [ u"es",u"Alcalá la Real",21377,37.461402,-3.923013 ],
    [ u"es",u"Alcañiz",13884,41.05,-.133333 ],
    [ u"es",u"Alcantarilla",37969,37.96939,-1.217138 ],
    [ u"es",u"Alcaudete",11197,37.590912,-4.082367 ],
    [ u"es",u"Alcázar de San Juan",26976,39.391324,-3.209756 ],
    [ u"es",u"Alcobendas",101860,40.543933,-3.635688 ],
    [ u"es",u"Alcorcón",169343,40.346467,-3.812453 ],
    [ u"es",u"Alcudia",14436,39.853605,3.122404 ],
    [ u"es",u"Alfafar",19880,39.416667,-.383333 ],
    [ u"es",u"Algeciras",104766,36.133257,-5.450511 ],
    [ u"es",u"Algemesí",26222,39.183333,-.433333 ],
    [ u"es",u"Algete",17554,40.597109,-3.49743 ],
    [ u"es",u"Alginet",12754,39.266667,-.466667 ],
    [ u"es",u"Alhama de Murcia",18060,37.851027,-1.425066 ],
    [ u"es",u"Alhaurín de la Torre",25791,36.663106,-4.562716 ],
    [ u"es",u"Alhaurín el Grande",19605,36.643002,-4.687276 ],
    [ u"es",u"Aller",14428,43.16148,-5.623441 ],
    [ u"es",u"Almansa",24502,38.869166,-1.097131 ],
    [ u"es",u"Almendralejo",27423,38.683159,-6.407468 ],
    [ u"es",u"Almería",181497,36.833333,-2.45 ],
    [ u"es",u"Almonte",18280,37.261589,-6.51691 ],
    [ u"es",u"Almoradí",16415,38.108786,-.791966 ],
    [ u"es",u"Almuñécar",22157,36.733594,-3.690619 ],
    [ u"es",u"Alora",13644,36.82389,-4.705908 ],
    [ u"es",u"Altea",18588,38.599844,-.050217 ],
    [ u"es",u"Amés",18960,42.9,-8.633333 ],
    [ u"es",u"Amposta",19140,40.710754,.578086 ],
    [ u"es",u"Amurrio",9806,43.05,-3 ],
    [ u"es",u"Andoain",13961,43.220711,-2.020336 ],
    [ u"es",u"Andújar",36594,38.039221,-4.050775 ],
    [ u"es",u"Antequera",44464,37.019382,-4.561228 ],
    [ u"es",u"Arahal",18847,37.262727,-5.545297 ],
    [ u"es",u"Aranda de Duero",30326,41.671664,-3.68795 ],
    [ u"es",u"Aranjuez",45125,40.031084,-3.602463 ],
    [ u"es",u"Archena",16563,38.116312,-1.300426 ],
    [ u"es",u"Archidona",9002,37.096046,-4.389942 ],
    [ u"es",u"Arcos de la Frontera",28754,36.750752,-5.81056 ],
    [ u"es",u"Arenys de Mar",13869,41.581905,2.549358 ],
    [ u"es",u"Armilla",15934,37.142181,-3.624931 ],
    [ u"es",u"Arnedo",14299,42.226301,-2.101386 ],
    [ u"es",u"Arona",44838,28.098519,-16.682201 ],
    [ u"es",u"Arrecife",48968,28.965706,-13.551378 ],
    [ u"es",u"Arrigorriaga",11118,43.210062,-2.885616 ],
    [ u"es",u"Arucas",35344,28.115992,-15.518724 ],
    [ u"es",u"Aspe",19430,38.345112,-.767215 ],
    [ u"es",u"Astorga",12037,42.458786,-6.056013 ],
    [ u"es",u"Atarfe",11535,37.224321,-3.686515 ],
    [ u"es",u"Ávila",49408,40.657237,-4.699511 ],
    [ u"es",u"Avilés",81984,43.554728,-5.924832 ],
    [ u"es",u"Ayamonte",17026,37.209938,-7.402661 ],
    [ u"es",u"Azpeitia",13854,43.18143,-2.263527 ],
    [ u"es",u"Azuaga",8435,38.266667,-5.683333 ],
    [ u"es",u"Azuqueca de Henares",24117,40.566881,-3.259921 ],
    [ u"es",u"Badajoz",133042,38.877894,-6.970613 ],
    [ u"es",u"Badalona",222413,41.447145,2.244789 ],
    [ u"es",u"Baena",19349,37.616696,-4.322453 ],
    [ u"es",u"Baeza",15149,37.993839,-3.471029 ],
    [ u"es",u"Bailén",17660,38.096386,-3.777855 ],
    [ u"es",u"Balaguer",14207,41.791172,.810942 ],
    [ u"es",u"Barañáin",22264,42.805668,-1.677313 ],
    [ u"es",u"Barbastro",15598,42.035573,.127019 ],
    [ u"es",u"Barbate",22524,36.192368,-5.921862 ],
    [ u"es",u"Barcelona",1570378,41.398371,2.1741 ],
    [ u"es",u"Baza",22558,37.487098,-2.771589 ],
    [ u"es",u"Beasain",12237,43.05,-2.183333 ],
    [ u"es",u"Béjar",15008,40.386411,-5.763406 ],
    [ u"es",u"Bembibre",9978,42.61771,-6.41545 ],
    [ u"es",u"Benalmádena",38147,36.595372,-4.573222 ],
    [ u"es",u"Benavente",16159,42.002491,-5.678255 ],
    [ u"es",u"Benicarló",22871,40.416501,.427087 ],
    [ u"es",u"Benidorm",60603,38.539234,-.136386 ],
    [ u"es",u"Berga",15860,42.098215,1.844004 ],
    [ u"es",u"Berja",14526,36.847369,-2.946839 ],
    [ u"es",u"Bermeo",16904,43.420416,-2.724232 ],
    [ u"es",u"Betanzos",12629,43.280418,-8.214674 ],
    [ u"es",u"Bétera",16267,39.583333,-.45 ],
    [ u"es",u"Bilbao",349270,43.260919,-2.938764 ],
    [ u"es",u"Blanes",34894,41.675766,2.789078 ],
    [ u"es",u"Boadilla del Monte",30354,40.402784,-3.875623 ],
    [ u"es",u"Boiro",17916,42.65,-8.9 ],
    [ u"es",u"Bolaños de Calatrava",11535,38.906904,-3.663455 ],
    [ u"es",u"Brenes",11078,37.549445,-5.871389 ],
    [ u"es",u"Bueu",12597,42.324579,-8.784973 ],
    [ u"es",u"Bullas",12184,38.046667,-1.672271 ],
    [ u"es",u"Buñol",9704,39.416667,-.783333 ],
    [ u"es",u"Burgos",168319,42.350221,-3.675273 ],
    [ u"es",u"Burriana",29791,39.889007,-.084989 ],
    [ u"es",u"Cabra",20806,37.47249,-4.44206 ],
    [ u"es",u"Cáceres",90938,39.481877,-6.373222 ],
    [ u"es",u"Cadiz",137698,36.515789,-6.279692 ],
    [ u"es",u"Calafell",15325,41.187937,1.569665 ],
    [ u"es",u"Calahorra",21923,42.30506,-1.965209 ],
    [ u"es",u"Calatayud",18623,41.353534,-1.643184 ],
    [ u"es",u"Calella",14797,41.618024,2.667809 ],
    [ u"es",u"Callosa de Segura",18465,38.123647,-.877392 ],
    [ u"es",u"Calviá",41549,39.566156,2.503669 ],
    [ u"es",u"Camargo",25107,43.407436,-3.884978 ],
    [ u"es",u"Camas",25622,37.402023,-6.033141 ],
    [ u"es",u"Cambados",13653,42.512806,-8.814421 ],
    [ u"es",u"Cambre",19445,43.294376,-8.34736 ],
    [ u"es",u"Cambrils",23833,41.074787,1.052436 ],
    [ u"es",u"Campo de Criptana",13470,39.404637,-3.123583 ],
    [ u"es",u"Canals",13569,38.962507,-.584431 ],
    [ u"es",u"Candelaria",15647,28.3548,-16.372684 ],
    [ u"es",u"Cangas",24460,42.264128,-8.784625 ],
    [ u"es",u"Carballo",28409,43.214403,-8.691015 ],
    [ u"es",u"Cardedeu",13822,41.639757,2.357387 ],
    [ u"es",u"Carlet",15173,39.233333,-.516667 ],
    [ u"es",u"Carmona",26471,37.471248,-5.646083 ],
    [ u"es",u"Cartagena",201977,37.605121,-.986232 ],
    [ u"es",u"Cártama",15604,36.711591,-4.630105 ],
    [ u"es",u"Cartaya",13854,37.281136,-7.150706 ],
    [ u"es",u"Castelldefels",50167,41.277658,1.968755 ],
    [ u"es",u"Castilleja de la Cuesta",16672,37.385937,-6.052577 ],
    [ u"es",u"Castrillón",22176,43.383333,-6.783333 ],
    [ u"es",u"Castro-Urdiales",21605,43.382855,-3.220433 ],
    [ u"es",u"Catarroja",22408,39.4,-.4 ],
    [ u"es",u"Cehegín",15959,38.092913,-1.797605 ],
    [ u"es",u"Cervo",4848,43.670188,-7.410134 ],
    [ u"es",u"Ceuta",71436,35.888688,-5.319247 ],
    [ u"es",u"Chantada",9086,42.609929,-7.769607 ],
    [ u"es",u"Chiclana",63012,36.421075,-6.148614 ],
    [ u"es",u"Chipiona",17400,36.736628,-6.437033 ],
    [ u"es",u"Ciempozuelos",16606,40.156067,-3.616453 ],
    [ u"es",u"Cieza",36545,38.239984,-1.419874 ],
    [ u"es",u"Ciudad Real",64625,38.986258,-3.92907 ],
    [ u"es",u"Cocentaina",12404,38.739751,-.439759 ],
    [ u"es",u"Colmenar Viejo",38913,40.6596,-3.766346 ],
    [ u"es",u"Conil",18644,36.277194,-6.088497 ],
    [ u"es",u"Consuegra",11223,39.462457,-3.608002 ],
    [ u"es",u"Córdoba",311186,37.89155,-4.772748 ],
    [ u"es",u"Coria",13287,39.987879,-6.537718 ],
    [ u"es",u"Coria del Río",24671,37.287661,-6.054101 ],
    [ u"es",u"Cornellá",86420,41.352784,2.070769 ],
    [ u"es",u"Coslada",85168,40.423776,-3.561287 ],
    [ u"es",u"Cuenca",47500,40.066667,-2.133333 ],
    [ u"es",u"Cullera",21756,39.166667,-.25 ],
    [ u"es",u"Culleredo",22560,43.28788,-8.38858 ],
    [ u"es",u"Daimiel",17466,39.07004,-3.614978 ],
    [ u"es",u"Denia",38953,38.841344,.10797 ],
    [ u"es",u"Don Benito",31425,38.956274,-5.861622 ],
    [ u"es",u"Dos Hermanas",104666,37.282867,-5.920884 ],
    [ u"es",u"Durango",24953,43.171235,-2.633795 ],
    [ u"es",u"Écija",37865,37.542203,-5.082599 ],
    [ u"es",u"Éibar",28520,43.18476,-2.473804 ],
    [ u"es",u"Ejea de los Caballeros",16586,42.126324,-1.137158 ],
    [ u"es",u"El Astillero",14710,43.400942,-3.820511 ],
    [ u"es",u"Elda",60276,38.477827,-.791573 ],
    [ u"es",u"El Ejido",63155,36.773804,-2.816556 ],
    [ u"es",u"El Escorial",12131,40.584557,-4.127668 ],
    [ u"es",u"Elgóibar",10551,43.214669,-2.416271 ],
    [ u"es",u"El Prat de Llobregat",66796,41.327836,2.094718 ],
    [ u"es",u"El Puerto de Santa María",78714,36.59952,-6.227507 ],
    [ u"es",u"El Vendrell",26947,41.220468,1.533654 ],
    [ u"es",u"El Viso del Alcor",16762,37.391063,-5.719934 ],
    [ u"es",u"Erandio",22377,43.305502,-2.945754 ],
    [ u"es",u"Ermúa",16761,43.1879,-2.503497 ],
    [ u"es",u"Estepa",12194,37.292487,-4.878709 ],
    [ u"es",u"Estepona",47577,36.427879,-5.145451 ],
    [ u"es",u"Felanitx",17187,39.471912,3.15082 ],
    [ u"es",u"Fene",14633,43.45,-8.15 ],
    [ u"es",u"Fernán-Núñez",9484,37.670436,-4.726395 ],
    [ u"es",u"Ferrol",78689,43.483213,-8.236893 ],
    [ u"es",u"Foz",9170,43.569197,-7.254405 ],
    [ u"es",u"Fraga",12538,41.521508,.35 ],
    [ u"es",u"Fuengirola",54823,36.543322,-4.626904 ],
    [ u"es",u"Fuenlabrada",202088,40.284189,-3.794147 ],
    [ u"es",u"Fuente Palmera",9925,37.704938,-5.09965 ],
    [ u"es",u"Galapagar",28271,40.576801,-4.006317 ],
    [ u"es",u"Gáldar",24118,28.14252,-15.654224 ],
    [ u"es",u"Gandía",63893,38.967418,-.18158 ],
    [ u"es",u"Gavá",43021,41.306068,2.002676 ],
    [ u"es",u"Getafe",167550,40.308423,-3.70596 ],
    [ u"es",u"Gibraleón",10904,37.37628,-6.968952 ],
    [ u"es",u"Gijón",262573,43.535731,-5.661519 ],
    [ u"es",u"Girona",85128,41.984444,2.821111 ],
    [ u"es",u"Godella",11829,39.533333,-.416667 ],
    [ u"es",u"Gondomar",12419,42.111554,-8.74971 ],
    [ u"es",u"Grado",11289,43.388014,-6.074327 ],
    [ u"es",u"Granada",248942,37.178354,-3.599201 ],
    [ u"es",u"Granadilla de Abona",23212,28.118816,-16.575989 ],
    [ u"es",u"Granollers",57382,41.607816,2.289721 ],
    [ u"es",u"Guadalajara",79616,40.628621,-3.161849 ],
    [ u"es",u"Guadix",18814,37.299324,-3.13922 ],
    [ u"es",u"Guía de Isora",16454,28.208587,-16.789471 ],
    [ u"es",u"Güimar",16772,28.3039,-16.432545 ],
    [ u"es",u"Hellín",28691,38.510605,-1.700961 ],
    [ u"es",u"Hernani",18482,43.264057,-1.978942 ],
    [ u"es",u"Huelva",145901,37.271447,-6.949464 ],
    [ u"es",u"Huércal-Overa",16204,37.388968,-1.945362 ],
    [ u"es",u"Huesca",47919,42.13868,-.409411 ],
    [ u"es",u"Huéscar",8182,37.811036,-2.54116 ],
    [ u"es",u"Ibi",25467,38.625334,-.572246 ],
    [ u"es",u"Icod de los Vinos",23885,28.372414,-16.711881 ],
    [ u"es",u"Igualada",35711,41.580977,1.6172 ],
    [ u"es",u"Illescas",13114,40.122128,-3.847038 ],
    [ u"es",u"Illora",10876,37.288253,-3.87954 ],
    [ u"es",u"Inca",26595,39.720034,2.910287 ],
    [ u"es",u"Ingenio",26606,27.918285,-15.447214 ],
    [ u"es",u"Irún",57205,43.338685,-1.793086 ],
    [ u"es",u"Jaca",11811,42.568976,-.549868 ],
    [ u"es",u"Jaén",116291,37.772404,-3.79013 ],
    [ u"es",u"Jerez",189230,36.686454,-6.136063 ],
    [ u"es",u"Jódar",12031,37.840641,-3.352622 ],
    [ u"es",u"Jumilla",24476,38.475721,-1.326995 ],
    [ u"es",u"La Algaba",13346,37.463671,-6.012938 ],
    [ u"es",u"La Bañeza",10019,42.30026,-5.897718 ],
    [ u"es",u"La Carlota",10865,37.673592,-4.931216 ],
    [ u"es",u"La Carolina",14836,38.275591,-3.615345 ],
    [ u"es",u"La Garriga",13006,41.683047,2.28626 ],
    [ u"es",u"Laguna de Duero",19362,41.581514,-4.723322 ],
    [ u"es",u"La Línea",61369,36.168024,-5.347195 ],
    [ u"es",u"Lalín",20266,42.660853,-8.112852 ],
    [ u"es",u"La Llagosta",13012,41.514348,2.19297 ],
    [ u"es",u"Langreo",45071,43.300086,-5.684644 ],
    [ u"es",u"La Orotava",41446,28.387309,-16.516774 ],
    [ u"es",u"La Palma del Condado",9904,37.386047,-6.55231 ],
    [ u"es",u"La Puebla de Cazalla",10794,37.221548,-5.311534 ],
    [ u"es",u"La Puebla del Río",10775,37.267874,-6.062641 ],
    [ u"es",u"Laredo",12871,43.409802,-3.416131 ],
    [ u"es",u"La Rinconada",30051,37.487342,-5.982579 ],
    [ u"es",u"La Roda",14535,39.216667,-2.15 ],
    [ u"es",u"La Solana",15374,38.944216,-3.238096 ],
    [ u"es",u"Las Palmas",365418,28.099727,-15.41343 ],
    [ u"es",u"Las Rozas de Madrid",70110,40.492113,-3.871271 ],
    [ u"es",u"Las Torres de Cotillas",18208,38.027933,-1.244291 ],
    [ u"es",u"La Unión",16095,37.619154,-.877993 ],
    [ u"es",u"Laviana",14321,43.245385,-5.562896 ],
    [ u"es",u"Lebrija",24754,36.920774,-6.075286 ],
    [ u"es",u"Leganés",192000,40.326946,-3.760422 ],
    [ u"es",u"Lena",13377,43.160886,-5.828783 ],
    [ u"es",u"León",127480,42.600031,-5.570316 ],
    [ u"es",u"Lepe",20176,37.254819,-7.204334 ],
    [ u"es",u"Linares",56982,38.095193,-3.63602 ],
    [ u"es",u"Llanera",12124,43.433333,-5.883333 ],
    [ u"es",u"Llanes",13084,43.422601,-4.756861 ],
    [ u"es",u"Lleida",119320,41.616667,0.633333 ],
    [ u"es",u"Llodio",19623,43.143222,-2.962042 ],
    [ u"es",u"Lloret de Mar",23009,41.699929,2.845646 ],
    [ u"es",u"Logroño",142103,42.466667,-2.45 ],
    [ u"es",u"Loja",20750,37.164893,-4.148524 ],
    [ u"es",u"Lora del Río",18761,37.658961,-5.52751 ],
    [ u"es",u"Lorca",85756,37.671192,-1.701699 ],
    [ u"es",u"Los Barrios",18314,36.184704,-5.489539 ],
    [ u"es",u"Los Corrales de Buelna",11066,43.263577,-4.072621 ],
    [ u"es",u"Los Llanos de Aridane",19461,28.658507,-17.918211 ],
    [ u"es",u"Lucena",37402,37.410533,-4.486109 ],
    [ u"es",u"Lugo",85450,43.013813,-7.558543 ],
    [ u"es",u"Madridejos",11743,39.468226,-3.531957 ],
    [ u"es",u"Madrid",3102644,40.408566,-3.69222 ],
    [ u"es",u"Mahón",26926,39.883333,4.25 ],
    [ u"es",u"Mairena del Alcor",17263,37.373014,-5.749515 ],
    [ u"es",u"Mairena del Aljarafe",36774,37.34461,-6.063913 ],
    [ u"es",u"Majadahonda",56060,40.4717,-3.869451 ],
    [ u"es",u"Málaga",557875,36.726666,-4.434802 ],
    [ u"es",u"Malgrat de Mar",15524,41.646217,2.741505 ],
    [ u"es",u"Manacor",36095,39.570524,3.211409 ],
    [ u"es",u"Manises",27420,39.483333,-.45 ],
    [ u"es",u"Manlleu",18944,42.002284,2.28476 ],
    [ u"es",u"Manresa",69134,41.726337,1.825837 ],
    [ u"es",u"Manzanares",18306,38.999149,-3.369911 ],
    [ u"es",u"Maracena",17085,37.208244,-3.633508 ],
    [ u"es",u"Marbella",115484,36.510485,-4.885745 ],
    [ u"es",u"Marchena",18319,37.329,-5.416815 ],
    [ u"es",u"Marín",25497,42.383333,-8.7 ],
    [ u"es",u"Marratxi",27035,39.65,2.8 ],
    [ u"es",u"Martorell",24877,41.47402,1.93062 ],
    [ u"es",u"Martos",22441,37.721072,-3.972645 ],
    [ u"es",u"Mataró",114923,41.542113,2.444503 ],
    [ u"es",u"Mazarrón",23068,37.598791,-1.315541 ],
    [ u"es",u"Medina del Campo",20273,41.312394,-4.914133 ],
    [ u"es",u"Mejorada del Campo",19019,40.392826,-3.481941 ],
    [ u"es",u"Melilla",66419,35.283924,-2.943075 ],
    [ u"es",u"Mérida",50333,38.916109,-6.343657 ],
    [ u"es",u"Miajadas",10733,39.151274,-5.908408 ],
    [ u"es",u"Mieres",45510,43.25,-5.766667 ],
    [ u"es",u"Mijas",51023,36.595299,-4.639861 ],
    [ u"es",u"Miranda de Ebro",36386,42.686503,-2.94695 ],
    [ u"es",u"Mislata",43287,39.466667,-.416667 ],
    [ u"es",u"Moaña",18244,42.283333,-8.75 ],
    [ u"es",u"Moguer",15606,37.275593,-6.838507 ],
    [ u"es",u"Molina de Segura",51917,38.054559,-1.207631 ],
    [ u"es",u"Mollet del Vallès",51077,41.538293,2.212456 ],
    [ u"es",u"Moncada",19890,39.55,-.4 ],
    [ u"es",u"Monforte de Lemos",18451,42.522226,-7.514324 ],
    [ u"es",u"Montijo",15199,38.908388,-6.617854 ],
    [ u"es",u"Montilla",23157,37.586266,-4.638054 ],
    [ u"es",u"Montornés del Vallés",13904,41.540328,2.26524 ],
    [ u"es",u"Montoro",9502,38.024086,-4.383405 ],
    [ u"es",u"Monzón",15461,41.913584,.194091 ],
    [ u"es",u"Morón de la Frontera",28438,37.120836,-5.45403 ],
    [ u"es",u"Móstoles",212504,40.320923,-3.862849 ],
    [ u"es",u"Motril",54313,36.750665,-3.517902 ],
    [ u"es",u"Mula",16172,38.040945,-1.490138 ],
    [ u"es",u"Murcia",410364,37.987041,-1.130042 ],
    [ u"es",u"Muros",10252,42.776173,-9.060316 ],
    [ u"es",u"Narón",32509,43.516667,-8.152778 ],
    [ u"es",u"Navalcarnero",16396,40.289078,-4.011966 ],
    [ u"es",u"Navalmoral de la Mata",16752,39.891585,-5.540639 ],
    [ u"es",u"Nerja",18536,36.750498,-3.873931 ],
    [ u"es",u"Nigrán",16432,42.147784,-8.801099 ],
    [ u"es",u"Níjar",19449,36.966298,-2.204491 ],
    [ u"es",u"Novelda",28974,38.384786,-.767731 ],
    [ u"es",u"Oleiros",27510,43.333333,-8.316667 ],
    [ u"es",u"Oliva",22422,38.919708,-.119349 ],
    [ u"es",u"Olivenza",10788,38.68402,-7.101034 ],
    [ u"es",u"Olot",31901,42.181691,2.48476 ],
    [ u"es",u"Onda",22289,39.966667,-.25 ],
    [ u"es",u"Ondárroa",9712,43.325088,-2.423304 ],
    [ u"es",u"Oria",17378,43.255304,-2.019831 ],
    [ u"es",u"Orihuela",63147,38.084834,-.944011 ],
    [ u"es",u"Osuna",17290,37.237651,-5.107465 ],
    [ u"es",u"Oviedo",198250,43.363223,-5.853128 ],
    [ u"es",u"Padrón",8925,42.740047,-8.663136 ],
    [ u"es",u"Paiporta",20134,39.433333,-.416667 ],
    [ u"es",u"Palafrugell",20830,41.917381,3.163098 ],
    [ u"es",u"Palamós",16874,41.84843,3.129121 ],
    [ u"es",u"Palencia",77438,42.009552,-4.524063 ],
    [ u"es",u"Palma del Río",19265,37.700239,-5.281208 ],
    [ u"es",u"Palma",378884,39.574337,2.655222 ],
    [ u"es",u"Pamplona",191549,42.814075,-1.641153 ],
    [ u"es",u"Parla",88983,40.236045,-3.767524 ],
    [ u"es",u"Paterna",50148,39.5,-.433333 ],
    [ u"es",u"Peñarroya-Pueblonuevo",12566,38.3,-5.266667 ],
    [ u"es",u"Pilar de la Horadada",14874,37.863021,-.791864 ],
    [ u"es",u"Pilas",11480,37.303373,-6.300969 ],
    [ u"es",u"Pinos Puente",13884,37.251095,-3.749671 ],
    [ u"es",u"Pinto",34665,40.240899,-3.696467 ],
    [ u"es",u"Plasencia",40337,43.173899,-2.411053 ],
    [ u"es",u"Ponferrada",61134,42.546638,-6.596187 ],
    [ u"es",u"Pontevedra",77595,42.433333,-8.633333 ],
    [ u"es",u"Portugalete",50964,43.319379,-3.020307 ],
    [ u"es",u"Pozoblanco",16534,38.379061,-4.848268 ],
    [ u"es",u"Pozuelo de Alarcón",83173,40.432931,-3.813375 ],
    [ u"es",u"Pravia",9132,43.492473,-6.111303 ],
    [ u"es",u"Premiá de Mar",28455,41.492256,2.359029 ],
    [ u"es",u"Priego de Córdoba",22604,37.436801,-4.196104 ],
    [ u"es",u"Puerto de la Cruz",29039,28.383333,-16.55 ],
    [ u"es",u"Puerto del Rosario",23184,28.50038,-13.862719 ],
    [ u"es",u"Puertollano",49130,38.6889,-4.108297 ],
    [ u"es",u"Puerto Lumbreras",12542,37.562904,-1.810008 ],
    [ u"es",u"Puerto Real",36946,36.528604,-6.191022 ],
    [ u"es",u"Punta Umbría",12578,37.182131,-6.96605 ],
    [ u"es",u"Redondela",29583,42.283366,-8.609603 ],
    [ u"es",u"Reinosa",10960,42.999585,-4.138007 ],
    [ u"es",u"Requena",20428,39.483333,-1.1 ],
    [ u"es",u"Reus",97508,41.155913,1.107423 ],
    [ u"es",u"Rianxo",11793,42.649765,-8.81763 ],
    [ u"es",u"Rincón de la Victoria",27924,36.716141,-4.287813 ],
    [ u"es",u"Ripollet",32670,41.496859,2.157387 ],
    [ u"es",u"Ripoll",12047,42.20033,2.190467 ],
    [ u"es",u"Ronda",38040,36.746115,-5.161443 ],
    [ u"es",u"Roquetas de Mar",54665,36.764072,-2.615144 ],
    [ u"es",u"Rota",25867,36.622363,-6.358589 ],
    [ u"es",u"Rubí",66084,41.492256,2.033047 ],
    [ u"es",u"Rute",10113,37.32617,-4.367592 ],
    [ u"es",u"Sabadell",198589,41.54329,2.109423 ],
    [ u"es",u"Sada",11573,43.356187,-8.257964 ],
    [ u"es",u"Salamanca",155175,40.9681,-5.66202 ],
    [ u"es",u"Salobreña",10725,36.742774,-3.587171 ],
    [ u"es",u"Salou",16075,41.076036,1.139829 ],
    [ u"es",u"Salt",24145,41.973982,2.791613 ],
    [ u"es",u"San Andrés del Rabanedo",25618,42.611745,-5.616709 ],
    [ u"es",u"San Bartolomé de Tirajana",37575,27.923673,-15.573557 ],
    [ u"es",u"San Bartolomé",14185,29.001726,-13.611669 ],
    [ u"es",u"San Fernando de Henares",40089,40.423857,-3.53261 ],
    [ u"es",u"San Fernando",90936,36.4759,-6.198166 ],
    [ u"es",u"San Javier",22276,37.804917,-.8373 ],
    [ u"es",u"San Juan de Aznalfarache",19848,37.358125,-6.037314 ],
    [ u"es",u"San Lorenzo de El Escorial",14422,40.593993,-4.144851 ],
    [ u"es",u"Sanlúcar de Barrameda",62213,36.778081,-6.351504 ],
    [ u"es",u"Sanlúcar la Mayor",11143,37.38714,-6.201059 ],
    [ u"es",u"San Pedro del Pinatar",18460,37.83399,-.791974 ],
    [ u"es",u"San Roque",24198,36.210667,-5.38415 ],
    [ u"es",u"San Sebastián de los Reyes",69954,40.550535,-3.626052 ],
    [ u"es",u"Santa Brígida",19158,28.031968,-15.50425 ],
    [ u"es",u"Santa Comba",10896,43.033062,-8.80925 ],
    [ u"es",u"Santa Cruz de la Palma",20501,28.682798,-17.763732 ],
    [ u"es",u"Santa Cruz de Tenerife",193852,28.460238,-16.280616 ],
    [ u"es",u"Santa Eulalia del Río",22876,38.985192,1.535644 ],
    [ u"es",u"Santa Lucía",51877,27.911307,-15.543416 ],
    [ u"es",u"Santa Marta de Tormes",11998,40.950653,-5.627226 ],
    [ u"es",u"Santander",185209,43.464722,-3.804444 ],
    [ u"es",u"Santa Pola",23111,38.19273,-.557868 ],
    [ u"es",u"Sant Cugat del Vallès",65118,41.471379,2.081834 ],
    [ u"es",u"Sant Feliu de Guíxols",20457,41.78476,3.028978 ],
    [ u"es",u"Santiago de Compostela",91141,42.880035,-8.544826 ],
    [ u"es",u"Sant Just Desvern",14987,41.383333,2.083333 ],
    [ u"es",u"Santomera",12979,38.06173,-1.048283 ],
    [ u"es",u"Santoña",11328,43.443864,-3.457571 ],
    [ u"es",u"Sant Pere de Ribes",24997,41.26126,1.772075 ],
    [ u"es",u"Segovia",55902,40.948083,-4.11839 ],
    [ u"es",u"Sestao",31709,43.310134,-3.002997 ],
    [ u"es",u"Sevilla",686647,37.382408,-5.976133 ],
    [ u"es",u"Siero",47199,43.39228,-5.66335 ],
    [ u"es",u"Silla",17303,39.366667,-.416667 ],
    [ u"es",u"Silleda",9271,42.696049,-8.24653 ],
    [ u"es",u"Sitges",21495,41.237045,1.807316 ],
    [ u"es",u"Socuéllamos",11920,39.285808,-2.792055 ],
    [ u"es",u"Sóller",12658,39.768206,2.716361 ],
    [ u"es",u"Sopelana",10688,43.380522,-2.982098 ],
    [ u"es",u"Soria",35129,41.764335,-2.468251 ],
    [ u"es",u"Sueca",27085,39.2,-.316667 ],
    [ u"es",u"Tacoronte",22289,28.476885,-16.410157 ],
    [ u"es",u"Tafalla",10881,42.526865,-1.674461 ],
    [ u"es",u"Talavera de la Reina",82704,39.963485,-4.830759 ],
    [ u"es",u"Tarancón",12081,40.008511,-3.00731 ],
    [ u"es",u"Tarazona",10935,41.903426,-1.726016 ],
    [ u"es",u"Tarifa",16179,36.01393,-5.606949 ],
    [ u"es",u"Tarragona",128391,41.116667,1.25 ],
    [ u"es",u"Tárrega",13663,41.648983,1.1396 ],
    [ u"es",u"Teguise",13491,29.060494,-13.563975 ],
    [ u"es",u"Telde",95503,27.992425,-15.419153 ],
    [ u"es",u"Teo",15623,42.75,-8.5 ],
    [ u"es",u"Teror",13110,28.064123,-15.548099 ],
    [ u"es",u"Terrassa",187770,41.561111,2.008056 ],
    [ u"es",u"Teruel",32210,40.345073,-1.104106 ],
    [ u"es",u"Tías",13957,28.961076,-13.645021 ],
    [ u"es",u"Tineo",12416,43.337651,-6.414516 ],
    [ u"es",u"Toledo",75054,39.867263,-4.02981 ],
    [ u"es",u"Tolosa",17830,43.137037,-2.075728 ],
    [ u"es",u"Tomares",18796,37.372807,-6.04589 ],
    [ u"es",u"Tomelloso",31320,39.158516,-3.020826 ],
    [ u"es",u"Tomiño",11598,41.987722,-8.755018 ],
    [ u"es",u"Torelló",13275,42.048215,2.263955 ],
    [ u"es",u"Toro",9041,41.524175,-5.395335 ],
    [ u"es",u"Torre del Campo",13235,37.772009,-3.897411 ],
    [ u"es",u"Torredonjimeno",13701,37.767478,-3.957762 ],
    [ u"es",u"Torrejón de Ardoz",111998,40.455354,-3.469734 ],
    [ u"es",u"Torrelavega",56856,43.349435,-4.047852 ],
    [ u"es",u"Torrelodones",17214,40.57466,-3.925302 ],
    [ u"es",u"Torremolinos",49412,36.625085,-4.498327 ],
    [ u"es",u"Torre-Pacheco",26932,37.742931,-.953964 ],
    [ u"es",u"Torrevieja",59528,37.978718,-.682222 ],
    [ u"es",u"Torrijos",11284,39.981945,-4.283494 ],
    [ u"es",u"Torrox",12610,36.759304,-3.952495 ],
    [ u"es",u"Tortosa",32836,40.812492,.521602 ],
    [ u"es",u"Totana",27292,37.768801,-1.502288 ],
    [ u"es",u"Tudela",31687,42.061308,-1.607164 ],
    [ u"es",u"Úbeda",33052,38.013284,-3.370496 ],
    [ u"es",u"Ubrique",17961,36.677775,-5.446004 ],
    [ u"es",u"Utiel",12277,39.566667,-1.2 ],
    [ u"es",u"Utrera",46361,37.185161,-5.78093 ],
    [ u"es",u"Valdemoro",36688,40.189007,-3.675662 ],
    [ u"es",u"Valdepeñas",26840,38.762112,-3.384829 ],
    [ u"es",u"Valencia",769897,39.466667,-.366667 ],
    [ u"es",u"Valladolid",315859,41.655181,-4.72372 ],
    [ u"es",u"Valls",22961,41.286117,1.249929 ],
    [ u"es",u"Valverde del Camino",12747,37.575112,-6.75432 ],
    [ u"es",u"Vélez-Málaga",63064,36.772621,-4.100447 ],
    [ u"es",u"Verín",12663,41.941548,-7.433918 ],
    [ u"es",u"Vícar",18315,36.83181,-2.642391 ],
    [ u"es",u"Vic",35337,41.929335,2.255497 ],
    [ u"es",u"Vigo",286585,42.232823,-8.722637 ],
    [ u"es",u"Viladecáns",61419,41.316881,2.016775 ],
    [ u"es",u"Vilanova del Camí",11015,41.571646,1.637509 ],
    [ u"es",u"Villablino",12250,42.939316,-6.319434 ],
    [ u"es",u"Villacarrillo",11063,38.115603,-3.084799 ],
    [ u"es",u"Villafranca de los Barros",12442,38.561445,-6.338095 ],
    [ u"es",u"Villamartín",12342,36.859787,-5.64485 ],
    [ u"es",u"Villanueva de Córdoba",9880,38.322774,-4.628725 ],
    [ u"es",u"Villanueva de la Serena",24006,38.976552,-5.797398 ],
    [ u"es",u"Villarrobledo",23663,39.269922,-2.601185 ],
    [ u"es",u"Villarrubia de los Ojos",9933,39.220846,-3.608023 ],
    [ u"es",u"Villaviciosa de Odón",24958,40.356923,-3.900107 ],
    [ u"es",u"Villaviciosa",13750,43.480936,-5.435249 ],
    [ u"es",u"Villena",38150,38.637303,-.865682 ],
    [ u"es",u"Vitoria",224774,42.85,-2.666667 ],
    [ u"es",u"Yecla",34118,38.613188,-1.111795 ],
    [ u"es",u"Zafra",15199,38.416667,-6.416667 ],
    [ u"es",u"Zamora",63160,41.50494,-5.745296 ],
    [ u"es",u"Zaragoza",635509,41.64531,-.884861 ],
    [ u"es",u"Zarautz",21303,43.283333,-2.166667 ],
    [ u"es",u"Zumárraga",10284,43.092848,-2.313718 ],
    [ u"et",u"Abiy Adi",10385,13.560833,38.973889 ],
    [ u"et",u"Abomsa",15261,9.983333,39.983333 ],
    [ u"et",u"Addis Abeba",2757807,9.024325,38.749226 ],
    [ u"et",u"Addis Zemen",22526,12.116667,37.783333 ],
    [ u"et",u"Adet",22950,11.266667,37.483333 ],
    [ u"et",u"Adwa",43582,14.163471,38.899237 ],
    [ u"et",u"Agaro",28273,7.85,36.65 ],
    [ u"et",u"Aksum",41256,14.124482,38.724442 ],
    [ u"et",u"Areka",33187,7.066667,37.7 ],
    [ u"et",u"Asasa",23794,7.1,39.2 ],
    [ u"et",u"Asayita",20342,11.563611,41.439444 ],
    [ u"et",u"Asbe Teferi",30777,9.083333,40.866667 ],
    [ u"et",u"Asosa",30544,10.066667,34.533333 ],
    [ u"et",u"Assela",60191,7.95,39.133333 ],
    [ u"et",u"Awash",11415,8.983333,40.166667 ],
    [ u"et",u"Awassa",133120,7.05,38.466667 ],
    [ u"et",u"Bahir Dar",168929,11.6,37.383333 ],
    [ u"et",u"Bako",17875,5.783333,36.566667 ],
    [ u"et",u"Bati",19263,11.183333,40.016667 ],
    [ u"et",u"Bedele",20297,8.456003,36.353024 ],
    [ u"et",u"Bedesa",17529,8.9,40.783333 ],
    [ u"et",u"Bichena",16411,10.45,38.2 ],
    [ u"et",u"Boditi",33068,6.966667,37.866667 ],
    [ u"et",u"Bonga",18976,7.266667,36.25 ],
    [ u"et",u"Bure",22042,10.7,37.066667 ],
    [ u"et",u"Butajira",30507,8.116667,38.366667 ],
    [ u"et",u"Dabat",11544,12.984167,37.765 ],
    [ u"et",u"Debre Birhan",57797,9.683333,39.533333 ],
    [ u"et",u"Debre Sina",9409,9.85,39.766667 ],
    [ u"et",u"Debre Tabor",32665,11.85,38.016667 ],
    [ u"et",u"Debre Zeyit",104234,8.75,38.983333 ],
    [ u"et",u"Deder",8884,9.316667,41.45 ],
    [ u"et",u"Dejen",11739,10.166667,38.133333 ],
    [ u"et",u"Dembi Dolo",26753,8.533333,34.8 ],
    [ u"et",u"Dese",136080,11.133333,39.633333 ],
    [ u"et",u"Dilla",47029,6.416667,38.316667 ],
    [ u"et",u"Dire Dawa",252347,9.593056,41.866111 ],
    [ u"et",u"Dodola",23120,6.983333,39.183333 ],
    [ u"et",u"Dubti",26375,11.736111,41.085278 ],
    [ u"et",u"Fiche",25763,9.8,38.733333 ],
    [ u"et",u"Finote Selam",23467,10.7,37.266667 ],
    [ u"et",u"Gambela",42474,8.25,34.583333 ],
    [ u"et",u"Gebre Guracha",16586,9.8,38.4 ],
    [ u"et",u"Gedo",7499,9.016667,37.45 ],
    [ u"et",u"Gelemso",16067,8.816667,40.516667 ],
    [ u"et",u"Gewane",11279,10.166389,40.645278 ],
    [ u"et",u"Gidole",10736,5.65,37.366667 ],
    [ u"et",u"Gimbi",31815,9.166667,35.833333 ],
    [ u"et",u"Ginir",16760,7.133333,40.7 ],
    [ u"et",u"Giyon",38401,8.533333,37.983333 ],
    [ u"et",u"Goba",34375,7.016667,39.983333 ],
    [ u"et",u"Gondar",153942,12.6,37.466667 ],
    [ u"et",u"Gore",9352,8.15,35.533333 ],
    [ u"et",u"Guder",12569,8.966667,37.766667 ],
    [ u"et",u"Hagere Hiywet",43928,8.983333,37.85 ],
    [ u"et",u"Hagere Selam",5169,6.483333,38.516667 ],
    [ u"et",u"Harer",90226,9.309444,42.125833 ],
    [ u"et",u"Himora",19708,14.290593,36.608076 ],
    [ u"et",u"Hirna",12295,9.216667,41.1 ],
    [ u"et",u"Huruta",12442,8.15,39.35 ],
    [ u"et",u"Jijiga",57146,9.35,42.8 ],
    [ u"et",u"Jimma",128330,7.666667,36.833333 ],
    [ u"et",u"Jinka",32151,5.65,36.65 ],
    [ u"et",u"Kembolcha",93709,11.083333,39.733333 ],
    [ u"et",u"Kemise",23888,10.716667,39.866667 ],
    [ u"et",u"Kibre Mengist",27859,5.883333,38.983333 ],
    [ u"et",u"Kofele",9643,7.066667,38.783333 ],
    [ u"et",u"Korem",30638,12.505833,39.522778 ],
    [ u"et",u"Lalibela",11152,12.033333,39.033333 ],
    [ u"et",u"Leku",11398,6.866667,38.45 ],
    [ u"et",u"Mega",6884,4.05,38.3 ],
    [ u"et",u"Mendi",25267,9.8,35.1 ],
    [ u"et",u"Metehara",23408,8.9,39.916667 ],
    [ u"et",u"Metu",29654,8.3,35.583333 ],
    [ u"et",u"Mizan Teferi",14002,6.983333,35.583333 ],
    [ u"et",u"Mojo",34553,8.6,39.116667 ],
    [ u"et",u"Moyale",25993,3.569167,39.083333 ],
    [ u"et",u"Nazret",214034,8.55,39.266667 ],
    [ u"et",u"Nedjo",20170,9.5,35.5 ],
    [ u"et",u"Negele",42358,7.35,38.7 ],
    [ u"et",u"Robe",41280,7.866667,39.633333 ],
    [ u"et",u"Sebeta",19537,8.916667,38.616667 ],
    [ u"et",u"Sendafa",7326,9.15,39.033333 ],
    [ u"et",u"Shakiso",34116,5.75,38.916667 ],
    [ u"et",u"Shambu",15357,9.566667,37.1 ],
    [ u"et",u"Sire",10089,8.283333,39.45 ],
    [ u"et",u"Tulu Bolo",10531,8.666667,38.216667 ],
    [ u"et",u"Wendo",12948,6.6,38.416667 ],
    [ u"et",u"Were Ilu",7636,10.6,39.433333 ],
    [ u"et",u"Werota",26818,11.916667,37.7 ],
    [ u"et",u"Wonji",17190,8.45,39.283333 ],
    [ u"et",u"Yabelo",17822,4.883333,38.083333 ],
    [ u"et",u"Ziway",49522,7.933333,38.716667 ],
    [ u"fi",u"Äänekoski",13406,62.6,25.733333 ],
    [ u"fi",u"Espoo",229528,60.216667,24.666667 ],
    [ u"fi",u"Eura",9338,61.133333,22.133333 ],
    [ u"fi",u"Eurajoki",5656,61.2,21.733333 ],
    [ u"fi",u"Forssa",17852,60.816667,23.633333 ],
    [ u"fi",u"Hämeenlinna",47261,61,24.45 ],
    [ u"fi",u"Hamina",21712,60.566667,27.2 ],
    [ u"fi",u"Hanko",9962,59.833333,22.95 ],
    [ u"fi",u"Harjavalta",7572,61.316667,22.133333 ],
    [ u"fi",u"Haukipudas",17298,65.183333,25.35 ],
    [ u"fi",u"Heinola",20849,61.216667,26.033333 ],
    [ u"fi",u"Helsinki",558457,60.175556,24.934167 ],
    [ u"fi",u"Hollola",20405,61.05,25.433333 ],
    [ u"fi",u"Huittinen",8952,61.183333,22.7 ],
    [ u"fi",u"Hyvinkää",43515,60.633333,24.866667 ],
    [ u"fi",u"Iisalmi",22588,63.566667,27.183333 ],
    [ u"fi",u"Ilmajoki",11694,62.733333,22.566667 ],
    [ u"fi",u"Imatra",29615,61.166667,28.766667 ],
    [ u"fi",u"Jämsä",15261,61.866667,25.2 ],
    [ u"fi",u"Janakkala",15698,60.9,24.6 ],
    [ u"fi",u"Järvenpää",38148,60.466667,25.1 ],
    [ u"fi",u"Joensuu",53389,62.6,29.766667 ],
    [ u"fi",u"Joutseno",10603,61.1,28.5 ],
    [ u"fi",u"Jyväskylä",85026,62.233333,25.733333 ],
    [ u"fi",u"Kaarina",21684,60.416667,22.416667 ],
    [ u"fi",u"Kajaani",35375,64.233333,27.683333 ],
    [ u"fi",u"Kangasala",24291,61.466667,24.083333 ],
    [ u"fi",u"Kankaanpää",12381,61.8,22.416667 ],
    [ u"fi",u"Kauhajoki",14526,62.433333,22.183333 ],
    [ u"fi",u"Kemijärvi",9341,66.666667,27.416667 ],
    [ u"fi",u"Kemi",22629,65.733333,24.566667 ],
    [ u"fi",u"Kempele",14293,64.916667,25.5 ],
    [ u"fi",u"Kerava",31347,60.4,25.116667 ],
    [ u"fi",u"Keuruu",10942,62.266667,24.7 ],
    [ u"fi",u"Kirkkonummi",32921,60.116667,24.433333 ],
    [ u"fi",u"Kokemäki",8390,61.25,22.35 ],
    [ u"fi",u"Kokkola",35586,63.833333,23.116667 ],
    [ u"fi",u"Kotka",54616,60.466667,26.916667 ],
    [ u"fi",u"Kouvola",31133,60.866667,26.7 ],
    [ u"fi",u"Kristiinankaupunki",7712,62.283333,21.383333 ],
    [ u"fi",u"Kuopio",89104,62.9,27.683333 ],
    [ u"fi",u"Kurikka",10628,62.616667,22.416667 ],
    [ u"fi",u"Kuusamo",17401,65.966667,29.183333 ],
    [ u"fi",u"Kuusankoski",19986,60.9,26.633333 ],
    [ u"fi",u"Lahti",98826,60.966667,25.666667 ],
    [ u"fi",u"Lappeenranta",59276,61.066667,28.183333 ],
    [ u"fi",u"Lapua",14091,62.95,23 ],
    [ u"fi",u"Laukaa",17093,62.416667,25.95 ],
    [ u"fi",u"Lempäälä",18096,61.316667,23.75 ],
    [ u"fi",u"Lieksa",13704,63.316667,30.016667 ],
    [ u"fi",u"Lieto",15258,60.5,22.45 ],
    [ u"fi",u"Lohja",35960,60.25,24.083333 ],
    [ u"fi",u"Loviisa",7264,60.45,26.233333 ],
    [ u"fi",u"Maarianhamina",10682,60.1,19.95 ],
    [ u"fi",u"Mäntsälä",18074,60.633333,25.316667 ],
    [ u"fi",u"Mikkeli",46550,61.683333,27.25 ],
    [ u"fi",u"Muhos",8232,64.766667,26.1 ],
    [ u"fi",u"Mustasaari",17176,63.116667,21.716667 ],
    [ u"fi",u"Naantali",13607,60.45,22.033333 ],
    [ u"fi",u"Nakkila",5792,61.366667,22 ],
    [ u"fi",u"Nastola",14911,60.95,25.933333 ],
    [ u"fi",u"Nivala",10610,63.916667,24.966667 ],
    [ u"fi",u"Nokia",28676,61.466667,23.5 ],
    [ u"fi",u"Noormarkku",6076,61.583333,21.866667 ],
    [ u"fi",u"Nurmijärvi",37074,60.466667,24.8 ],
    [ u"fi",u"Orimattila",14603,60.8,25.75 ],
    [ u"fi",u"Oulainen",8300,64.266667,24.8 ],
    [ u"fi",u"Oulu",128618,65.016667,25.466667 ],
    [ u"fi",u"Parainen",11962,60.3,22.3 ],
    [ u"fi",u"Pietarsaari",19238,63.65,22.683333 ],
    [ u"fi",u"Pirkkala",14914,61.466667,23.566667 ],
    [ u"fi",u"Pori",76773,61.483333,21.783333 ],
    [ u"fi",u"Porvoo",47192,60.4,25.666667 ],
    [ u"fi",u"Raahe",22217,64.683333,24.483333 ],
    [ u"fi",u"Raisio",23598,60.483333,22.183333 ],
    [ u"fi",u"Rauma",36550,61.133333,21.5 ],
    [ u"fi",u"Riihimäki",26451,60.75,24.766667 ],
    [ u"fi",u"Rovaniemi",34781,66.5,25.716667 ],
    [ u"fi",u"Säkylä",4870,61.033333,22.333333 ],
    [ u"fi",u"Salo",24900,60.383333,23.133333 ],
    [ u"fi",u"Savonlinna",27353,61.866667,28.883333 ],
    [ u"fi",u"Seinäjoki",32149,62.8,22.833333 ],
    [ u"fi",u"Siilinjärvi",20210,63.083333,27.666667 ],
    [ u"fi",u"Sipoo",19430,60.366667,25.266667 ],
    [ u"fi",u"Tammisaari",14377,59.966667,23.433333 ],
    [ u"fi",u"Tampere",202688,61.5,23.75 ],
    [ u"fi",u"Tornio",21236,65.85,24.183333 ],
    [ u"fi",u"Turku",175944,60.45,22.283333 ],
    [ u"fi",u"Tuusula",34725,60.416667,25.033333 ],
    [ u"fi",u"Ulvila",12314,61.433333,21.883333 ],
    [ u"fi",u"Uusikaupunki",16226,60.8,21.416667 ],
    [ u"fi",u"Vaasa",57014,63.1,21.6 ],
    [ u"fi",u"Valkeakoski",20376,61.266667,24.033333 ],
    [ u"fi",u"Valkeala",11059,60.95,26.8 ],
    [ u"fi",u"Vammala",14982,61.333333,22.9 ],
    [ u"fi",u"Varkaus",22365,62.316667,27.916667 ],
    [ u"fi",u"Vihti",26280,60.416667,24.333333 ],
    [ u"fi",u"Ylivieska",13159,64.083333,24.55 ],
    [ u"fi",u"Ylöjärvi",22140,61.55,23.6 ],
    [ u"fo",u"Akrar",13,61.45,-6.75 ],
    [ u"fo",u"Ánirnar",18,62.25,-6.5666667 ],
    [ u"fo",u"Argir",1871,61.9833333,-6.75 ],
    [ u"fo",u"Bøur",67,62.0833333,-7.35 ],
    [ u"fo",u"Dalur",45,61.7833333,-6.6666667 ],
    [ u"fo",u"Elduvík",23,62.2833333,-6.9 ],
    [ u"fo",u"Fámjin",111,61.5166667,-6.8666667 ],
    [ u"fo",u"Funningur",66,62.2833333,-6.95 ],
    [ u"fo",u"Gásadalur",17,62.1166667,-7.4333333 ],
    [ u"fo",u"Gjánoyri",55,62.2333333,-7.0333333 ],
    [ u"fo",u"Gjov",53,62.3166667,-6.9333333 ],
    [ u"fo",u"Glyvrar",425,62.1333333,-6.7166667 ],
    [ u"fo",u"Gøtugjógv",46,62.1833333,-6.7333333 ],
    [ u"fo",u"Haldarsvík",175,62.2833333,-7.0833333 ],
    [ u"fo",u"Haraldssund",77,62.2666667,-6.6 ],
    [ u"fo",u"Hattarvík",19,62.3333333,-6.25 ],
    [ u"fo",u"Hellur",30,62.2666667,-6.8333333 ],
    [ u"fo",u"Hestur",44,61.95,-6.8666667 ],
    [ u"fo",u"Hósvík",344,62.15,-6.9333333 ],
    [ u"fo",u"Hove",149,61.5166667,-6.7333333 ],
    [ u"fo",u"Hoyvík",2777,62.0333333,-6.75 ],
    [ u"fo",u"Húsar",60,62.2666667,-6.6833333 ],
    [ u"fo",u"Húsavík",82,61.8,-6.6666667 ],
    [ u"fo",u"Hvalba",673,61.6,-6.95 ],
    [ u"fo",u"Hvalvík",183,62.1833333,-7.0166667 ],
    [ u"fo",u"Hvannasund",271,62.3,-6.5 ],
    [ u"fo",u"Hvítanes",104,62.05,-6.7666667 ],
    [ u"fo",u"Kaldbak",229,62.05,-6.8166667 ],
    [ u"fo",u"Kirkja",31,62.3166667,-6.3 ],
    [ u"fo",u"Kirkjubøur",81,61.95,-6.7833333 ],
    [ u"fo",u"Klaksvík",4664,62.2333333,-6.6 ],
    [ u"fo",u"Kunoy",70,62.2833333,-6.6666667 ],
    [ u"fo",u"Kvívík",372,62.1166667,-7.0666667 ],
    [ u"fo",u"Lambi",148,62.1333333,-6.6833333 ],
    [ u"fo",u"Leirvík",960,62.2166667,-6.6833333 ],
    [ u"fo",u"Leynar",114,62.1166667,-7.0333333 ],
    [ u"fo",u"Ljósá",33,62.2666667,-7.05 ],
    [ u"fo",u"Lopra",124,61.4333333,-6.7666667 ],
    [ u"fo",u"Mikladalur",60,62.3333333,-6.75 ],
    [ u"fo",u"Morskranes",45,62.1333333,-6.8333333 ],
    [ u"fo",u"Mykines",25,62.1,-7.6333333 ],
    [ u"fo",u"Nes",233,62.0833333,-6.7166667 ],
    [ u"fo",u"Nólsoy",283,62.0166667,-6.6666667 ],
    [ u"fo",u"Øravík",36,61.5333333,-6.8 ],
    [ u"fo",u"Oyrarbakki",104,62.2,-6.9833333 ],
    [ u"fo",u"Oyri",140,62.1833333,-6.9666667 ],
    [ u"fo",u"Porkeri",396,61.4833333,-6.7333333 ],
    [ u"fo",u"Rituvík",268,62.1,-6.6666667 ],
    [ u"fo",u"Runavík",503,62.1166667,-6.7166667 ],
    [ u"fo",u"Saksun",37,62.25,-7.1666667 ],
    [ u"fo",u"Saltangará",799,62.1166667,-6.7166667 ],
    [ u"fo",u"Saltnes",163,62.1,-6.7333333 ],
    [ u"fo",u"Sandavágur",779,62.05,-7.1333333 ],
    [ u"fo",u"Sandur",608,61.8333333,-6.8 ],
    [ u"fo",u"Sandvík",116,61.6333333,-6.9166667 ],
    [ u"fo",u"Skælingur",11,62.1,-7.0 ],
    [ u"fo",u"Skálabotnur",105,62.2,-6.85 ],
    [ u"fo",u"Skálavík",171,61.8333333,-6.65 ],
    [ u"fo",u"Skáli",621,62.15,-6.7666667 ],
    [ u"fo",u"Skipanes",61,62.1666667,-6.75 ],
    [ u"fo",u"Skopun",464,61.9,-6.8666667 ],
    [ u"fo",u"Skúvoy",53,61.7666667,-6.8 ],
    [ u"fo",u"Sörvag",1066,62.0666667,-7.3 ],
    [ u"fo",u"Strendur",854,62.1166667,-6.75 ],
    [ u"fo",u"Streymnes",189,62.2,-7.0166667 ],
    [ u"fo",u"Sumba",289,61.4,-6.7 ],
    [ u"fo",u"Svínáir",23,62.2333333,-7.0166667 ],
    [ u"fo",u"Svínoy",95,62.2833333,-6.3333333 ],
    [ u"fo",u"Tjørnuvík",66,62.2833333,-7.1333333 ],
    [ u"fo",u"Toftir",854,61.6,-6.95 ],
    [ u"fo",u"Tórshavn",13200,62.0166667,-6.7666667 ],
    [ u"fo",u"Trøllanes",26,62.3666667,-6.7833333 ],
    [ u"fo",u"Tvøroyri",1230,61.55,-6.8 ],
    [ u"fo",u"Vágur",1569,61.4666667,-6.8166667 ],
    [ u"fo",u"Vatnsoyrar",41,62.0666667,-7.2333333 ],
    [ u"fo",u"Vestmanna",1284,62.15,-7.1666667 ],
    [ u"fr",u"Abbeville",25274,50.106602,1.832691 ],
    [ u"fr",u"Achères",22282,48.961155,2.068824 ],
    [ u"fr",u"Agde",21950,43.310991,3.47534 ],
    [ u"fr",u"Agen",30236,44.199912,.626641 ],
    [ u"fr",u"Aire-sur-la-Lys",9829,50.638713,2.398759 ],
    [ u"fr",u"Aix-en-Provence",142133,43.528695,5.448791 ],
    [ u"fr",u"Aix-les-Bains",26688,45.683378,5.922406 ],
    [ u"fr",u"Ajaccio",51058,41.927226,8.734619 ],
    [ u"fr",u"Albert",10180,50.000906,2.650961 ],
    [ u"fr",u"Albertville",17485,45.669738,6.387059 ],
    [ u"fr",u"Albi",46510,43.927186,2.149255 ],
    [ u"fr",u"Alençon",28505,48.434758,.093111 ],
    [ u"fr",u"Alès",38661,44.131126,4.087188 ],
    [ u"fr",u"Alfortville",36566,48.80575,2.420402 ],
    [ u"fr",u"Allauch",21156,43.335552,5.482769 ],
    [ u"fr",u"Allonnes",11707,47.967395,.158067 ],
    [ u"fr",u"Ambérieu-en-Bugey",12289,45.958853,5.343197 ],
    [ u"fr",u"Amboise",11896,47.412491,.98266 ],
    [ u"fr",u"Amiens",138816,49.9,2.3 ],
    [ u"fr",u"Amilly",11965,47.972812,2.771859 ],
    [ u"fr",u"Amnéville",9640,49.257495,6.142026 ],
    [ u"fr",u"Andrésy",12646,48.982345,2.056872 ],
    [ u"fr",u"Angers",158585,47.473806,-.54774 ],
    [ u"fr",u"Anglet",36946,43.476642,-1.513456 ],
    [ u"fr",u"Angoulême",43509,45.65,.15 ],
    [ u"fr",u"Aniche",9905,50.329955,3.253457 ],
    [ u"fr",u"Annecy",51119,45.906206,6.126699 ],
    [ u"fr",u"Annecy-le-Vieux",20103,45.919715,6.143929 ],
    [ u"fr",u"Annemasse",27386,46.186519,6.241324 ],
    [ u"fr",u"Annoeullin",10442,50.528492,2.933615 ],
    [ u"fr",u"Annonay",17082,45.239695,4.670747 ],
    [ u"fr",u"Antibes",75311,43.562407,7.127766 ],
    [ u"fr",u"Antony",61595,48.758283,2.305568 ],
    [ u"fr",u"Anzin",14153,50.372014,3.50387 ],
    [ u"fr",u"Apt",11115,43.87566,5.392292 ],
    [ u"fr",u"Arcachon",11391,44.659252,-1.169382 ],
    [ u"fr",u"Arcueil",16869,48.799931,2.332555 ],
    [ u"fr",u"Argentan",16845,48.745175,-.018062 ],
    [ u"fr",u"Argenteuil",95075,48.939396,2.2367 ],
    [ u"fr",u"Arles",49925,43.681659,4.636331 ],
    [ u"fr",u"Armentières",25468,50.685679,2.882139 ],
    [ u"fr",u"Arnouville-lès-Gonesse",12543,48.983333,2.416667 ],
    [ u"fr",u"Arras",41551,50.291799,2.780306 ],
    [ u"fr",u"Athis-Mons",30025,48.705224,2.391474 ],
    [ u"fr",u"Aubagne",43979,43.290958,5.586814 ],
    [ u"fr",u"Aubenas",11076,44.620057,4.389937 ],
    [ u"fr",u"Aubergenville",11785,48.959957,1.854673 ],
    [ u"fr",u"Aubière",10529,45.751574,3.112506 ],
    [ u"fr",u"Auch",21221,43.645401,.587933 ],
    [ u"fr",u"Auchel",11227,50.503451,2.473462 ],
    [ u"fr",u"Audincourt",15114,47.483271,6.853407 ],
    [ u"fr",u"Aulnay-sous-Bois",79622,48.938138,2.494022 ],
    [ u"fr",u"Aulnoye-Aymeries",8864,50.201412,3.838439 ],
    [ u"fr",u"Auray",11425,47.670252,-2.991828 ],
    [ u"fr",u"Aurillac",30652,44.9214,2.437319 ],
    [ u"fr",u"Autun",15684,46.954878,4.300357 ],
    [ u"fr",u"Auxerre",37515,47.7996,3.57033 ],
    [ u"fr",u"Avallon",8053,47.49181,3.914723 ],
    [ u"fr",u"Avignon",85848,43.945404,4.810226 ],
    [ u"fr",u"Avion",18305,50.410379,2.830534 ],
    [ u"fr",u"Avon",14436,48.402195,2.720223 ],
    [ u"fr",u"Avrillé",13219,47.5,-.583333 ],
    [ u"fr",u"Bagneux",38003,48.795645,2.307962 ],
    [ u"fr",u"Bagnolet",32781,48.866667,2.416667 ],
    [ u"fr",u"Bagnols-sur-Cèze",18497,44.159897,4.617757 ],
    [ u"fr",u"Bailleul",14450,50.735924,2.735944 ],
    [ u"fr",u"Balma",13955,43.610145,1.503705 ],
    [ u"fr",u"Barentin",13031,49.545327,.955152 ],
    [ u"fr",u"Bar-le-Duc",16686,48.772749,5.161085 ],
    [ u"fr",u"Bastia",37668,42.702778,9.45 ],
    [ u"fr",u"Bayeux",15286,49.281062,-.705711 ],
    [ u"fr",u"Bayonne",40336,43.483333,-1.483333 ],
    [ u"fr",u"Beaucaire",14162,43.808365,4.63946 ],
    [ u"fr",u"Beauchamps",9173,48.83238,-1.360005 ],
    [ u"fr",u"Beaumont",11742,45.751226,3.083551 ],
    [ u"fr",u"Beaune",22573,47.02441,4.838925 ],
    [ u"fr",u"Beausoleil",13268,43.749038,7.417022 ],
    [ u"fr",u"Beauvais",56526,49.433333,2.083333 ],
    [ u"fr",u"Bègles",22658,44.808446,-.548086 ],
    [ u"fr",u"Behren-lès-Forbach",10010,49.166397,6.943363 ],
    [ u"fr",u"Belfort",50809,47.638831,6.854187 ],
    [ u"fr",u"Bellegarde-sur-Valserine",10815,46.110377,5.830437 ],
    [ u"fr",u"Berck",14638,50.408139,1.577515 ],
    [ u"fr",u"Bergerac",25766,44.852547,.484862 ],
    [ u"fr",u"Bernay",11491,49.09378,.601411 ],
    [ u"fr",u"Besançon",120139,47.248778,6.018152 ],
    [ u"fr",u"Béthune",29961,50.529848,2.641221 ],
    [ u"fr",u"Béziers",68264,43.345287,3.222374 ],
    [ u"fr",u"Bezons",27094,48.924257,2.212803 ],
    [ u"fr",u"Biarritz",31231,43.480119,-1.555581 ],
    [ u"fr",u"Bihorel",8954,49.454685,1.122298 ],
    [ u"fr",u"Billère",14055,43.299999,-.4 ],
    [ u"fr",u"Biscarrosse",9515,44.394434,-1.164097 ],
    [ u"fr",u"Bischheim",17164,48.610191,7.742446 ],
    [ u"fr",u"Bischwiller",12109,48.765883,7.858307 ],
    [ u"fr",u"Blagnac",23313,43.632759,1.393986 ],
    [ u"fr",u"Blanquefort",14791,44.91248,-.636633 ],
    [ u"fr",u"Blois",49510,47.594322,1.329122 ],
    [ u"fr",u"Bobigny",44153,48.909825,2.45012 ],
    [ u"fr",u"Bois-Colombes",23663,48.919363,2.274845 ],
    [ u"fr",u"Bois-Guillaume",13395,49.460197,1.12219 ],
    [ u"fr",u"Boissy-Saint-Léger",15451,48.751495,2.511632 ],
    [ u"fr",u"Bolbec",12847,49.573209,.473389 ],
    [ u"fr",u"Bollène",14470,44.28476,4.75303 ],
    [ u"fr",u"Bondues",11026,50.701956,3.094972 ],
    [ u"fr",u"Bondy",47242,48.901797,2.489312 ],
    [ u"fr",u"Bonneuil",17644,48.974455,2.431536 ],
    [ u"fr",u"Bonneville",10931,46.084257,6.404214 ],
    [ u"fr",u"Bordeaux",219311,44.840439,-.5805 ],
    [ u"fr",u"Bouc-Bel-Air",12946,43.45223,5.413189 ],
    [ u"fr",u"Bouguenais",16135,47.177624,-1.621426 ],
    [ u"fr",u"Boulogne-Billancourt",109765,48.835684,2.247342 ],
    [ u"fr",u"Boulogne-sur-Mer",45715,50.720702,1.604562 ],
    [ u"fr",u"Bourg-en-Bresse",40856,46.20445,5.227911 ],
    [ u"fr",u"Bourges",71500,47.083333,2.4 ],
    [ u"fr",u"Bourg-la-Reine",18179,48.778882,2.317807 ],
    [ u"fr",u"Bourg-lès-Valence",18645,44.956009,4.910227 ],
    [ u"fr",u"Bressuire",17952,46.839886,-.489639 ],
    [ u"fr",u"Brest",150554,48.390756,-4.486165 ],
    [ u"fr",u"Brétigny-sur-Orge",23336,48.61892,2.309158 ],
    [ u"fr",u"Briançon",10627,44.900465,6.638075 ],
    [ u"fr",u"Brie-Comte-Robert",15080,48.692468,2.610902 ],
    [ u"fr",u"Brignais",12121,45.673577,4.754842 ],
    [ u"fr",u"Brignoles",13579,43.405419,6.062253 ],
    [ u"fr",u"Brive-la-Gaillarde",49092,45.158003,1.535048 ],
    [ u"fr",u"Bron",36263,45.740218,4.922415 ],
    [ u"fr",u"Bruges",12117,44.87981,-.612194 ],
    [ u"fr",u"Brunoy",23418,48.694204,2.492233 ],
    [ u"fr",u"Bry-sur-Marne",15911,48.838106,2.524879 ],
    [ u"fr",u"Bully-les-Mines",11819,50.443805,2.727029 ],
    [ u"fr",u"Bures-sur-Yvette",10115,48.699812,2.170636 ],
    [ u"fr",u"Cachan",25391,48.796324,2.336609 ],
    [ u"fr",u"Caen",115358,49.197188,-.326822 ],
    [ u"fr",u"Cagnes-sur-Mer",46624,43.664595,7.153389 ],
    [ u"fr",u"Cahors",20336,44.454598,1.43924 ],
    [ u"fr",u"Calais",79010,50.951241,1.85899 ],
    [ u"fr",u"Caluire-et-Cuire",41524,45.790412,4.841124 ],
    [ u"fr",u"Cambrai",34140,50.177216,3.233826 ],
    [ u"fr",u"Cannes",66687,43.549744,6.9943 ],
    [ u"fr",u"Canteleu",15157,49.440654,1.024586 ],
    [ u"fr",u"Cappelle-la-Grande",8495,50.999793,2.358484 ],
    [ u"fr",u"Carcassonne",44697,43.213513,2.351625 ],
    [ u"fr",u"Carmaux",9876,44.050993,2.15795 ],
    [ u"fr",u"Carpentras",27734,44.054413,5.047716 ],
    [ u"fr",u"Carquefou",17387,47.298215,-1.490244 ],
    [ u"fr",u"Carrières-sous-Poissy",15261,48.949521,2.040682 ],
    [ u"fr",u"Carrières-sur-Seine",12635,48.906872,2.179199 ],
    [ u"fr",u"Carros",10849,43.789413,7.18395 ],
    [ u"fr",u"Carvin",18397,50.492985,2.96826 ],
    [ u"fr",u"Castelnaudary",10730,43.318288,1.954494 ],
    [ u"fr",u"Castelnau-le-Lez",16890,43.633331,3.9 ],
    [ u"fr",u"Castres",43013,43.604992,2.243259 ],
    [ u"fr",u"Caudebec-lès-Elbeuf",9998,49.280817,1.02195 ],
    [ u"fr",u"Caudry",13503,50.124905,3.411859 ],
    [ u"fr",u"Cavaillon",25890,43.836033,5.040492 ],
    [ u"fr",u"Cenon",21483,44.8559,-.51839 ],
    [ u"fr",u"Cergy",60288,49.036448,2.076133 ],
    [ u"fr",u"Cernay",10614,47.808694,7.175062 ],
    [ u"fr",u"Cestas",17230,44.743446,-.67905 ],
    [ u"fr",u"Châlette-sur-Loing",13771,48.013368,2.735871 ],
    [ u"fr",u"Challans",17688,46.843626,-1.874905 ],
    [ u"fr",u"Châlons-en-Champagne",46981,48.953926,4.367238 ],
    [ u"fr",u"Chalon-sur-Saône",47968,46.78875,4.84877 ],
    [ u"fr",u"Chamalières",18853,45.77559,3.063097 ],
    [ u"fr",u"Chambéry",57591,45.564646,5.926453 ],
    [ u"fr",u"Chamonix-Mont-Blanc",10061,45.924308,6.867316 ],
    [ u"fr",u"Champagnole",8313,46.744516,5.913538 ],
    [ u"fr",u"Champigny-sur-Marne",71985,48.81642,2.493656 ],
    [ u"fr",u"Chanteloup-les-Vignes",9311,48.976144,2.032614 ],
    [ u"fr",u"Chantilly",10772,49.192811,2.464271 ],
    [ u"fr",u"Charenton-le-Pont",30298,48.822086,2.412167 ],
    [ u"fr",u"Charleville-Mézières",54946,49.768501,4.724866 ],
    [ u"fr",u"Chartres",41229,48.448201,1.491737 ],
    [ u"fr",u"Châteaudun",14786,48.068709,1.343312 ],
    [ u"fr",u"Château-Gontier",11267,47.827711,-.700268 ],
    [ u"fr",u"Châteauneuf-lès-Martigues",11225,43.384848,5.16283 ],
    [ u"fr",u"Châteaurenard",14088,43.882248,4.853279 ],
    [ u"fr",u"Châteauroux",49170,46.812479,1.693623 ],
    [ u"fr",u"Château-Thierry",14873,49.05,3.4 ],
    [ u"fr",u"Châtellerault",34022,46.815274,.541305 ],
    [ u"fr",u"Châtenay-Malabry",31708,48.765068,2.266547 ],
    [ u"fr",u"Châtillon",30261,48.802396,2.293464 ],
    [ u"fr",u"Chatou",29450,48.889803,2.158627 ],
    [ u"fr",u"Chaumont",25562,48.12282,5.141413 ],
    [ u"fr",u"Chauny",12374,49.615144,3.218571 ],
    [ u"fr",u"Chaville",18166,48.805653,2.188642 ],
    [ u"fr",u"Chelles",46390,48.883333,2.6 ],
    [ u"fr",u"Chenôve",15551,47.293232,5.004569 ],
    [ u"fr",u"Cherbourg",24435,49.639971,-1.615505 ],
    [ u"fr",u"Chevilly-Larue",19630,48.76476,2.350297 ],
    [ u"fr",u"Chilly-Mazarin",18523,48.714893,2.316378 ],
    [ u"fr",u"Choisy-le-Roi",34757,48.768463,2.418736 ],
    [ u"fr",u"Cholet",54292,47.060836,-.875481 ],
    [ u"fr",u"Clamart",49508,48.802987,2.266917 ],
    [ u"fr",u"Claye-Souilly",10648,48.944924,2.68566 ],
    [ u"fr",u"Clermont",10368,49.380338,2.411622 ],
    [ u"fr",u"Clermont-Ferrand",137364,45.779657,3.086281 ],
    [ u"fr",u"Clichy",50908,48.90018,2.309525 ],
    [ u"fr",u"Clichy-sous-Bois",28642,48.910197,2.553235 ],
    [ u"fr",u"Cluses",18907,46.064816,6.588355 ],
    [ u"fr",u"Cognac",19585,45.7,-.333333 ],
    [ u"fr",u"Colmar",66637,48.078708,7.355401 ],
    [ u"fr",u"Colombes",76209,48.918824,2.254044 ],
    [ u"fr",u"Colomiers",29888,43.613709,1.334631 ],
    [ u"fr",u"Combs-la-Ville",22067,48.664967,2.569571 ],
    [ u"fr",u"Comines",12467,50.761503,3.010633 ],
    [ u"fr",u"Compiègne",41508,49.416667,2.833333 ],
    [ u"fr",u"Concarneau",20178,47.875019,-3.922449 ],
    [ u"fr",u"Conflans-Sainte-Honorine",35122,49.001575,2.096945 ],
    [ u"fr",u"Corbeil-Essonnes",38760,48.606034,2.487571 ],
    [ u"fr",u"Cormeilles-en-Parisis",21487,48.971112,2.204912 ],
    [ u"fr",u"Coudekerque-Branche",24669,51.022884,2.393586 ],
    [ u"fr",u"Couëron",19016,47.215077,-1.721712 ],
    [ u"fr",u"Coulommiers",14672,48.81451,3.084983 ],
    [ u"fr",u"Courbevoie",70896,48.897,2.2564 ],
    [ u"fr",u"Courcouronnes",14617,48.614287,2.407623 ],
    [ u"fr",u"Courrières",10202,50.457013,2.947245 ],
    [ u"fr",u"Coutances",9503,49.052141,-1.438687 ],
    [ u"fr",u"Cran-Gévrier",17317,45.903908,6.101226 ],
    [ u"fr",u"Creil",30250,49.256722,2.484771 ],
    [ u"fr",u"Crépy-en-Valois",15487,49.233587,2.888071 ],
    [ u"fr",u"Créteil",84133,48.792661,2.465694 ],
    [ u"fr",u"Creutzwald",13970,49.199657,6.689863 ],
    [ u"fr",u"Croissy-sur-Seine",10501,48.879248,2.138365 ],
    [ u"fr",u"Croix",21062,50.678464,3.149304 ],
    [ u"fr",u"Cugnaux",14348,43.536188,1.344141 ],
    [ u"fr",u"Cusset",13359,46.130017,3.459632 ],
    [ u"fr",u"Darnétal",8993,49.445327,1.151438 ],
    [ u"fr",u"Dax",19827,43.706102,-1.053855 ],
    [ u"fr",u"Décines-Charpieu",24661,45.768991,4.972767 ],
    [ u"fr",u"Denain",20736,50.329295,3.394298 ],
    [ u"fr",u"Deuil-la-Barre",21233,48.976743,2.327222 ],
    [ u"fr",u"Déville-lès-Rouen",10483,49.469423,1.052144 ],
    [ u"fr",u"Dieppe",34788,49.920403,1.086542 ],
    [ u"fr",u"Digoin",8368,46.481236,3.979459 ],
    [ u"fr",u"Dijon",153692,47.316667,5.016667 ],
    [ u"fr",u"Dinan",10257,48.454561,-2.048525 ],
    [ u"fr",u"Dinard",10880,48.631433,-2.061445 ],
    [ u"fr",u"Dole",24186,47.092847,5.493003 ],
    [ u"fr",u"Dombasle-sur-Meurthe",8896,48.625201,6.349671 ],
    [ u"fr",u"Domont",16314,49.027821,2.326384 ],
    [ u"fr",u"Douai",43404,50.372362,3.088996 ],
    [ u"fr",u"Douchy-les-Mines",10174,50.300795,3.392699 ],
    [ u"fr",u"Dourdan",10036,48.527725,2.011133 ],
    [ u"fr",u"Draguignan",35217,43.536545,6.463455 ],
    [ u"fr",u"Drancy",63535,48.925785,2.445327 ],
    [ u"fr",u"Draveil",28638,48.684657,2.414175 ],
    [ u"fr",u"Dreux",30303,48.735358,1.365537 ],
    [ u"fr",u"Dunkirk",71740,51.05,2.366667 ],
    [ u"fr",u"Eaubonne",23739,48.997124,2.282494 ],
    [ u"fr",u"Échirolles",32133,45.143898,5.728831 ],
    [ u"fr",u"Écully",17940,45.77726,4.77481 ],
    [ u"fr",u"Élancourt",30088,48.784205,1.955195 ],
    [ u"fr",u"Elbeuf",16613,49.286688,1.002876 ],
    [ u"fr",u"Enghien-les-Bains",10675,48.966667,2.316667 ],
    [ u"fr",u"Épernay",25573,49.042267,3.95809 ],
    [ u"fr",u"Épinal",35423,48.18324,6.453043 ],
    [ u"fr",u"Épinay-sous-Sénart",12620,48.689701,2.511863 ],
    [ u"fr",u"Épinay-sur-Orge",9351,48.673384,2.310739 ],
    [ u"fr",u"Épinay-sur-Seine",45614,48.953505,2.315139 ],
    [ u"fr",u"Éragny",15040,49.016667,2.1 ],
    [ u"fr",u"Ermont",27575,48.990043,2.25804 ],
    [ u"fr",u"Escaudain",9252,50.333147,3.344296 ],
    [ u"fr",u"Étampes",22399,48.433046,2.175806 ],
    [ u"fr",u"Étaples",11191,50.516667,1.640689 ],
    [ u"fr",u"Évreux",53040,49.023288,1.155517 ],
    [ u"fr",u"Évry",51978,48.632804,2.440492 ],
    [ u"fr",u"Eysines",19925,44.883522,-.646859 ],
    [ u"fr",u"Ézanville",8770,49.027941,2.367865 ],
    [ u"fr",u"Fameck",11966,49.30335,6.108598 ],
    [ u"fr",u"Fécamp",21300,49.756728,.372873 ],
    [ u"fr",u"Figeac",9720,44.611598,2.033065 ],
    [ u"fr",u"Firminy",17356,45.387323,4.290744 ],
    [ u"fr",u"Flers",16502,48.737217,-.574657 ],
    [ u"fr",u"Fleury-les-Aubrais",20981,47.933276,1.918111 ],
    [ u"fr",u"Fleury-Mérogis",8834,48.63108,2.361942 ],
    [ u"fr",u"Floirac",15928,44.83238,-.514107 ],
    [ u"fr",u"Florange",10533,49.323732,6.121196 ],
    [ u"fr",u"Foix",8661,42.960457,1.607872 ],
    [ u"fr",u"Fontainebleau",16217,48.405367,2.700199 ],
    [ u"fr",u"Fontaine",23869,45.198394,5.682654 ],
    [ u"fr",u"Fontenay-aux-Roses",23784,48.793253,2.29275 ],
    [ u"fr",u"Fontenay-le-Comte",13535,46.465715,-.800487 ],
    [ u"fr",u"Fontenay-le-Fleury",12403,48.812532,2.048632 ],
    [ u"fr",u"Fontenay-sous-Bois",51077,48.854419,2.482676 ],
    [ u"fr",u"Forbach",20938,49.185575,6.891406 ],
    [ u"fr",u"Fosses",10421,49.098083,2.509573 ],
    [ u"fr",u"Fos-sur-Mer",15783,43.438569,4.945717 ],
    [ u"fr",u"Fougères",21710,48.350305,-1.194229 ],
    [ u"fr",u"Fourmies",13610,50.015318,4.047837 ],
    [ u"fr",u"Francheville",11724,45.738792,4.772185 ],
    [ u"fr",u"Franconville",33870,48.983333,2.233333 ],
    [ u"fr",u"Fréjus",51514,43.432858,6.735237 ],
    [ u"fr",u"Fresnes",24335,48.757423,2.321484 ],
    [ u"fr",u"Frontignan",21511,43.448478,3.753997 ],
    [ u"fr",u"Gagny",37511,48.883333,2.533333 ],
    [ u"fr",u"Gaillac",11635,43.901111,1.902021 ],
    [ u"fr",u"Gaillard",10253,46.186794,6.21614 ],
    [ u"fr",u"Gap",38617,44.561514,6.081061 ],
    [ u"fr",u"Garches",18170,48.842257,2.182317 ],
    [ u"fr",u"Gardanne",20541,43.454638,5.469878 ],
    [ u"fr",u"Garges-lès-Gonesse",39285,48.966188,2.410676 ],
    [ u"fr",u"Genas",12584,45.732153,4.99943 ],
    [ u"fr",u"Gennevillers",41553,48.933333,2.3 ],
    [ u"fr",u"Gentilly",15639,48.812937,2.341701 ],
    [ u"fr",u"Gérardmer",8839,48.073456,6.877869 ],
    [ u"fr",u"Gerzat",9050,45.82432,3.144044 ],
    [ u"fr",u"Gien",14842,47.693316,2.630939 ],
    [ u"fr",u"Gif-sur-Yvette",22774,48.683333,2.133333 ],
    [ u"fr",u"Gisors",12062,49.281783,1.780098 ],
    [ u"fr",u"Givors",17777,45.584146,4.772558 ],
    [ u"fr",u"Gonesse",26212,48.986928,2.448922 ],
    [ u"fr",u"Goussainville",29494,49.013672,2.465948 ],
    [ u"fr",u"Gouvieux",9324,49.187047,2.41439 ],
    [ u"fr",u"Gradignan",22760,44.772615,-.613931 ],
    [ u"fr",u"Grand-Couronne",9311,49.355631,1.00647 ],
    [ u"fr",u"Grande-Synthe",22738,51.015397,2.299748 ],
    [ u"fr",u"Granville",13003,48.837401,-1.593931 ],
    [ u"fr",u"Grasse",46221,43.660921,6.92917 ],
    [ u"fr",u"Graulhet",12246,43.762838,1.988349 ],
    [ u"fr",u"Grenoble",154853,45.171546,5.722387 ],
    [ u"fr",u"Grigny",24600,48.659982,2.384137 ],
    [ u"fr",u"Guebwiller",12005,47.908124,7.209761 ],
    [ u"fr",u"Guérande",15124,47.329107,-2.428291 ],
    [ u"fr",u"Guéret",13834,46.172337,1.874562 ],
    [ u"fr",u"Gueugnon",7962,46.603569,4.06286 ],
    [ u"fr",u"Guipavas",13109,48.435221,-4.397224 ],
    [ u"fr",u"Gujan-Mestras",17953,44.633333,-1.066667 ],
    [ u"fr",u"Guyancourt",31107,48.773336,2.073927 ],
    [ u"fr",u"Hagondange",8935,49.251339,6.168115 ],
    [ u"fr",u"Haguenau",35807,48.814228,7.786232 ],
    [ u"fr",u"Halluin",20075,50.786277,3.126114 ],
    [ u"fr",u"Harfleur",8175,49.511248,.192722 ],
    [ u"fr",u"Harnes",13440,50.446427,2.904812 ],
    [ u"fr",u"Haubourdin",15508,50.608263,2.991429 ],
    [ u"fr",u"Hautmont",15289,50.247704,3.924607 ],
    [ u"fr",u"Hayange",14729,49.334278,6.052675 ],
    [ u"fr",u"Hazebrouck",22109,50.723741,2.537292 ],
    [ u"fr",u"Hem",19497,50.656636,3.189708 ],
    [ u"fr",u"Hendaye",13423,43.37172,-1.773821 ],
    [ u"fr",u"Hénin-Beaumont",24725,50.413587,2.964852 ],
    [ u"fr",u"Hennebont",13423,47.805121,-3.273366 ],
    [ u"fr",u"Herblay",24116,48.989935,2.169902 ],
    [ u"fr",u"Héricourt",10488,47.573048,6.761392 ],
    [ u"fr",u"Hérouville-Saint-Clair",23792,49.210875,-.30653 ],
    [ u"fr",u"Hirson",10529,49.922619,4.082586 ],
    [ u"fr",u"Hoenheim",10834,48.620287,7.770066 ],
    [ u"fr",u"Hombourg-Haut",9522,49.123586,6.773968 ],
    [ u"fr",u"Houilles",30101,48.921609,2.192631 ],
    [ u"fr",u"Hyères",54588,43.119539,6.13897 ],
    [ u"fr",u"Igny",9484,48.744369,2.224277 ],
    [ u"fr",u"Illkirch-Graffenstaden",25023,48.523635,7.71542 ],
    [ u"fr",u"Illzach",14729,47.780882,7.346624 ],
    [ u"fr",u"Issoire",14034,45.548695,3.249423 ],
    [ u"fr",u"Issoudun",13676,46.948477,1.993623 ],
    [ u"fr",u"Issy-les-Moulineaux",57127,48.821042,2.277183 ],
    [ u"fr",u"Istres",42036,43.509052,4.987973 ],
    [ u"fr",u"Ivry-sur-Seine",49463,48.81568,2.384868 ],
    [ u"fr",u"Jarville-la-Malgrange",9658,48.66907,6.206364 ],
    [ u"fr",u"Jeumont",10687,50.295338,4.098979 ],
    [ u"fr",u"Joigny",10355,47.982883,3.400958 ],
    [ u"fr",u"Joinville-le-Pont",17542,48.82538,2.474576 ],
    [ u"fr",u"Joué-lés-Tours",36725,47.352234,.669055 ],
    [ u"fr",u"Jouy-le-Moutier",18705,49.010676,2.040282 ],
    [ u"fr",u"Juvisy-sur-Orge",12185,48.683333,2.383333 ],
    [ u"fr",u"Kingersheim",12528,47.792586,7.334908 ],
    [ u"fr",u"La Baule-Escoublac",16658,47.285604,-2.394031 ],
    [ u"fr",u"La Celle-Saint-Cloud",21069,48.85029,2.145234 ],
    [ u"fr",u"La Chapelle-sur-Erdre",17646,47.295835,-1.553093 ],
    [ u"fr",u"La Ciotat",32596,43.176032,5.607892 ],
    [ u"fr",u"La Courneuve",35862,48.92805,2.396273 ],
    [ u"fr",u"La Crau",17335,43.149807,6.074247 ],
    [ u"fr",u"La Ferté-Bernard",9245,48.18633,.653568 ],
    [ u"fr",u"La Flèche",15559,47.703042,-.077532 ],
    [ u"fr",u"La Garde",28016,43.122773,6.007453 ],
    [ u"fr",u"La Garenne-Colombes",25781,48.904718,2.2469 ],
    [ u"fr",u"La Madeleine",23098,50.660329,3.071575 ],
    [ u"fr",u"Lamballe",11085,48.467617,-2.514361 ],
    [ u"fr",u"Lambersart",28256,50.65,3.033333 ],
    [ u"fr",u"La Motte-Servolex",12172,45.594156,5.87575 ],
    [ u"fr",u"Landerneau",14419,48.452517,-4.252517 ],
    [ u"fr",u"Lanester",22065,47.761319,-3.339652 ],
    [ u"fr",u"Langres",9416,47.85896,5.332966 ],
    [ u"fr",u"Lannion",19495,48.732445,-3.459116 ],
    [ u"fr",u"Laon",26340,49.563098,3.627137 ],
    [ u"fr",u"La Queue-en-Brie",11589,48.785198,2.58112 ],
    [ u"fr",u"La Ricamarie",7527,45.416843,4.311988 ],
    [ u"fr",u"La Rochelle",80406,46.166667,-1.15 ],
    [ u"fr",u"La Roche-sur-Yon",52595,46.666667,-1.433333 ],
    [ u"fr",u"La Seyne-sur-Mer",61417,43.098184,5.884715 ],
    [ u"fr",u"La Teste-de-Buch",25116,44.628749,-1.140591 ],
    [ u"fr",u"La Trinité",10101,43.741487,7.313533 ],
    [ u"fr",u"Lattes",16857,43.567522,3.904604 ],
    [ u"fr",u"La Valette-du-Var",22816,43.137413,5.983139 ],
    [ u"fr",u"Laval",51626,48.073203,-.763399 ],
    [ u"fr",u"Laxou",15264,48.683146,6.147995 ],
    [ u"fr",u"Le Blanc-Mesnil",47234,48.938725,2.461383 ],
    [ u"fr",u"Le Bourget",12503,48.934052,2.435838 ],
    [ u"fr",u"Le Bouscat",23331,44.866002,-.59411 ],
    [ u"fr",u"Le Cannet",42659,43.574445,7.006431 ],
    [ u"fr",u"Le Chambon-Feugerolles",13080,45.396887,4.325923 ],
    [ u"fr",u"Le Chesnay",28353,48.822203,2.122129 ],
    [ u"fr",u"Le Creusot",24836,46.807138,4.41632 ],
    [ u"fr",u"Leers",9741,50.682172,3.244289 ],
    [ u"fr",u"Le Grand-Quevilly",26342,49.400761,1.045824 ],
    [ u"fr",u"Le Havre",188605,49.5,.133333 ],
    [ u"fr",u"Le Kremlin-Bicêtre",27194,48.814713,2.360728 ],
    [ u"fr",u"Le Mans",147413,48.000386,.204709 ],
    [ u"fr",u"Le Mée-sur-Seine",21861,48.531566,2.628287 ],
    [ u"fr",u"Lens",36979,50.431178,2.833213 ],
    [ u"fr",u"Le Passage",8887,45.531697,5.505376 ],
    [ u"fr",u"Le Pecq",16151,48.89317,2.103714 ],
    [ u"fr",u"Le Petit-Quevilly",22373,49.413384,1.06155 ],
    [ u"fr",u"Le Plessis-Robinson",21931,48.788887,2.270778 ],
    [ u"fr",u"Le Plessis-Trévise",18254,48.810737,2.573626 ],
    [ u"fr",u"Le Pont-de-Claix",11597,45.124434,5.706396 ],
    [ u"fr",u"Le Pontet",15747,43.96625,4.860409 ],
    [ u"fr",u"Le Portel",10880,50.705587,1.575745 ],
    [ u"fr",u"Le Pradet",12070,43.106607,6.017185 ],
    [ u"fr",u"Le Pré-Saint-Gervais",17220,48.88549,2.404224 ],
    [ u"fr",u"Le Raincy",12770,48.895926,2.526372 ],
    [ u"fr",u"Les Clayes-sous-Bois",17491,48.822056,1.986773 ],
    [ u"fr",u"Les Herbiers",14433,46.866667,-1.016667 ],
    [ u"fr",u"Les Lilas",20499,48.879918,2.420573 ],
    [ u"fr",u"Les Mureaux",31406,48.991733,1.909718 ],
    [ u"fr",u"Les Pavillons-sous-Bois",19309,48.90683,2.506483 ],
    [ u"fr",u"Les Ponts-de-Cé",11757,47.424076,-.524165 ],
    [ u"fr",u"Levallois-Perret",59434,48.893889,2.288635 ],
    [ u"fr",u"Le Vésinet",16162,48.892811,2.133082 ],
    [ u"fr",u"Libercourt",8393,50.483225,3.015844 ],
    [ u"fr",u"Libourne",22514,44.916667,-.233333 ],
    [ u"fr",u"Liévin",33588,50.419797,2.78068 ],
    [ u"fr",u"Lillebonne",10099,49.520298,.536166 ],
    [ u"fr",u"Lille",189746,50.632971,3.058585 ],
    [ u"fr",u"Lillers",9929,50.56345,2.48042 ],
    [ u"fr",u"Limay",18306,48.995532,1.740814 ],
    [ u"fr",u"Limeil-Brévannes",18658,48.744795,2.48705 ],
    [ u"fr",u"Limoges",134549,45.831534,1.257805 ],
    [ u"fr",u"Limoux",9353,43.054021,2.218795 ],
    [ u"fr",u"Lingolsheim",17242,48.558334,7.684356 ],
    [ u"fr",u"Lisieux",23100,49.147664,.226625 ],
    [ u"fr",u"Livry-Gargan",38935,48.919303,2.543051 ],
    [ u"fr",u"Lognes",15391,48.835407,2.62998 ],
    [ u"fr",u"Lomme",29084,50.643579,2.987148 ],
    [ u"fr",u"Longjumeau",20301,48.695029,2.307355 ],
    [ u"fr",u"Longuenesse",12570,50.733954,2.235195 ],
    [ u"fr",u"Longwy",13971,49.519364,5.768815 ],
    [ u"fr",u"Lons-le-Saunier",18245,46.675351,5.55575 ],
    [ u"fr",u"Lons",12684,43.316666,-.4 ],
    [ u"fr",u"Loos",21167,50.609823,3.018743 ],
    [ u"fr",u"Lorient",59242,47.75,-3.366667 ],
    [ u"fr",u"Lormont",21437,44.874949,-.517819 ],
    [ u"fr",u"Loudéac",9177,48.178258,-2.75433 ],
    [ u"fr",u"Lourdes",14671,43.099998,-.05 ],
    [ u"fr",u"Louviers",18401,49.216667,1.166667 ],
    [ u"fr",u"Lucé",17295,48.436895,1.463588 ],
    [ u"fr",u"Lunel",25598,43.675482,4.136189 ],
    [ u"fr",u"Lunéville",20017,48.591172,6.495426 ],
    [ u"fr",u"Lure",8736,47.685152,6.498127 ],
    [ u"fr",u"Luxeuil-les-Bains",8261,47.817099,6.364997 ],
    [ u"fr",u"Lyon",463700,45.748457,4.846711 ],
    [ u"fr",u"Mâcon",33004,46.314074,4.828233 ],
    [ u"fr",u"Maisons-Alfort",50249,48.811707,2.43945 ],
    [ u"fr",u"Maisons-Laffitte",22006,48.952636,2.145207 ],
    [ u"fr",u"Maizières-lès-Metz",9708,49.207544,6.160515 ],
    [ u"fr",u"Malakoff",28583,48.819988,2.299977 ],
    [ u"fr",u"Manosque",20170,43.832871,5.783948 ],
    [ u"fr",u"Mantes-la-Jolie",43439,48.990163,1.70792 ],
    [ u"fr",u"Mantes-la-Ville",19639,48.973736,1.702529 ],
    [ u"fr",u"Marck",9012,50.948965,1.943275 ],
    [ u"fr",u"Marcq-en-Baroeul",37837,50.681615,3.09561 ],
    [ u"fr",u"Marignane",35453,43.416043,5.214526 ],
    [ u"fr",u"Marly-le-Roi",17041,48.866667,2.083333 ],
    [ u"fr",u"Marly",10637,49.062188,6.151934 ],
    [ u"fr",u"Marly",11497,50.345561,3.549588 ],
    [ u"fr",u"Marmande",17143,44.500371,.16546 ],
    [ u"fr",u"Maromme",12302,49.479248,1.023748 ],
    [ u"fr",u"Marseille",792823,43.285413,5.37606 ],
    [ u"fr",u"Martigues",44437,43.405088,5.05348 ],
    [ u"fr",u"Massy",37529,48.726924,2.283007 ],
    [ u"fr",u"Maubeuge",33017,50.278499,3.974426 ],
    [ u"fr",u"Mauguio",17688,43.618096,4.007387 ],
    [ u"fr",u"Maurepas",19817,48.764859,1.92923 ],
    [ u"fr",u"Mayenne",13969,48.302042,-.618914 ],
    [ u"fr",u"Mazamet",10071,43.490014,2.373037 ],
    [ u"fr",u"Meaux",50910,48.963579,2.882403 ],
    [ u"fr",u"Melun",36223,48.545699,2.653562 ],
    [ u"fr",u"Mende",12214,44.518486,3.50372 ],
    [ u"fr",u"Mennecy",14216,48.569028,2.443839 ],
    [ u"fr",u"Menton",29199,43.774227,7.499087 ],
    [ u"fr",u"Méricourt",11450,50.401157,2.86246 ],
    [ u"fr",u"Mérignac",65847,44.832475,-.633809 ],
    [ u"fr",u"Méru",13430,49.233333,2.133333 ],
    [ u"fr",u"Merville",8894,50.643294,2.641251 ],
    [ u"fr",u"Metz",128021,49.115461,6.175875 ],
    [ u"fr",u"Meudon",42802,48.813807,2.235 ],
    [ u"fr",u"Meylan",19569,45.219879,5.790074 ],
    [ u"fr",u"Meyzieu",28198,45.770489,5.00007 ],
    [ u"fr",u"Millau",21215,44.098553,3.080528 ],
    [ u"fr",u"Mions",11171,45.664319,4.949939 ],
    [ u"fr",u"Miramas",23354,43.586663,5.00464 ],
    [ u"fr",u"Mitry-Mory",18409,48.983333,2.616667 ],
    [ u"fr",u"Moissac",12686,44.102361,1.094502 ],
    [ u"fr",u"Moissy-Cramayel",16104,48.626052,2.601247 ],
    [ u"fr",u"Mondeville",11193,49.170604,-.317979 ],
    [ u"fr",u"Mons-en-Baroeul",22710,50.636925,3.110259 ],
    [ u"fr",u"Montargis",15048,48.001158,2.753601 ],
    [ u"fr",u"Montataire",12031,49.258999,2.437766 ],
    [ u"fr",u"Montauban",52818,44.018194,1.364319 ],
    [ u"fr",u"Montbéliard",26895,47.510316,6.798629 ],
    [ u"fr",u"Montbrison",15072,45.606096,4.067416 ],
    [ u"fr",u"Montceau-les-Mines",19375,46.666667,4.366667 ],
    [ u"fr",u"Mont-de-Marsan",30529,43.889518,-.500476 ],
    [ u"fr",u"Montélimar",32631,44.558379,4.750937 ],
    [ u"fr",u"Montesson",14947,48.909238,2.137539 ],
    [ u"fr",u"Montfermeil",23484,48.898203,2.579128 ],
    [ u"fr",u"Montgeron",22319,48.705431,2.45039 ],
    [ u"fr",u"Montigny-en-Gohelle",10603,50.425403,2.939019 ],
    [ u"fr",u"Montigny-le-Bretonneux",38264,48.766356,2.03405 ],
    [ u"fr",u"Montigny-lès-Cormeilles",17587,48.982015,2.200347 ],
    [ u"fr",u"Montigny-lès-Metz",24655,49.094353,6.151673 ],
    [ u"fr",u"Montivilliers",16390,49.545182,.187688 ],
    [ u"fr",u"Montluçon",39664,46.333333,2.6 ],
    [ u"fr",u"Montmagny",14305,48.973377,2.346885 ],
    [ u"fr",u"Montmorency",20723,48.988258,2.343398 ],
    [ u"fr",u"Montpellier",238887,43.61092,3.87723 ],
    [ u"fr",u"Montreuil",89125,48.864151,2.443218 ],
    [ u"fr",u"Montrouge",37670,48.816202,2.313935 ],
    [ u"fr",u"Mont-Saint-Aignan",22380,49.463073,1.093637 ],
    [ u"fr",u"Morangis",11145,48.703827,2.339084 ],
    [ u"fr",u"Morlaix",15696,48.58733,-3.825005 ],
    [ u"fr",u"Morsang-sur-Orge",19567,48.661805,2.353385 ],
    [ u"fr",u"Mougins",18615,43.598726,7.004343 ],
    [ u"fr",u"Moulins",21425,46.566667,3.333333 ],
    [ u"fr",u"Mouvaux",13035,50.699435,3.134292 ],
    [ u"fr",u"Moyeuvre-Grande",8826,49.251646,6.047541 ],
    [ u"fr",u"Mulhouse",111972,47.738082,7.347932 ],
    [ u"fr",u"Muret",22819,43.465874,1.327316 ],
    [ u"fr",u"Nancy",106857,48.69211,6.187756 ],
    [ u"fr",u"Nanterre",84448,48.891373,2.20027 ],
    [ u"fr",u"Nantes",284677,47.216509,-1.552379 ],
    [ u"fr",u"Narbonne",47433,43.184417,3.008816 ],
    [ u"fr",u"Nemours",13743,48.27511,2.690778 ],
    [ u"fr",u"Neuilly-Plaisance",18446,48.859523,2.502783 ],
    [ u"fr",u"Neuilly-sur-Marne",33940,48.853733,2.549027 ],
    [ u"fr",u"Neuilly-sur-Seine",57141,48.883333,2.266667 ],
    [ u"fr",u"Neuville-en-Ferrain",9372,50.748391,3.156756 ],
    [ u"fr",u"Nevers",40520,46.991203,3.157084 ],
    [ u"fr",u"Nice",341621,43.713644,7.25952 ],
    [ u"fr",u"Nîmes",137532,43.833778,4.359623 ],
    [ u"fr",u"Niort",56715,46.323875,-.461334 ],
    [ u"fr",u"Noeux-les-Mines",11828,50.475481,2.667939 ],
    [ u"fr",u"Nogent-le-Rotrou",11657,48.320197,.820593 ],
    [ u"fr",u"Nogent-sur-Marne",30453,48.838814,2.478642 ],
    [ u"fr",u"Nogent-sur-Oise",19184,49.271579,2.470741 ],
    [ u"fr",u"Noisiel",15205,48.848675,2.624346 ],
    [ u"fr",u"Noisy-le-Grand",61650,48.849792,2.562658 ],
    [ u"fr",u"Noisy-le-Sec",38153,48.891481,2.46451 ],
    [ u"fr",u"Notre-Dame-de-Gravenchon",8511,49.489405,.571878 ],
    [ u"fr",u"Noyon",14711,49.583333,3 ],
    [ u"fr",u"Obernai",11146,48.462783,7.481764 ],
    [ u"fr",u"Octeville",16417,49.626118,-1.643486 ],
    [ u"fr",u"Oignies",10539,50.463311,2.993761 ],
    [ u"fr",u"Oissel",11100,49.333093,1.094129 ],
    [ u"fr",u"Olivet",20579,47.862194,1.8991 ],
    [ u"fr",u"Ollioules",13730,43.135174,5.848004 ],
    [ u"fr",u"Oloron-Sainte-Marie",11007,43.200001,-.6 ],
    [ u"fr",u"Onnaing",8603,50.38584,3.599627 ],
    [ u"fr",u"Orange",29053,44.139195,4.807906 ],
    [ u"fr",u"Orléans",118190,47.902891,1.903887 ],
    [ u"fr",u"Orly",19830,48.747921,2.392525 ],
    [ u"fr",u"Ormesson-sur-Marne",9710,48.786295,2.544712 ],
    [ u"fr",u"Orsay",17418,48.695722,2.187268 ],
    [ u"fr",u"Orthez",10203,43.488385,-.77244 ],
    [ u"fr",u"Orvault",24080,47.270949,-1.621902 ],
    [ u"fr",u"Osny",16027,49.059366,2.061833 ],
    [ u"fr",u"Ostwald",11224,48.544203,7.71087 ],
    [ u"fr",u"Oullins",24803,45.717743,4.80382 ],
    [ u"fr",u"Outreau",15316,50.705354,1.589696 ],
    [ u"fr",u"Oyonnax",24712,46.250567,5.659845 ],
    [ u"fr",u"Ozoir-la-Ferrière",22320,48.766993,2.668712 ],
    [ u"fr",u"Palaiseau",29749,48.716736,2.249106 ],
    [ u"fr",u"Pantin",52147,48.894369,2.409346 ],
    [ u"fr",u"Paray-le-Monial",8867,46.454574,4.115844 ],
    [ u"fr",u"Paris",2110694,48.866667,2.333333 ],
    [ u"fr",u"Parthenay",10352,46.645813,-.24463 ],
    [ u"fr",u"Passy",10859,45.920277,6.687651 ],
    [ u"fr",u"Pau",77475,43.299999,-.366667 ],
    [ u"fr",u"Périgueux",30198,45.183333,.716667 ],
    [ u"fr",u"Perpignan",104783,42.696172,2.897098 ],
    [ u"fr",u"Persan",9138,49.153355,2.272179 ],
    [ u"fr",u"Pertuis",19530,43.69252,5.502854 ],
    [ u"fr",u"Pessac",59818,44.810112,-.641294 ],
    [ u"fr",u"Pierre-Bénite",10304,45.700895,4.825112 ],
    [ u"fr",u"Pierrefitte-sur-Seine",27441,48.966907,2.361036 ],
    [ u"fr",u"Pierrelatte",12201,44.377556,4.701976 ],
    [ u"fr",u"Pithiviers",9313,48.175047,2.252062 ],
    [ u"fr",u"Plaisance-du-Touch",17770,43.565663,1.297494 ],
    [ u"fr",u"Plaisir",35407,48.823186,1.954099 ],
    [ u"fr",u"Plan-de-Cuques",10995,43.346437,5.462554 ],
    [ u"fr",u"Plérin",12890,48.542494,-2.779835 ],
    [ u"fr",u"Ploemeur",18944,47.733333,-3.433333 ],
    [ u"fr",u"Ploufragan",10651,48.491411,-2.794576 ],
    [ u"fr",u"Plougastel-Daoulas",13128,48.366667,-4.366667 ],
    [ u"fr",u"Plouzané",12588,48.383333,-4.616667 ],
    [ u"fr",u"Poissy",35663,48.92902,2.049521 ],
    [ u"fr",u"Poitiers",86639,46.583333,.333333 ],
    [ u"fr",u"Pont-à-Mousson",14657,48.907861,6.058897 ],
    [ u"fr",u"Pontarlier",18665,46.908792,6.35917 ],
    [ u"fr",u"Pont-Audemer",9125,49.35,.516667 ],
    [ u"fr",u"Pontivy",13789,48.066539,-2.96442 ],
    [ u"fr",u"Pontoise",28186,49.055272,2.105512 ],
    [ u"fr",u"Pont-Sainte-Maxence",13709,49.301677,2.604673 ],
    [ u"fr",u"Pont-Saint-Esprit",9382,44.254942,4.647364 ],
    [ u"fr",u"Port-de-Bouc",15621,43.406069,4.981073 ],
    [ u"fr",u"Porto-Vecchio",11065,41.589364,9.279907 ],
    [ u"fr",u"Privas",8722,44.733939,4.597013 ],
    [ u"fr",u"Provins",11958,48.561463,3.297725 ],
    [ u"fr",u"Puteaux",39752,48.878888,2.239264 ],
    [ u"fr",u"Quétigny",9628,47.31417,5.110176 ],
    [ u"fr",u"Quimperlé",11015,47.866667,-3.55 ],
    [ u"fr",u"Quimper",66251,48,-4.1 ],
    [ u"fr",u"Raismes",13554,50.383333,3.483333 ],
    [ u"fr",u"Rambouillet",25429,48.642276,1.831259 ],
    [ u"fr",u"Ramonville-Saint-Agne",11732,43.547937,1.470791 ],
    [ u"fr",u"Reims",192688,49.25,4.033333 ],
    [ u"fr",u"Remiremont",8274,48.017537,6.5882 ],
    [ u"fr",u"Rennes",213334,48.111981,-1.674291 ],
    [ u"fr",u"Revin",8770,49.936162,4.643896 ],
    [ u"fr",u"Rezé",37338,47.181441,-1.549654 ],
    [ u"fr",u"Riom",18557,45.892557,3.113549 ],
    [ u"fr",u"Riorges",10303,46.041786,4.049655 ],
    [ u"fr",u"Ris-Orangis",24628,48.651104,2.414057 ],
    [ u"fr",u"Rive-de-Gier",13733,45.530668,4.621306 ],
    [ u"fr",u"Rixheim",13348,47.751403,7.400913 ],
    [ u"fr",u"Roanne",37144,46.043291,4.068553 ],
    [ u"fr",u"Rochefort",26150,45.941828,-.967334 ],
    [ u"fr",u"Roche-la-Molière",10160,45.43408,4.322765 ],
    [ u"fr",u"Rodez",23268,44.35237,2.572616 ],
    [ u"fr",u"Rognac",12096,43.488925,5.229288 ],
    [ u"fr",u"Roissy-en-Brie",20799,48.791594,2.64747 ],
    [ u"fr",u"Romainville",24158,48.8854,2.434819 ],
    [ u"fr",u"Romans-sur-Isère",32933,45.046388,5.056197 ],
    [ u"fr",u"Rombas",10764,49.249107,6.094054 ],
    [ u"fr",u"Romilly-sur-Seine",14158,48.510852,3.726338 ],
    [ u"fr",u"Ronchin",18177,50.598832,3.09056 ],
    [ u"fr",u"Roncq",13251,50.753296,3.121314 ],
    [ u"fr",u"Roquebrune-Cap-Martin",11416,43.764078,7.482065 ],
    [ u"fr",u"Rosny-sous-Bois",40571,48.870172,2.499104 ],
    [ u"fr",u"Roubaix",96806,50.694207,3.174556 ],
    [ u"fr",u"Rouen",108101,49.433333,1.083333 ],
    [ u"fr",u"Rouvroy",9072,49.854572,3.317458 ],
    [ u"fr",u"Royan",17408,45.628461,-1.0281 ],
    [ u"fr",u"Rueil-Malmaison",78645,48.876503,2.189666 ],
    [ u"fr",u"Rumilly",12278,45.868733,5.936522 ],
    [ u"fr",u"Sablé-sur-Sarthe",13182,47.839422,-.329716 ],
    [ u"fr",u"Saint-Amand-les-Eaux",17568,50.447176,3.43076 ],
    [ u"fr",u"Saint-André-les-Vergers",11085,48.285266,4.052104 ],
    [ u"fr",u"Saint-André-lez-Lille",10201,50.660169,3.040672 ],
    [ u"fr",u"Saint-Avertin",15619,47.363569,.739933 ],
    [ u"fr",u"Saint-Avold",17340,49.102696,6.700636 ],
    [ u"fr",u"Saint-Brice-sous-Forêt",13356,49.001318,2.353607 ],
    [ u"fr",u"Saint-Brieuc",43522,48.510504,-2.765927 ],
    [ u"fr",u"Saint-Chamond",36734,45.473646,4.525411 ],
    [ u"fr",u"Saint-Claude",12169,46.390153,5.863737 ],
    [ u"fr",u"Saint-Cloud",28009,48.845985,2.202889 ],
    [ u"fr",u"Saint-Cyr-sur-Loire",16907,47.4,.666667 ],
    [ u"fr",u"Saint-Denis",84027,48.934172,2.354805 ],
    [ u"fr",u"Saint-Dié",22682,48.281037,6.959461 ],
    [ u"fr",u"Saint-Dizier",29573,48.638001,4.945553 ],
    [ u"fr",u"Saint-Doulchard",9058,47.103712,2.351999 ],
    [ u"fr",u"Sainte-Foy-lès-Lyon",21206,45.73692,4.796883 ],
    [ u"fr",u"Sainte-Geneviève-des-Bois",33133,48.646824,2.319653 ],
    [ u"fr",u"Sainte-Luce-sur-Loire",12550,47.253807,-1.484296 ],
    [ u"fr",u"Sainte-Maxime",13291,43.309716,6.628328 ],
    [ u"fr",u"Sainte-Savine",10631,48.296369,4.046417 ],
    [ u"fr",u"Saintes",25616,45.745604,-.631674 ],
    [ u"fr",u"Saint-Estève",9919,42.711755,2.844896 ],
    [ u"fr",u"Saint-Étienne-du-Rouvray",28344,49.377941,1.104673 ],
    [ u"fr",u"Saint-Étienne",170416,45.435382,4.391051 ],
    [ u"fr",u"Saint-Fons",15760,45.708803,4.860567 ],
    [ u"fr",u"Saint-Gaudens",10698,43.110387,.725481 ],
    [ u"fr",u"Saint-Genis-Laval",19668,45.695582,4.793397 ],
    [ u"fr",u"Saint-Germain-en-Laye",38098,48.904194,2.086688 ],
    [ u"fr",u"Saint-Gilles",11995,43.677923,4.432586 ],
    [ u"fr",u"Saint-Gratien",19521,48.973497,2.287287 ],
    [ u"fr",u"Saint-Herblain",44790,47.217646,-1.64841 ],
    [ u"fr",u"Saint-Jean-de-Braye",18949,47.913029,1.977047 ],
    [ u"fr",u"Saint-Jean-de-la-Ruelle",16931,47.911271,1.864833 ],
    [ u"fr",u"Saint-Jean-de-Luz",13523,43.389075,-1.658095 ],
    [ u"fr",u"Saint-Jean-de-Maurienne",8671,45.284946,6.384018 ],
    [ u"fr",u"Saint-Junien",10779,45.888671,.901429 ],
    [ u"fr",u"Saint-Laurent-du-Var",29461,43.670968,7.17606 ],
    [ u"fr",u"Saint-Leu-la-Forêt",15812,49.016667,2.25 ],
    [ u"fr",u"Saint-Lô",19411,49.113813,-1.081905 ],
    [ u"fr",u"Saint-Louis",20387,47.588364,7.562469 ],
    [ u"fr",u"Saint-Malo",52909,48.6361,-2.004935 ],
    [ u"fr",u"Saint-Mandé",20516,48.838642,2.415791 ],
    [ u"fr",u"Saint-Martin-Boulogne",11892,50.726909,1.618642 ],
    [ u"fr",u"Saint-Martin-de-Crau",11117,43.638328,4.813693 ],
    [ u"fr",u"Saint-Maur-des-Fossés",71267,48.793945,2.493233 ],
    [ u"fr",u"Saint-Maurice",13975,48.821815,2.427157 ],
    [ u"fr",u"Saint-Maximin-la-Sainte-Baume",14807,43.452141,5.862186 ],
    [ u"fr",u"Saint-Max",10926,48.704294,6.209989 ],
    [ u"fr",u"Saint-Médard-en-Jalles",28405,44.896921,-.721356 ],
    [ u"fr",u"Saint-Michel-sur-Orge",20413,48.634788,2.30831 ],
    [ u"fr",u"Saint-Nazaire",66937,47.279883,-2.208804 ],
    [ u"fr",u"Saint-Omer",16785,50.748345,2.257656 ],
    [ u"fr",u"Saint-Orens-de-Gameville",12024,43.554021,1.534106 ],
    [ u"fr",u"Saint-Ouen",38590,48.9,2.333333 ],
    [ u"fr",u"Saint-Paul-lès-Dax",10850,43.727147,-1.051618 ],
    [ u"fr",u"Saint-Pierre-des-Corps",14679,47.386229,.748487 ],
    [ u"fr",u"Saint-Pol-sur-Mer",23205,51.03116,2.339835 ],
    [ u"fr",u"Saint-Priest",40824,45.696125,4.938915 ],
    [ u"fr",u"Saint-Quentin",58399,49.849176,3.288062 ],
    [ u"fr",u"Saint-Raphaël",33115,43.424758,6.770236 ],
    [ u"fr",u"Saint-Rémy-de-Provence",10211,43.787747,4.831401 ],
    [ u"fr",u"Saint-Saulve",11061,50.371412,3.556119 ],
    [ u"fr",u"Saint-Sébastien-sur-Loire",27631,47.195847,-1.509875 ],
    [ u"fr",u"Saint-Vallier",9332,46.641066,4.371069 ],
    [ u"fr",u"Sallanches",15747,45.936882,6.636638 ],
    [ u"fr",u"Sallaumines",10544,50.417491,2.861742 ],
    [ u"fr",u"Salon-de-Provence",39598,43.640737,5.095449 ],
    [ u"fr",u"Sanary-sur-Mer",18928,43.117835,5.800065 ],
    [ u"fr",u"Sannois",25858,48.966667,2.25 ],
    [ u"fr",u"Saran",15983,47.950127,1.876014 ],
    [ u"fr",u"Sarcelles",59372,48.99365,2.410771 ],
    [ u"fr",u"Sarlat-la-Canéda",9670,44.883333,1.216667 ],
    [ u"fr",u"Sarrebourg",13458,48.734217,7.056016 ],
    [ u"fr",u"Sarreguemines",23427,49.113579,7.072387 ],
    [ u"fr",u"Sartrouville",50954,48.948203,2.19169 ],
    [ u"fr",u"Saumur",30036,47.256629,-.075025 ],
    [ u"fr",u"Saverne",11925,48.740039,7.365086 ],
    [ u"fr",u"Savigny-le-Temple",25707,48.574087,2.582871 ],
    [ u"fr",u"Savigny-sur-Orge",38818,48.676775,2.348351 ],
    [ u"fr",u"Sceaux",20564,48.776442,2.290258 ],
    [ u"fr",u"Schiltigheim",32138,48.60557,7.747763 ],
    [ u"fr",u"Seclin",12061,50.548729,3.027313 ],
    [ u"fr",u"Sedan",19997,49.70022,4.948389 ],
    [ u"fr",u"Sélestat",18457,48.259323,7.454285 ],
    [ u"fr",u"Senlis",17910,49.207668,2.584531 ],
    [ u"fr",u"Sens",27060,48.2,3.283333 ],
    [ u"fr",u"Septèmes-les-Vallons",10165,43.400537,5.36979 ],
    [ u"fr",u"Sète",38788,43.406283,3.693041 ],
    [ u"fr",u"Sevran",46648,48.944716,2.527462 ],
    [ u"fr",u"Sèvres",22993,48.822916,2.217569 ],
    [ u"fr",u"Seynod",17733,45.885488,6.088313 ],
    [ u"fr",u"Seyssinet-Pariset",13135,45.176755,5.693872 ],
    [ u"fr",u"Sin-le-Noble",17431,50.361594,3.131128 ],
    [ u"fr",u"Soissons",29480,49.380825,3.327146 ],
    [ u"fr",u"Soisy-sous-Montmorency",17214,48.988126,2.301558 ],
    [ u"fr",u"Solliès-Pont",11933,43.189784,6.043205 ],
    [ u"fr",u"Somain",12132,50.359606,3.281081 ],
    [ u"fr",u"Sorgues",17978,44.008367,4.874924 ],
    [ u"fr",u"Sotteville-lès-Rouen",29848,49.409718,1.090055 ],
    [ u"fr",u"Soyaux",10156,45.65,.2 ],
    [ u"fr",u"Stains",31921,48.95,2.383333 ],
    [ u"fr",u"Stiring-Wendel",12872,49.2,6.933333 ],
    [ u"fr",u"Strasbourg",273506,48.600381,7.787355 ],
    [ u"fr",u"Sucy-en-Brie",24354,48.768716,2.534738 ],
    [ u"fr",u"Suresnes",42243,48.87143,2.229289 ],
    [ u"fr",u"Talant",11877,47.336935,5.008876 ],
    [ u"fr",u"Talence",39514,44.804768,-.595431 ],
    [ u"fr",u"Tarare",10319,45.897614,4.432722 ],
    [ u"fr",u"Tarascon",14080,43.805769,4.665598 ],
    [ u"fr",u"Tarbes",45628,43.233334,.083333 ],
    [ u"fr",u"Tarnos",10850,43.541205,-1.461599 ],
    [ u"fr",u"Tassin-la-Demi-Lune",16450,45.754987,4.788123 ],
    [ u"fr",u"Taverny",26828,49.025425,2.216907 ],
    [ u"fr",u"Tergnier",15296,49.656068,3.301071 ],
    [ u"fr",u"Thiais",28905,48.764965,2.3961 ],
    [ u"fr",u"Thiers",12576,45.858139,3.556275 ],
    [ u"fr",u"Thionville",41802,49.356794,6.167606 ],
    [ u"fr",u"Thonon-les-Bains",29698,46.372465,6.487007 ],
    [ u"fr",u"Thouars",10601,46.976018,-.215073 ],
    [ u"fr",u"Tinqueux",10137,49.25,3.983333 ],
    [ u"fr",u"Tonneins",8951,44.392063,.312408 ],
    [ u"fr",u"Torcy",24189,48.854483,2.650567 ],
    [ u"fr",u"Toulon",154465,43.117705,5.941712 ],
    [ u"fr",u"Toulouse",411145,43.599516,1.433188 ],
    [ u"fr",u"Toul",16848,48.674594,5.892905 ],
    [ u"fr",u"Tourcoing",93835,50.723907,3.161168 ],
    [ u"fr",u"Tourlaville",17763,49.638285,-1.566392 ],
    [ u"fr",u"Tournefeuille",28022,43.583905,1.34685 ],
    [ u"fr",u"Tournon-sur-Rhône",10314,45.065816,4.835274 ],
    [ u"fr",u"Tours",135143,47.394836,.703977 ],
    [ u"fr",u"Trappes",28013,48.774129,2.017811 ],
    [ u"fr",u"Trélazé",11481,47.445648,-.465395 ],
    [ u"fr",u"Triel-sur-Seine",12351,48.978181,2.007429 ],
    [ u"fr",u"Troyes",61903,48.300727,4.085244 ],
    [ u"fr",u"Tulle",14728,45.270009,1.773087 ],
    [ u"fr",u"Uckange",7264,49.303036,6.149202 ],
    [ u"fr",u"Ussel",10420,45.55,2.316667 ],
    [ u"fr",u"Vaires-sur-Marne",12418,48.876492,2.639816 ],
    [ u"fr",u"Valbonne",11782,43.641272,7.005747 ],
    [ u"fr",u"Valence",63754,44.92801,4.895103 ],
    [ u"fr",u"Valenciennes",42941,50.357065,3.527885 ],
    [ u"fr",u"Valentigney",12221,47.463879,6.83168 ],
    [ u"fr",u"Valenton",11716,48.74527,2.464669 ],
    [ u"fr",u"Vallauris",27144,43.577483,7.062556 ],
    [ u"fr",u"Valréas",9792,44.383661,4.990843 ],
    [ u"fr",u"Vandoeuvre-lès-Nancy",31012,48.662127,6.178281 ],
    [ u"fr",u"Vannes",56649,47.657897,-2.755735 ],
    [ u"fr",u"Vanves",25184,48.823451,2.290253 ],
    [ u"fr",u"Vaulx-en-Velin",36564,45.781801,4.920852 ],
    [ u"fr",u"Vauréal",20250,49.033333,2.033333 ],
    [ u"fr",u"Vauvert",10377,43.695289,4.277051 ],
    [ u"fr",u"Vélizy-Villacoublay",20426,48.781981,2.193947 ],
    [ u"fr",u"Vence",18399,43.721624,7.112324 ],
    [ u"fr",u"Vendôme",18006,47.807543,1.057611 ],
    [ u"fr",u"Vénissieux",53678,45.702538,4.871473 ],
    [ u"fr",u"Verdun",19048,49.158146,5.388608 ],
    [ u"fr",u"Verneuil-sur-Seine",16261,48.980817,1.966678 ],
    [ u"fr",u"Vernon",24688,49.092918,1.463324 ],
    [ u"fr",u"Vernouillet",11554,48.97146,1.980817 ],
    [ u"fr",u"Verrières-le-Buisson",16288,48.745653,2.267956 ],
    [ u"fr",u"Versailles",85134,48.803593,2.134236 ],
    [ u"fr",u"Vertou",21897,47.16869,-1.469294 ],
    [ u"fr",u"Vesoul",17050,47.626044,6.142506 ],
    [ u"fr",u"Vichy",25900,46.128264,3.423472 ],
    [ u"fr",u"Vienne",30651,45.524785,4.873453 ],
    [ u"fr",u"Vierzon",28503,47.216667,2.083333 ],
    [ u"fr",u"Vieux-Condé",10586,50.45944,3.567375 ],
    [ u"fr",u"Vigneux-sur-Seine",26310,48.702911,2.413574 ],
    [ u"fr",u"Villebon-sur-Yvette",9700,48.705944,2.240194 ],
    [ u"fr",u"Villefontaine",19076,45.612505,5.145577 ],
    [ u"fr",u"Villefranche-de-Rouergue",11775,44.350712,2.034177 ],
    [ u"fr",u"Villefranche-sur-Saône",31543,45.987214,4.728309 ],
    [ u"fr",u"Villejuif",46913,48.793899,2.359919 ],
    [ u"fr",u"Villemomble",27351,48.883333,2.5 ],
    [ u"fr",u"Villeneuve-la-Garenne",21557,48.939354,2.31478 ],
    [ u"fr",u"Villeneuve-le-Roi",17229,48.736837,2.400812 ],
    [ u"fr",u"Villeneuve-lès-Avignon",12688,43.968405,4.796298 ],
    [ u"fr",u"Villeneuve-Loubet",14120,43.666628,7.120396 ],
    [ u"fr",u"Villeneuve-Saint-Georges",29506,48.732194,2.44925 ],
    [ u"fr",u"Villeneuve-sur-Lot",22933,44.4071,.705603 ],
    [ u"fr",u"Villeparisis",23557,48.94208,2.61463 ],
    [ u"fr",u"Villepinte",36557,48.962034,2.532534 ],
    [ u"fr",u"Villers-lès-Nancy",15296,48.67103,6.150832 ],
    [ u"fr",u"Villerupt",9514,49.46737,5.932854 ],
    [ u"fr",u"Villeurbanne",126230,45.765502,4.875522 ],
    [ u"fr",u"Villiers-le-Bel",26611,49.008747,2.39819 ],
    [ u"fr",u"Villiers-sur-Marne",29652,48.830999,2.548441 ],
    [ u"fr",u"Vincennes",44781,48.848603,2.437692 ],
    [ u"fr",u"Vire",12898,48.843564,-.885237 ],
    [ u"fr",u"Viroflay",15803,48.800785,2.161808 ],
    [ u"fr",u"Viry-Châtillon",30479,48.672115,2.393179 ],
    [ u"fr",u"Vitré",16026,48.117755,-1.205771 ],
    [ u"fr",u"Vitrolles",38052,43.454847,5.24598 ],
    [ u"fr",u"Vitry-le-François",16714,48.727074,4.591969 ],
    [ u"fr",u"Vitry-sur-Seine",77035,48.787159,2.403322 ],
    [ u"fr",u"Voiron",20795,45.363948,5.592093 ],
    [ u"fr",u"Voisins-le-Bretonneux",12987,48.75793,2.051366 ],
    [ u"fr",u"Wasquehal",19030,50.670426,3.133819 ],
    [ u"fr",u"Wattignies",14474,50.586392,3.043938 ],
    [ u"fr",u"Wattrelos",42522,50.70118,3.218116 ],
    [ u"fr",u"Waziers",7431,50.387171,3.114902 ],
    [ u"fr",u"Wittelsheim",10164,47.802546,7.236579 ],
    [ u"fr",u"Wittenheim",15612,47.807801,7.337023 ],
    [ u"fr",u"Woippy",13508,49.149465,6.149088 ],
    [ u"fr",u"Yerres",28052,48.717853,2.493384 ],
    [ u"fr",u"Yvetot",10857,49.617442,.758138 ],
    [ u"fr",u"Yzeure",12306,46.564383,3.354949 ],
    [ u"ga",u"Bitam",10297,2.0833333,11.4833333 ],
    [ u"ga",u"Booué",5787,-0.1,11.9333333 ],
    [ u"ga",u"Cocobeach",1653,0.9833333,9.6 ],
    [ u"ga",u"Fougamou",5649,-1.2166667,10.6 ],
    [ u"ga",u"Gamba",9928,-2.65,10.0 ],
    [ u"ga",u"Kango",1516,0.15,10.1333333 ],
    [ u"ga",u"Koulamoutou",16222,-1.1333333,12.4833333 ],
    [ u"ga",u"Lambaréné",20714,-0.7,10.2166667 ],
    [ u"ga",u"Lastoursville",8340,-0.8166667,12.7 ],
    [ u"ga",u"Lékoni",3583,-1.5833333,14.2333333 ],
    [ u"ga",u"Libreville",578156,0.3833333,9.45 ],
    [ u"ga",u"Makokou",13571,0.5666667,12.8666667 ],
    [ u"ga",u"Mayumba",3996,-3.4166667,10.65 ],
    [ u"ga",u"Mbigou",4134,-1.8833333,11.9333333 ],
    [ u"ga",u"Mimongo",3307,-1.6333333,11.65 ],
    [ u"ga",u"Mitzic",3886,0.7833333,11.5666667 ],
    [ u"ga",u"Moanda",30151,-1.5666667,13.2 ],
    [ u"ga",u"Mouila",22469,-1.8666667,11.0166667 ],
    [ u"ga",u"Mounana",8780,-1.4333333,13.1666667 ],
    [ u"ga",u"Ndendé",6200,-2.3833333,11.3833333 ],
    [ u"ga",u"Ndjolé",5098,-0.1833333,10.75 ],
    [ u"ga",u"Nkan",8526,0.7166667,9.6666667 ],
    [ u"ga",u"Ntoum",8569,0.3666667,9.7833333 ],
    [ u"ga",u"Okandja",7155,-0.6833333,13.7833333 ],
    [ u"ga",u"Omboué",1667,-1.5666667,9.25 ],
    [ u"ga",u"Oyem",30870,1.6166667,11.5833333 ],
    [ u"ga",u"Port-Gentil",109163,-0.7166667,8.7833333 ],
    [ u"ga",u"Tchibanga",19365,-2.85,11.0333333 ],
    [ u"ga",u"Tsogni",9957,-2.8,10.1666667 ],
    [ u"gb",u"Aberchirder",1159,57.55,-2.616667 ],
    [ u"gb",u"Aberdare",32756,51.715,-3.454167 ],
    [ u"gb",u"Aberdeen",183791,57.133333,-2.1 ],
    [ u"gb",u"Aberdour",1742,56.05,-3.3 ],
    [ u"gb",u"Aberfeldy",1937,56.616667,-3.85 ],
    [ u"gb",u"Aberfoyle",577,56.183333,-4.383333 ],
    [ u"gb",u"Aberlady",876,56,-2.85 ],
    [ u"gb",u"Aberlour",828,57.466667,-3.233333 ],
    [ u"gb",u"Abernethy",1010,56.333333,-3.333333 ],
    [ u"gb",u"Aberystwyth",18392,52.416667,-4.066667 ],
    [ u"gb",u"Abingdon",37192,51.666667,-1.283333 ],
    [ u"gb",u"Aboyne",2236,57.083333,-2.833333 ],
    [ u"gb",u"Accrington",35318,53.766667,-2.35 ],
    [ u"gb",u"Airdrie",35440,55.85,-3.983333 ],
    [ u"gb",u"Airth",1414,56.066667,-3.766667 ],
    [ u"gb",u"Aldershot",61339,51.25,-.766667 ],
    [ u"gb",u"Alford",2237,57.216667,-2.7 ],
    [ u"gb",u"Alfreton",22550,53.1,-1.383333 ],
    [ u"gb",u"Allanton",1266,55.783333,-2.216667 ],
    [ u"gb",u"Alloa",18885,56.116667,-3.8 ],
    [ u"gb",u"Almondbank",617,56.4,-3.55 ],
    [ u"gb",u"Alness",4921,57.683333,-4.25 ],
    [ u"gb",u"Altrincham",41548,53.383333,-2.35 ],
    [ u"gb",u"Alva",5130,56.15,-3.8 ],
    [ u"gb",u"Alyth",2354,56.616667,-3.216667 ],
    [ u"gb",u"Amersham",21731,51.666667,-.616667 ],
    [ u"gb",u"Andover",39951,51.2,-1.483333 ],
    [ u"gb",u"Annan",8231,54.983333,-3.266667 ],
    [ u"gb",u"Annbank",822,55.466667,-4.516667 ],
    [ u"gb",u"Anstruther",3527,56.216667,-2.7 ],
    [ u"gb",u"Antrim",25525,54.666667,-6.25 ],
    [ u"gb",u"Arbroath",22291,56.55,-2.583333 ],
    [ u"gb",u"Ardersier",930,57.566667,-4.033333 ],
    [ u"gb",u"Ardrishaig",1261,56.016667,-5.45 ],
    [ u"gb",u"Ardrossan",10936,55.616667,-4.816667 ],
    [ u"gb",u"Armadale",9026,55.883333,-3.7 ],
    [ u"gb",u"Arnold",37873,53,-1.133333 ],
    [ u"gb",u"Ashford",62787,51.133333,.883333 ],
    [ u"gb",u"Ashington",27546,55.163889,-1.586389 ],
    [ u"gb",u"Ashton-under-Lyne",43675,53.5,-2.1 ],
    [ u"gb",u"Atherton",20149,53.516667,-2.5 ],
    [ u"gb",u"Auchinleck",3282,55.466667,-4.3 ],
    [ u"gb",u"Auchterarder",4220,56.3,-3.7 ],
    [ u"gb",u"Auchtermuchty",2023,56.283333,-3.216667 ],
    [ u"gb",u"Aviemore",2545,57.2,-3.833333 ],
    [ u"gb",u"Avoch",843,57.566667,-4.166667 ],
    [ u"gb",u"Avonbridge",560,55.933333,-3.75 ],
    [ u"gb",u"Aylesbury",74565,51.816667,-.8 ],
    [ u"gb",u"Ayr",45514,55.45,-4.616667 ],
    [ u"gb",u"Ayton",548,55.85,-2.133333 ],
    [ u"gb",u"Balfron",1605,56.066667,-4.333333 ],
    [ u"gb",u"Balintore",1045,57.75,-3.9 ],
    [ u"gb",u"Ballachulish",633,56.666667,-5.116667 ],
    [ u"gb",u"Ballater",1466,57.05,-3.05 ],
    [ u"gb",u"Ballingry",5758,56.15,-3.333333 ],
    [ u"gb",u"Balloch",1743,56,-4.583333 ],
    [ u"gb",u"Ballymena",30997,54.833333,-6.25 ],
    [ u"gb",u"Balmedie",1814,57.25,-2.05 ],
    [ u"gb",u"Balmullo",1085,56.366667,-2.916667 ],
    [ u"gb",u"Banbury",46075,52.05,-1.333333 ],
    [ u"gb",u"Banchory",5978,57.05,-2.516667 ],
    [ u"gb",u"Banff",3914,57.666667,-2.533333 ],
    [ u"gb",u"Bangor",62568,54.65,-5.7 ],
    [ u"gb",u"Bankfoot",1178,56.5,-3.5 ],
    [ u"gb",u"Barnsley",71448,53.55,-1.483333 ],
    [ u"gb",u"Barnstaple",32532,51.083333,-4.05 ],
    [ u"gb",u"Barry",51681,51.406667,-3.269444 ],
    [ u"gb",u"Basildon",101363,51.566667,.466667 ],
    [ u"gb",u"Basingstoke",96349,51.266667,-1.083333 ],
    [ u"gb",u"Bath",93238,51.379444,-2.365556 ],
    [ u"gb",u"Bathgate",15337,55.9,-3.633333 ],
    [ u"gb",u"Batley",50807,53.7,-1.616667 ],
    [ u"gb",u"Bearsden",27839,55.916667,-4.35 ],
    [ u"gb",u"Beauly",1169,57.466667,-4.466667 ],
    [ u"gb",u"Bebington",56803,53.35,-3.016667 ],
    [ u"gb",u"Bedford",86659,52.133333,-.45 ],
    [ u"gb",u"Bedworth",29981,52.466667,-1.466667 ],
    [ u"gb",u"Beith",6288,55.733333,-4.633333 ],
    [ u"gb",u"Belfast",585994,54.583333,-5.933333 ],
    [ u"gb",u"Bellshill",20201,55.816667,-4.016667 ],
    [ u"gb",u"Benfleet",48824,51.533333,.55 ],
    [ u"gb",u"Bentley",34821,53.533333,-1.15 ],
    [ u"gb",u"Beverley",31968,53.833333,-.416667 ],
    [ u"gb",u"Bexhill",40478,50.85,.483333 ],
    [ u"gb",u"Bicester",35902,51.9,-1.15 ],
    [ u"gb",u"Bideford",16624,51.016667,-4.216667 ],
    [ u"gb",u"Biggar",2120,55.616667,-3.516667 ],
    [ u"gb",u"Billericay",34467,51.616667,.416667 ],
    [ u"gb",u"Billingham",35709,54.6,-1.3 ],
    [ u"gb",u"Birkenhead",81806,53.4,-3.033333 ],
    [ u"gb",u"Birmingham",984336,52.466667,-1.916667 ],
    [ u"gb",u"Bishop Auckland",25665,54.65,-1.666667 ],
    [ u"gb",u"Bishopbriggs",22668,55.9,-4.233333 ],
    [ u"gb",u"Bishopton",5029,55.9,-4.5 ],
    [ u"gb",u"Blackburn",106154,53.75,-2.483333 ],
    [ u"gb",u"Blackburn",1136,57.2,-2.3 ],
    [ u"gb",u"Blackburn",4631,55.866667,-3.633333 ],
    [ u"gb",u"Blackford",541,56.25,-3.766667 ],
    [ u"gb",u"Blackpool",143101,53.816667,-3.05 ],
    [ u"gb",u"Blackwood",1901,55.666667,-3.916667 ],
    [ u"gb",u"Blairgowrie",8081,56.583333,-3.333333 ],
    [ u"gb",u"Blairhall",651,56.066667,-3.6 ],
    [ u"gb",u"Blantyre",16739,55.766667,-4.1 ],
    [ u"gb",u"Bletchley",50193,51.983333,-.733333 ],
    [ u"gb",u"Blyth",36356,55.120556,-1.514167 ],
    [ u"gb",u"Boat of Garten",517,57.333333,-3.733333 ],
    [ u"gb",u"Boddam",1327,57.466667,-1.783333 ],
    [ u"gb",u"Bodmin",13063,50.466389,-4.725556 ],
    [ u"gb",u"Bognor Regis",65391,50.783333,-.65 ],
    [ u"gb",u"Bolton",141331,53.583333,-2.433333 ],
    [ u"gb",u"Bonnybridge",7123,56,-3.883333 ],
    [ u"gb",u"Bootle",57791,53.466667,-3.016667 ],
    [ u"gb",u"Borehamwood",32176,51.65,-.266667 ],
    [ u"gb",u"Boston",35859,52.983333,-.016667 ],
    [ u"gb",u"Bourne",12060,52.766667,-.383333 ],
    [ u"gb",u"Bournemouth",175017,50.716667,-1.883333 ],
    [ u"gb",u"Bowmore",852,55.75,-6.283333 ],
    [ u"gb",u"Bracknell",76103,51.416667,-.75 ],
    [ u"gb",u"Braco",455,56.25,-3.883333 ],
    [ u"gb",u"Bradford",299310,53.783333,-1.75 ],
    [ u"gb",u"Brae",622,60.383333,-1.35 ],
    [ u"gb",u"Braintree",46765,51.883333,.566667 ],
    [ u"gb",u"Brechin",6977,56.733333,-2.65 ],
    [ u"gb",u"Brentwood",47606,51.616667,.316667 ],
    [ u"gb",u"Bridgend",41352,51.505833,-3.577222 ],
    [ u"gb",u"Bridge of Earn",2231,56.333333,-3.4 ],
    [ u"gb",u"Bridge of Weir",4418,55.85,-4.583333 ],
    [ u"gb",u"Bridgwater",38021,51.129722,-3.000556 ],
    [ u"gb",u"Bridlington",35057,54.095,-.208056 ],
    [ u"gb",u"Brigg",5988,53.55,-.483333 ],
    [ u"gb",u"Brighouse",32873,53.7,-1.783333 ],
    [ u"gb",u"Brighton",139001,50.833333,-.15 ],
    [ u"gb",u"Bristol",430714,51.45,-2.583333 ],
    [ u"gb",u"Broadford",522,57.233333,-5.916667 ],
    [ u"gb",u"Broadstairs",23283,51.366667,1.45 ],
    [ u"gb",u"Brodick",655,55.583333,-5.166667 ],
    [ u"gb",u"Brora",1095,58.016667,-3.866667 ],
    [ u"gb",u"Broxburn",13288,55.933333,-3.466667 ],
    [ u"gb",u"Brynmawr",14924,51.8,-3.183333 ],
    [ u"gb",u"Buchlyvie",448,56.116667,-4.3 ],
    [ u"gb",u"Buckhaven",16063,56.166667,-3.033333 ],
    [ u"gb",u"Buckie",7860,57.666667,-2.966667 ],
    [ u"gb",u"Burgess Hill",31183,50.966667,-.133333 ],
    [ u"gb",u"Burghead",1684,57.7,-3.483333 ],
    [ u"gb",u"Burnley",73480,53.8,-2.233333 ],
    [ u"gb",u"Burntwood",29766,52.683333,-1.9 ],
    [ u"gb",u"Bury",61045,53.6,-2.3 ],
    [ u"gb",u"Bury Saint Edmunds",38622,52.25,.716667 ],
    [ u"gb",u"Buxton",21300,53.25,-1.916667 ],
    [ u"gb",u"Caernarfon",9836,53.15,-4.266667 ],
    [ u"gb",u"Cairneyhill",2660,56.05,-3.533333 ],
    [ u"gb",u"Caldercruix",1980,55.883333,-3.883333 ],
    [ u"gb",u"Callander",2782,56.25,-4.233333 ],
    [ u"gb",u"Cambridge",128489,52.2,.116667 ],
    [ u"gb",u"Campbeltown",4939,55.433333,-5.633333 ],
    [ u"gb",u"Cannock",68067,52.683333,-2.016667 ],
    [ u"gb",u"Canterbury",46978,51.266667,1.083333 ],
    [ u"gb",u"Cardenden",4913,56.133333,-3.25 ],
    [ u"gb",u"Cardiff",302142,51.5,-3.2 ],
    [ u"gb",u"Cardross",1897,55.966667,-4.633333 ],
    [ u"gb",u"Carlisle",72633,54.883333,-2.933333 ],
    [ u"gb",u"Carlton",49687,52.95,-1.083333 ],
    [ u"gb",u"Carluke",13465,55.716667,-3.833333 ],
    [ u"gb",u"Carmarthen",15244,51.859167,-4.311667 ],
    [ u"gb",u"Carmunnock",1080,55.783333,-4.266667 ],
    [ u"gb",u"Carnoustie",10500,56.5,-2.716667 ],
    [ u"gb",u"Carnwath",1471,55.683333,-3.633333 ],
    [ u"gb",u"Carradale",497,55.583333,-5.483333 ],
    [ u"gb",u"Carrickfergus",33080,54.716667,-5.733333 ],
    [ u"gb",u"Carstairs",691,55.7,-3.7 ],
    [ u"gb",u"Castle Douglas",3631,54.933333,-3.95 ],
    [ u"gb",u"Castleford",37713,53.716667,-1.35 ],
    [ u"gb",u"Castletown",772,58.583333,-3.383333 ],
    [ u"gb",u"Catrine",1974,55.483333,-4.316667 ],
    [ u"gb",u"Ceres",1023,56.283333,-2.966667 ],
    [ u"gb",u"Chapelton",760,55.716667,-4.083333 ],
    [ u"gb",u"Chapeltown",22785,53.466667,-1.466667 ],
    [ u"gb",u"Chatham",75510,51.383333,.516667 ],
    [ u"gb",u"Chelmsford",102671,51.733333,.483333 ],
    [ u"gb",u"Cheltenham",103249,51.9,-2.083333 ],
    [ u"gb",u"Chesham",20649,51.7,-.6 ],
    [ u"gb",u"Cheshunt",57374,51.7,-.033333 ],
    [ u"gb",u"Chester",81313,53.2,-2.916667 ],
    [ u"gb",u"Chesterfield",70680,53.25,-1.416667 ],
    [ u"gb",u"Chester-le-Street",36917,54.85,-1.566667 ],
    [ u"gb",u"Chichester",28222,50.833333,-.783333 ],
    [ u"gb",u"Chippenham",36890,51.46,-2.124722 ],
    [ u"gb",u"Chipping Sodbury",36108,51.533333,-2.383333 ],
    [ u"gb",u"Chirnside",1176,55.8,-2.2 ],
    [ u"gb",u"Chorley",33888,53.65,-2.616667 ],
    [ u"gb",u"Christchurch",42397,50.733333,-1.766667 ],
    [ u"gb",u"Chryston",2495,55.9,-4.1 ],
    [ u"gb",u"Clackmannan",3432,56.1,-3.75 ],
    [ u"gb",u"Clacton-on-Sea",54674,51.783333,1.166667 ],
    [ u"gb",u"Cleethorpes",32017,53.55,-.033333 ],
    [ u"gb",u"Cleland",2733,55.8,-3.9 ],
    [ u"gb",u"Clevedon",22414,51.435278,-2.8525 ],
    [ u"gb",u"Clydebank",29867,55.9,-4.4 ],
    [ u"gb",u"Coalburn",1267,55.583333,-3.9 ],
    [ u"gb",u"Coalville",33288,52.716667,-1.366667 ],
    [ u"gb",u"Coatbridge",39752,55.866667,-4.033333 ],
    [ u"gb",u"Cockenzie",5962,55.95,-2.95 ],
    [ u"gb",u"Colchester",109415,51.883333,.9 ],
    [ u"gb",u"Coldingham",631,55.883333,-2.166667 ],
    [ u"gb",u"Coldstream",1823,55.65,-2.25 ],
    [ u"gb",u"Coleraine",24509,55.083333,-6.666667 ],
    [ u"gb",u"Colwyn Bay",30829,53.3,-3.75 ],
    [ u"gb",u"Comrie",2033,56.366667,-4 ],
    [ u"gb",u"Congleton",26030,53.15,-2.2 ],
    [ u"gb",u"Consett",21016,54.85,-1.833333 ],
    [ u"gb",u"Corby",50029,52.483333,-.666667 ],
    [ u"gb",u"Coupar Angus",2160,56.55,-3.266667 ],
    [ u"gb",u"Coventry",308314,52.416667,-1.55 ],
    [ u"gb",u"Cowdenbeath",11350,56.116667,-3.35 ],
    [ u"gb",u"Cowie",2506,56.066667,-3.866667 ],
    [ u"gb",u"Coylton",2607,55.433333,-4.483333 ],
    [ u"gb",u"Cramlington",29985,55.066667,-1.583333 ],
    [ u"gb",u"Crawley",107061,51.116667,-.183333 ],
    [ u"gb",u"Creetown",677,54.9,-4.383333 ],
    [ u"gb",u"Crewe",70456,53.1,-2.433333 ],
    [ u"gb",u"Crieff",6685,56.366667,-3.833333 ],
    [ u"gb",u"Crimond",758,57.6,-1.9 ],
    [ u"gb",u"Cromarty",712,57.666667,-4.033333 ],
    [ u"gb",u"Crosby",52140,53.477778,-3.033333 ],
    [ u"gb",u"Crossford",2448,56.05,-3.5 ],
    [ u"gb",u"Crossford",702,55.7,-3.866667 ],
    [ u"gb",u"Crossgates",2200,56.066667,-3.383333 ],
    [ u"gb",u"Crosshill",495,55.316667,-4.633333 ],
    [ u"gb",u"Crosshouse",2418,55.633333,-4.55 ],
    [ u"gb",u"Crowthorne",25522,51.366667,-.816667 ],
    [ u"gb",u"Croy",641,57.516667,-4.033333 ],
    [ u"gb",u"Cruden Bay",1620,57.416667,-1.833333 ],
    [ u"gb",u"Cullen",1283,57.683333,-2.816667 ],
    [ u"gb",u"Cumbernauld",49393,55.95,-3.983333 ],
    [ u"gb",u"Cuminestown",492,57.533333,-2.333333 ],
    [ u"gb",u"Cumnock",9189,55.45,-4.266667 ],
    [ u"gb",u"Cupar",8822,56.316667,-3.016667 ],
    [ u"gb",u"Cwmbran",48157,51.653056,-3.026667 ],
    [ u"gb",u"Dailly",866,55.266667,-4.716667 ],
    [ u"gb",u"Dalbeattie",4205,54.933333,-3.833333 ],
    [ u"gb",u"Dalkeith",11502,55.866667,-3.066667 ],
    [ u"gb",u"Dalry",5234,55.683333,-4.716667 ],
    [ u"gb",u"Dalrymple",1264,55.383333,-4.583333 ],
    [ u"gb",u"Darlington",87205,54.533333,-1.566667 ],
    [ u"gb",u"Dartford",56694,51.45,.216667 ],
    [ u"gb",u"Darvel",3225,55.583333,-4.283333 ],
    [ u"gb",u"Darwen",32566,53.7,-2.466667 ],
    [ u"gb",u"Dawlish",10676,50.583333,-3.466667 ],
    [ u"gb",u"Denholm",609,55.45,-2.683333 ],
    [ u"gb",u"Denton",27464,53.45,-2.116667 ],
    [ u"gb",u"Derby",235029,52.933333,-1.5 ],
    [ u"gb",u"Dewsbury",56641,53.7,-1.616667 ],
    [ u"gb",u"Dingwall",4687,57.6,-4.45 ],
    [ u"gb",u"Dirleton",496,56.033333,-2.766667 ],
    [ u"gb",u"Dollar",2845,56.15,-3.666667 ],
    [ u"gb",u"Doncaster",67671,53.533333,-1.116667 ],
    [ u"gb",u"Dorchester",16879,50.716667,-2.433333 ],
    [ u"gb",u"Dornoch",1261,57.866667,-4.033333 ],
    [ u"gb",u"Douglas",1685,55.55,-3.85 ],
    [ u"gb",u"Doune",1616,56.2,-4.083333 ],
    [ u"gb",u"Droitwich",23589,52.266667,-2.15 ],
    [ u"gb",u"Dronfield",20942,53.3,-1.466667 ],
    [ u"gb",u"Droylsden",23689,53.483333,-2.15 ],
    [ u"gb",u"Drumnadrochit",881,57.333333,-4.483333 ],
    [ u"gb",u"Drymen",623,56.066667,-4.433333 ],
    [ u"gb",u"Dudley",199060,52.5,-2.083333 ],
    [ u"gb",u"Dufftown",1384,57.433333,-3.133333 ],
    [ u"gb",u"Dumbarton",19878,55.95,-4.566667 ],
    [ u"gb",u"Dumfries",30656,55.066667,-3.55 ],
    [ u"gb",u"Dunbar",6414,56,-2.516667 ],
    [ u"gb",u"Dunblane",8056,56.2,-3.966667 ],
    [ u"gb",u"Dundee",151593,56.5,-2.966667 ],
    [ u"gb",u"Dundonald",2399,55.566667,-4.583333 ],
    [ u"gb",u"Dunfermline",38961,56.083333,-3.466667 ],
    [ u"gb",u"Dunlop",844,55.7,-4.533333 ],
    [ u"gb",u"Dunning",955,56.3,-3.583333 ],
    [ u"gb",u"Dunoon",7981,55.95,-4.95 ],
    [ u"gb",u"Duns",2630,55.766667,-2.35 ],
    [ u"gb",u"Dunstable",51974,51.883333,-.516667 ],
    [ u"gb",u"Durham",45696,54.766667,-1.566667 ],
    [ u"gb",u"Eaglesfield",601,55.05,-3.2 ],
    [ u"gb",u"Eaglesham",3077,55.733333,-4.266667 ],
    [ u"gb",u"Earlston",1728,55.633333,-2.666667 ],
    [ u"gb",u"Eastbourne",112906,50.8,.25 ],
    [ u"gb",u"East Grinstead",26523,51.116667,-.016667 ],
    [ u"gb",u"East Kilbride",74231,55.766667,-4.166667 ],
    [ u"gb",u"Eastleigh",54225,50.966667,-1.35 ],
    [ u"gb",u"East Linton",2008,55.983333,-2.65 ],
    [ u"gb",u"East Retford",21897,53.316667,-.933333 ],
    [ u"gb",u"East Wemyss",1856,56.15,-3.066667 ],
    [ u"gb",u"Eaton Socon",12712,52.216667,-.283333 ],
    [ u"gb",u"Ebbw Vale",18345,51.783333,-3.2 ],
    [ u"gb",u"Ecclefechan",705,55.05,-3.266667 ],
    [ u"gb",u"Eccles",37275,53.483333,-2.333333 ],
    [ u"gb",u"Edinburgh",435794,55.95,-3.2 ],
    [ u"gb",u"Edzell",790,56.8,-2.65 ],
    [ u"gb",u"Egham",29663,51.416667,-.566667 ],
    [ u"gb",u"Elgin",21236,57.65,-3.333333 ],
    [ u"gb",u"Elie",949,56.2,-2.816667 ],
    [ u"gb",u"Ellesmere Port",67768,53.283333,-2.9 ],
    [ u"gb",u"Ellon",8750,57.35,-2.083333 ],
    [ u"gb",u"Errol",1039,56.383333,-3.2 ],
    [ u"gb",u"Evanton",1138,57.666667,-4.333333 ],
    [ u"gb",u"Exeter",113119,50.7,-3.533333 ],
    [ u"gb",u"Exmouth",35154,50.583333,-3.4 ],
    [ u"gb",u"Eyemouth",3395,55.866667,-2.1 ],
    [ u"gb",u"Failsworth",20210,53.516667,-2.133333 ],
    [ u"gb",u"Fairlie",1568,55.75,-4.85 ],
    [ u"gb",u"Falkirk",32479,56,-3.75 ],
    [ u"gb",u"Falkland",1168,56.25,-3.2 ],
    [ u"gb",u"Falmouth",22222,50.148333,-5.076111 ],
    [ u"gb",u"Fareham",57390,50.85,-1.183333 ],
    [ u"gb",u"Farnborough",59902,51.266667,-.733333 ],
    [ u"gb",u"Farnham",36971,51.2,-.8 ],
    [ u"gb",u"Farnworth",25680,53.55,-2.4 ],
    [ u"gb",u"Fauldhouse",4610,55.816667,-3.716667 ],
    [ u"gb",u"Felling",34355,54.955,-1.56 ],
    [ u"gb",u"Fenwick",828,55.65,-4.433333 ],
    [ u"gb",u"Findhorn",1040,57.65,-3.6 ],
    [ u"gb",u"Findochty",1102,57.683333,-2.9 ],
    [ u"gb",u"Fleet",34218,51.283333,-.833333 ],
    [ u"gb",u"Fleetwood",27077,53.916667,-3 ],
    [ u"gb",u"Fochabers",1494,57.616667,-3.083333 ],
    [ u"gb",u"Folkestone",45992,51.083333,1.183333 ],
    [ u"gb",u"Forfar",13237,56.65,-2.883333 ],
    [ u"gb",u"Formby",24225,53.55,-3.05 ],
    [ u"gb",u"Forres",9134,57.6,-3.616667 ],
    [ u"gb",u"Fort Augustus",499,57.133333,-4.683333 ],
    [ u"gb",u"Forth",2087,55.75,-3.683333 ],
    [ u"gb",u"Fortrose",1206,57.583333,-4.133333 ],
    [ u"gb",u"Fort William",9652,56.816667,-5.116667 ],
    [ u"gb",u"Fraserburgh",12249,57.683333,-2.016667 ],
    [ u"gb",u"Freuchie",1120,56.233333,-3.15 ],
    [ u"gb",u"Friockheim",787,56.633333,-2.633333 ],
    [ u"gb",u"Frome",24948,51.229167,-2.318333 ],
    [ u"gb",u"Fyvie",499,57.416667,-2.383333 ],
    [ u"gb",u"Gainsborough",19871,53.383333,-.766667 ],
    [ u"gb",u"Galashiels",14351,55.6,-2.816667 ],
    [ u"gb",u"Galston",4902,55.583333,-4.383333 ],
    [ u"gb",u"Gardenstown",700,57.666667,-2.333333 ],
    [ u"gb",u"Garelochhead",1296,56.083333,-4.85 ],
    [ u"gb",u"Gargunnock",677,56.116667,-4.083333 ],
    [ u"gb",u"Gatehouse of Fleet",875,54.883333,-4.183333 ],
    [ u"gb",u"Gateshead",77649,54.945,-1.6175 ],
    [ u"gb",u"Giffnock",16038,55.8,-4.283333 ],
    [ u"gb",u"Gifford",674,55.9,-2.733333 ],
    [ u"gb",u"Gillingham",101187,51.4,.566667 ],
    [ u"gb",u"Girvan",6821,55.233333,-4.866667 ],
    [ u"gb",u"Glasgow",610271,55.833333,-4.25 ],
    [ u"gb",u"Glassford",606,55.7,-4.033333 ],
    [ u"gb",u"Glenboig",1468,55.883333,-4.033333 ],
    [ u"gb",u"Glenfarg",449,56.266667,-3.4 ],
    [ u"gb",u"Glenluce",618,54.866667,-4.833333 ],
    [ u"gb",u"Glenrothes",38734,56.2,-3.183333 ],
    [ u"gb",u"Glossop",33243,53.416667,-1.9 ],
    [ u"gb",u"Gloucester",128722,51.833333,-2.166667 ],
    [ u"gb",u"Godalming",22199,51.183333,-.6 ],
    [ u"gb",u"Golborne",24021,53.466667,-2.6 ],
    [ u"gb",u"Golspie",1381,57.966667,-3.966667 ],
    [ u"gb",u"Gorebridge",5874,55.833333,-3.05 ],
    [ u"gb",u"Gosforth",23975,55,-1.616667 ],
    [ u"gb",u"Gosport",70793,50.8,-1.133333 ],
    [ u"gb",u"Gourdon",569,56.816667,-2.283333 ],
    [ u"gb",u"Grantham",35720,52.9,-.633333 ],
    [ u"gb",u"Gravesend",54264,51.433333,.366667 ],
    [ u"gb",u"Grays",70935,51.483333,.333333 ],
    [ u"gb",u"Great Malvern",37663,52.116667,-2.316667 ],
    [ u"gb",u"Great Sankey",43793,53.383333,-2.616667 ],
    [ u"gb",u"Great Yarmouth",59601,52.633333,1.75 ],
    [ u"gb",u"Greenlaw",570,55.7,-2.466667 ],
    [ u"gb",u"Greenock",43496,55.933333,-4.75 ],
    [ u"gb",u"Gretna",2692,54.983333,-3.066667 ],
    [ u"gb",u"Grimsby",87819,53.533333,-.05 ],
    [ u"gb",u"Guildford",71873,51.216667,-.566667 ],
    [ u"gb",u"Gullane",2133,56.033333,-2.816667 ],
    [ u"gb",u"Haddington",8780,55.916667,-2.75 ],
    [ u"gb",u"Halesowen",55265,52.45,-2.05 ],
    [ u"gb",u"Halifax",82625,53.716667,-1.85 ],
    [ u"gb",u"Halkirk",897,58.5,-3.5 ],
    [ u"gb",u"Harlow",94365,51.783333,.166667 ],
    [ u"gb",u"Harpenden",28966,51.8,-.35 ],
    [ u"gb",u"Harrogate",87024,53.983333,-1.533333 ],
    [ u"gb",u"Harthill",3464,55.866667,-3.75 ],
    [ u"gb",u"Hartlepool",86713,54.686111,-1.2125 ],
    [ u"gb",u"Hastings",89100,50.85,.6 ],
    [ u"gb",u"Hatfield",14199,53.566667,-.983333 ],
    [ u"gb",u"Hatfield",33044,51.766667,-.166667 ],
    [ u"gb",u"Havant",45574,50.85,-.983333 ],
    [ u"gb",u"Haverfordwest",13469,51.801667,-4.970833 ],
    [ u"gb",u"Hawick",14053,55.433333,-2.783333 ],
    [ u"gb",u"Hawkhead",968,55.833333,-4.383333 ],
    [ u"gb",u"Haywards Heath",29660,50.983333,-.1 ],
    [ u"gb",u"Heanor",23122,53,-1.3 ],
    [ u"gb",u"Helensburgh",14108,56.016667,-4.733333 ],
    [ u"gb",u"Helmsdale",637,58.116667,-3.666667 ],
    [ u"gb",u"Hemel Hempstead",85630,51.75,-.466667 ],
    [ u"gb",u"Hereford",58281,52.05,-2.716667 ],
    [ u"gb",u"Herne Bay",36642,51.366667,1.133333 ],
    [ u"gb",u"Hertford",25848,51.8,-.066667 ],
    [ u"gb",u"Heswall",30065,53.316667,-3.1 ],
    [ u"gb",u"Heywood",28016,53.583333,-2.216667 ],
    [ u"gb",u"High Valleyfield",2837,56.05,-3.6 ],
    [ u"gb",u"High Wycombe",80357,51.633333,-.766667 ],
    [ u"gb",u"Hillside",999,56.733333,-2.483333 ],
    [ u"gb",u"Hinckley",45130,52.533333,-1.366667 ],
    [ u"gb",u"Hindley",24169,53.533333,-2.583333 ],
    [ u"gb",u"Hitchin",33830,51.95,-.266667 ],
    [ u"gb",u"Hoddesdon",35174,51.75,0 ],
    [ u"gb",u"Holbeach",7408,52.8,.016667 ],
    [ u"gb",u"Honiton",11463,50.8,-3.183333 ],
    [ u"gb",u"Hopeman",1675,57.7,-3.416667 ],
    [ u"gb",u"Horsham",50680,51.05,-.333333 ],
    [ u"gb",u"Houston",7031,55.866667,-4.55 ],
    [ u"gb",u"Hove",75174,50.833333,-.183333 ],
    [ u"gb",u"Huddersfield",149018,53.65,-1.783333 ],
    [ u"gb",u"Huntingdon",21059,52.333333,-.183333 ],
    [ u"gb",u"Huntly",4390,57.45,-2.783333 ],
    [ u"gb",u"Hyde",31926,53.45,-2.083333 ],
    [ u"gb",u"Ilfracombe",10486,51.216667,-4.116667 ],
    [ u"gb",u"Ilkeston",38587,52.966667,-1.3 ],
    [ u"gb",u"Inchture",715,56.433333,-3.166667 ],
    [ u"gb",u"Innellan",1132,55.883333,-4.966667 ],
    [ u"gb",u"Innerleithen",2591,55.616667,-3.066667 ],
    [ u"gb",u"Insch",1504,57.333333,-2.616667 ],
    [ u"gb",u"Inveraray",568,56.233333,-5.066667 ],
    [ u"gb",u"Inverbervie",2162,56.85,-2.266667 ],
    [ u"gb",u"Invergordon",3949,57.683333,-4.183333 ],
    [ u"gb",u"Inverkeithing",5163,56.033333,-3.383333 ],
    [ u"gb",u"Inverkip",1733,55.9,-4.866667 ],
    [ u"gb",u"Inverness",40755,57.466667,-4.233333 ],
    [ u"gb",u"Inverurie",11324,57.266667,-2.366667 ],
    [ u"gb",u"Ipswich",143768,52.083333,1.166667 ],
    [ u"gb",u"Irvine",32749,55.6,-4.666667 ],
    [ u"gb",u"Ivybridge",13277,50.383333,-3.916667 ],
    [ u"gb",u"Jarrow",27264,54.980556,-1.450833 ],
    [ u"gb",u"Jedburgh",4045,55.466667,-2.566667 ],
    [ u"gb",u"Johnshaven",641,56.783333,-2.333333 ],
    [ u"gb",u"Keighley",50171,53.883333,-1.916667 ],
    [ u"gb",u"Keith",4396,57.533333,-2.933333 ],
    [ u"gb",u"Kelso",5154,55.583333,-2.433333 ],
    [ u"gb",u"Kelty",5644,56.133333,-3.383333 ],
    [ u"gb",u"Kemnay",3889,57.233333,-2.45 ],
    [ u"gb",u"Kendal",29468,54.316667,-2.75 ],
    [ u"gb",u"Kenilworth",22799,52.35,-1.583333 ],
    [ u"gb",u"Kennoway",4596,56.2,-3.05 ],
    [ u"gb",u"Kettering",53329,52.4,-.716667 ],
    [ u"gb",u"Kidderminster",56657,52.383333,-2.25 ],
    [ u"gb",u"Kidsgrove",29480,53.083333,-2.233333 ],
    [ u"gb",u"Kilbirnie",6972,55.75,-4.7 ],
    [ u"gb",u"Kilcreggan",1343,55.983333,-4.833333 ],
    [ u"gb",u"Killin",666,56.466667,-4.316667 ],
    [ u"gb",u"Kilmacolm",3887,55.883333,-4.616667 ],
    [ u"gb",u"Kilmarnock",42905,55.633333,-4.533333 ],
    [ u"gb",u"Kilmaurs",2528,55.633333,-4.533333 ],
    [ u"gb",u"Kilsyth",9662,55.966667,-4.05 ],
    [ u"gb",u"Kilwinning",16000,55.65,-4.716667 ],
    [ u"gb",u"Kincardine",3014,56.066667,-3.716667 ],
    [ u"gb",u"Kinghorn",2776,56.066667,-3.166667 ],
    [ u"gb",u"Kinglassie",1274,56.166667,-3.233333 ],
    [ u"gb",u"Kingseat",500,56.683333,-3.4 ],
    [ u"gb",u"Kingskettle",993,56.25,-3.116667 ],
    [ u"gb",u"Kingsteignton",11360,50.55,-3.583333 ],
    [ u"gb",u"Kingston upon Hull",302297,53.716667,-.333333 ],
    [ u"gb",u"Kingswood",64793,51.452778,-2.508333 ],
    [ u"gb",u"Kingussie",1442,57.083333,-4.05 ],
    [ u"gb",u"Kinlochleven",831,56.7,-4.966667 ],
    [ u"gb",u"Kinloss",2011,57.616667,-3.566667 ],
    [ u"gb",u"Kinross",4691,56.2,-3.416667 ],
    [ u"gb",u"Kintore",1688,57.216667,-2.35 ],
    [ u"gb",u"Kippen",990,56.116667,-4.166667 ],
    [ u"gb",u"Kirkby in Ashfield",27539,53.083333,-1.266667 ],
    [ u"gb",u"Kirkby",39208,53.483333,-2.9 ],
    [ u"gb",u"Kirkconnel",1993,55.383333,-4 ],
    [ u"gb",u"Kirkcudbright",3367,54.833333,-4.033333 ],
    [ u"gb",u"Kirkintilloch",19489,55.916667,-4.166667 ],
    [ u"gb",u"Kirkliston",3139,55.95,-3.4 ],
    [ u"gb",u"Kirknewton",1755,55.883333,-3.416667 ],
    [ u"gb",u"Kirkton of Largo",496,56.216667,-2.916667 ],
    [ u"gb",u"Kirkwall",6196,58.966667,-2.95 ],
    [ u"gb",u"Kirriemuir",6108,56.666667,-3 ],
    [ u"gb",u"Kyle of Lochalsh",734,57.266667,-5.716667 ],
    [ u"gb",u"Ladybank",1519,56.266667,-3.133333 ],
    [ u"gb",u"Lamlash",1046,55.533333,-5.15 ],
    [ u"gb",u"Lanark",8152,55.65,-3.783333 ],
    [ u"gb",u"Lancaster",47162,54.066667,-2.833333 ],
    [ u"gb",u"Langbank",884,55.916667,-4.583333 ],
    [ u"gb",u"Langholm",2213,55.15,-3 ],
    [ u"gb",u"Largs",11126,55.783333,-4.85 ],
    [ u"gb",u"Larkhall",15410,55.733333,-3.966667 ],
    [ u"gb",u"Lauder",1078,55.7,-2.75 ],
    [ u"gb",u"Laurencekirk",1916,56.816667,-2.45 ],
    [ u"gb",u"Law",2994,55.75,-3.883333 ],
    [ u"gb",u"Leatherhead",43544,51.283333,-.316667 ],
    [ u"gb",u"Leeds",455124,53.8,-1.583333 ],
    [ u"gb",u"Leicester",339240,52.633333,-1.133333 ],
    [ u"gb",u"Leicester",339240,52.664913,-1.034894 ],
    [ u"gb",u"Leigh",43627,53.483333,-2.516667 ],
    [ u"gb",u"Leighton Buzzard",33467,51.916667,-.65 ],
    [ u"gb",u"Lennoxtown",3795,55.966667,-4.2 ],
    [ u"gb",u"Lerwick",6594,60.15,-1.15 ],
    [ u"gb",u"Lesmahagow",3823,55.616667,-3.9 ],
    [ u"gb",u"Letchworth",33955,51.966667,-.216667 ],
    [ u"gb",u"Letham",1591,56.616667,-2.766667 ],
    [ u"gb",u"Leuchars",2341,56.383333,-2.883333 ],
    [ u"gb",u"Lewes",16479,50.866667,-.016667 ],
    [ u"gb",u"Leyland",37615,53.683333,-2.7 ],
    [ u"gb",u"Lhanbryde",1845,57.616667,-3.216667 ],
    [ u"gb",u"Lichfield",28973,52.683333,-1.816667 ],
    [ u"gb",u"Limekilns",1329,56.033333,-3.466667 ],
    [ u"gb",u"Lincoln",89228,53.233333,-.533333 ],
    [ u"gb",u"Linlithgow",13863,55.889082,-3.569419 ],
    [ u"gb",u"Lisburn",45314,54.516667,-6.066667 ],
    [ u"gb",u"Litherland",22971,53.466667,-3 ],
    [ u"gb",u"Littlehampton",58714,50.8,-.533333 ],
    [ u"gb",u"Liverpool",468946,53.416667,-3 ],
    [ u"gb",u"Livingston",53798,55.883333,-3.533333 ],
    [ u"gb",u"Llandrindod Wells",5350,52.233333,-3.383333 ],
    [ u"gb",u"Llanelli",47206,51.676111,-4.156667 ],
    [ u"gb",u"Llangefni",4361,53.266667,-4.333333 ],
    [ u"gb",u"Loanhead",6358,55.866667,-3.15 ],
    [ u"gb",u"Loans",825,55.55,-4.633333 ],
    [ u"gb",u"Locharbriggs",6333,55.1,-3.583333 ],
    [ u"gb",u"Lochgilphead",2272,56.033333,-5.416667 ],
    [ u"gb",u"Lochmaben",1910,55.116667,-3.45 ],
    [ u"gb",u"Lochwinnoch",2684,55.783333,-4.633333 ],
    [ u"gb",u"Lockerbie",3986,55.116667,-3.35 ],
    [ u"gb",u"Londonderry",86312,55,-7.25 ],
    [ u"gb",u"London",7421228,51.514125,-.093689 ],
    [ u"gb",u"Long Eaton",47898,52.9,-1.266667 ],
    [ u"gb",u"Longforgan",678,56.45,-3.116667 ],
    [ u"gb",u"Longniddry",2482,55.966667,-2.883333 ],
    [ u"gb",u"Longside",722,57.516667,-1.933333 ],
    [ u"gb",u"Lossiemouth",6841,57.7,-3.283333 ],
    [ u"gb",u"Loughborough",59317,52.766667,-1.2 ],
    [ u"gb",u"Loughton",42229,51.633333,.066667 ],
    [ u"gb",u"Louth",16635,53.366667,-.016667 ],
    [ u"gb",u"Lowestoft",71479,52.483333,1.75 ],
    [ u"gb",u"Luncarty",1236,56.45,-3.466667 ],
    [ u"gb",u"Lundin Links",2124,56.2,-2.95 ],
    [ u"gb",u"Lurgan",23602,54.466667,-6.333333 ],
    [ u"gb",u"Luton",193670,51.883333,-.416667 ],
    [ u"gb",u"Macclesfield",51739,53.25,-2.116667 ],
    [ u"gb",u"Macduff",3747,57.666667,-2.483333 ],
    [ u"gb",u"Macmerry",1082,55.933333,-2.9 ],
    [ u"gb",u"Maesteg",17830,51.605,-3.650833 ],
    [ u"gb",u"Maidenhead",59463,51.516667,-.7 ],
    [ u"gb",u"Maidens",530,55.333333,-4.816667 ],
    [ u"gb",u"Maidstone",90894,51.266667,.516667 ],
    [ u"gb",u"Mallaig",742,57,-5.833333 ],
    [ u"gb",u"Manchester",395516,53.5,-2.216667 ],
    [ u"gb",u"Mangotsfield",36427,51.493056,-2.508611 ],
    [ u"gb",u"Mansfield",70447,53.133333,-1.2 ],
    [ u"gb",u"Margate",60134,51.383333,1.416667 ],
    [ u"gb",u"Matlock",11516,53.133333,-1.533333 ],
    [ u"gb",u"Mauchline",4137,55.516667,-4.366667 ],
    [ u"gb",u"Maud",673,57.516667,-2.1 ],
    [ u"gb",u"Maybole",4447,55.333333,-4.7 ],
    [ u"gb",u"Melrose",1640,55.583333,-2.716667 ],
    [ u"gb",u"Melton Mowbray",26405,52.766667,-.883333 ],
    [ u"gb",u"Merthyr Tydfil",30821,51.75,-3.383333 ],
    [ u"gb",u"Methven",1161,56.416667,-3.566667 ],
    [ u"gb",u"Middlesbrough",142708,54.572778,-1.162778 ],
    [ u"gb",u"Middleton",45589,53.55,-2.2 ],
    [ u"gb",u"Millport",1260,55.75,-4.95 ],
    [ u"gb",u"Milnathort",1885,56.216667,-3.416667 ],
    [ u"gb",u"Milton Keynes",31967,52.033333,-.7 ],
    [ u"gb",u"Mintlaw",2673,57.516667,-2 ],
    [ u"gb",u"Moffat",2077,55.316667,-3.45 ],
    [ u"gb",u"Mold",9995,53.166667,-3.133333 ],
    [ u"gb",u"Monkton",668,55.5,-4.6 ],
    [ u"gb",u"Montrose",10620,56.7,-2.45 ],
    [ u"gb",u"Morecambe",51645,54.066667,-2.85 ],
    [ u"gb",u"Morley",57386,53.733333,-1.583333 ],
    [ u"gb",u"Motherwell",29908,55.783333,-4 ],
    [ u"gb",u"Muirkirk",1539,55.516667,-4.05 ],
    [ u"gb",u"Muir of Ord",1807,57.516667,-4.45 ],
    [ u"gb",u"Musselburgh",22656,55.933333,-3.05 ],
    [ u"gb",u"Muthill",668,56.316667,-3.833333 ],
    [ u"gb",u"Nailsea",16537,51.430278,-2.7625 ],
    [ u"gb",u"Nairn",8551,57.5,-3.833333 ],
    [ u"gb",u"Neath",46126,51.656111,-3.802222 ],
    [ u"gb",u"Neilston",5091,55.783333,-4.416667 ],
    [ u"gb",u"Nelson",29317,53.833333,-2.2 ],
    [ u"gb",u"Netherburn",710,55.7,-3.916667 ],
    [ u"gb",u"Newburgh",1377,57.3,-2 ],
    [ u"gb",u"Newburgh",1909,56.333333,-3.25 ],
    [ u"gb",u"Newburn",41347,54.966667,-1.733333 ],
    [ u"gb",u"Newbury",33065,51.4,-1.316667 ],
    [ u"gb",u"Newcastleton",751,55.166667,-2.816667 ],
    [ u"gb",u"Newcastle upon Tyne",192382,54.988056,-1.619444 ],
    [ u"gb",u"New Cumnock",2884,55.4,-4.183333 ],
    [ u"gb",u"New Deer",559,57.5,-2.2 ],
    [ u"gb",u"New Pitsligo",907,57.583333,-2.183333 ],
    [ u"gb",u"Newport",24200,50.7,-1.3 ],
    [ u"gb",u"Newport",117327,51.583333,-2.983333 ],
    [ u"gb",u"Newry",26271,54.183333,-6.333333 ],
    [ u"gb",u"New Scone",4355,56.416667,-3.4 ],
    [ u"gb",u"Newton Abbot",25789,50.533333,-3.6 ],
    [ u"gb",u"Newton Aycliffe",26269,54.616667,-1.566667 ],
    [ u"gb",u"Newtonhill",3284,57.033333,-2.15 ],
    [ u"gb",u"Newtonmore",988,57.066667,-4.133333 ],
    [ u"gb",u"Newton Stewart",3548,54.966667,-4.483333 ],
    [ u"gb",u"Newtownards",28878,54.583333,-5.666667 ],
    [ u"gb",u"Newtown Saint Boswells",1225,55.583333,-2.683333 ],
    [ u"gb",u"Newtyle",731,56.55,-3.133333 ],
    [ u"gb",u"Northallerton",16480,54.333333,-1.433333 ],
    [ u"gb",u"Northam",7668,51.033333,-4.216667 ],
    [ u"gb",u"Northampton",197323,52.25,-.883333 ],
    [ u"gb",u"North Berwick",6439,56.066667,-2.716667 ],
    [ u"gb",u"North Kessock",881,57.5,-4.25 ],
    [ u"gb",u"North Shields",39747,55.004722,-1.472778 ],
    [ u"gb",u"Northwich",42113,53.266667,-2.5 ],
    [ u"gb",u"Norwich",177636,52.633333,1.3 ],
    [ u"gb",u"Nottingham",246655,52.966667,-1.166667 ],
    [ u"gb",u"Nuneaton",73555,52.516667,-1.466667 ],
    [ u"gb",u"Oakham",10150,52.666667,-.733333 ],
    [ u"gb",u"Oakley",4067,56.066667,-3.55 ],
    [ u"gb",u"Oban",8082,56.416667,-5.466667 ],
    [ u"gb",u"Ochiltree",665,55.45,-4.366667 ],
    [ u"gb",u"Oldham",104783,53.55,-2.116667 ],
    [ u"gb",u"Oldmeldrum",2023,57.316667,-2.316667 ],
    [ u"gb",u"Omagh",18463,54.583333,-7.25 ],
    [ u"gb",u"Ormiston",2062,55.9,-2.933333 ],
    [ u"gb",u"Ormskirk",23792,53.566667,-2.9 ],
    [ u"gb",u"Ossett",21616,53.666667,-1.566667 ],
    [ u"gb",u"Overtown",2519,55.75,-3.916667 ],
    [ u"gb",u"Oxford",154567,51.75,-1.25 ],
    [ u"gb",u"Paignton",49886,50.433333,-3.566667 ],
    [ u"gb",u"Paisley",73074,55.833333,-4.433333 ],
    [ u"gb",u"Patna",2088,55.35,-4.5 ],
    [ u"gb",u"Peebles",8404,55.633333,-3.183333 ],
    [ u"gb",u"Penarth",23438,51.434722,-3.18 ],
    [ u"gb",u"Pencaitland",1671,55.9,-2.883333 ],
    [ u"gb",u"Penicuik",14314,55.816667,-3.233333 ],
    [ u"gb",u"Penzance",20812,50.113611,-5.547778 ],
    [ u"gb",u"Perth",43634,56.4,-3.433333 ],
    [ u"gb",u"Peterborough",140142,52.583333,-.25 ],
    [ u"gb",u"Peterhead",17627,57.5,-1.783333 ],
    [ u"gb",u"Peterlee",29979,54.762222,-1.3475 ],
    [ u"gb",u"Pitlochry",2551,56.7,-3.716667 ],
    [ u"gb",u"Pitmedden",1246,57.333333,-2.183333 ],
    [ u"gb",u"Pittenweem",1807,56.2,-2.733333 ],
    [ u"gb",u"Plean",1752,56.05,-3.866667 ],
    [ u"gb",u"Plymouth",247298,50.396389,-4.138611 ],
    [ u"gb",u"Pontefract",28620,53.683333,-1.3 ],
    [ u"gb",u"Pontypool",35687,51.701111,-3.044444 ],
    [ u"gb",u"Pontypridd",30420,51.601389,-3.344722 ],
    [ u"gb",u"Poole",150092,50.716667,-2 ],
    [ u"gb",u"Portadown",21617,54.433333,-6.45 ],
    [ u"gb",u"Port Bannatyne",1331,55.85,-5.066667 ],
    [ u"gb",u"Port Ellen",779,55.633333,-6.183333 ],
    [ u"gb",u"Portgordon",763,57.65,-3.016667 ],
    [ u"gb",u"Portknockie",1179,57.683333,-2.85 ],
    [ u"gb",u"Portlethen",6841,57.05,-2.1 ],
    [ u"gb",u"Portpatrick",599,54.85,-5.116667 ],
    [ u"gb",u"Portree",1886,57.4,-6.2 ],
    [ u"gb",u"Portsmouth",194151,50.7967,-1.083333 ],
    [ u"gb",u"Portsoy",1688,57.683333,-2.683333 ],
    [ u"gb",u"Port Talbot",35180,51.6,-3.783333 ],
    [ u"gb",u"Port William",466,54.75,-4.6 ],
    [ u"gb",u"Potters Bar",22192,51.683333,-.166667 ],
    [ u"gb",u"Prescot",40889,53.416667,-2.8 ],
    [ u"gb",u"Prestonpans",7145,55.933333,-2.966667 ],
    [ u"gb",u"Preston",190688,53.766667,-2.716667 ],
    [ u"gb",u"Prestwich",32125,53.533333,-2.283333 ],
    [ u"gb",u"Pudsey",33109,53.783333,-1.666667 ],
    [ u"gb",u"Quarter",959,55.733333,-4.033333 ],
    [ u"gb",u"Queensferry",9477,55.983333,-3.4 ],
    [ u"gb",u"Radcliffe",35638,53.55,-2.333333 ],
    [ u"gb",u"Ramsgate",38624,51.333333,1.433333 ],
    [ u"gb",u"Ratho",1515,55.916667,-3.366667 ],
    [ u"gb",u"Rawtenstall",22115,53.7,-2.283333 ],
    [ u"gb",u"Reading",244071,51.433333,-1 ],
    [ u"gb",u"Redcar",37203,54.6075,-1.059444 ],
    [ u"gb",u"Redditch",77129,52.3,-1.933333 ],
    [ u"gb",u"Reigate",52123,51.233333,-.216667 ],
    [ u"gb",u"Rhondda",59450,51.65,-3.483333 ],
    [ u"gb",u"Rhyl",25874,53.316667,-3.5 ],
    [ u"gb",u"Rhymney",7089,51.766667,-3.283333 ],
    [ u"gb",u"Rochdale",97550,53.616667,-2.15 ],
    [ u"gb",u"Rochester",28671,51.383333,.516667 ],
    [ u"gb",u"Rosehearty",1320,57.683333,-2.116667 ],
    [ u"gb",u"Rosneath",901,56.016667,-4.816667 ],
    [ u"gb",u"Rotherham",117619,53.433333,-1.35 ],
    [ u"gb",u"Rothesay",4912,55.833333,-5.066667 ],
    [ u"gb",u"Rothes",1132,57.516667,-3.216667 ],
    [ u"gb",u"Rottingdean",21756,50.8,-.05 ],
    [ u"gb",u"Royal Leamington Spa",64641,52.3,-1.533333 ],
    [ u"gb",u"Royal Tunbridge Wells",61075,51.133333,.283333 ],
    [ u"gb",u"Royton",22848,53.566667,-2.116667 ],
    [ u"gb",u"Rugby",63323,52.366667,-1.25 ],
    [ u"gb",u"Rugeley",22937,52.766667,-1.933333 ],
    [ u"gb",u"Runcorn",59679,53.333333,-2.75 ],
    [ u"gb",u"Rushden",26307,52.283333,-.583333 ],
    [ u"gb",u"Ruthin",5344,53.116667,-3.3 ],
    [ u"gb",u"Ryde",24107,50.716667,-1.166667 ],
    [ u"gb",u"Saint Albans",84561,51.75,-.333333 ],
    [ u"gb",u"Saint Andrews",15435,56.333333,-2.783333 ],
    [ u"gb",u"Saint Austell",23432,50.338333,-4.765833 ],
    [ u"gb",u"Saint Boswells",1062,55.566667,-2.65 ],
    [ u"gb",u"Saint Combs",719,57.65,-1.9 ],
    [ u"gb",u"Saint Cyrus",914,56.766667,-2.4 ],
    [ u"gb",u"Saint Helens",102555,53.45,-2.733333 ],
    [ u"gb",u"Saint Monans",1447,56.2,-2.766667 ],
    [ u"gb",u"Sale",55689,53.416667,-2.3 ],
    [ u"gb",u"Salford",70905,53.483333,-2.266667 ],
    [ u"gb",u"Saline",1161,56.1,-3.566667 ],
    [ u"gb",u"Salisbury",45600,51.066667,-1.783333 ],
    [ u"gb",u"Sandhaven",690,57.683333,-2.066667 ],
    [ u"gb",u"Sandwick",1217,60,-1.25 ],
    [ u"gb",u"Sanquhar",1987,55.35,-3.916667 ],
    [ u"gb",u"Scalloway",809,60.133333,-1.3 ],
    [ u"gb",u"Scarborough",38909,54.287222,-.414167 ],
    [ u"gb",u"Scunthorpe",72515,53.583333,-.65 ],
    [ u"gb",u"Seafield",1386,55.966667,-3.15 ],
    [ u"gb",u"Seaham",21170,54.836667,-1.338056 ],
    [ u"gb",u"Selkirk",5629,55.533333,-2.85 ],
    [ u"gb",u"Sevenoaks",27871,51.266667,.2 ],
    [ u"gb",u"Sheffield",447048,53.366667,-1.5 ],
    [ u"gb",u"Shipley",28544,53.833333,-1.766667 ],
    [ u"gb",u"Shotts",7981,55.833333,-3.85 ],
    [ u"gb",u"Shrewsbury",69520,52.716667,-2.733333 ],
    [ u"gb",u"Sidmouth",11853,50.683333,-3.25 ],
    [ u"gb",u"Sittingbourne",41148,51.333333,.75 ],
    [ u"gb",u"Skegness",17072,53.133333,.35 ],
    [ u"gb",u"Skelmersdale",38944,53.533333,-2.8 ],
    [ u"gb",u"Skelmorlie",1859,55.866667,-4.9 ],
    [ u"gb",u"Slamannan",1195,55.933333,-3.833333 ],
    [ u"gb",u"Sleaford",15558,52.983333,-.4 ],
    [ u"gb",u"Slough",134072,51.5,-.583333 ],
    [ u"gb",u"Solihull",96268,52.416667,-1.783333 ],
    [ u"gb",u"Southampton",246201,50.9,-1.4 ],
    [ u"gb",u"Southend-on-Sea",163378,51.533333,.7 ],
    [ u"gb",u"Southport",93044,53.666667,-3 ],
    [ u"gb",u"South Shields",83656,54.987778,-1.421389 ],
    [ u"gb",u"Spalding",22357,52.783333,-.166667 ],
    [ u"gb",u"Springside",1114,55.616667,-4.6 ],
    [ u"gb",u"Stafford",65290,52.8,-2.1 ],
    [ u"gb",u"Stafford",65290,52.833333,-2 ],
    [ u"gb",u"Staines",51040,51.433333,-.516667 ],
    [ u"gb",u"Stalybridge",22748,53.483333,-2.066667 ],
    [ u"gb",u"Stamford",20526,52.65,-.483333 ],
    [ u"gb",u"Stanley",1491,56.466667,-3.45 ],
    [ u"gb",u"Staveley",25719,53.266667,-1.35 ],
    [ u"gb",u"Stevenage",84652,51.916667,-.216667 ],
    [ u"gb",u"Stewarton",6615,55.666667,-4.5 ],
    [ u"gb",u"Stirling",33013,56.116667,-3.95 ],
    [ u"gb",u"Stockport",139053,53.4,-2.15 ],
    [ u"gb",u"Stockton-on-Tees",79957,54.583333,-1.416667 ],
    [ u"gb",u"Stoke-on-Trent",260420,53,-2.183333 ],
    [ u"gb",u"Stonehaven",9592,56.95,-2.2 ],
    [ u"gb",u"Stonehouse",4950,55.666667,-3.983333 ],
    [ u"gb",u"Stornoway",5423,58.216667,-6.366667 ],
    [ u"gb",u"Stourbridge",56284,52.466667,-2.133333 ],
    [ u"gb",u"Stow",551,55.7,-2.85 ],
    [ u"gb",u"Stranraer",10582,54.9,-5.033333 ],
    [ u"gb",u"Stratford-upon-Avon",22576,52.183333,-1.7 ],
    [ u"gb",u"Strathaven",8190,55.666667,-4.066667 ],
    [ u"gb",u"Strathblane",1803,55.966667,-4.3 ],
    [ u"gb",u"Strathmiglo",926,56.266667,-3.266667 ],
    [ u"gb",u"Strathpeffer",893,57.583333,-4.55 ],
    [ u"gb",u"Stretford",41954,53.45,-2.316667 ],
    [ u"gb",u"Strichen",857,57.566667,-2.083333 ],
    [ u"gb",u"Stromness",1564,58.95,-3.3 ],
    [ u"gb",u"Strone",502,55.983333,-4.9 ],
    [ u"gb",u"Strood",33381,51.383333,.5 ],
    [ u"gb",u"Stroud",30600,51.75,-2.2 ],
    [ u"gb",u"Stuartfield",649,57.5,-2.05 ],
    [ u"gb",u"Sunbury",27784,51.4,-.4 ],
    [ u"gb",u"Sunderland",177965,54.911944,-1.383333 ],
    [ u"gb",u"Sutton Coldfield",107030,52.566667,-1.816667 ],
    [ u"gb",u"Sutton in Ashfield",43912,53.116667,-1.266667 ],
    [ u"gb",u"Swadlincote",40961,52.766667,-1.55 ],
    [ u"gb",u"Swansea",170885,51.633333,-3.966667 ],
    [ u"gb",u"Swindon",162439,51.516667,-1.783333 ],
    [ u"gb",u"Symington",997,55.533333,-4.566667 ],
    [ u"gb",u"Tain",3409,57.8,-4.066667 ],
    [ u"gb",u"Tamworth",74130,52.616667,-1.683333 ],
    [ u"gb",u"Tarbert",1364,55.866667,-5.433333 ],
    [ u"gb",u"Tarbolton",1649,55.5,-4.483333 ],
    [ u"gb",u"Tarland",550,57.133333,-2.866667 ],
    [ u"gb",u"Tarves",978,57.366667,-2.216667 ],
    [ u"gb",u"Taunton",60433,51.021111,-3.104722 ],
    [ u"gb",u"Tayport",4093,56.45,-2.883333 ],
    [ u"gb",u"Teignmouth",15498,50.55,-3.466667 ],
    [ u"gb",u"Telford",43244,52.633333,-2.5 ],
    [ u"gb",u"Thatcham",24275,51.4,-1.266667 ],
    [ u"gb",u"Thornaby",22356,54.533333,-1.3 ],
    [ u"gb",u"Thornhill",1504,55.233333,-3.766667 ],
    [ u"gb",u"Thornton",1743,56.166667,-3.15 ],
    [ u"gb",u"Thurso",7492,58.6,-3.5 ],
    [ u"gb",u"Tighnabruaich",603,55.9,-5.216667 ],
    [ u"gb",u"Tillicoultry",5404,56.15,-3.75 ],
    [ u"gb",u"Tiverton",16799,50.9,-3.483333 ],
    [ u"gb",u"Tobermory",993,56.633333,-6.083333 ],
    [ u"gb",u"Tonbridge",36894,51.183333,.283333 ],
    [ u"gb",u"Torphichen",605,55.933333,-3.65 ],
    [ u"gb",u"Torphins",1245,57.1,-2.616667 ],
    [ u"gb",u"Torquay",65389,50.45,-3.5 ],
    [ u"gb",u"Totton",29261,50.916667,-1.483333 ],
    [ u"gb",u"Townhill",1190,56.083333,-3.433333 ],
    [ u"gb",u"Tranent",9042,55.933333,-2.95 ],
    [ u"gb",u"Troon",14900,55.533333,-4.666667 ],
    [ u"gb",u"Trowbridge",36922,51.318889,-2.208611 ],
    [ u"gb",u"Truro",22044,50.261667,-5.043333 ],
    [ u"gb",u"Turriff",4711,57.533333,-2.45 ],
    [ u"gb",u"Tyldesley",35932,53.516667,-2.466667 ],
    [ u"gb",u"Ullapool",1327,57.9,-5.166667 ],
    [ u"gb",u"Uplawmoor",581,55.75,-4.483333 ],
    [ u"gb",u"Urmston",41198,53.45,-2.35 ],
    [ u"gb",u"Wakefield",78978,53.7,-1.483333 ],
    [ u"gb",u"Walkden",35938,53.516667,-2.4 ],
    [ u"gb",u"Walkerburn",638,55.633333,-3.016667 ],
    [ u"gb",u"Wallasey",58794,53.433333,-3.066667 ],
    [ u"gb",u"Wallsend",42739,54.991389,-1.559722 ],
    [ u"gb",u"Walsall",172142,52.6,-2 ],
    [ u"gb",u"Warrington",81238,53.383333,-2.6 ],
    [ u"gb",u"Warwick",24040,52.283333,-1.583333 ],
    [ u"gb",u"Washington",53527,54.9,-1.516667 ],
    [ u"gb",u"Waterfoot",1286,55.05,-6.066667 ],
    [ u"gb",u"Waterlooville",64350,50.866667,-1.016667 ],
    [ u"gb",u"Watford",125708,51.666667,-.4 ],
    [ u"gb",u"Wellingborough",49783,52.3,-.7 ],
    [ u"gb",u"Welwyn Garden City",44725,51.8,-.2 ],
    [ u"gb",u"West Bridgeford",48314,52.916667,-1.116667 ],
    [ u"gb",u"West Bromwich",135618,52.516667,-2 ],
    [ u"gb",u"West Calder",2769,55.833333,-3.566667 ],
    [ u"gb",u"Westhoughton",22994,53.55,-2.516667 ],
    [ u"gb",u"West Kilbride",4322,55.683333,-4.85 ],
    [ u"gb",u"West Linton",1578,55.75,-3.35 ],
    [ u"gb",u"Weston-super-Mare",82903,51.345833,-2.967778 ],
    [ u"gb",u"Weymouth",50253,50.6,-2.45 ],
    [ u"gb",u"Whitburn",10137,55.866667,-3.683333 ],
    [ u"gb",u"Whitefield",23546,53.55,-2.3 ],
    [ u"gb",u"Whitehaven",24803,54.55,-3.6 ],
    [ u"gb",u"Whitehills",1019,57.666667,-2.583333 ],
    [ u"gb",u"Whithorn",830,54.733333,-4.416667 ],
    [ u"gb",u"Whitley Bay",38055,55.050833,-1.453889 ],
    [ u"gb",u"Whitstable",31166,51.35,1.1 ],
    [ u"gb",u"Wickford",32975,51.6,.516667 ],
    [ u"gb",u"Wick",7147,58.433333,-3.083333 ],
    [ u"gb",u"Widnes",56098,53.35,-2.733333 ],
    [ u"gb",u"Wigan",80789,53.533333,-2.616667 ],
    [ u"gb",u"Wigston",33720,52.583333,-1.1 ],
    [ u"gb",u"Wigtown",934,54.866667,-4.45 ],
    [ u"gb",u"Wilmslow",36618,53.333333,-2.233333 ],
    [ u"gb",u"Winchester",44094,51.016667,-1.316667 ],
    [ u"gb",u"Winsford",30812,53.183333,-2.516667 ],
    [ u"gb",u"Wishaw",27627,55.766667,-3.916667 ],
    [ u"gb",u"Witham",22995,51.783333,.633333 ],
    [ u"gb",u"Witney",24103,51.783333,-1.483333 ],
    [ u"gb",u"Wokingham",41144,51.416667,-.833333 ],
    [ u"gb",u"Wolverhampton",252792,52.583333,-2.133333 ],
    [ u"gb",u"Worcester",100023,52.166667,-2.166667 ],
    [ u"gb",u"Workington",20618,54.65,-3.566667 ],
    [ u"gb",u"Worksop",40443,53.3,-1.133333 ],
    [ u"gb",u"Worthing",99110,50.8,-.366667 ],
    [ u"gb",u"Wrexham",43650,53.05,-3 ],
    [ u"gb",u"Yeovil",43733,50.95,-2.633333 ],
    [ u"gb",u"Yetholm",584,55.55,-2.266667 ],
    [ u"gb",u"York",144202,53.954115,-1.064262 ],
    [ u"gd",u"Gouyave",3378,12.1666667,-61.7333333 ],
    [ u"gd",u"Grenville",2476,12.1166667,-61.6166667 ],
    [ u"gd",u"Hillsborough",770,12.4833333,-61.4666667 ],
    [ u"gd",u"Sauteurs",1320,12.2166667,-61.6333333 ],
    [ u"gd",u"Victoria",2256,12.1833333,-61.7 ],
    [ u"ge",u"Abasha",6222,42.1941667,42.2241667 ],
    [ u"ge",u"Abastumani",1285,41.7,42.85 ],
    [ u"ge",u"Adigeni",1313,41.6858333,42.7102778 ],
    [ u"ge",u"Agara",5811,42.035,43.8352778 ],
    [ u"ge",u"Akhaldaba",3640,41.6530556,42.1580556 ],
    [ u"ge",u"Akhalgori",1420,42.1241667,44.4858333 ],
    [ u"ge",u"Akhmeta",8569,42.0311111,45.2075 ],
    [ u"ge",u"Ambrolauri",2408,42.5211111,43.1622222 ],
    [ u"ge",u"Aspindza",3940,41.5738889,43.2561111 ],
    [ u"ge",u"Bakuriani",2392,41.7497222,43.5325 ],
    [ u"ge",u"Bakurianis Andeziti",1085,41.7338889,43.4702778 ],
    [ u"ge",u"Bediani",227,41.5441667,44.2444444 ],
    [ u"ge",u"Bolnisi",9030,41.445,44.5411111 ],
    [ u"ge",u"Borjomi",13826,41.8375,43.3791667 ],
    [ u"ge",u"Didi Lilo",3349,41.7363889,44.9658333 ],
    [ u"ge",u"Dioknisi",7727,41.6311111,42.4152778 ],
    [ u"ge",u"Dmanisi",3040,41.5227778,44.3533333 ],
    [ u"ge",u"Gagra",8266,43.3222222,40.2436111 ],
    [ u"ge",u"Gali",11861,42.6405556,41.7372222 ],
    [ u"ge",u"Gardabani",10973,41.4547222,45.0947222 ],
    [ u"ge",u"Gori",46680,41.9736111,44.1111111 ],
    [ u"ge",u"Gurjaani",9467,41.7430556,45.8027778 ],
    [ u"ge",u"Java",426,42.3997222,43.9366667 ],
    [ u"ge",u"Jvari",4756,42.7138889,42.0536111 ],
    [ u"ge",u"Kaspi",14735,41.9161111,44.4241667 ],
    [ u"ge",u"Kazbegi",2628,42.6566667,44.6433333 ],
    [ u"ge",u"Kharagauli",5096,42.0202778,43.2138889 ],
    [ u"ge",u"Khashuri",27814,41.9911111,43.59 ],
    [ u"ge",u"Khobi",5376,42.3269444,41.8972222 ],
    [ u"ge",u"Khoni",10796,42.3241667,42.43 ],
    [ u"ge",u"Khulo",768,41.6463889,42.3111111 ],
    [ u"ge",u"Kojori",678,41.6608333,44.6916667 ],
    [ u"ge",u"Kornisi",208,42.2708333,43.8175 ],
    [ u"ge",u"Kulashi",2691,42.2041667,42.3566667 ],
    [ u"ge",u"Kvaisi",237,42.5230556,43.6486111 ],
    [ u"ge",u"Kvareli",8613,41.9513889,45.8016667 ],
    [ u"ge",u"Lagodekhi",6551,41.8227778,46.2755556 ],
    [ u"ge",u"Lajanurhesi",95,42.6180556,42.8355556 ],
    [ u"ge",u"Lentekhi",10442,42.7855556,42.7261111 ],
    [ u"ge",u"Makhinjauri",2736,41.6794444,41.6983333 ],
    [ u"ge",u"Manglisi",4817,41.6930556,44.3780556 ],
    [ u"ge",u"Marneuli",18757,41.4636111,44.8108333 ],
    [ u"ge",u"Martvili",5484,42.4152778,42.3738889 ],
    [ u"ge",u"Mestia",3187,43.0455556,42.7297222 ],
    [ u"ge",u"Naruja",3065,41.9052778,41.9341667 ],
    [ u"ge",u"Ninotsminda",6142,41.2669444,43.5905556 ],
    [ u"ge",u"Ochamchira",15517,42.6966667,41.4783333 ],
    [ u"ge",u"Oni",3014,42.5794444,43.4425 ],
    [ u"ge",u"Pitsunda",8402,43.1569444,40.35 ],
    [ u"ge",u"Sagarejo",12174,41.7363889,45.3302778 ],
    [ u"ge",u"Samtredia",28751,42.1538889,42.335 ],
    [ u"ge",u"Senaki",27755,42.2688889,42.0791667 ],
    [ u"ge",u"Shaumiani",5237,41.3494444,44.7563889 ],
    [ u"ge",u"Shorapani",1699,42.0958333,43.1155556 ],
    [ u"ge",u"Shuakhevi",380,41.63,42.1908333 ],
    [ u"ge",u"Signagi",1923,41.6188889,45.9216667 ],
    [ u"ge",u"Sioni",777,42.6072222,44.5852778 ],
    [ u"ge",u"Sukhumi",81546,43.0033333,41.0152778 ],
    [ u"ge",u"Surami",10091,42.0225,43.5555556 ],
    [ u"ge",u"Tbilisi",1049516,41.725,44.7908333 ],
    [ u"ge",u"Tkibuli",13203,42.3441667,42.99 ],
    [ u"ge",u"Tkvarcheli",17847,42.8525,41.6788889 ],
    [ u"ge",u"Tsagveri",2745,41.8047222,43.4819444 ],
    [ u"ge",u"Tsalenjikha",8881,42.6044444,42.0772222 ],
    [ u"ge",u"Tsalka",1572,41.5913889,44.0869444 ],
    [ u"ge",u"Tskaltubo",16737,42.3397222,42.5991667 ],
    [ u"ge",u"Tskneti",4172,41.6947222,44.6986111 ],
    [ u"ge",u"Tsnori",6613,41.6169444,45.9719444 ],
    [ u"ge",u"Ureki",1625,41.9886111,41.7633333 ],
    [ u"ge",u"Vale",4734,41.6186111,42.8627778 ],
    [ u"ge",u"Vani",4266,42.0813889,42.5244444 ],
    [ u"ge",u"Zahesi",1933,41.8244444,44.7577778 ],
    [ u"ge",u"Zugdidi",73014,42.5013889,41.8613889 ],
    [ u"gf",u"Apatou",4753,5.15,-54.3333333 ],
    [ u"gf",u"Camopi",1295,3.1666667,-52.35 ],
    [ u"gf",u"Cayenne",61642,4.9333333,-52.3333333 ],
    [ u"gf",u"Grand-Santi",3942,4.25,-54.3833333 ],
    [ u"gf",u"Iracoubo",1539,5.4833333,-53.2166667 ],
    [ u"gf",u"Kourou",24035,5.15,-52.65 ],
    [ u"gf",u"Macouria",8786,4.9166667,-52.3666667 ],
    [ u"gf",u"Mana",5887,5.6666667,-53.7833333 ],
    [ u"gf",u"Matoury",26357,4.85,-52.3333333 ],
    [ u"gf",u"Roura",2230,4.7333333,-52.3333333 ],
    [ u"gf",u"Saint-Georges",2743,3.9,-51.8 ],
    [ u"gf",u"Sinnamary",3190,5.3833333,-52.95 ],
    [ u"gh",u"Aboso",8790,5.3666667,-1.9333333 ],
    [ u"gh",u"Aburi",15053,5.85,-0.1833333 ],
    [ u"gh",u"Accra",1963460,5.55,-0.2166667 ],
    [ u"gh",u"Aflao",29991,6.1177778,1.1927778 ],
    [ u"gh",u"Agogo",37123,6.8,-1.0833333 ],
    [ u"gh",u"Akim Swedru",8355,5.9,-1.0166667 ],
    [ u"gh",u"Akropong",11096,5.9666667,-0.0833333 ],
    [ u"gh",u"Akwatia",20451,6.05,-0.8 ],
    [ u"gh",u"Anloga",29748,5.8,0.9 ],
    [ u"gh",u"Apam",20148,5.2833333,-0.7333333 ],
    [ u"gh",u"Asamankese",36589,5.8666667,-0.6666667 ],
    [ u"gh",u"Axim",24500,4.8683333,-2.2413889 ],
    [ u"gh",u"Bawku",41808,11.0580556,-0.2416667 ],
    [ u"gh",u"Bechem",14391,7.0833333,-2.0333333 ],
    [ u"gh",u"Begoro",23759,6.3833333,-0.3833333 ],
    [ u"gh",u"Bekwai",4260,6.45,-1.5833333 ],
    [ u"gh",u"Berekum",36409,7.45,-2.5833333 ],
    [ u"gh",u"Bibiani",19076,6.4666667,-2.3333333 ],
    [ u"gh",u"Bolgatanga",39870,10.7855556,-0.8513889 ],
    [ u"gh",u"Cape Coast",143044,5.1,-1.25 ],
    [ u"gh",u"Duayaw Nkwanta",14227,7.1666667,-2.1 ],
    [ u"gh",u"Dunkwa",25410,5.9666667,-1.7833333 ],
    [ u"gh",u"Ejura",43403,7.3833333,-1.3666667 ],
    [ u"gh",u"Elmina",25560,5.0833333,-1.35 ],
    [ u"gh",u"Foso",15637,5.7,-1.2833333 ],
    [ u"gh",u"Ho",54199,6.6,0.4666667 ],
    [ u"gh",u"Hohoe",30120,7.15,0.4666667 ],
    [ u"gh",u"Kade",13315,6.0833333,-0.8333333 ],
    [ u"gh",u"Keta",18077,5.9166667,0.9833333 ],
    [ u"gh",u"Kibi",9399,6.1666667,-0.55 ],
    [ u"gh",u"Kintampo",22731,8.05,-1.7166667 ],
    [ u"gh",u"Koforidua",76669,6.0833333,-0.25 ],
    [ u"gh",u"Konongo",26909,6.6166667,-1.2166667 ],
    [ u"gh",u"Kpandae",8652,8.4666667,-0.0166667 ],
    [ u"gh",u"Kpandu",22525,7.0,0.3 ],
    [ u"gh",u"Kumasi",1468797,6.6833333,-1.6166667 ],
    [ u"gh",u"Madina",68591,5.6833333,-0.1666667 ],
    [ u"gh",u"Mampong",39732,7.0666667,-1.4 ],
    [ u"gh",u"Mpraeso",9007,6.5833333,-0.7333333 ],
    [ u"gh",u"Mumford",13983,5.2666667,-0.75 ],
    [ u"gh",u"Navrongo",25470,10.895,-1.0938889 ],
    [ u"gh",u"Nkawkaw",41493,6.55,-0.7666667 ],
    [ u"gh",u"Nsawam",26682,5.8,-0.35 ],
    [ u"gh",u"Nungua",70482,5.6,-0.0666667 ],
    [ u"gh",u"Obuasi",119063,6.2,-1.6666667 ],
    [ u"gh",u"Oda",32151,5.9166667,-0.9833333 ],
    [ u"gh",u"Prestea",31607,5.4333333,-2.15 ],
    [ u"gh",u"Salaga",19609,8.55,-0.5166667 ],
    [ u"gh",u"Saltpond",18794,5.2,-1.0666667 ],
    [ u"gh",u"Savelugu",29310,9.6247222,-0.8277778 ],
    [ u"gh",u"Sekondi",104194,4.9333333,-1.7 ],
    [ u"gh",u"Shama",20946,5.0,-1.65 ],
    [ u"gh",u"Suhum",25192,6.0333333,-0.45 ],
    [ u"gh",u"Sunyani",63180,7.3333333,-2.3333333 ],
    [ u"gh",u"Swedru",46950,5.5333333,-0.7 ],
    [ u"gh",u"Tafo",50456,6.7333333,-1.6166667 ],
    [ u"gh",u"Takoradi",114989,4.8833333,-1.75 ],
    [ u"gh",u"Tamale",360644,9.4,-0.8333333 ],
    [ u"gh",u"Tarkwa",41345,5.3,-1.9833333 ],
    [ u"gh",u"Techiman",41315,7.5833333,-1.9333333 ],
    [ u"gh",u"Tema",351556,5.6166667,-0.0166667 ],
    [ u"gh",u"Teshie",144012,5.5833333,-0.1 ],
    [ u"gh",u"Wa",50268,10.05,-2.4833333 ],
    [ u"gh",u"Wenchi",30389,7.7333333,-2.1 ],
    [ u"gh",u"Winneba",40754,5.3333333,-0.6166667 ],
    [ u"gh",u"Yendi",54411,9.4333333,-0.0166667 ],
    [ u"gi",u"Gibraltar",26544,36.1333333,-5.35 ],
    [ u"gl",u"Aappilattoq",208,72.8833333,-55.6 ],
    [ u"gl",u"Aasiaat",3115,68.7166667,-52.8666667 ],
    [ u"gl",u"Akunnaaq",107,68.75,-52.3333333 ],
    [ u"gl",u"Alluitsup Paa",364,60.45,-45.55 ],
    [ u"gl",u"Ammassivik",83,60.6,-45.3833333 ],
    [ u"gl",u"Arsuk",145,61.1666667,-48.45 ],
    [ u"gl",u"Atammik",250,64.8,-52.2166667 ],
    [ u"gl",u"Attu",281,67.95,-53.6333333 ],
    [ u"gl",u"Igaliku",49,60.9833333,-45.4166667 ],
    [ u"gl",u"Iginniarfik",103,68.15,-53.1666667 ],
    [ u"gl",u"Ikamiut",92,68.6333333,-51.8333333 ],
    [ u"gl",u"Ikerasaarsuk",116,68.1333333,-53.5333333 ],
    [ u"gl",u"Ikerasak",286,70.5,-51.3 ],
    [ u"gl",u"Ilimanaq",84,69.0833333,-51.1166667 ],
    [ u"gl",u"Illoqqortoormiut",531,70.4833333,-21.9666667 ],
    [ u"gl",u"Illorsuit",97,71.2333333,-53.5666667 ],
    [ u"gl",u"Ilulissat",4413,69.2166667,-51.1 ],
    [ u"gl",u"Isortoq",113,65.5333333,-38.9833333 ],
    [ u"gl",u"Itilleq",121,66.5833333,-53.5 ],
    [ u"gl",u"Itterajivit",15,70.45,-22.3833333 ],
    [ u"gl",u"Ivittuut",11,61.2,-48.1666667 ],
    [ u"gl",u"Kangaamiut",396,65.8333333,-53.3333333 ],
    [ u"gl",u"Kangaatsiaq",680,68.3,-53.4666667 ],
    [ u"gl",u"Kangersuatsiaq",244,72.3833333,-55.5333333 ],
    [ u"gl",u"Kapisillit",89,64.4333333,-50.2666667 ],
    [ u"gl",u"Kullorsuaq",408,74.5833333,-57.2 ],
    [ u"gl",u"Kulusuk",312,65.5666667,-37.1833333 ],
    [ u"gl",u"Maarmorilik",50,71.1333333,-51.2833333 ],
    [ u"gl",u"Maniitsoq",2866,65.4166667,-52.9 ],
    [ u"gl",u"Moriusaq",21,76.7561111,-69.8863889 ],
    [ u"gl",u"Nanortalik",1509,60.1166667,-45.2166667 ],
    [ u"gl",u"Napasoq",99,65.05,-52.4 ],
    [ u"gl",u"Narsaq Kujalleq",110,60.0030556,-44.6636111 ],
    [ u"gl",u"Narsaq",1709,77.3025,-68.8425 ],
    [ u"gl",u"Narsarsuaq",154,61.1666667,-45.4166667 ],
    [ u"gl",u"Neriunaq",7,64.4666667,-50.3166667 ],
    [ u"gl",u"Niaqornaarsuk",336,68.2333333,-52.8666667 ],
    [ u"gl",u"Niaqornat",60,70.8,-53.65 ],
    [ u"gl",u"Nuugaatsiaq",99,71.55,-53.2166667 ],
    [ u"gl",u"Nuuk",14799,64.1833333,-51.75 ],
    [ u"gl",u"Paamiut",1862,62.0,-49.75 ],
    [ u"gl",u"Qaanaaq",616,77.4894444,-69.3322222 ],
    [ u"gl",u"Qaarsut",204,70.7333333,-52.65 ],
    [ u"gl",u"Qallimiut",12,60.7,-45.3333333 ],
    [ u"gl",u"Qaqortoq",3224,60.7166667,-46.0333333 ],
    [ u"gl",u"Qasigiannguit",1341,68.8166667,-51.1833333 ],
    [ u"gl",u"Qassiarsuk",40,61.15,-45.5166667 ],
    [ u"gl",u"Qassimiut",49,60.7833333,-47.1666667 ],
    [ u"gl",u"Qeqertaq",154,70.0,-51.3166667 ],
    [ u"gl",u"Qeqertarsuatsiaat",261,63.0833333,-50.6666667 ],
    [ u"gl",u"Qeqertat",18,77.5097222,-66.6477778 ],
    [ u"gl",u"Saarloq",48,60.5333333,-46.0333333 ],
    [ u"gl",u"Saattut",211,70.8166667,-51.6333333 ],
    [ u"gl",u"Saqqaq",169,70.0166667,-51.95 ],
    [ u"gl",u"Sarfannguit",110,66.9,-52.8666667 ],
    [ u"gl",u"Savissivik",82,76.0233333,-65.0813889 ],
    [ u"gl",u"Sermiligaaq",223,65.9,-36.3666667 ],
    [ u"gl",u"Siorapaluk",75,77.7952778,-70.7558333 ],
    [ u"gl",u"Sisimiut",5227,66.9333333,-53.6833333 ],
    [ u"gl",u"Tasiilaq",1829,65.6,-37.6333333 ],
    [ u"gl",u"Tasiusaq",7,73.3666667,-56.05 ],
    [ u"gl",u"Timerliit",7,65.8333333,-53.25 ],
    [ u"gl",u"Tiniteqilaaq",169,65.8833333,-37.7833333 ],
    [ u"gl",u"Ukkusissat",195,71.05,-51.8833333 ],
    [ u"gl",u"Upernaviarsuk",13,60.75,-45.8833333 ],
    [ u"gl",u"Upernavik Kujalleq",205,72.15,-55.5333333 ],
    [ u"gl",u"Upernavik",1129,72.7833333,-56.1666667 ],
    [ u"gm",u"Bakau",47654,13.4780556,-16.6819444 ],
    [ u"gm",u"Banjul",34598,13.4530556,-16.5775 ],
    [ u"gm",u"Bansang",7152,13.4333333,-14.65 ],
    [ u"gm",u"Barra",5323,13.4827778,-16.5455556 ],
    [ u"gm",u"Basse",16190,13.3166667,-14.2166667 ],
    [ u"gm",u"Brikama",101805,13.2675,-16.6461111 ],
    [ u"gm",u"Brufut",9332,13.3841667,-16.7513889 ],
    [ u"gm",u"Essau",4997,13.4838889,-16.5347222 ],
    [ u"gm",u"Farafenni",36831,13.5666667,-15.6 ],
    [ u"gm",u"Gambissara",6755,13.2333333,-14.3166667 ],
    [ u"gm",u"Gunjur",12530,13.1816667,-16.7583333 ],
    [ u"gm",u"Kerewan",3017,13.4894444,-16.0911111 ],
    [ u"gm",u"Kuntaur",11399,13.65,-14.8666667 ],
    [ u"gm",u"Lamin",16525,13.3522222,-16.4338889 ],
    [ u"gm",u"Sabi",7738,13.2333333,-14.2 ],
    [ u"gm",u"Serekunda",218790,13.4425,-16.6813889 ],
    [ u"gm",u"Sukuta",15131,13.4113889,-16.7088889 ],
    [ u"gn",u"Beyla",14053,8.6833333,-8.6333333 ],
    [ u"gn",u"Boffa",2332,10.1666667,-14.0333333 ],
    [ u"gn",u"Boké",15462,10.9333333,-14.3 ],
    [ u"gn",u"Conakry",1871185,9.5091667,-13.7122222 ],
    [ u"gn",u"Coyah",1632,9.7055556,-13.3769444 ],
    [ u"gn",u"Dabola",13056,10.75,-11.1166667 ],
    [ u"gn",u"Dalaba",12823,10.7,-12.25 ],
    [ u"gn",u"Dinguiraye",6062,11.3,-10.7166667 ],
    [ u"gn",u"Dubréka",10363,9.7911111,-13.5233333 ],
    [ u"gn",u"Faranah",9349,10.0333333,-10.7333333 ],
    [ u"gn",u"Forécariah",12357,9.4305556,-13.0880556 ],
    [ u"gn",u"Fria",9326,10.45,-13.5333333 ],
    [ u"gn",u"Gaoual",7461,11.75,-13.2 ],
    [ u"gn",u"Guékédou",5534,8.5625,-10.1325 ],
    [ u"gn",u"Kankan",114103,10.3833333,-9.3 ],
    [ u"gn",u"Kérouané",7228,9.2666667,-9.0166667 ],
    [ u"gn",u"Kindia",117095,10.0666667,-12.85 ],
    [ u"gn",u"Kissidougou",47097,9.1833333,-10.1 ],
    [ u"gn",u"Koubia",9909,11.5833333,-11.9 ],
    [ u"gn",u"Koundara",13989,12.4833333,-13.3 ],
    [ u"gn",u"Kouroussa",14222,10.65,-9.8833333 ],
    [ u"gn",u"Labé",46510,11.3166667,-12.2833333 ],
    [ u"gn",u"Lola",1982,7.8,-8.5333333 ],
    [ u"gn",u"Macenta",43107,8.5461111,-9.4694444 ],
    [ u"gn",u"Mali",5479,12.0833333,-12.3 ],
    [ u"gn",u"Mamou",41618,10.15,-11.95 ],
    [ u"gn",u"Mandiana",10608,10.6333333,-8.6833333 ],
    [ u"gn",u"Nzérékoré",132842,7.7472222,-8.8238889 ],
    [ u"gn",u"Pita",20051,11.0833333,-12.4 ],
    [ u"gn",u"Sanguéya",6117,10.7,-14.3666667 ],
    [ u"gn",u"Siguiri",43599,11.4166667,-9.1666667 ],
    [ u"gn",u"Télimélé",30310,10.9,-13.0333333 ],
    [ u"gn",u"Tokonou",6729,9.65,-9.7833333 ],
    [ u"gn",u"Tondon",12235,10.3666667,-13.35 ],
    [ u"gn",u"Tougué",25530,11.45,-11.6833333 ],
    [ u"gn",u"Yomou",3614,7.5602778,-9.2652778 ],
    [ u"gn",u"Youkounkoun",7952,12.5333333,-13.1333333 ],
    [ u"gp",u"Anse-Bertrand",5146,16.4666667,-61.5 ],
    [ u"gp",u"Baie-Mahault",30553,16.2666667,-61.5833333 ],
    [ u"gp",u"Baillif",5705,16.0166667,-61.7333333 ],
    [ u"gp",u"Basse-Terre",11472,16.0,-61.7166667 ],
    [ u"gp",u"Bouillante",7541,16.1333333,-61.7666667 ],
    [ u"gp",u"Capesterre-Belle-Eau",19823,16.05,-61.55 ],
    [ u"gp",u"Gourbeyre",8572,15.9833333,-61.6833333 ],
    [ u"gp",u"Grand-Bourg",5869,15.8833333,-61.3 ],
    [ u"gp",u"Lamentin",14892,16.2666667,-61.6166667 ],
    [ u"gp",u"Le Gosier",28700,16.2,-61.4833333 ],
    [ u"gp",u"Le Moule",22694,16.3333333,-61.3333333 ],
    [ u"gp",u"Les Abymes",63061,16.2666667,-61.5 ],
    [ u"gp",u"Marigot",3368,18.0666667,-63.0833333 ],
    [ u"gp",u"Petit-Bourg",24996,16.1833333,-61.5833333 ],
    [ u"gp",u"Petit-Canal",8554,16.3833333,-61.4833333 ],
    [ u"gp",u"Pointe-Noire",7750,16.2333333,-61.7833333 ],
    [ u"gp",u"Port-Louis",5515,16.4166667,-61.5166667 ],
    [ u"gp",u"Saint-Claude",10135,16.0166667,-61.6833333 ],
    [ u"gp",u"Sainte-Anne",22861,16.2333333,-61.3666667 ],
    [ u"gp",u"Sainte-Rose",20194,16.3333333,-61.6833333 ],
    [ u"gp",u"Saint-François",12733,16.25,-61.2666667 ],
    [ u"gp",u"Terre-de-Bas",1315,15.85,-61.6333333 ],
    [ u"gp",u"Trois-Rivières",8812,15.9666667,-61.6333333 ],
    [ u"gp",u"Vieux-Habitants",7729,16.05,-61.75 ],
    [ u"gq",u"Aconibe",11199,1.3,10.9333333 ],
    [ u"gq",u"Acurenam",2738,1.0333333,10.6666667 ],
    [ u"gq",u"Añisoc",10197,1.85,10.7666667 ],
    [ u"gq",u"Bata",173036,1.85,9.75 ],
    [ u"gq",u"Ebebiyín",24857,2.15,11.3333333 ],
    [ u"gq",u"Evinayong",8468,1.45,10.5666667 ],
    [ u"gq",u"Luba",8668,3.45,8.55 ],
    [ u"gq",u"Malabo",156039,3.75,8.7833333 ],
    [ u"gq",u"Mbini",4061,1.5833333,9.6166667 ],
    [ u"gq",u"Micomeseng",5818,2.1333333,10.6166667 ],
    [ u"gq",u"Mongomo",6397,1.6333333,11.3166667 ],
    [ u"gq",u"Riaba",972,3.3833333,8.7666667 ],
    [ u"gr",u"Adámas",1478,36.7333333,24.4333333 ],
    [ u"gr",u"Ádendron",2312,40.6716667,22.6044444 ],
    [ u"gr",u"Afántou",5562,36.3,28.15 ],
    [ u"gr",u"Áfitos",1428,40.1,23.4333333 ],
    [ u"gr",u"Áfra",879,39.6197222,19.8577778 ],
    [ u"gr",u"Afrátion",1365,38.45,23.6833333 ],
    [ u"gr",u"Agnanterón",1859,39.4872222,21.8455556 ],
    [ u"gr",u"Ágra",983,39.1666667,26.0666667 ],
    [ u"gr",u"Ágrafa",820,39.1372222,21.65 ],
    [ u"gr",u"Ágras",855,40.805,22.0005556 ],
    [ u"gr",u"Agriá",5519,39.3333333,23.0166667 ],
    [ u"gr",u"Agrínion",43526,38.6213889,21.4077778 ],
    [ u"gr",u"Aianí",2119,40.1666667,21.8166667 ],
    [ u"gr",u"Aiántion",3936,37.9166667,23.4666667 ],
    [ u"gr",u"Aigáleo",72320,37.9833333,23.6833333 ],
    [ u"gr",u"Aitolikón",4323,38.4333333,21.35 ],
    [ u"gr",u"Aíyina",7823,37.7466667,23.4275 ],
    [ u"gr",u"Aiyínion",4275,40.5013889,22.54 ],
    [ u"gr",u"Aíyion",20665,38.2486111,22.0819444 ],
    [ u"gr",u"Aíyira",1666,38.15,22.35 ],
    [ u"gr",u"Akharnaí",82376,38.0833333,23.7333333 ],
    [ u"gr",u"Akhinós",898,38.9,22.7333333 ],
    [ u"gr",u"Akraífnion",1195,38.45,23.2166667 ],
    [ u"gr",u"Akráta",1833,38.15,22.3166667 ],
    [ u"gr",u"Akriní",1113,40.4333333,21.9 ],
    [ u"gr",u"Akrolímni",1398,40.6791667,22.2638889 ],
    [ u"gr",u"Alepoú",1640,39.6102778,19.8888889 ],
    [ u"gr",u"Alexándria",13665,40.6266667,22.4441667 ],
    [ u"gr",u"Alexandroúpoli",52978,40.8475,25.8744444 ],
    [ u"gr",u"Alfioúsa",1067,37.65,21.5333333 ],
    [ u"gr",u"Alíartos",4275,38.3666667,23.1 ],
    [ u"gr",u"Alistráti",2965,41.0666667,23.95 ],
    [ u"gr",u"Alivérion",5184,38.4166667,24.0333333 ],
    [ u"gr",u"Álli Meriá",1189,39.3666667,22.9833333 ],
    [ u"gr",u"Almirós",7253,39.1822222,22.7594444 ],
    [ u"gr",u"Alónia",653,40.3944444,22.5416667 ],
    [ u"gr",u"Amaliás",19580,37.8,21.35 ],
    [ u"gr",u"Amárinthos",4360,38.4,23.8833333 ],
    [ u"gr",u"Amaroúsion",72310,38.05,23.8 ],
    [ u"gr",u"Ambelákia",4671,37.9513889,23.5275 ],
    [ u"gr",u"Ambelíai",1070,40.8336111,22.3786111 ],
    [ u"gr",u"Ámbeloi",1118,41.0,23.3666667 ],
    [ u"gr",u"Ambelókipoi",1218,37.7666667,20.8666667 ],
    [ u"gr",u"Ambelón",5961,39.75,22.3666667 ],
    [ u"gr",u"Amfíklia",3674,38.6333333,22.5833333 ],
    [ u"gr",u"Amfilokhía",4023,38.8594444,21.1663889 ],
    [ u"gr",u"Ámfissa",6854,38.525,22.3730556 ],
    [ u"gr",u"Amisianá",1293,40.9333333,24.35 ],
    [ u"gr",u"Ammokhórion",1192,40.7833333,21.4833333 ],
    [ u"gr",u"Análipsis",1259,35.3166667,25.5666667 ],
    [ u"gr",u"Anarrákhi",1147,40.4833333,21.5666667 ],
    [ u"gr",u"Anatolí",6422,39.6388889,20.8652778 ],
    [ u"gr",u"Anatolikón",959,40.55,21.75 ],
    [ u"gr",u"Anatolikón",2583,40.6630556,22.7113889 ],
    [ u"gr",u"Anávissos",8459,37.7333333,23.95 ],
    [ u"gr",u"Anávra",1024,39.0666667,22.55 ],
    [ u"gr",u"Anayénnisis",990,41.1166667,23.3333333 ],
    [ u"gr",u"Andravída",3626,37.9,21.2666667 ],
    [ u"gr",u"Ándros",1556,37.8333333,24.9333333 ],
    [ u"gr",u"Anéza",1197,39.0866667,20.9233333 ],
    [ u"gr",u"Angelókastron",1614,38.5666667,21.3 ],
    [ u"gr",u"Angelokhórion",1526,40.6783333,22.1991667 ],
    [ u"gr",u"Angelokhórion",991,40.4972222,22.8344444 ],
    [ u"gr",u"Anífion",922,37.6666667,22.7833333 ],
    [ u"gr",u"Ánoixis",6482,38.1333333,23.85 ],
    [ u"gr",u"Áno Kastrítsion",1003,38.2666667,21.8333333 ],
    [ u"gr",u"Áno Kómi",1547,40.2333333,21.8333333 ],
    [ u"gr",u"Áno Korakiána",837,39.7077778,19.7916667 ],
    [ u"gr",u"Áno Lekhónia",1214,39.3333333,23.05 ],
    [ u"gr",u"Áno Liósia",28529,38.0833333,23.7 ],
    [ u"gr",u"Áno Merá",1611,37.45,25.4 ],
    [ u"gr",u"Áno Poróïa",1558,41.2833333,23.0333333 ],
    [ u"gr",u"Áno Síros",1138,37.45,24.9333333 ],
    [ u"gr",u"Anóyia",2545,35.2833333,24.8833333 ],
    [ u"gr",u"Ánthia",914,40.8666667,25.9833333 ],
    [ u"gr",u"Anthíli",1381,38.85,22.4666667 ],
    [ u"gr",u"Antimakhia",2251,36.8108333,27.0997222 ],
    [ u"gr",u"Ántissa",841,39.2333333,25.9833333 ],
    [ u"gr",u"Apóllona",982,36.25,27.9666667 ],
    [ u"gr",u"Apollonía",1054,36.9666667,24.7166667 ],
    [ u"gr",u"Ápsalos",1149,40.8927778,22.0544444 ],
    [ u"gr",u"Arakhnaíon",803,37.6833333,22.9666667 ],
    [ u"gr",u"Arákhova",3992,38.4833333,22.5833333 ],
    [ u"gr",u"Áratos",1152,41.0833333,25.55 ],
    [ u"gr",u"Aravissós",1513,40.84,22.2955556 ],
    [ u"gr",u"Árdassa",934,40.4833333,21.6333333 ],
    [ u"gr",u"Aréthousa",905,40.75,23.5833333 ],
    [ u"gr",u"Arfará",1285,37.15,22.0333333 ],
    [ u"gr",u"Argalastí",1285,39.2333333,23.2166667 ],
    [ u"gr",u"Árgos",25091,37.6333333,22.7333333 ],
    [ u"gr",u"Árgos Orestikón",7894,40.4666667,21.2666667 ],
    [ u"gr",u"Argostólion",9820,38.1730556,20.4819444 ],
    [ u"gr",u"Ária",2080,37.5666667,22.8333333 ],
    [ u"gr",u"Aridaía",6091,40.9730556,22.0563889 ],
    [ u"gr",u"Áris",1036,37.1,22.0 ],
    [ u"gr",u"Arísvi",1068,41.0666667,25.5833333 ],
    [ u"gr",u"Arkalokhórion",3537,35.15,25.2666667 ],
    [ u"gr",u"Arkhaía Kórinthos",1701,37.9166667,22.8833333 ],
    [ u"gr",u"Arkhaía Olimbía",1208,37.65,21.6333333 ],
    [ u"gr",u"Arkhángelos",5398,36.1833333,28.1333333 ],
    [ u"gr",u"Árma",1078,38.35,23.4833333 ],
    [ u"gr",u"Arménion",727,39.4833333,22.7 ],
    [ u"gr",u"Armenokhórion",1079,40.8,21.4666667 ],
    [ u"gr",u"Arnaía",2271,40.4819444,23.5927778 ],
    [ u"gr",u"Árnissa",1556,40.8,21.8333333 ],
    [ u"gr",u"Arrianá",1158,41.0833333,25.7 ],
    [ u"gr",u"Arsénion",1389,40.7141667,22.1622222 ],
    [ u"gr",u"Árta",19541,39.1605556,20.9852778 ],
    [ u"gr",u"Artesianón",1412,39.4027778,21.8947222 ],
    [ u"gr",u"Aryiropoúlion",1782,39.8333333,22.3 ],
    [ u"gr",u"Asímion",1259,35.05,25.1 ],
    [ u"gr",u"Asíni",1081,37.55,22.8666667 ],
    [ u"gr",u"Askós",1406,40.75,23.3833333 ],
    [ u"gr",u"Asopía",1375,38.3,23.5 ],
    [ u"gr",u"Asopós",1279,36.7333333,22.8666667 ],
    [ u"gr",u"Asprópirgos",32712,38.0666667,23.5833333 ],
    [ u"gr",u"Áspros",891,40.8991667,22.6222222 ],
    [ u"gr",u"Asproválta",3333,40.7166667,23.7 ],
    [ u"gr",u"Ássiros",2409,40.8166667,23.0333333 ],
    [ u"gr",u"Ássos",2730,37.9333333,22.8333333 ],
    [ u"gr",u"Astakós",2569,38.5333333,21.0833333 ],
    [ u"gr",u"Astipálaia",1129,36.55,26.35 ],
    [ u"gr",u"Ástros",2222,37.4,22.7166667 ],
    [ u"gr",u"Asvestokhórion",5345,40.65,23.0333333 ],
    [ u"gr",u"Atalánti",5859,38.6511111,22.9991667 ],
    [ u"gr",u"Athens",729139,37.9833333,23.7333333 ],
    [ u"gr",u"Athíkia",2058,37.8166667,22.9333333 ],
    [ u"gr",u"Áthira",1722,40.8252778,22.5833333 ],
    [ u"gr",u"Atsikí",886,39.95,25.2166667 ],
    [ u"gr",u"Atsipópoulon",1826,35.35,24.4333333 ],
    [ u"gr",u"Ávaton",1357,40.9666667,24.8 ],
    [ u"gr",u"Axioúpoli",3368,40.9836111,22.535 ],
    [ u"gr",u"Axós",1336,40.7988889,22.3558333 ],
    [ u"gr",u"Ayía Ánna",823,38.8666667,23.4 ],
    [ u"gr",u"Ayiá",2827,39.7177778,22.7636111 ],
    [ u"gr",u"Ayía Galíni",1369,35.1,24.6833333 ],
    [ u"gr",u"Ayía Marína",732,40.5977778,22.2152778 ],
    [ u"gr",u"Ayía Marína",2731,37.75,23.5333333 ],
    [ u"gr",u"Ayía Marína",1671,35.5166667,23.9333333 ],
    [ u"gr",u"Ayía Marína",2743,37.15,26.8666667 ],
    [ u"gr",u"Ayía Paraskeví",978,40.95,23.4666667 ],
    [ u"gr",u"Ayía Paraskeví",1501,40.4833333,23.05 ],
    [ u"gr",u"Ayía Paraskeví",998,38.5833333,22.75 ],
    [ u"gr",u"Ayía Paraskeví",60662,38.0166667,23.8333333 ],
    [ u"gr",u"Ayía Paraskeví",2193,39.2480556,26.2716667 ],
    [ u"gr",u"Ayíasma",1185,40.9088889,24.6572222 ],
    [ u"gr",u"Ayiásos",2357,39.085,26.37 ],
    [ u"gr",u"Ayía Triás",3580,40.4994444,22.8761111 ],
    [ u"gr",u"Ayía Triás",754,39.2947222,21.7330556 ],
    [ u"gr",u"Ayía Triás",1098,38.35,22.9166667 ],
    [ u"gr",u"Ayía Varvára",31218,37.9833333,23.6666667 ],
    [ u"gr",u"Ayía Varvára",2167,35.1333333,25.0 ],
    [ u"gr",u"Áyioi Apóstoloi",4338,38.3,23.9 ],
    [ u"gr",u"Áyios Andréas",1033,37.35,22.7666667 ],
    [ u"gr",u"Áyios Athanásios",4648,40.7172222,22.7280556 ],
    [ u"gr",u"Áyios Athanásios",3419,41.0666667,24.25 ],
    [ u"gr",u"Áyios Ioánnis",983,38.45,24.0 ],
    [ u"gr",u"Áyios Kírikos",1908,37.6147222,26.2944444 ],
    [ u"gr",u"Áyios Loukás",1666,40.7194444,22.295 ],
    [ u"gr",u"Áyios Loukás",955,38.4333333,24.0333333 ],
    [ u"gr",u"Áyios Mámas",1044,40.2666667,23.3333333 ],
    [ u"gr",u"Áyios Matthaíos",1640,39.4958333,19.8730556 ],
    [ u"gr",u"Áyios Nikólaos",1913,40.25,23.7 ],
    [ u"gr",u"Áyios Nikólaos",982,38.7333333,21.1166667 ],
    [ u"gr",u"Áyios Nikólaos",2880,38.4166667,23.65 ],
    [ u"gr",u"Áyios Nikólaos",1305,37.85,21.1166667 ],
    [ u"gr",u"Áyios Nikólaos",10799,35.1913889,25.7133333 ],
    [ u"gr",u"Áyios Pétros",1763,40.8647222,22.5763889 ],
    [ u"gr",u"Áyios Pétros",857,37.3333333,22.55 ],
    [ u"gr",u"Áyios Serafím",1071,38.8,22.7 ],
    [ u"gr",u"Áyios Stéfanos",10940,38.15,23.85 ],
    [ u"gr",u"Áyios Thomás",1433,38.2833333,23.5833333 ],
    [ u"gr",u"Áyios Vasílios",1328,40.6666667,23.1166667 ],
    [ u"gr",u"Áyios Vasílios",2303,38.3166667,21.8166667 ],
    [ u"gr",u"Áyios Vasílios",1462,37.8,22.8 ],
    [ u"gr",u"Áyios Yeóryios",1767,40.6011111,22.1941667 ],
    [ u"gr",u"Áyios Yeóryios",2046,38.4,22.9333333 ],
    [ u"gr",u"Darátsos",3747,35.5,23.9833333 ],
    [ u"gr",u"Dervéni",1379,38.1333333,22.4166667 ],
    [ u"gr",u"Deskáti",3856,39.9225,21.8027778 ],
    [ u"gr",u"Diavatá",10216,40.6888889,22.8569444 ],
    [ u"gr",u"Diavatós",1294,40.5455556,22.2669444 ],
    [ u"gr",u"Díkaia",737,41.7041667,26.2933333 ],
    [ u"gr",u"Díon",1413,40.1733333,22.4866667 ],
    [ u"gr",u"Dolianá",616,39.9019444,20.5794444 ],
    [ u"gr",u"Domokós",1433,39.1272222,22.3002778 ],
    [ u"gr",u"Domvraína",1138,38.25,22.9833333 ],
    [ u"gr",u"Dráma",44225,41.1544444,24.1394444 ],
    [ u"gr",u"Drosáton",1148,41.1627778,22.7988889 ],
    [ u"gr",u"Édessa",18669,40.8005556,22.0472222 ],
    [ u"gr",u"Ekáli",5666,38.1166667,23.8333333 ],
    [ u"gr",u"Ekhínos",2162,41.2833333,24.9666667 ],
    [ u"gr",u"Elassón",7060,39.8947222,22.1886111 ],
    [ u"gr",u"Elátia",2449,38.6333333,22.7666667 ],
    [ u"gr",u"Eláti",886,39.5038889,21.5347222 ],
    [ u"gr",u"Eleón",656,38.35,23.4833333 ],
    [ u"gr",u"Eleoúsa",3064,39.7063889,20.7925 ],
    [ u"gr",u"Eleoúsa",963,39.1513889,20.9855556 ],
    [ u"gr",u"Eleusis",27055,38.0333333,23.5333333 ],
    [ u"gr",u"Ellinikón",18094,37.8833333,23.7333333 ],
    [ u"gr",u"Élos",957,36.8333333,22.7 ],
    [ u"gr",u"Émbonas",1211,36.2166667,27.8666667 ],
    [ u"gr",u"Embórion",1033,40.4833333,21.55 ],
    [ u"gr",u"Emboríon",1946,36.35,25.45 ],
    [ u"gr",u"Emmanouíl Pappás",1129,41.0833333,23.7166667 ],
    [ u"gr",u"Epáno Arkhánai",3913,35.2333333,25.1666667 ],
    [ u"gr",u"Epanomí",8121,40.4272222,22.9283333 ],
    [ u"gr",u"Epinianá",682,39.1419444,21.6133333 ],
    [ u"gr",u"Episkopí",967,35.25,25.2333333 ],
    [ u"gr",u"Epitálion",1953,37.6333333,21.5 ],
    [ u"gr",u"Eratinón",920,40.95,24.6333333 ],
    [ u"gr",u"Erátira",1383,40.35,21.5166667 ],
    [ u"gr",u"Eresós",1042,39.1666667,25.9333333 ],
    [ u"gr",u"Erétria",3217,38.4,23.8 ],
    [ u"gr",u"Erikoússa",863,39.8808333,19.5913889 ],
    [ u"gr",u"Erithraí",3250,38.2166667,23.3166667 ],
    [ u"gr",u"Ermióni",2856,37.3833333,23.25 ],
    [ u"gr",u"Ermoúpolis",11351,37.45,24.9333333 ],
    [ u"gr",u"Esóvalta",988,40.7072222,22.2630556 ],
    [ u"gr",u"Examília",1631,37.9,22.9333333 ],
    [ u"gr",u"Exaplátanos",1665,40.9772222,22.125 ],
    [ u"gr",u"Éxarkhos",965,38.5833333,22.95 ],
    [ u"gr",u"Exokhí",1739,40.0975,20.7402778 ],
    [ u"gr",u"Fálanna",3557,39.7166667,22.4 ],
    [ u"gr",u"Fánai",868,36.35,27.9833333 ],
    [ u"gr",u"Fáros",1195,38.4,23.6166667 ],
    [ u"gr",u"Fársala",10380,39.2947222,22.3847222 ],
    [ u"gr",u"Férai",5403,40.8955556,26.17 ],
    [ u"gr",u"Fíki",1098,39.5169444,21.6555556 ],
    [ u"gr",u"Filiátes",2129,39.6011111,20.3119444 ],
    [ u"gr",u"Filiatrá",6970,37.15,21.5833333 ],
    [ u"gr",u"Filí",2875,38.1,23.6666667 ],
    [ u"gr",u"Filippiás",4256,39.2047222,20.8822222 ],
    [ u"gr",u"Fíliron",4362,40.6833333,23.0 ],
    [ u"gr",u"Fílla",1276,38.4333333,23.6833333 ],
    [ u"gr",u"Fillíra",1041,41.1166667,25.6333333 ],
    [ u"gr",u"Filótas",1774,40.6333333,21.7 ],
    [ u"gr",u"Filótion",1744,37.05,25.5 ],
    [ u"gr",u"Fitíai",1516,38.7,21.1833333 ],
    [ u"gr",u"Flámbouron",762,40.9333333,23.5666667 ],
    [ u"gr",u"Flórina",14910,40.7833333,21.4 ],
    [ u"gr",u"Floyitá",1589,40.2666667,23.2166667 ],
    [ u"gr",u"Fotolívos",1844,41.0666667,24.0666667 ],
    [ u"gr",u"Foúrnoi",1033,37.7794444,26.7516667 ],
    [ u"gr",u"Fteliá",1006,41.0833333,24.1833333 ],
    [ u"gr",u"Gaïtánion",1584,37.7833333,20.8666667 ],
    [ u"gr",u"Galatádes",2459,40.7544444,22.2716667 ],
    [ u"gr",u"Galatás",1057,38.35,21.5666667 ],
    [ u"gr",u"Galatás",2759,37.5,23.45 ],
    [ u"gr",u"Galatás",2377,35.5,23.9666667 ],
    [ u"gr",u"Galatiní",2085,40.3166667,21.55 ],
    [ u"gr",u"Galátista",2710,40.4666667,23.2833333 ],
    [ u"gr",u"Galátsion",58625,38.0166667,23.75 ],
    [ u"gr",u"Galiá",852,35.0833333,24.8666667 ],
    [ u"gr",u"Gallikós",1239,40.8591667,22.8755556 ],
    [ u"gr",u"Gargaliánoi",6282,37.0666667,21.6333333 ],
    [ u"gr",u"Gastoúni",8114,37.85,21.25 ],
    [ u"gr",u"Gastóuri",1129,39.56,19.8975 ],
    [ u"gr",u"Gavaloú",1419,38.5333333,21.5333333 ],
    [ u"gr",u"Gázion",9721,35.3333333,25.0666667 ],
    [ u"gr",u"Gázoros",1677,41.0166667,23.7666667 ],
    [ u"gr",u"Glóssa",987,39.1666667,23.6166667 ],
    [ u"gr",u"Gómfoi",1064,39.4636111,21.6925 ],
    [ u"gr",u"Gónnoi",2113,39.8666667,22.4666667 ],
    [ u"gr",u"Gorgópi",913,40.9588889,22.5130556 ],
    [ u"gr",u"Gouménissa",4010,40.9438889,22.4441667 ],
    [ u"gr",u"Goúmeron",1072,37.7666667,21.6166667 ],
    [ u"gr",u"Gouriá",1096,38.4666667,21.2666667 ],
    [ u"gr",u"Goúrnai",1539,35.3166667,25.2833333 ],
    [ u"gr",u"Gouviá",874,39.6502778,19.8433333 ],
    [ u"gr",u"Graikokhórion",1264,39.4788889,20.295 ],
    [ u"gr",u"Gra Liyiá",1282,35.0166667,25.6833333 ],
    [ u"gr",u"Grammatikón",1334,38.2,23.9666667 ],
    [ u"gr",u"Grammatikoú",1061,38.5333333,21.5 ],
    [ u"gr",u"Grammenítsa",1193,39.1830556,20.9805556 ],
    [ u"gr",u"Grevená",10563,40.0833333,21.4166667 ],
    [ u"gr",u"Grízanon",1528,39.6333333,22.05 ],
    [ u"gr",u"Ialisós",11473,36.4,28.1666667 ],
    [ u"gr",u"Íasmos",2787,41.1333333,25.1833333 ],
    [ u"gr",u"Ierápetra",12536,35.01,25.7352778 ],
    [ u"gr",u"Ierissós",3135,40.4,23.8833333 ],
    [ u"gr",u"Igoumenítsa",9496,39.5038889,20.2655556 ],
    [ u"gr",u"Ioánnina",64012,39.6675,20.8508333 ],
    [ u"gr",u"Íos",1803,36.7333333,25.2833333 ],
    [ u"gr",u"Ípsos",769,39.6947222,19.8366667 ],
    [ u"gr",u"Iráklia",3424,41.1666667,23.2666667 ],
    [ u"gr",u"Iráklion",876,40.7666667,23.0333333 ],
    [ u"gr",u"Iráklion",47007,38.0666667,23.7666667 ],
    [ u"gr",u"Iráklion",137155,35.325,25.1305556 ],
    [ u"gr",u"Isthmía",1043,37.9166667,23.0 ],
    [ u"gr",u"Istiaía",4199,38.9558333,23.1527778 ],
    [ u"gr",u"Itéa",1301,39.4666667,22.1666667 ],
    [ u"gr",u"Itéa",4782,38.4333333,22.4166667 ],
    [ u"gr",u"Itháki",1842,38.3602778,20.7161111 ],
    [ u"gr",u"Kainoúryion",1214,38.8,22.7166667 ],
    [ u"gr",u"Kainoúryion",2946,38.6,21.5 ],
    [ u"gr",u"Kaisarianí",26126,37.9666667,23.8 ],
    [ u"gr",u"Kalamákion",820,37.7333333,20.9166667 ],
    [ u"gr",u"Kalamákion",40490,37.9166667,23.7166667 ],
    [ u"gr",u"Kalamariá",91617,40.5825,22.9502778 ],
    [ u"gr",u"Kalamáta",51108,37.0388889,22.1141667 ],
    [ u"gr",u"Kalambáka",8138,39.7044444,21.6269444 ],
    [ u"gr",u"Kalambákion",3514,41.05,24.1833333 ],
    [ u"gr",u"Kalamiá",1197,39.1655556,20.9316667 ],
    [ u"gr",u"Kálamos",2158,38.2833333,23.8666667 ],
    [ u"gr",u"Kalamotón",871,40.5666667,23.3666667 ],
    [ u"gr",u"Kalá Nerá",841,39.3,23.1166667 ],
    [ u"gr",u"Kalávrita",1629,38.0322222,22.1125 ],
    [ u"gr",u"Kalí",1773,40.82,22.1752778 ],
    [ u"gr",u"Kálimnos",10002,36.95,26.9833333 ],
    [ u"gr",u"Kalívai",1288,35.45,24.1666667 ],
    [ u"gr",u"Kalívai Poliyírou",1147,40.2833333,23.4 ],
    [ u"gr",u"Kalívia",1130,40.7561111,22.2136111 ],
    [ u"gr",u"Kalívia",990,38.6166667,21.3 ],
    [ u"gr",u"Kalívia Thorikoú",14712,37.8333333,23.9166667 ],
    [ u"gr",u"Kalí Vrísi",1163,41.15,23.9 ],
    [ u"gr",u"Kallífitos",1098,41.1666667,24.2166667 ],
    [ u"gr",u"Kallifónion",1208,39.2725,21.9561111 ],
    [ u"gr",u"Kallimasiá",895,38.2941667,26.1011111 ],
    [ u"gr",u"Kallithéa",976,40.0833333,23.45 ],
    [ u"gr",u"Kallithéa",1131,41.25,24.7333333 ],
    [ u"gr",u"Kallithéa",3100,40.2763889,22.5783333 ],
    [ u"gr",u"Kallithéa",107767,37.95,23.7 ],
    [ u"gr",u"Kallithéa",949,37.55,21.8166667 ],
    [ u"gr",u"Kallíthiron",1098,39.2816667,21.9061111 ],
    [ u"gr",u"Kalloní",1776,39.2327778,26.2080556 ],
    [ u"gr",u"Kalokhórion",4162,40.6413889,22.8566667 ],
    [ u"gr",u"Kalós Agrós",1275,41.1,24.0833333 ],
    [ u"gr",u"Kamárai",1200,38.3,22.0 ],
    [ u"gr",u"Kamárion",1166,38.1,22.5833333 ],
    [ u"gr",u"Kamárion",1599,36.8,25.8166667 ],
    [ u"gr",u"Kamariótissa",1022,40.4833333,25.4666667 ],
    [ u"gr",u"Kamaterón",24310,38.0666667,23.7 ],
    [ u"gr",u"Kambánis",1523,40.8880556,22.9102778 ],
    [ u"gr",u"Kambí",1027,39.2166667,20.9 ],
    [ u"gr",u"Kaména Voúrla",2881,38.7833333,22.7833333 ],
    [ u"gr",u"Kamínia",850,38.15,21.6166667 ],
    [ u"gr",u"Kanália",1144,39.5,22.8833333 ],
    [ u"gr",u"Kanálion",964,39.0652778,20.6986111 ],
    [ u"gr",u"Kanálion",3953,39.6055556,19.8925 ],
    [ u"gr",u"Kanallákion",2446,39.2336111,20.6 ],
    [ u"gr",u"Kandíla",1245,38.7,20.9333333 ],
    [ u"gr",u"Kapandrítion",2672,38.2166667,23.8833333 ],
    [ u"gr",u"Kaparéllion",1478,38.2333333,23.2166667 ],
    [ u"gr",u"Karátoulas",1004,37.7333333,21.5333333 ],
    [ u"gr",u"Kardámaina",1926,36.7813889,27.1425 ],
    [ u"gr",u"Kardamás",1138,37.7666667,21.3333333 ],
    [ u"gr",u"Kardiá",1751,40.4677778,22.9947222 ],
    [ u"gr",u"Kardítsa",32789,39.3655556,21.9216667 ],
    [ u"gr",u"Karditsomagoúla",2200,39.3919444,21.9241667 ],
    [ u"gr",u"Kariaí",237,40.25,24.25 ],
    [ u"gr",u"Kariaí",1048,37.3,22.5 ],
    [ u"gr",u"Kariá",994,38.7666667,20.65 ],
    [ u"gr",u"Kariótissa",1965,40.7683333,22.3052778 ],
    [ u"gr",u"Káristos",5091,38.0133333,24.4161111 ],
    [ u"gr",u"Karítsa",2225,40.1875,22.4819444 ],
    [ u"gr",u"Karotí",663,41.4,26.4166667 ],
    [ u"gr",u"Karousádes",993,39.7808333,19.7411111 ],
    [ u"gr",u"Kárpathos",2243,35.5,27.2333333 ],
    [ u"gr",u"Karpenísion",6888,38.9166667,21.7833333 ],
    [ u"gr",u"Karperí",1035,41.1166667,23.3 ],
    [ u"gr",u"Karpokhórion",1059,39.3333333,22.0166667 ],
    [ u"gr",u"Kassiópi",1165,39.7886111,19.9186111 ],
    [ u"gr",u"Kastanéai",1213,41.65,26.4666667 ],
    [ u"gr",u"Kastélla",1370,38.5666667,23.6333333 ],
    [ u"gr",u"Kastéllion",1828,35.2,25.3333333 ],
    [ u"gr",u"Kastoriá",14665,40.5166667,21.2666667 ],
    [ u"gr",u"Kastrákion",1172,39.7155556,21.6180556 ],
    [ u"gr",u"Kastrákion",912,38.4166667,21.9 ],
    [ u"gr",u"Kástron",818,38.5,23.1666667 ],
    [ u"gr",u"Katastárion",1321,37.8333333,20.7666667 ],
    [ u"gr",u"Kateríni",53294,40.2719444,22.5025 ],
    [ u"gr",u"Káto Akhaïa",5752,38.15,21.55 ],
    [ u"gr",u"Káto Asítai",1264,35.2,25.0 ],
    [ u"gr",u"Káto Ássos",1617,37.95,22.8333333 ],
    [ u"gr",u"Káto Glikóvrisi",1753,36.8333333,22.7833333 ],
    [ u"gr",u"Káto Kamíla",1398,41.0166667,23.4833333 ],
    [ u"gr",u"Katokhí",2850,38.4166667,21.25 ],
    [ u"gr",u"Káto Khoríon",1110,35.05,25.7833333 ],
    [ u"gr",u"Káto Korakiána",1055,39.6897222,19.8252778 ],
    [ u"gr",u"Káto Lekhónia",1751,39.3333333,23.0333333 ],
    [ u"gr",u"Káto Mazarákion",1005,38.0666667,21.65 ],
    [ u"gr",u"Káto Miléa",1286,40.2483333,22.3377778 ],
    [ u"gr",u"Káto Mitroúsion",662,41.0666667,23.45 ],
    [ u"gr",u"Káto Skholárion",1904,40.4333333,23.0333333 ],
    [ u"gr",u"Káto Soúlion",1493,38.1666667,24.0 ],
    [ u"gr",u"Káto Tithoréa",2753,38.6,22.7166667 ],
    [ u"gr",u"Katoúna",2235,38.7833333,21.1166667 ],
    [ u"gr",u"Katsikás",2993,39.6225,20.8875 ],
    [ u"gr",u"Kavála",59240,40.9397222,24.4019444 ],
    [ u"gr",u"Kavallárion",2025,40.7166667,23.05 ],
    [ u"gr",u"Kavásilas",1623,37.8666667,21.2666667 ],
    [ u"gr",u"Kavíli",1531,41.5666667,26.5166667 ],
    [ u"gr",u"Kávos",923,39.3838889,20.1133333 ],
    [ u"gr",u"Kéfalos",2528,36.7452778,26.9588889 ],
    [ u"gr",u"Kefalóvrison",1011,40.0144444,20.5625 ],
    [ u"gr",u"Kefalóvrison",959,39.5805556,21.6930556 ],
    [ u"gr",u"Kélla",746,40.7833333,21.6833333 ],
    [ u"gr",u"Keramotí",1338,40.8583333,24.7061111 ],
    [ u"gr",u"Keratéa",7701,37.8,23.9833333 ],
    [ u"gr",u"Keratsínion",77222,37.9625,23.6197222 ],
    [ u"gr",u"Kerkíni",1573,41.2166667,23.0833333 ],
    [ u"gr",u"Kérkira",27004,39.62,19.9197222 ],
    [ u"gr",u"Khalándrion",74211,38.0333333,23.8 ],
    [ u"gr",u"Khalandrítsa",949,38.1166667,21.7833333 ],
    [ u"gr",u"Khalástra",7360,40.6286111,22.7327778 ],
    [ u"gr",u"Khálki",1837,39.5666667,22.5333333 ],
    [ u"gr",u"Khalkís",54559,38.4636111,23.5994444 ],
    [ u"gr",u"Khalkoútsion",2293,38.3333333,23.7333333 ],
    [ u"gr",u"Khaniá",54565,35.5122222,24.0155556 ],
    [ u"gr",u"Khánion toú Kokkíni",1385,35.3333333,25.25 ],
    [ u"gr",u"Khaniótis",1177,40.0,23.5833333 ],
    [ u"gr",u"Kharíessa",926,40.6519444,22.1666667 ],
    [ u"gr",u"Kharopón",1523,41.2666667,23.3833333 ],
    [ u"gr",u"Khavárion",1467,37.85,21.3833333 ],
    [ u"gr",u"Khersónisos",938,35.3,25.3666667 ],
    [ u"gr",u"Khiliomodion",1769,37.8166667,22.8666667 ],
    [ u"gr",u"Khímarros",950,41.1166667,23.25 ],
    [ u"gr",u"Khíos",23953,38.3677778,26.1358333 ],
    [ u"gr",u"Kholargós",31545,38.0,23.8 ],
    [ u"gr",u"Khóra",3591,37.05,21.7166667 ],
    [ u"gr",u"Khóra",1498,37.7036111,26.9055556 ],
    [ u"gr",u"Khoríon",3331,36.9666667,26.9666667 ],
    [ u"gr",u"Khoristí",2719,41.1333333,24.2166667 ],
    [ u"gr",u"Khoríyion",928,40.9941667,22.7205556 ],
    [ u"gr",u"Khortiátis",3466,40.6,23.1 ],
    [ u"gr",u"Khrisókastron",767,40.8833333,24.1833333 ],
    [ u"gr",u"Khrisokhórafa",1302,41.1833333,23.2333333 ],
    [ u"gr",u"Khrisokhórion",1866,40.9333333,24.7166667 ],
    [ u"gr",u"Khrisón",2079,41.0666667,23.65 ],
    [ u"gr",u"Kiáto",10032,38.0166667,22.75 ],
    [ u"gr",u"Kifisiá",45755,38.0666667,23.8166667 ],
    [ u"gr",u"Kilkís",19734,40.9919444,22.8708333 ],
    [ u"gr",u"Killíni",1133,37.9333333,21.15 ],
    [ u"gr",u"Kími",2979,38.6333333,24.1 ],
    [ u"gr",u"Kímina",3775,40.6147222,22.6911111 ],
    [ u"gr",u"Kimméria",3423,41.15,24.9333333 ],
    [ u"gr",u"Kinéta",2004,37.9666667,23.2 ],
    [ u"gr",u"Kinopiástai",1463,39.5694444,19.8825 ],
    [ u"gr",u"Kiparissía",5033,37.2511111,21.6736111 ],
    [ u"gr",u"Kipía",737,40.8833333,24.2 ],
    [ u"gr",u"Kiprínos",1095,41.5755556,26.2305556 ],
    [ u"gr",u"Kipséli",2096,38.0,23.7333333 ],
    [ u"gr",u"Kirás Vrísi",1151,37.9166667,22.9833333 ],
    [ u"gr",u"Kiriákion",2227,38.35,22.7833333 ],
    [ u"gr",u"Kíria",1611,41.1,24.2833333 ],
    [ u"gr",u"Kírra",1348,38.4333333,22.45 ],
    [ u"gr",u"Kíssamos",4205,35.4938889,23.6569444 ],
    [ u"gr",u"Kítros",1412,40.3755556,22.5783333 ],
    [ u"gr",u"Kivérion",979,37.5166667,22.7333333 ],
    [ u"gr",u"Klítos",1382,40.4333333,21.8666667 ],
    [ u"gr",u"Koíla",1493,40.3333333,21.7833333 ],
    [ u"gr",u"Koilás",1126,37.4166667,23.1333333 ],
    [ u"gr",u"Koímisis",1490,41.2166667,23.3 ],
    [ u"gr",u"Kokkárion",1003,37.7763889,26.8938889 ],
    [ u"gr",u"Kokkínion",891,39.6105556,19.8102778 ],
    [ u"gr",u"Kokkinókhoma",1934,40.9333333,24.3 ],
    [ u"gr",u"Kókkinon",744,38.4833333,23.2333333 ],
    [ u"gr",u"Kokkónion",1221,37.9666667,22.7833333 ],
    [ u"gr",u"Kolimvári",1032,35.55,23.7833333 ],
    [ u"gr",u"Kolindrós",3590,40.4758333,22.4808333 ],
    [ u"gr",u"Kolkhikón",2010,40.75,23.1333333 ],
    [ u"gr",u"Kombótion",2150,39.1022222,21.0852778 ],
    [ u"gr",u"Komniná",1126,40.6,21.7833333 ],
    [ u"gr",u"Komotiní",45630,41.1227778,25.3963889 ],
    [ u"gr",u"Kónitsa",2875,40.0486111,20.7566667 ],
    [ u"gr",u"Kontariótissa",2088,40.2288889,22.4622222 ],
    [ u"gr",u"Kontokálion",1798,39.6452778,19.8494444 ],
    [ u"gr",u"Kopanós",2202,40.6336111,22.1302778 ],
    [ u"gr",u"Korifí",1552,40.6,22.5 ],
    [ u"gr",u"Korinós",4191,40.315,22.5852778 ],
    [ u"gr",u"Kórinthos",30900,37.9166667,22.8833333 ],
    [ u"gr",u"Korisós",1389,40.5,21.3833333 ],
    [ u"gr",u"Kormísta",1008,40.9833333,24.05 ],
    [ u"gr",u"Koromiléa",774,41.0741667,22.8480556 ],
    [ u"gr",u"Koróni",1620,36.8,21.95 ],
    [ u"gr",u"Koropíon",17151,37.9,23.8833333 ],
    [ u"gr",u"Kos",19244,36.8933333,27.2888889 ],
    [ u"gr",u"Kostakioí",1417,39.1375,20.9588889 ],
    [ u"gr",u"Kostaléxis",951,38.85,22.3666667 ],
    [ u"gr",u"Kostarázion",935,40.4333333,21.3333333 ],
    [ u"gr",u"Koufália",8305,40.7777778,22.5719444 ],
    [ u"gr",u"Koufóvounon",883,41.35,26.4333333 ],
    [ u"gr",u"Kouloúra",1156,40.5452778,22.3180556 ],
    [ u"gr",u"Koutouloufárion",751,35.3,25.3833333 ],
    [ u"gr",u"Koutsélion",1177,39.5888889,20.9141667 ],
    [ u"gr",u"Koutsourás",869,35.0333333,25.95 ],
    [ u"gr",u"Kouvarás",1381,37.8333333,23.9666667 ],
    [ u"gr",u"Kozáni",36481,40.3011111,21.7863889 ],
    [ u"gr",u"Kranéa Elassónos",2936,39.9483333,21.9658333 ],
    [ u"gr",u"Kranídion",4442,37.3816667,23.1552778 ],
    [ u"gr",u"Kremastí",4700,36.4,28.1166667 ],
    [ u"gr",u"Kréstena",4733,37.6166667,21.6333333 ],
    [ u"gr",u"Kría Vrísi",6839,40.6872222,22.3022222 ],
    [ u"gr",u"Krikellos",1312,38.95,21.1833333 ],
    [ u"gr",u"Kríni",845,39.6166667,22.0166667 ],
    [ u"gr",u"Krionérion",928,40.8166667,23.2833333 ],
    [ u"gr",u"Krionérion",3393,38.15,23.8333333 ],
    [ u"gr",u"Krionérion",968,37.9666667,22.6333333 ],
    [ u"gr",u"Kristallopiyí",699,40.6380556,21.0852778 ],
    [ u"gr",u"Kristóni",1195,40.9555556,22.8552778 ],
    [ u"gr",u"Krithiá",1374,40.8411111,22.9777778 ],
    [ u"gr",u"Kritsá",1560,35.1666667,25.65 ],
    [ u"gr",u"Krokeaí",1329,36.8833333,22.55 ],
    [ u"gr",u"Krókos",3004,40.2666667,21.8166667 ],
    [ u"gr",u"Krousón",2811,35.2333333,24.9833333 ],
    [ u"gr",u"Lagós",1535,41.45,26.4666667 ],
    [ u"gr",u"Lakkíon",1956,37.1333333,26.85 ],
    [ u"gr",u"Lákkoma",1280,40.3833333,23.05 ],
    [ u"gr",u"Lálas",1168,37.7166667,21.7166667 ],
    [ u"gr",u"Lamía",47246,38.9,22.4333333 ],
    [ u"gr",u"Lápas",1377,38.1,21.4166667 ],
    [ u"gr",u"Lárdos",1348,36.1,28.0166667 ],
    [ u"gr",u"Lárimna",1196,38.5666667,23.2833333 ],
    [ u"gr",u"Lárisa",128760,39.6372222,22.4202778 ],
    [ u"gr",u"Lávara",1447,41.2666667,26.3833333 ],
    [ u"gr",u"Layiná",2649,40.7230556,23.0 ],
    [ u"gr",u"Lekhainá",3714,37.9333333,21.2666667 ],
    [ u"gr",u"Lékhaion",4837,37.9333333,22.85 ],
    [ u"gr",u"Lékhovon",1188,40.5833333,21.4833333 ],
    [ u"gr",u"Leonídion",3020,37.1686111,22.8552778 ],
    [ u"gr",u"Lepenoú",2170,38.7,21.2833333 ],
    [ u"gr",u"Lianovéryion",1712,40.6377778,22.5030556 ],
    [ u"gr",u"Liapádes",928,39.6694444,19.7363889 ],
    [ u"gr",u"Lidoríkion",840,38.5238889,22.1997222 ],
    [ u"gr",u"Ligourión",2817,37.6166667,23.0333333 ],
    [ u"gr",u"Líkion",1081,41.05,25.6833333 ],
    [ u"gr",u"Likoporiá",801,38.1333333,22.5166667 ],
    [ u"gr",u"Likóvrisi",9087,38.0666667,23.7833333 ],
    [ u"gr",u"Limenária",2503,40.6333333,24.5833333 ],
    [ u"gr",u"Limín Khersonísou",3103,35.3166667,25.3833333 ],
    [ u"gr",u"Límnai",862,37.7166667,22.8833333 ],
    [ u"gr",u"Límni",2072,38.7666667,23.3166667 ],
    [ u"gr",u"Lithakiá",1300,37.7166667,20.8333333 ],
    [ u"gr",u"Lití",3226,40.7452778,22.9786111 ],
    [ u"gr",u"Litókhoron",6709,40.1005556,22.4977778 ],
    [ u"gr",u"Livaderón",1663,40.0333333,21.9333333 ],
    [ u"gr",u"Livádi",2655,40.125,22.1516667 ],
    [ u"gr",u"Livanátai",3142,38.7166667,23.05 ],
    [ u"gr",u"Lixoúrion",3758,38.2019444,20.4313889 ],
    [ u"gr",u"Lófos",1772,40.2447222,22.3797222 ],
    [ u"gr",u"Longá",983,36.8666667,21.9 ],
    [ u"gr",u"Loudías",981,40.6772222,22.5413889 ],
    [ u"gr",u"Loukísia",1038,38.4833333,23.45 ],
    [ u"gr",u"Loúros",2034,39.1627778,20.7519444 ],
    [ u"gr",u"Loutrá Ipátis",579,38.9,22.2833333 ],
    [ u"gr",u"Loutrákion",12276,37.9833333,22.9666667 ],
    [ u"gr",u"Loutrá",1115,39.0569444,26.545 ],
    [ u"gr",u"Loutrós",984,40.8791667,26.0436111 ],
    [ u"gr",u"Loutrós",1296,40.5883333,22.3994444 ],
    [ u"gr",u"Magoúla",1036,39.4555556,21.8027778 ],
    [ u"gr",u"Magoúla",1552,38.4166667,23.8333333 ],
    [ u"gr",u"Magoúla",4219,38.0833333,23.5166667 ],
    [ u"gr",u"Magoúla",1545,37.0833333,22.4166667 ],
    [ u"gr",u"Makrakómi",2065,38.9333333,22.1166667 ],
    [ u"gr",u"Makrikápa",878,38.6166667,23.75 ],
    [ u"gr",u"Makrikhórion",1835,39.8,22.4833333 ],
    [ u"gr",u"Makrikhórion",1188,39.44,21.9663889 ],
    [ u"gr",u"Makrinítsa",1014,39.4,22.9833333 ],
    [ u"gr",u"Makrísia",1902,37.6166667,21.6 ],
    [ u"gr",u"Makríyialos",2009,40.4163889,22.6027778 ],
    [ u"gr",u"Makrokhórion",4965,40.5513889,22.25 ],
    [ u"gr",u"Malesína",4281,38.6166667,23.2333333 ],
    [ u"gr",u"Mália",4343,35.2833333,25.4666667 ],
    [ u"gr",u"Mándalon",1204,40.8583333,22.2097222 ],
    [ u"gr",u"Mándra",11294,38.0666667,23.5 ],
    [ u"gr",u"Maniákoi",2771,40.5,21.25 ],
    [ u"gr",u"Manolás",1650,38.05,21.35 ],
    [ u"gr",u"Mantamádos",1120,39.3116667,26.3338889 ],
    [ u"gr",u"Mantoúdion",1794,38.8,23.4833333 ],
    [ u"gr",u"Marathókambos",1268,37.7263889,26.69 ],
    [ u"gr",u"Marathón",4051,38.15,23.9666667 ],
    [ u"gr",u"Marathópolis",877,37.0666667,21.5833333 ],
    [ u"gr",u"Marína",1091,40.6961111,22.1008333 ],
    [ u"gr",u"Markópoulon",4214,38.2833333,23.8333333 ],
    [ u"gr",u"Marmárion",1013,38.05,24.3166667 ],
    [ u"gr",u"Mármaron",953,38.5408333,26.1130556 ],
    [ u"gr",u"Martínon",3038,38.5666667,23.2166667 ],
    [ u"gr",u"Megála Kalívia",2092,39.5,21.7875 ],
    [ u"gr",u"Megáli Khóra",1191,38.6333333,21.3666667 ],
    [ u"gr",u"Megáli Panayía",2782,40.45,23.6833333 ],
    [ u"gr",u"Megáli Vrísi",963,38.8833333,22.4833333 ],
    [ u"gr",u"Megalokhórion",741,41.25,23.2166667 ],
    [ u"gr",u"Megalokhórion",1564,39.5594444,21.8408333 ],
    [ u"gr",u"Megalópoli",5283,37.4011111,22.1422222 ],
    [ u"gr",u"Méga Pistón",966,41.15,25.3 ],
    [ u"gr",u"Mégara",24047,38.0,23.3455556 ],
    [ u"gr",u"Meligalás",1431,37.2166667,21.9666667 ],
    [ u"gr",u"Melíki",3033,40.5166667,22.3952778 ],
    [ u"gr",u"Melíssia",22385,38.05,23.8333333 ],
    [ u"gr",u"Melíssion",1024,40.7741667,22.3441667 ],
    [ u"gr",u"Melíssion",864,38.05,22.6833333 ],
    [ u"gr",u"Melissokhórion",2002,40.7666667,22.925 ],
    [ u"gr",u"Melissourgoí",593,39.5094444,21.1466667 ],
    [ u"gr",u"Melíti",1521,40.8333333,21.5833333 ],
    [ u"gr",u"Melívoia",1249,39.75,22.8 ],
    [ u"gr",u"Meneméni",15706,40.6569444,22.9 ],
    [ u"gr",u"Menídion",1110,39.0419444,21.1177778 ],
    [ u"gr",u"Mesariá",1233,36.4,25.45 ],
    [ u"gr",u"Mesimérion",899,40.7905556,22.0222222 ],
    [ u"gr",u"Mesimérion",1491,40.4166667,23.0 ],
    [ u"gr",u"Mesolóngion",12702,38.3691667,21.4291667 ],
    [ u"gr",u"Mesopotamiá",1812,40.5,21.1666667 ],
    [ u"gr",u"Messíni",6773,37.0511111,22.0077778 ],
    [ u"gr",u"Metamórfosis",873,40.2333333,23.6 ],
    [ u"gr",u"Metaxádes",818,41.4219444,26.2252778 ],
    [ u"gr",u"Méthana",1183,37.5833333,23.3833333 ],
    [ u"gr",u"Methóni",973,40.4483333,22.5869444 ],
    [ u"gr",u"Methóni",1166,36.8166667,21.7 ],
    [ u"gr",u"Métsovon",3305,39.7694444,21.1822222 ],
    [ u"gr",u"Míki",1130,41.25,24.9166667 ],
    [ u"gr",u"Míkonos",7739,37.45,25.3333333 ],
    [ u"gr",u"Mikrókambos",1207,40.8386111,22.7697222 ],
    [ u"gr",u"Mikrománi",997,37.0833333,22.0333333 ],
    [ u"gr",u"Mikrón Monastírion",1518,40.7058333,22.5413889 ],
    [ u"gr",u"Mikrópolis",1094,41.2,23.8166667 ],
    [ u"gr",u"Miléai",577,39.3333333,23.15 ],
    [ u"gr",u"Miléa",426,40.2502778,22.2958333 ],
    [ u"gr",u"Milésion",1121,38.2833333,23.8 ],
    [ u"gr",u"Míloi",833,37.55,22.7166667 ],
    [ u"gr",u"Mílos",844,36.75,24.4333333 ],
    [ u"gr",u"Mírina",5406,39.8797222,25.0741667 ],
    [ u"gr",u"Mirsíni",1213,37.9166667,21.2333333 ],
    [ u"gr",u"Míthimna",1558,39.3666667,26.1666667 ],
    [ u"gr",u"Mítikas",934,38.6666667,20.9333333 ],
    [ u"gr",u"Mítikas",1632,38.4333333,23.65 ],
    [ u"gr",u"Mitilíni",28322,39.11,26.5547222 ],
    [ u"gr",u"Mitilinioí",2255,37.7286111,26.9083333 ],
    [ u"gr",u"Mitrópoli",1572,39.3394444,21.8369444 ],
    [ u"gr",u"Moírai",6450,35.05,24.8666667 ],
    [ u"gr",u"Mokhós",1132,35.2666667,25.4166667 ],
    [ u"gr",u"Moláoi",3018,36.8002778,22.8558333 ],
    [ u"gr",u"Mólos",3280,38.8166667,22.65 ],
    [ u"gr",u"Monastirákion",1299,38.85,20.95 ],
    [ u"gr",u"Monóspita",897,40.6172222,22.1769444 ],
    [ u"gr",u"Morfovoúnion",1271,39.3525,21.75 ],
    [ u"gr",u"Mória",1176,39.1333333,26.5166667 ],
    [ u"gr",u"Moskháton",23533,37.95,23.6666667 ],
    [ u"gr",u"Moskhokhórion",763,38.8333333,22.45 ],
    [ u"gr",u"Moúlkion",1316,38.0,22.7333333 ],
    [ u"gr",u"Mouriaí",988,41.2494444,22.7905556 ],
    [ u"gr",u"Mourniés",6879,35.4763889,24.0091667 ],
    [ u"gr",u"Mousthéni",1159,40.8666667,24.1166667 ],
    [ u"gr",u"Mouzákion",2127,39.4297222,21.6636111 ],
    [ u"gr",u"Mouzákion",1545,37.7333333,20.8166667 ],
    [ u"gr",u"Mouzourás",1462,35.5333333,24.15 ],
    [ u"gr",u"Náousa",19887,40.6294444,22.0680556 ],
    [ u"gr",u"Náousa",2596,37.1166667,25.2333333 ],
    [ u"gr",u"Nauplion",14582,37.5636111,22.8075 ],
    [ u"gr",u"Náxos",7574,37.1055556,25.3763889 ],
    [ u"gr",u"Néa Alikarnassós",11886,35.3333333,25.15 ],
    [ u"gr",u"Néa Ankhíalos",5908,39.2833333,22.8166667 ],
    [ u"gr",u"Néa Apollonía",1953,40.6333333,23.45 ],
    [ u"gr",u"Néa Artáki",9193,38.5166667,23.6333333 ],
    [ u"gr",u"Néa Éfesos",2006,40.23,22.4963889 ],
    [ u"gr",u"Néa Erithraía",16432,38.1,23.8166667 ],
    [ u"gr",u"Néa Fókaia",1941,40.1333333,23.4 ],
    [ u"gr",u"Néa Ionía",67835,38.0333333,23.75 ],
    [ u"gr",u"Néa Iraklítsa",1147,40.8644444,24.3158333 ],
    [ u"gr",u"Néa Kallikrátia",7078,40.3166667,23.0666667 ],
    [ u"gr",u"Néa Kariá",1820,40.9075,24.7083333 ],
    [ u"gr",u"Néa Karváli",2380,40.9616667,24.51 ],
    [ u"gr",u"Néa Kerasiá",1300,40.3666667,23.2333333 ],
    [ u"gr",u"Néa Kíos",4214,37.5833333,22.75 ],
    [ u"gr",u"Néa Magnisía",4144,40.6875,22.8469444 ],
    [ u"gr",u"Néa Mákri",14723,38.0833333,23.9833333 ],
    [ u"gr",u"Néa Málgara",2476,40.6094444,22.6816667 ],
    [ u"gr",u"Néa Manolás",2219,38.05,21.3833333 ],
    [ u"gr",u"Néa Mesimvría",2349,40.7513889,22.7625 ],
    [ u"gr",u"Néa Mikhanióna",7908,40.4644444,22.8608333 ],
    [ u"gr",u"Néa Palátia",2400,38.3166667,23.8 ],
    [ u"gr",u"Néa Pélla",1595,40.7661111,22.4855556 ],
    [ u"gr",u"Néa Péramos",2642,40.8388889,24.3036111 ],
    [ u"gr",u"Néa Péramos",7705,38.0,23.4333333 ],
    [ u"gr",u"Néa Pláyia",1332,40.2666667,23.2 ],
    [ u"gr",u"Neápolis",2809,35.2538889,25.6097222 ],
    [ u"gr",u"Néa Sánta",1420,40.8416667,22.9144444 ],
    [ u"gr",u"Néa Smírni",75421,37.95,23.7166667 ],
    [ u"gr",u"Néa Stíra",1061,38.1833333,24.2 ],
    [ u"gr",u"Néa Tírins",1305,37.6,22.8166667 ],
    [ u"gr",u"Néa Tríglia",3028,40.3,23.2 ],
    [ u"gr",u"Néa Víssa",2673,41.5833333,26.5333333 ],
    [ u"gr",u"Néa Zíkhni",2400,41.0330556,23.8297222 ],
    [ u"gr",u"Neméa",4344,37.8166667,22.6666667 ],
    [ u"gr",u"Nénita",1032,38.2388889,26.0930556 ],
    [ u"gr",u"Néoi Epivátai",5077,40.5002778,22.9111111 ],
    [ u"gr",u"Neokaisária",805,39.5866667,20.8777778 ],
    [ u"gr",u"Neokhórion",1160,41.5166667,26.45 ],
    [ u"gr",u"Neokhórion",1189,41.1833333,23.25 ],
    [ u"gr",u"Neokhórion",2103,39.0694444,21.0188889 ],
    [ u"gr",u"Neokhórion",1121,39.2769444,21.7330556 ],
    [ u"gr",u"Neokhórion",3116,38.4166667,21.2833333 ],
    [ u"gr",u"Neokhórion",1105,37.9166667,21.2 ],
    [ u"gr",u"Neokhorópoulon",1088,39.6286111,20.8341667 ],
    [ u"gr",u"Néon Ayionérion",1649,40.8086111,22.7002778 ],
    [ u"gr",u"Néon Karlovásion",5925,37.7902778,26.7044444 ],
    [ u"gr",u"Néon Monastírion",1497,39.2333333,22.25 ],
    [ u"gr",u"Néon Petrítsion",2322,41.2833333,23.3 ],
    [ u"gr",u"Néon Rísion",3012,40.4966667,22.9886111 ],
    [ u"gr",u"Néon Soúlion",2725,41.1,23.65 ],
    [ u"gr",u"Néos Marmarás",3013,40.1,23.7833333 ],
    [ u"gr",u"Néos Milótopos",2835,40.8163889,22.3463889 ],
    [ u"gr",u"Néos Oropós",1375,39.1513889,20.7366667 ],
    [ u"gr",u"Néos Pírgos",932,41.5,26.5 ],
    [ u"gr",u"Néos Pírgos",890,38.9333333,23.0666667 ],
    [ u"gr",u"Néos Skopós",2560,41.0166667,23.6166667 ],
    [ u"gr",u"Nerokoúros",4388,35.4833333,24.0333333 ],
    [ u"gr",u"Nestórion",884,40.4127778,21.0622222 ],
    [ u"gr",u"Nigríta",5320,40.9052778,23.4994444 ],
    [ u"gr",u"Níkaia",3274,39.5666667,22.4666667 ],
    [ u"gr",u"Níkaia",94608,37.9666667,23.65 ],
    [ u"gr",u"Nikísiani",2454,40.95,24.15 ],
    [ u"gr",u"Nikóklia",1502,40.9333333,23.4333333 ],
    [ u"gr",u"Nisíon",1473,40.6369444,22.3877778 ],
    [ u"gr",u"Oía",934,36.4666667,25.3666667 ],
    [ u"gr",u"Oinófita",2971,38.3166667,23.6333333 ],
    [ u"gr",u"Oinóï",898,38.1666667,23.4166667 ],
    [ u"gr",u"Oinoússai",1182,38.5141667,26.2202778 ],
    [ u"gr",u"Ólinthos",1155,40.2833333,23.35 ],
    [ u"gr",u"Omvriakí",1213,39.1,22.2666667 ],
    [ u"gr",u"Oraiókastron",15006,40.7308333,22.9172222 ],
    [ u"gr",u"Oreoí",1293,38.95,23.1 ],
    [ u"gr",u"Orestiás",16221,41.5030556,26.5297222 ],
    [ u"gr",u"Orkhomenós",5920,38.5,22.9833333 ],
    [ u"gr",u"Orménion",750,41.7191667,26.2144444 ],
    [ u"gr",u"Ormília",3436,40.3,23.55 ],
    [ u"gr",u"Órmos Korthíou",903,37.7666667,24.95 ],
    [ u"gr",u"Othonoí",761,39.8436111,19.4097222 ],
    [ u"gr",u"Ouranópolis",1047,40.3333333,23.9833333 ],
    [ u"gr",u"Ovriá",5838,38.1833333,21.7166667 ],
    [ u"gr",u"Oxílithos",1062,38.5833333,24.1166667 ],
    [ u"gr",u"Pagóndas",695,37.6727778,26.8319444 ],
    [ u"gr",u"Pagoúria",843,41.0333333,25.3166667 ],
    [ u"gr",u"Paianía",14246,37.95,23.85 ],
    [ u"gr",u"Pákhni",1110,41.3,24.9 ],
    [ u"gr",u"Palaiá Fókaia",2824,37.7166667,23.95 ],
    [ u"gr",u"Palaífiton",1475,40.7816667,22.2661111 ],
    [ u"gr",u"Palaíkastron",1094,35.2,26.25 ],
    [ u"gr",u"Palaiokhóra",923,40.5,23.45 ],
    [ u"gr",u"Palaiokhóra",2372,35.2333333,23.6833333 ],
    [ u"gr",u"Palaiokhórion",1607,40.95,24.1833333 ],
    [ u"gr",u"Palaiokhórion",1474,40.5,23.65 ],
    [ u"gr",u"Palaiókipos",1184,39.0558333,26.4511111 ],
    [ u"gr",u"Palaiokómi",1862,40.8666667,23.9 ],
    [ u"gr",u"Palaiománina",855,38.55,21.2333333 ],
    [ u"gr",u"Palaiomonástiron",1182,39.4625,21.6586111 ],
    [ u"gr",u"Palaión Ayionérion",997,40.8133333,22.7216667 ],
    [ u"gr",u"Palaión Fáliron",66292,37.9333333,23.7 ],
    [ u"gr",u"Palaiópirgos",1035,39.6072222,21.8172222 ],
    [ u"gr",u"Pálairos",2589,38.7833333,20.8833333 ],
    [ u"gr",u"Palamás",5719,39.4666667,22.0833333 ],
    [ u"gr",u"Paliámbela",996,38.9166667,20.95 ],
    [ u"gr",u"Pallíni",14808,38.0,23.8833333 ],
    [ u"gr",u"Pámfila",1251,39.1566667,26.5216667 ],
    [ u"gr",u"Panaitólion",2915,38.5833333,21.45 ],
    [ u"gr",u"Panórama",16551,40.5833333,23.0333333 ],
    [ u"gr",u"Pánormos",1157,35.4166667,24.7 ],
    [ u"gr",u"Papágos",12903,37.9833333,23.8166667 ],
    [ u"gr",u"Pappadátai",1313,39.3133333,20.7925 ],
    [ u"gr",u"Pappádos",1534,39.0394444,26.4547222 ],
    [ u"gr",u"Pappayiánnis",1055,40.8333333,21.5 ],
    [ u"gr",u"Parákoila",881,39.1666667,26.1333333 ],
    [ u"gr",u"Paralía",1801,40.2680556,22.5952778 ],
    [ u"gr",u"Paralía",804,38.3833333,23.6333333 ],
    [ u"gr",u"Paralía",7299,38.2,21.7 ],
    [ u"gr",u"Parálion Ástros",827,37.4166667,22.7666667 ],
    [ u"gr",u"Paramithiá",2569,39.4711111,20.5111111 ],
    [ u"gr",u"Parapótamos",1126,39.5491667,20.3227778 ],
    [ u"gr",u"Paravóla",1215,38.6166667,21.5166667 ],
    [ u"gr",u"Párga",2379,39.2830556,20.3963889 ],
    [ u"gr",u"Páros",5289,37.0833333,25.15 ],
    [ u"gr",u"Pásion",1150,38.0166667,22.7333333 ],
    [ u"gr",u"Patitírion",1647,39.15,23.8666667 ],
    [ u"gr",u"Pátrai",163361,38.2444444,21.7344444 ],
    [ u"gr",u"Patrís",1330,40.5611111,22.1861111 ],
    [ u"gr",u"Pediní",2128,39.5997222,20.8433333 ],
    [ u"gr",u"Pedinón",1133,40.9088889,22.8666667 ],
    [ u"gr",u"Pelasyía",1586,38.95,22.8333333 ],
    [ u"gr",u"Pélla",2476,40.76,22.5191667 ],
    [ u"gr",u"Pelópion",1073,37.6833333,21.5833333 ],
    [ u"gr",u"Pentálofos",2107,40.7416667,22.8519444 ],
    [ u"gr",u"Pentaplátanon",1015,40.8166667,22.4086111 ],
    [ u"gr",u"Pentápolis",1607,41.05,23.6833333 ],
    [ u"gr",u"Péplos",1037,40.9583333,26.2655556 ],
    [ u"gr",u"Peraía",16067,40.5002778,22.925 ],
    [ u"gr",u"Perakhóra",1246,38.0333333,22.95 ],
    [ u"gr",u"Pérama",3066,39.6952778,20.8486111 ],
    [ u"gr",u"Pérama",26288,37.9680556,23.565 ],
    [ u"gr",u"Pérama",1655,35.3697222,24.6972222 ],
    [ u"gr",u"Pérdika",1875,39.3688889,20.3038889 ],
    [ u"gr",u"Perístasis",2454,40.2741667,22.5411111 ],
    [ u"gr",u"Peristerá",1137,40.55,23.1666667 ],
    [ u"gr",u"Peristérion",137660,38.0166667,23.7 ],
    [ u"gr",u"Perivólia",3320,35.4833333,23.9833333 ],
    [ u"gr",u"Perivólion",1432,39.4205556,20.0147222 ],
    [ u"gr",u"Periyiálion",2042,37.95,22.8333333 ],
    [ u"gr",u"Pérni",913,41.0,24.6333333 ],
    [ u"gr",u"Péta",1952,39.1666667,21.0347222 ],
    [ u"gr",u"Petinós",1014,41.1,24.9 ],
    [ u"gr",u"Petraía",939,40.7208333,22.1444444 ],
    [ u"gr",u"Pétra",1299,39.3333333,26.1833333 ],
    [ u"gr",u"Petrokhórion",1052,41.1166667,24.8333333 ],
    [ u"gr",u"Petrotón",842,39.5861111,21.9630556 ],
    [ u"gr",u"Petroússa",1985,41.2,24.0166667 ],
    [ u"gr",u"Pigaí",1037,40.9041667,24.6708333 ],
    [ u"gr",u"Pikérmion",1385,38.0,23.95 ],
    [ u"gr",u"Pilaía",23494,40.6005556,22.9875 ],
    [ u"gr",u"Pilíon",2430,36.8477778,27.1613889 ],
    [ u"gr",u"Píli",1791,39.4580556,21.6188889 ],
    [ u"gr",u"Pílos",2135,36.91,21.6986111 ],
    [ u"gr",u"Pírgos",22402,37.6833333,21.45 ],
    [ u"gr",u"Pírgos",1134,35.0,25.15 ],
    [ u"gr",u"Piryetós",1681,39.9186111,22.5927778 ],
    [ u"gr",u"Piryíon",1002,38.2258333,25.9952778 ],
    [ u"gr",u"Pithárion",1302,35.5166667,24.0833333 ],
    [ u"gr",u"Piyí",1158,39.5119444,21.7011111 ],
    [ u"gr",u"Plános",1033,37.8166667,20.85 ],
    [ u"gr",u"Plataiaí",919,38.2166667,23.2666667 ],
    [ u"gr",u"Plátanos",745,40.5647222,22.5494444 ],
    [ u"gr",u"Plátanos",1764,37.6666667,21.6166667 ],
    [ u"gr",u"Plátanos",1077,35.4666667,23.6 ],
    [ u"gr",u"Platariá",1044,39.4525,20.2761111 ],
    [ u"gr",u"Platíkambos",1889,39.6166667,22.5333333 ],
    [ u"gr",u"Platí",2228,40.6402778,22.5338889 ],
    [ u"gr",u"Playiá",939,38.8,20.7666667 ],
    [ u"gr",u"Playiárion",4561,40.4741667,22.9572222 ],
    [ u"gr",u"Plomárion",3338,38.9766667,26.3680556 ],
    [ u"gr",u"Polikárpion",1045,40.9272222,22.0136111 ],
    [ u"gr",u"Políkastron",6961,40.9936111,22.5658333 ],
    [ u"gr",u"Políkhni",39765,40.6616667,22.9463889 ],
    [ u"gr",u"Polikhnítos",2667,39.0811111,26.1833333 ],
    [ u"gr",u"Políkhronon",1174,40.0166667,23.5333333 ],
    [ u"gr",u"Poliplátanos",892,40.6825,22.1913889 ],
    [ u"gr",u"Politiká",1499,38.6,23.55 ],
    [ u"gr",u"Políyiros",5258,40.3744444,23.4383333 ],
    [ u"gr",u"Pómbia",953,35.0166667,24.8666667 ],
    [ u"gr",u"Póros",1059,38.15,20.7833333 ],
    [ u"gr",u"Póros",4454,37.4994444,23.4536111 ],
    [ u"gr",u"Portariá",1468,40.2833333,23.3 ],
    [ u"gr",u"Portariá",1429,39.3833333,23.0 ],
    [ u"gr",u"Portokhélion",2219,37.3166667,23.15 ],
    [ u"gr",u"Potamiá",1260,40.7166667,24.7333333 ],
    [ u"gr",u"Potamós",2556,39.625,19.8755556 ],
    [ u"gr",u"Prámanta",1570,39.5230556,21.1013889 ],
    [ u"gr",u"Préveza",17283,38.95,20.75 ],
    [ u"gr",u"Prínos",1174,40.7333333,24.6166667 ],
    [ u"gr",u"Proástion",1766,39.4886111,21.9025 ],
    [ u"gr",u"Pródromos",994,39.3752778,21.9752778 ],
    [ u"gr",u"Profítis Ilías",1225,40.8127778,22.1569444 ],
    [ u"gr",u"Profítis Ilías",1482,35.2,25.1 ],
    [ u"gr",u"Profítis",963,40.6833333,23.2833333 ],
    [ u"gr",u"Prókhoma",1422,40.7969444,22.6583333 ],
    [ u"gr",u"Prokópion",1108,38.7333333,23.4833333 ],
    [ u"gr",u"Prómakhoi",1809,41.0252778,22.0 ],
    [ u"gr",u"Prosotsáni",4021,41.1833333,23.9666667 ],
    [ u"gr",u"Próti",1783,40.95,24.0 ],
    [ u"gr",u"Provatás",1275,41.0666667,23.3833333 ],
    [ u"gr",u"Provatón",766,41.0225,26.2583333 ],
    [ u"gr",u"Psakhná",5828,38.5833333,23.6333333 ],
    [ u"gr",u"Psikhikón",1142,41.0,23.6333333 ],
    [ u"gr",u"Psikhikón",10995,38.0166667,23.7666667 ],
    [ u"gr",u"Pteleós",1349,39.05,22.95 ],
    [ u"gr",u"Ptolemais",30045,40.5147222,21.6786111 ],
    [ u"gr",u"Rafína",12745,38.0166667,24.0 ],
    [ u"gr",u"Rapsáni",909,39.9022222,22.5488889 ],
    [ u"gr",u"Rentína",828,39.0638889,21.9752778 ],
    [ u"gr",u"Réthimnon",29907,35.3647222,24.4713889 ],
    [ u"gr",u"Ríon",6084,38.3,21.7833333 ],
    [ u"gr",u"Ritíni",1711,40.2869444,22.2808333 ],
    [ u"gr",u"Rizárion",1098,40.7872222,22.0838889 ],
    [ u"gr",u"Rizarión",821,39.5383333,21.7997222 ],
    [ u"gr",u"Rízia",1645,41.6166667,26.4333333 ],
    [ u"gr",u"Rízoma",1410,39.665,21.735 ],
    [ u"gr",u"Rizómata",1157,40.3472222,22.2036111 ],
    [ u"gr",u"Rizómilos",1594,39.4333333,22.75 ],
    [ u"gr",u"Rizón",1106,40.7338889,22.1358333 ],
    [ u"gr",u"Rodópolis",1250,41.2577778,22.9983333 ],
    [ u"gr",u"Ródos",56128,36.4408333,28.2225 ],
    [ u"gr",u"Rodotópion",1130,39.7083333,20.7258333 ],
    [ u"gr",u"Roviaí",1206,38.8166667,23.2333333 ],
    [ u"gr",u"Royítika",1206,38.1833333,21.6833333 ],
    [ u"gr",u"Salamís",26964,37.9666667,23.4833333 ],
    [ u"gr",u"Samarína",839,40.1013889,21.0152778 ],
    [ u"gr",u"Sámi",1347,38.2541667,20.6513889 ],
    [ u"gr",u"Sámos",6389,37.7572222,26.9769444 ],
    [ u"gr",u"Sápai",4506,41.0286111,25.6930556 ],
    [ u"gr",u"Sardínia",1064,38.8833333,21.2 ],
    [ u"gr",u"Sárti",1258,40.1,23.9833333 ],
    [ u"gr",u"Savália",1339,37.8166667,21.2833333 ],
    [ u"gr",u"Séleron",1811,41.1333333,25.0 ],
    [ u"gr",u"Selianítika",1210,38.2833333,22.0333333 ],
    [ u"gr",u"Selínia",2331,37.9336111,23.5336111 ],
    [ u"gr",u"Sérrai",55886,41.0855556,23.5497222 ],
    [ u"gr",u"Sérvia",3390,40.1797222,21.9944444 ],
    [ u"gr",u"Sevastianá",1561,40.7680556,22.1202778 ],
    [ u"gr",u"Sevastí",842,40.3586111,22.5438889 ],
    [ u"gr",u"Siátista",5612,40.2619444,21.5441667 ],
    [ u"gr",u"Sidirókastron",5825,41.2347222,23.3866667 ],
    [ u"gr",u"Sikéai",44955,40.6494444,22.9508333 ],
    [ u"gr",u"Sikéa",2336,40.0333333,23.9333333 ],
    [ u"gr",u"Sikéa",1031,36.7666667,22.9333333 ],
    [ u"gr",u"Sikión",1131,37.9833333,22.7333333 ],
    [ u"gr",u"Sikoúrion",2318,39.7583333,22.5786111 ],
    [ u"gr",u"Silivainiótika",1595,38.1666667,22.3333333 ],
    [ u"gr",u"Sími",2508,36.6133333,27.8408333 ],
    [ u"gr",u"Sinarádes",1150,39.5647222,19.8458333 ],
    [ u"gr",u"Síndos",8228,40.6697222,22.8047222 ],
    [ u"gr",u"Sisamía",1168,40.95,23.4166667 ],
    [ u"gr",u"Sísion",875,35.3,25.5166667 ],
    [ u"gr",u"Sitagroí",1105,41.1166667,24.0333333 ],
    [ u"gr",u"Sitía",8707,35.2,26.0986111 ],
    [ u"gr",u"Sívota",973,39.4066667,20.25 ],
    [ u"gr",u"Skála Foúrkas",853,40.0,23.3833333 ],
    [ u"gr",u"Skalánion",1012,35.2833333,25.1833333 ],
    [ u"gr",u"Skála Oropoú",1284,38.3333333,23.7833333 ],
    [ u"gr",u"Skála",2817,36.85,22.6666667 ],
    [ u"gr",u"Skála",1849,37.3166667,26.5333333 ],
    [ u"gr",u"Skhimatárion",5007,38.35,23.5833333 ],
    [ u"gr",u"Skhísma",1968,35.2666667,25.7166667 ],
    [ u"gr",u"Skíathos",5187,39.1666667,23.4833333 ],
    [ u"gr",u"Skíros",1732,38.9041667,24.5630556 ],
    [ u"gr",u"Skópelos",2886,39.1247222,23.7247222 ],
    [ u"gr",u"Skópelos",1728,39.0297222,26.4483333 ],
    [ u"gr",u"Skotína",953,39.9936111,22.5341667 ],
    [ u"gr",u"Skotoússa",1371,41.1333333,23.3833333 ],
    [ u"gr",u"Skoúrta",982,38.2166667,23.55 ],
    [ u"gr",u"Skoútari",2690,41.0166667,23.5166667 ],
    [ u"gr",u"Skoutáros",952,39.3,26.1333333 ],
    [ u"gr",u"Sofikón",1799,37.8,23.05 ],
    [ u"gr",u"Sokhós",2748,40.8166667,23.35 ],
    [ u"gr",u"Sosándra",1217,40.9983333,22.0294444 ],
    [ u"gr",u"Soúda",6729,35.4844444,24.0744444 ],
    [ u"gr",u"Souflíon",4149,41.1919444,26.2994444 ],
    [ u"gr",u"Sourotí",1048,40.4666667,23.0833333 ],
    [ u"gr",u"Soúrpi",2137,39.1,22.9 ],
    [ u"gr",u"Sozópolis",925,40.2833333,23.15 ],
    [ u"gr",u"Spárta",801,38.0333333,23.1666667 ],
    [ u"gr",u"Spárti",15497,37.0733333,22.4297222 ],
    [ u"gr",u"Spáta",8137,37.9666667,23.9166667 ],
    [ u"gr",u"Sperkhiás",2844,38.9,22.1166667 ],
    [ u"gr",u"Sperkhóyia",1004,37.0666667,22.0666667 ],
    [ u"gr",u"Spétsai",3972,37.2666667,23.15 ],
    [ u"gr",u"Spoláïta",632,38.7,21.35 ],
    [ u"gr",u"Stalís",1182,35.3,25.4333333 ],
    [ u"gr",u"Stamáta",2904,38.1333333,23.8833333 ],
    [ u"gr",u"Stamná",921,38.5166667,21.2833333 ],
    [ u"gr",u"Stános",1132,38.8,21.1666667 ],
    [ u"gr",u"Stefanovíkion",2016,39.4666667,22.7333333 ],
    [ u"gr",u"Stérnai",836,35.5166667,24.15 ],
    [ u"gr",u"Stérna",815,41.5666667,26.45 ],
    [ u"gr",u"Stilís",5132,38.9166667,22.6166667 ],
    [ u"gr",u"Stípsi",1020,39.3116667,26.2197222 ],
    [ u"gr",u"Stírion",1056,38.4,22.7166667 ],
    [ u"gr",u"Stournaraíïka",537,39.4516667,21.4905556 ],
    [ u"gr",u"Stratónion",1150,40.5166667,23.8333333 ],
    [ u"gr",u"Strátos",1110,38.6666667,21.3166667 ],
    [ u"gr",u"Strimonikón",1869,41.05,23.3166667 ],
    [ u"gr",u"Svorónos",2066,40.2644444,22.46 ],
    [ u"gr",u"Taxiárkhis",1055,40.4333333,23.5166667 ],
    [ u"gr",u"Témeni",1125,38.2333333,22.1166667 ],
    [ u"gr",u"Terpní",2132,40.9166667,23.4833333 ],
    [ u"gr",u"Terpsithéa",1308,39.6166667,22.3666667 ],
    [ u"gr",u"Thásos",3339,40.77,24.7238889 ],
    [ u"gr",u"Theodóriana",999,39.4341667,21.2086111 ],
    [ u"gr",u"Theológos",655,40.6666667,24.7 ],
    [ u"gr",u"Thérmi",14373,40.55,23.0166667 ],
    [ u"gr",u"Thérmon",1958,38.5833333,21.6666667 ],
    [ u"gr",u"Thespiaí",1437,38.3,23.15 ],
    [ u"gr",u"Thesprotikón",1718,39.25,20.7847222 ],
    [ u"gr",u"Thessaloníki",354291,40.6402778,22.9438889 ],
    [ u"gr",u"Thimianá",1483,38.315,26.1336111 ],
    [ u"gr",u"Thíra",2376,36.4166667,25.4333333 ],
    [ u"gr",u"Thírion",753,38.8666667,20.9833333 ],
    [ u"gr",u"Thívai",22028,38.325,23.3188889 ],
    [ u"gr",u"Tholós",854,41.0,23.7833333 ],
    [ u"gr",u"Thouría",1302,37.0833333,22.05 ],
    [ u"gr",u"Thrapsanón",1499,35.1833333,25.2833333 ],
    [ u"gr",u"Tikherón",2029,41.0333333,26.2833333 ],
    [ u"gr",u"Tílisos",1026,35.3,25.0166667 ],
    [ u"gr",u"Timbákion",4923,35.0666667,24.7666667 ],
    [ u"gr",u"Tínos",4573,37.5333333,25.1666667 ],
    [ u"gr",u"Tírnavos",10797,39.7377778,22.2891667 ],
    [ u"gr",u"Tithoréa",865,38.5833333,22.6666667 ],
    [ u"gr",u"Tolón",2322,37.5166667,22.85 ],
    [ u"gr",u"Toúmba",947,41.0166667,23.7 ],
    [ u"gr",u"Toúmba",993,40.9322222,22.5375 ],
    [ u"gr",u"Tragána",1320,38.6166667,23.1166667 ],
    [ u"gr",u"Traganón",2414,37.8833333,21.3166667 ],
    [ u"gr",u"Triandría",11082,40.6227778,22.9711111 ],
    [ u"gr",u"Trífos",708,38.8333333,21.0666667 ],
    [ u"gr",u"Tríkala",1704,40.5980556,22.5566667 ],
    [ u"gr",u"Tríkala",49810,39.5552778,21.7675 ],
    [ u"gr",u"Tríkerion",1182,39.1,23.0833333 ],
    [ u"gr",u"Trílofon",4362,40.4672222,22.9694444 ],
    [ u"gr",u"Trípoli",26562,37.5088889,22.3794444 ],
    [ u"gr",u"Tsákoi",1004,40.9586111,22.0363889 ],
    [ u"gr",u"Tsarítsani",2514,39.8833333,22.2333333 ],
    [ u"gr",u"Tsikalariá",1204,35.4833333,24.0666667 ],
    [ u"gr",u"Tsotílion",1695,40.2666667,21.3166667 ],
    [ u"gr",u"Tzermiádon",682,35.2036111,25.4847222 ],
    [ u"gr",u"Valíra",991,37.1666667,21.9833333 ],
    [ u"gr",u"Valsamáta",1008,38.1666667,20.6 ],
    [ u"gr",u"Valterón",1285,41.1833333,23.3166667 ],
    [ u"gr",u"Valtotópion",1106,41.0,23.6 ],
    [ u"gr",u"Vamvakófiton",1161,41.1833333,23.4 ],
    [ u"gr",u"Vamvakoú",1104,39.3333333,22.4166667 ],
    [ u"gr",u"Vanáton",944,37.8,20.85 ],
    [ u"gr",u"Várda",3307,38.0333333,21.3666667 ],
    [ u"gr",u"Variá",1518,39.0833333,26.5666667 ],
    [ u"gr",u"Vári",12090,37.8333333,23.8 ],
    [ u"gr",u"Vári",1266,37.4,24.95 ],
    [ u"gr",u"Varnávas",1516,38.2166667,23.9166667 ],
    [ u"gr",u"Vartholomió",3068,37.8666667,21.2 ],
    [ u"gr",u"Varvásaina",1280,37.6833333,21.5 ],
    [ u"gr",u"Vasilíai",984,35.2666667,25.1333333 ],
    [ u"gr",u"Vasiliká",4519,40.4666667,23.1333333 ],
    [ u"gr",u"Vasilikí",1388,39.6388889,21.7047222 ],
    [ u"gr",u"Vasilikón",7039,38.4333333,23.6666667 ],
    [ u"gr",u"Vathílakkos",2218,40.7694444,22.7016667 ],
    [ u"gr",u"Vathí",2575,38.4,23.6 ],
    [ u"gr",u"Vathí",1615,37.7666667,23.4833333 ],
    [ u"gr",u"Vathí",1885,37.75,26.9833333 ],
    [ u"gr",u"Váyia",4535,38.3166667,23.1833333 ],
    [ u"gr",u"Velestínon",3211,39.3833333,22.75 ],
    [ u"gr",u"Vélon",3018,37.9666667,22.7666667 ],
    [ u"gr",u"Velventós",3378,40.2516667,22.0630556 ],
    [ u"gr",u"Veneráton",938,35.2,25.0333333 ],
    [ u"gr",u"Verdikoússa",1603,39.7802778,21.9722222 ],
    [ u"gr",u"Véroia",44465,40.5233333,22.2036111 ],
    [ u"gr",u"Veryína",1242,40.4811111,22.3136111 ],
    [ u"gr",u"Véryi",1382,40.95,23.4 ],
    [ u"gr",u"Vília",1967,38.1666667,23.3333333 ],
    [ u"gr",u"Virónia",858,41.2833333,23.2333333 ],
    [ u"gr",u"Víron",61888,37.9666667,23.75 ],
    [ u"gr",u"Virós",1057,39.5838889,19.8819444 ],
    [ u"gr",u"Vitína",906,37.6666667,22.1833333 ],
    [ u"gr",u"Vlakhiótis",2404,36.8666667,22.7 ],
    [ u"gr",u"Vlakhokeraséa",773,37.3666667,22.3833333 ],
    [ u"gr",u"Vlakhópoulon",1446,37.0333333,21.7833333 ],
    [ u"gr",u"Vlakhoyiánnion",855,39.75,22.0833333 ],
    [ u"gr",u"Vokhaïkón",961,37.95,22.8 ],
    [ u"gr",u"Vólax",1225,41.3166667,24.0 ],
    [ u"gr",u"Vólos",84427,39.3666667,22.9458333 ],
    [ u"gr",u"Vónitsa",3770,38.9163889,20.8863889 ],
    [ u"gr",u"Voúla",29033,37.85,23.7666667 ],
    [ u"gr",u"Vouliagméni",7717,37.8166667,23.7833333 ],
    [ u"gr",u"Vrakhátion",3252,37.9666667,22.8166667 ],
    [ u"gr",u"Vrakhnaíika",2780,38.1666667,21.6666667 ],
    [ u"gr",u"Vrína",860,37.5666667,21.6333333 ],
    [ u"gr",u"Vríses",982,35.3833333,24.2 ],
    [ u"gr",u"Vrontádos",4600,38.4088889,26.1327778 ],
    [ u"gr",u"Vrontoú",2196,40.1922222,22.4327778 ],
    [ u"gr",u"Xánthi",48221,41.1413889,24.8836111 ],
    [ u"gr",u"Xilaganí",1445,40.9833333,25.4166667 ],
    [ u"gr",u"Xilókastron",5256,38.0833333,22.6333333 ],
    [ u"gr",u"Xilópolis",1442,40.9333333,23.1833333 ],
    [ u"gr",u"Xinón Nerón",1176,40.6833333,21.6166667 ],
    [ u"gr",u"Xirokámbion",995,36.9666667,22.45 ],
    [ u"gr",u"Xirókambos",879,37.1,26.8666667 ],
    [ u"gr",u"Xiropótamos",2670,41.2,24.1 ],
    [ u"gr",u"Yéfira",3451,40.7333333,22.6922222 ],
    [ u"gr",u"Yéfira",1465,36.6833333,23.0333333 ],
    [ u"gr",u"Yeniséa",1935,41.0666667,24.9666667 ],
    [ u"gr",u"Yeoryianí",642,40.95,24.15 ],
    [ u"gr",u"Yerakaroú",1308,40.6333333,23.2166667 ],
    [ u"gr",u"Yerákion",1323,37.0,22.7 ],
    [ u"gr",u"Yeráni",804,35.35,24.4 ],
    [ u"gr",u"Yéryeri",1444,35.1333333,24.95 ],
    [ u"gr",u"Yialós",873,35.2333333,23.6333333 ],
    [ u"gr",u"Yiannitsá",27818,40.7919444,22.4075 ],
    [ u"gr",u"Yiánnouli",7031,39.6666667,22.3833333 ],
    [ u"gr",u"Yimnón",2041,38.4333333,23.8833333 ],
    [ u"gr",u"Yíthion",4576,36.755,22.5641667 ],
    [ u"gr",u"Zagorá",2385,39.45,23.1 ],
    [ u"gr",u"Zakháro",5894,37.4833333,21.65 ],
    [ u"gr",u"Zákinthos",11540,37.7913889,20.8952778 ],
    [ u"gr",u"Zárakes",936,38.3,24.2 ],
    [ u"gr",u"Zárkos",1407,39.6166667,22.1333333 ],
    [ u"gr",u"Zarós",2205,35.1333333,24.9 ],
    [ u"gr",u"Zélion",868,38.6666667,22.8833333 ],
    [ u"gr",u"Zigós",1504,41.0166667,24.3833333 ],
    [ u"gr",u"Zipárion",2706,36.875,27.2041667 ],
    [ u"gr",u"Zítsa",914,39.7530556,20.6486111 ],
    [ u"gr",u"Zonianá",1703,35.3,24.8333333 ],
    [ u"gt",u"Acatenango",6905,14.551944,-90.942222 ],
    [ u"gt",u"Agua Blanca",2719,14.5,-89.65 ],
    [ u"gt",u"Aguacatán",5457,15.343056,-91.311667 ],
    [ u"gt",u"Almolonga",11668,14.816667,-91.5 ],
    [ u"gt",u"Alotenango",17052,14.480278,-90.8075 ],
    [ u"gt",u"Amatitlán",70357,14.4875,-90.615278 ],
    [ u"gt",u"Antigua Guatemala",38560,14.561111,-90.734444 ],
    [ u"gt",u"Asunción Mita",15287,14.330833,-89.710833 ],
    [ u"gt",u"Atescatempa",11306,14.174444,-89.7425 ],
    [ u"gt",u"Ayutla",11197,14.666667,-92.15 ],
    [ u"gt",u"Barberena",29861,14.309444,-90.361111 ],
    [ u"gt",u"Barillas",13810,15.803611,-91.315833 ],
    [ u"gt",u"Cabañas",4582,14.933333,-89.8 ],
    [ u"gt",u"Cabricán",11663,15.133333,-91.616667 ],
    [ u"gt",u"Cahabón",4575,15.566667,-89.816667 ],
    [ u"gt",u"Cajolá",2867,14.916667,-91.616667 ],
    [ u"gt",u"Camotán",1565,14.816667,-89.366667 ],
    [ u"gt",u"Canillá",1663,15.166667,-90.85 ],
    [ u"gt",u"Cantel",25485,14.816667,-91.45 ],
    [ u"gt",u"Casillas",8786,14.422222,-90.244167 ],
    [ u"gt",u"Catarina",2977,14.85,-92.083333 ],
    [ u"gt",u"Chahal",5100,15.75,-89.566667 ],
    [ u"gt",u"Chajul",11416,15.485278,-91.034167 ],
    [ u"gt",u"Champerico",7602,14.3,-91.916667 ],
    [ u"gt",u"Chiantla",8290,15.354722,-91.458333 ],
    [ u"gt",u"Chicacao",20006,14.533333,-91.316667 ],
    [ u"gt",u"Chicamán",2046,15.4,-90.766667 ],
    [ u"gt",u"Chiché",2357,15.008611,-91.065 ],
    [ u"gt",u"Chichicastenango",77861,14.933333,-91.116667 ],
    [ u"gt",u"Chimaltenango",80680,14.668611,-90.816667 ],
    [ u"gt",u"Chinautla",94508,14.708333,-90.499444 ],
    [ u"gt",u"Chinique",2637,15.044722,-91.025833 ],
    [ u"gt",u"Chiquimula",40669,14.8,-89.55 ],
    [ u"gt",u"Chiquimulilla",12578,14.085833,-90.376667 ],
    [ u"gt",u"Chisec",12038,15.816667,-90.283333 ],
    [ u"gt",u"Chuarrancho",7001,14.821667,-90.508611 ],
    [ u"gt",u"Ciudad Vieja",29584,14.526389,-90.759722 ],
    [ u"gt",u"Cobán",46726,15.483333,-90.366667 ],
    [ u"gt",u"Colomba",18722,14.716667,-91.733333 ],
    [ u"gt",u"Colotenango",1656,15.416667,-91.716667 ],
    [ u"gt",u"Comalapa",20311,14.741111,-90.8875 ],
    [ u"gt",u"Comapa",1462,14.116667,-89.916667 ],
    [ u"gt",u"Comitancillo",19203,15.083333,-91.716667 ],
    [ u"gt",u"Concepción Chiquirichapa",7914,14.85,-91.616667 ],
    [ u"gt",u"Concepción",8741,15.616667,-91.683333 ],
    [ u"gt",u"Concepción",3224,14.783333,-91.15 ],
    [ u"gt",u"Concepción Tutuapa",1147,15.283333,-91.783333 ],
    [ u"gt",u"Conguaco",3345,14.044167,-90.031111 ],
    [ u"gt",u"Cubulco",10073,15.133333,-90.583333 ],
    [ u"gt",u"Cuilapa",16484,14.276389,-90.300278 ],
    [ u"gt",u"Cuilco",1677,15.4,-91.966667 ],
    [ u"gt",u"Cunén",8227,15.3375,-91.026944 ],
    [ u"gt",u"Cuyotenango",10602,14.533333,-91.566667 ],
    [ u"gt",u"Dolores",10385,16.514167,-89.415833 ],
    [ u"gt",u"El Adelanto",1923,14.166667,-89.833333 ],
    [ u"gt",u"El Asintal",6018,14.6,-91.733333 ],
    [ u"gt",u"El Chol",2480,14.964167,-90.480556 ],
    [ u"gt",u"El Estor",15516,15.533333,-89.35 ],
    [ u"gt",u"El Jícaro",4155,14.866667,-90.266667 ],
    [ u"gt",u"El Palmar",14828,14.65,-91.583333 ],
    [ u"gt",u"El Progreso",7199,14.35,-89.85 ],
    [ u"gt",u"El Quetzal",11853,14.766667,-91.816667 ],
    [ u"gt",u"El Rodeo",1849,14.916667,-91.966667 ],
    [ u"gt",u"El Tejar",15445,14.647778,-90.792778 ],
    [ u"gt",u"El Tumbador",7406,14.866667,-91.933333 ],
    [ u"gt",u"Escuintla",101047,14.305,-90.785 ],
    [ u"gt",u"Esquipulas",20249,14.566667,-89.35 ],
    [ u"gt",u"Esquipulas Palo Gordo",1502,14.933333,-91.816667 ],
    [ u"gt",u"Estanzuela",8753,15,-89.566667 ],
    [ u"gt",u"Flores Costa Cuca",11716,14.65,-91.816667 ],
    [ u"gt",u"Flores",20002,16.933333,-89.883333 ],
    [ u"gt",u"Fraijanes",27852,14.465278,-90.440833 ],
    [ u"gt",u"Génova",3667,14.616667,-91.833333 ],
    [ u"gt",u"Granados",1120,14.913611,-90.522778 ],
    [ u"gt",u"Gualán",18957,15.133333,-89.366667 ],
    [ u"gt",u"Guanagazapa",2784,14.225278,-90.643333 ],
    [ u"gt",u"Guastatoya",13190,14.853889,-90.064722 ],
    [ u"gt",u"Guatemala City",973208,14.621111,-90.526944 ],
    [ u"gt",u"Guatemala",973208,14.621111,-90.526944 ],
    [ u"gt",u"Guazacapán",6935,14.074167,-90.416667 ],
    [ u"gt",u"Huehuetenango",77797,15.319722,-91.470833 ],
    [ u"gt",u"Huitán",9737,15.1,-91.616667 ],
    [ u"gt",u"Huité",2656,14.933333,-89.716667 ],
    [ u"gt",u"Ipala",5174,14.616667,-89.616667 ],
    [ u"gt",u"Ixchiguán",2217,15.2,-91.883333 ],
    [ u"gt",u"Ixtahuacán",3631,15.416667,-91.766667 ],
    [ u"gt",u"Iztapa",3937,13.933333,-90.7075 ],
    [ u"gt",u"Jacaltenango",33384,15.666667,-91.733333 ],
    [ u"gt",u"Jalapa",44896,14.633333,-89.983333 ],
    [ u"gt",u"Jalpatagua",10254,14.141667,-90.008611 ],
    [ u"gt",u"Jerez",4330,14.1,-89.75 ],
    [ u"gt",u"Jocotán",4829,14.816667,-89.383333 ],
    [ u"gt",u"Jocotenango",17550,14.581944,-90.743611 ],
    [ u"gt",u"Joyabaj",12893,14.995,-90.806111 ],
    [ u"gt",u"Jutiapa",33626,14.283333,-89.9 ],
    [ u"gt",u"La Democracia",5366,14.230833,-90.947222 ],
    [ u"gt",u"La Esperanza",16095,14.866667,-91.566667 ],
    [ u"gt",u"La Gomera",23460,14.083333,-91.05 ],
    [ u"gt",u"La Libertad",6307,15.5,-91.833333 ],
    [ u"gt",u"La Libertad",8467,16.783333,-90.116667 ],
    [ u"gt",u"Lanquín",1949,15.566667,-89.966667 ],
    [ u"gt",u"La Reforma",4804,14.8,-91.816667 ],
    [ u"gt",u"La Unión",3606,14.966667,-89.283333 ],
    [ u"gt",u"Lívingston",14056,15.833333,-88.75 ],
    [ u"gt",u"Los Amates",3347,15.266667,-89.1 ],
    [ u"gt",u"Magdalena Milpas Altas",5467,14.545278,-90.675278 ],
    [ u"gt",u"Malacatancito",2078,15.216667,-91.516667 ],
    [ u"gt",u"Malacatán",14616,14.9,-92.05 ],
    [ u"gt",u"Masagua",9818,14.203056,-90.848056 ],
    [ u"gt",u"Mataquescuintla",7384,14.529167,-90.184167 ],
    [ u"gt",u"Mazatenango",43225,14.533333,-91.5 ],
    [ u"gt",u"Melchor de Mencos",11220,17.068611,-89.152222 ],
    [ u"gt",u"Mixco",460576,14.633333,-90.606389 ],
    [ u"gt",u"Momostenango",31088,15.043611,-91.408611 ],
    [ u"gt",u"Monjas",10138,14.5,-89.866667 ],
    [ u"gt",u"Morales",18571,15.483333,-88.816667 ],
    [ u"gt",u"Morazán",2502,14.932778,-90.143056 ],
    [ u"gt",u"Moyuta",7978,14.038611,-90.080833 ],
    [ u"gt",u"Nahualá",27076,14.85,-91.316667 ],
    [ u"gt",u"Nebaj",22821,15.405833,-91.146111 ],
    [ u"gt",u"Nentón",2478,15.8,-91.75 ],
    [ u"gt",u"Nueva Concepción",10892,14.2,-91.3 ],
    [ u"gt",u"Nueva Santa Rosa",9922,14.381111,-90.276111 ],
    [ u"gt",u"Nuevo Progreso",7947,14.8,-91.916667 ],
    [ u"gt",u"Nuevo San Carlos",18681,14.6,-91.7 ],
    [ u"gt",u"Ocós",9252,14.509444,-92.193333 ],
    [ u"gt",u"Olintepeque",28239,14.883333,-91.516667 ],
    [ u"gt",u"Olopa",1655,14.683333,-89.35 ],
    [ u"gt",u"Oratorio",9946,14.228056,-90.175833 ],
    [ u"gt",u"Ostuncalco",28301,14.866667,-91.616667 ],
    [ u"gt",u"Pachalum",2295,14.924722,-90.662778 ],
    [ u"gt",u"Pajapita",7996,14.716667,-92.033333 ],
    [ u"gt",u"Palencia",18192,14.664722,-90.358611 ],
    [ u"gt",u"Palestina de los Altos",1657,14.933333,-91.7 ],
    [ u"gt",u"Palín",30684,14.405556,-90.698333 ],
    [ u"gt",u"Panajachel",12599,14.733333,-91.15 ],
    [ u"gt",u"Panzós",18302,15.4,-89.666667 ],
    [ u"gt",u"Parramos",9415,14.607778,-90.803056 ],
    [ u"gt",u"Pasaco",1834,13.977222,-90.206389 ],
    [ u"gt",u"Pastores",10180,14.596667,-90.754722 ],
    [ u"gt",u"Patulul",13905,14.416667,-91.166667 ],
    [ u"gt",u"Patzicía",16155,14.631667,-90.926944 ],
    [ u"gt",u"Patzité",983,14.966667,-91.216667 ],
    [ u"gt",u"Patzún",18319,14.683333,-91.016667 ],
    [ u"gt",u"Petapa",137839,14.502778,-90.551667 ],
    [ u"gt",u"Pochuta",3799,14.55,-91.083333 ],
    [ u"gt",u"Poptún",16963,16.331111,-89.416944 ],
    [ u"gt",u"Pueblo Nuevo",3051,14.65,-91.533333 ],
    [ u"gt",u"Pueblo Nuevo Viñas",4125,14.225833,-90.474167 ],
    [ u"gt",u"Puerto Barrios",55445,15.716667,-88.6 ],
    [ u"gt",u"Purulhá",5606,15.266667,-90.2 ],
    [ u"gt",u"Quetzaltenango",132231,14.833333,-91.516667 ],
    [ u"gt",u"Quezada",2203,14.270278,-90.040278 ],
    [ u"gt",u"Quezaltepeque",4041,14.633333,-89.45 ],
    [ u"gt",u"Rabinal",12641,15.1,-90.45 ],
    [ u"gt",u"Retalhuleu",35903,14.533333,-91.683333 ],
    [ u"gt",u"Río Blanco",812,15.033333,-91.683333 ],
    [ u"gt",u"Río Bravo",7412,14.4,-91.316667 ],
    [ u"gt",u"Río Hondo",5874,15.066667,-89.583333 ],
    [ u"gt",u"Sacapulas",11839,15.286667,-91.087222 ],
    [ u"gt",u"Salamá",22247,15.1,-90.266667 ],
    [ u"gt",u"Salcajá",11720,14.883333,-91.45 ],
    [ u"gt",u"Samayac",8809,14.583333,-91.466667 ],
    [ u"gt",u"San Agustín Acasaguastlán",10123,14.95,-89.966667 ],
    [ u"gt",u"San Andrés Itzapa",18263,14.62,-90.844167 ],
    [ u"gt",u"San Andrés Sajcabajá",1947,15.216667,-90.916667 ],
    [ u"gt",u"San Andrés",7086,16.966667,-89.916667 ],
    [ u"gt",u"San Andrés Semetabaj",2552,14.75,-91.133333 ],
    [ u"gt",u"San Andrés Villa Seca",4988,14.566667,-91.583333 ],
    [ u"gt",u"San Andrés Xecul",11884,14.9,-91.483333 ],
    [ u"gt",u"San Antonio Aguas Calientes",7650,14.539722,-90.769444 ],
    [ u"gt",u"San Antonio Huista",5553,15.65,-91.766667 ],
    [ u"gt",u"San Antonio Ilotenango",1979,15.054722,-91.229722 ],
    [ u"gt",u"San Antonio Palopó",3514,14.7,-91.116667 ],
    [ u"gt",u"San Antonio Sacatepéquez",1623,14.966667,-91.733333 ],
    [ u"gt",u"San Antonio Suchitepéquez",10726,14.533333,-91.416667 ],
    [ u"gt",u"Sanarate",15517,14.795,-90.192222 ],
    [ u"gt",u"San Bartolomé Jocotenango",1586,15.192778,-91.077222 ],
    [ u"gt",u"San Bartolomé Milpas Altas",6132,14.606111,-90.68 ],
    [ u"gt",u"San Bartolo",1264,15.084444,-91.455833 ],
    [ u"gt",u"San Benito",30131,16.916667,-89.9 ],
    [ u"gt",u"San Bernardino",5388,14.533333,-91.45 ],
    [ u"gt",u"San Carlos Sija",6691,14.983333,-91.55 ],
    [ u"gt",u"San Cristóbal Acasaguastlán",2127,14.916667,-89.883333 ],
    [ u"gt",u"San Cristóbal Cucho",8948,14.9,-91.783333 ],
    [ u"gt",u"San Cristóbal Totonicapán",4104,14.916667,-91.433333 ],
    [ u"gt",u"San Cristóbal Verapaz",18748,15.383333,-90.4 ],
    [ u"gt",u"San Diego",546,14.783333,-89.783333 ],
    [ u"gt",u"San Felipe",8737,14.616667,-91.6 ],
    [ u"gt",u"San Francisco El Alto",53226,14.95,-91.45 ],
    [ u"gt",u"San Francisco",3873,16.8,-89.933333 ],
    [ u"gt",u"San Francisco Zapotitlán",13544,14.583333,-91.516667 ],
    [ u"gt",u"San Gabriel",4033,14.516667,-91.516667 ],
    [ u"gt",u"San Gaspar Ixchil",540,15.383333,-91.716667 ],
    [ u"gt",u"San Jacinto",1488,14.666667,-89.5 ],
    [ u"gt",u"San Jerónimo",8317,15.05,-90.2 ],
    [ u"gt",u"San José Acatempa",6236,14.265278,-90.126944 ],
    [ u"gt",u"San José Chacayá",820,14.766667,-91.216667 ],
    [ u"gt",u"San José del Golfo",4807,14.762778,-90.376389 ],
    [ u"gt",u"San José El Ídolo",2362,14.45,-91.416667 ],
    [ u"gt",u"San José Ojetenán",1243,15.216667,-91.966667 ],
    [ u"gt",u"San José Pinula",46188,14.546111,-90.411389 ],
    [ u"gt",u"San José Poaquil",5864,14.819722,-90.906389 ],
    [ u"gt",u"San José",18270,13.925556,-90.824444 ],
    [ u"gt",u"San José",1176,16.983333,-89.9 ],
    [ u"gt",u"San Juan Atitán",1870,15.433333,-91.633333 ],
    [ u"gt",u"San Juan Bautista",2625,14.416667,-91.183333 ],
    [ u"gt",u"San Juan Chamelco",11389,15.433333,-90.333333 ],
    [ u"gt",u"San Juan Cotzal",10818,15.434167,-91.034167 ],
    [ u"gt",u"San Juan Ermita",1590,14.766667,-89.433333 ],
    [ u"gt",u"San Juan Ixcoy",2483,15.599722,-91.445278 ],
    [ u"gt",u"San Juan Sacatepéquez",133613,14.718889,-90.644167 ],
    [ u"gt",u"San Juan Tecuaco",2164,14.082222,-90.261111 ],
    [ u"gt",u"San Lorenzo",925,15.033333,-91.733333 ],
    [ u"gt",u"San Lorenzo",2121,14.483333,-91.516667 ],
    [ u"gt",u"San Lucas Sacatepéquez",17590,14.609722,-90.656944 ],
    [ u"gt",u"San Lucas Tolimán",14246,14.633333,-91.133333 ],
    [ u"gt",u"San Luis Jilotepeque",10094,14.65,-89.733333 ],
    [ u"gt",u"San Luis",6636,16.198889,-89.440278 ],
    [ u"gt",u"San Manuel Chaparrón",2570,14.516667,-89.766667 ],
    [ u"gt",u"San Marcos",24573,14.966667,-91.8 ],
    [ u"gt",u"San Martín Jilotepeque",9643,14.787778,-90.7925 ],
    [ u"gt",u"San Martín Sacatepéquez",3582,14.816667,-91.65 ],
    [ u"gt",u"San Martín Zapotitlán",4328,14.6,-91.6 ],
    [ u"gt",u"San Mateo Ixtatán",12942,15.831944,-91.478056 ],
    [ u"gt",u"San Mateo",5421,14.866667,-91.583333 ],
    [ u"gt",u"San Miguel Acatán",2716,15.7,-91.616667 ],
    [ u"gt",u"San Miguel Chicaj",12708,15.1,-90.4 ],
    [ u"gt",u"San Miguel Dueñas",8251,14.523889,-90.798333 ],
    [ u"gt",u"San Miguel Ixtahuacán",3587,15.25,-91.75 ],
    [ u"gt",u"San Miguel Panán",1983,14.533333,-91.366667 ],
    [ u"gt",u"San Miguel Sigüilá",7384,14.9,-91.616667 ],
    [ u"gt",u"San Pablo Jocopilas",19774,14.583333,-91.45 ],
    [ u"gt",u"San Pablo",13340,14.933333,-92 ],
    [ u"gt",u"San Pedro Ayampuc",45755,14.786667,-90.451111 ],
    [ u"gt",u"San Pedro Carchá",12941,15.483333,-90.266667 ],
    [ u"gt",u"San Pedro Jocopilas",1019,15.094444,-91.151389 ],
    [ u"gt",u"San Pedro Necta",3481,15.5,-91.766667 ],
    [ u"gt",u"San Pedro Pinula",3235,14.666667,-89.85 ],
    [ u"gt",u"San Pedro Sacatepéquez",14020,14.684167,-90.644167 ],
    [ u"gt",u"San Pedro Sacatepéquez",39200,14.966667,-91.766667 ],
    [ u"gt",u"San Rafael Petzal",1494,15.416667,-91.666667 ],
    [ u"gt",u"San Raymundo",8510,14.764722,-90.595556 ],
    [ u"gt",u"Sansare",3714,14.747222,-90.1125 ],
    [ u"gt",u"San Sebastián Coatán",784,15.733333,-91.566667 ],
    [ u"gt",u"San Sebastián Huehuetenango",1284,15.383333,-91.583333 ],
    [ u"gt",u"San Sebastián",14519,14.566667,-91.65 ],
    [ u"gt",u"Santa Ana Huista",1963,15.683333,-91.816667 ],
    [ u"gt",u"Santa Ana",9309,16.8,-89.833333 ],
    [ u"gt",u"Santa Apolonia",2346,14.791389,-90.970833 ],
    [ u"gt",u"Santa Bárbara",868,15.316667,-91.616667 ],
    [ u"gt",u"Santa Bárbara",12618,14.433333,-91.233333 ],
    [ u"gt",u"Santa Catarina Barahona",3148,14.548889,-90.788333 ],
    [ u"gt",u"Santa Catarina Ixtahuacán",14405,14.8,-91.366667 ],
    [ u"gt",u"Santa Catarina Mita",10595,14.45,-89.75 ],
    [ u"gt",u"Santa Catarina Palopó",2887,14.716667,-91.133333 ],
    [ u"gt",u"Santa Catarina Pinula",66351,14.568889,-90.495278 ],
    [ u"gt",u"Santa Cruz Balanyá",7664,14.687222,-90.915 ],
    [ u"gt",u"Santa Cruz del Quiché",23131,15.030556,-91.148889 ],
    [ u"gt",u"Santa Cruz Muluá",2650,14.583333,-91.616667 ],
    [ u"gt",u"Santa Cruz Naranjo",6126,14.388056,-90.369722 ],
    [ u"gt",u"Santa Cruz Verapaz",5656,15.366667,-90.433333 ],
    [ u"gt",u"Santa Eulalia",4820,15.733056,-91.456944 ],
    [ u"gt",u"Santa Lucía Cotzumalguapa",60821,14.333333,-91.016667 ],
    [ u"gt",u"Santa Lucía Milpas Altas",12711,14.575833,-90.678611 ],
    [ u"gt",u"Santa Lucía Utatlán",1278,14.766667,-91.266667 ],
    [ u"gt",u"Santa María Chiquimula",6837,15.030278,-91.329167 ],
    [ u"gt",u"Santa María de Jesús",15210,14.518333,-90.726667 ],
    [ u"gt",u"Santa María Ixhuatán",3559,14.19,-90.274722 ],
    [ u"gt",u"Santa María Visitación",1456,14.716667,-91.316667 ],
    [ u"gt",u"Santa Rosa de Lima",5861,14.388056,-90.295556 ],
    [ u"gt",u"Santiago Atitlán",32625,14.633333,-91.233333 ],
    [ u"gt",u"Santiago Chimaltenango",2958,15.466667,-91.716667 ],
    [ u"gt",u"Santiago Sacatepéquez",23713,14.635278,-90.676389 ],
    [ u"gt",u"Santo Domingo Suchitepéquez",6141,14.466667,-91.483333 ],
    [ u"gt",u"Santo Domingo Xenacoj",8610,14.677778,-90.697778 ],
    [ u"gt",u"San Vicente Pacaya",7014,14.416111,-90.639167 ],
    [ u"gt",u"Sayaxché",8913,16.516667,-90.166667 ],
    [ u"gt",u"Senahú",5378,15.4,-89.833333 ],
    [ u"gt",u"Sibilia",1155,15,-91.616667 ],
    [ u"gt",u"Sibinal",1623,15.133333,-92.05 ],
    [ u"gt",u"Sipacapa",647,15.2,-91.666667 ],
    [ u"gt",u"Siquinalá",12881,14.306111,-90.965 ],
    [ u"gt",u"Sololá",44443,14.766667,-91.183333 ],
    [ u"gt",u"Soloma",10692,15.716667,-91.45 ],
    [ u"gt",u"Sumpango",20454,14.646389,-90.733889 ],
    [ u"gt",u"Tacaná",6305,15.233333,-92.083333 ],
    [ u"gt",u"Tactic",8723,15.333333,-90.3 ],
    [ u"gt",u"Tajumulco",4226,15.083333,-91.883333 ],
    [ u"gt",u"Tamahú",1078,15.333333,-90.166667 ],
    [ u"gt",u"Taxisco",6384,14.070833,-90.463056 ],
    [ u"gt",u"Tecpán Guatemala",21526,14.766944,-90.994167 ],
    [ u"gt",u"Tectitán",728,15.333333,-92.033333 ],
    [ u"gt",u"Teculután",6275,14.983333,-89.716667 ],
    [ u"gt",u"Tejutla",2599,15.116667,-91.8 ],
    [ u"gt",u"Tiquisate",17814,14.283333,-91.366667 ],
    [ u"gt",u"Todos Santos Cuchumatán",3221,15.516667,-91.616667 ],
    [ u"gt",u"Totonicapán",68213,14.916667,-91.366667 ],
    [ u"gt",u"Tucurú",3961,15.3,-90.066667 ],
    [ u"gt",u"Uspantán",4617,15.383333,-90.833333 ],
    [ u"gt",u"Usumatlán",4884,14.95,-89.783333 ],
    [ u"gt",u"Villa Canales",119084,14.481389,-90.531667 ],
    [ u"gt",u"Villa Nueva",397158,14.526944,-90.5875 ],
    [ u"gt",u"Yepocapa",8777,14.504167,-90.956944 ],
    [ u"gt",u"Yupiltepeque",2966,14.2,-89.783333 ],
    [ u"gt",u"Zacapa",35349,14.966667,-89.533333 ],
    [ u"gt",u"Zacualpa",9050,15.083333,-90.833333 ],
    [ u"gt",u"Zapotitlán",1583,14.133333,-89.833333 ],
    [ u"gt",u"Zaragoza",9168,14.654444,-90.889444 ],
    [ u"gt",u"Zunilito",2688,14.616667,-91.516667 ],
    [ u"gt",u"Zunil",9780,14.783333,-91.483333 ],
    [ u"gw",u"Bafatá",22521,12.1666667,-14.6666667 ],
    [ u"gw",u"Bissau",388094,11.85,-15.5833333 ],
    [ u"gw",u"Bissorã",12688,12.04,-15.4280556 ],
    [ u"gw",u"Bolama",10769,11.5833333,-15.4666667 ],
    [ u"gw",u"Buba",7779,11.5833333,-15.0 ],
    [ u"gw",u"Bubaque",9941,11.2833333,-15.8333333 ],
    [ u"gw",u"Cacheu",10490,12.2705556,-16.1658333 ],
    [ u"gw",u"Canchungo",6853,12.0672222,-16.0333333 ],
    [ u"gw",u"Catió",9898,11.2833333,-15.25 ],
    [ u"gw",u"Farim",6792,12.4838889,-15.2216667 ],
    [ u"gw",u"Fulacunda",1327,11.7666667,-15.1666667 ],
    [ u"gw",u"Gabú",14430,12.2833333,-14.2166667 ],
    [ u"gw",u"Mansôa",7821,12.0733333,-15.3188889 ],
    [ u"gw",u"Quebo",7072,11.3333333,-14.9333333 ],
    [ u"gy",u"Bartica",11159,6.4,-58.6166667 ],
    [ u"gy",u"Fort Wellington",2253,6.4,-57.6 ],
    [ u"gy",u"Georgetown",235017,6.8,-58.1666667 ],
    [ u"gy",u"Ituni",4567,5.5333333,-58.25 ],
    [ u"gy",u"Lethem",716,3.3833333,-59.8 ],
    [ u"gy",u"Linden",44690,6.0,-58.3 ],
    [ u"gy",u"Mabaruma",717,8.2,-59.7833333 ],
    [ u"gy",u"Mahaicony",2130,6.55,-57.8 ],
    [ u"gy",u"New Amsterdam",35039,6.25,-57.5166667 ],
    [ u"gy",u"Rosignol",5782,6.2833333,-57.5333333 ],
    [ u"gy",u"Skeldon",5859,5.8833333,-57.1333333 ],
    [ u"gy",u"Vreed en Hoop",3073,6.8,-58.1833333 ],
    [ u"hn",u"Achiotal",1210,14.0833333,-88.75 ],
    [ u"hn",u"Agalteca",1029,14.45,-87.2666667 ],
    [ u"hn",u"Agua Azul Rancho",1043,14.9,-87.95 ],
    [ u"hn",u"Agua Azul Sierra",1079,14.9166667,-87.9666667 ],
    [ u"hn",u"Agua Blanca Sur",7592,15.25,-87.8833333 ],
    [ u"hn",u"Agua Caliente",1075,14.8833333,-88.8166667 ],
    [ u"hn",u"Agua Caliente de Linaca",973,13.4352778,-87.2316667 ],
    [ u"hn",u"Agua Dulcita",1017,14.7,-87.75 ],
    [ u"hn",u"Agua Fría",3196,13.45,-87.55 ],
    [ u"hn",u"Agualote",1759,15.3352778,-88.5530556 ],
    [ u"hn",u"Aguas del Padre",1104,14.5666667,-87.8833333 ],
    [ u"hn",u"Ahuás",1505,15.4833333,-84.3333333 ],
    [ u"hn",u"Ajuterique",5354,14.3833333,-87.7 ],
    [ u"hn",u"Alubarén",983,13.7961111,-87.4688889 ],
    [ u"hn",u"Amapala",2137,13.2922222,-87.6538889 ],
    [ u"hn",u"Antigua Ocotepeque",1862,14.4,-89.2 ],
    [ u"hn",u"Apacilagua",1251,13.4780556,-87.0755556 ],
    [ u"hn",u"Arada",2913,14.85,-88.3 ],
    [ u"hn",u"Aramecina",1071,13.75,-87.7166667 ],
    [ u"hn",u"Araulí",1160,13.95,-86.55 ],
    [ u"hn",u"Arenal",1722,15.35,-86.8333333 ],
    [ u"hn",u"Arimís",1817,14.7833333,-86.0 ],
    [ u"hn",u"Arizona",4444,15.6333333,-87.3166667 ],
    [ u"hn",u"Armenia",1488,15.4666667,-86.3666667 ],
    [ u"hn",u"Armenta",2989,15.5,-88.05 ],
    [ u"hn",u"Atenas de San Cristóbal",1783,15.6833333,-87.3166667 ],
    [ u"hn",u"Atima",1703,14.9333333,-88.4833333 ],
    [ u"hn",u"Auka",1254,14.9333333,-83.8333333 ],
    [ u"hn",u"Ayapa",1559,15.1,-87.15 ],
    [ u"hn",u"Azacualpa",966,14.2666667,-88.3833333 ],
    [ u"hn",u"Azacualpa",966,14.2166667,-88.45 ],
    [ u"hn",u"Azacualpa",1258,14.7166667,-88.1 ],
    [ u"hn",u"Bálsamo Oriental",1465,15.4833333,-86.3333333 ],
    [ u"hn",u"Baracoa",9202,15.7666667,-87.85 ],
    [ u"hn",u"Barra Patuca",2759,15.8,-84.2833333 ],
    [ u"hn",u"Bejuco",1276,15.1333333,-87.9333333 ],
    [ u"hn",u"Belén Gualcho",2359,14.4833333,-88.8 ],
    [ u"hn",u"Berlín",1050,14.8333333,-88.5 ],
    [ u"hn",u"Bonito Oriental",3732,15.7333333,-85.7333333 ],
    [ u"hn",u"Brus Laguna",4067,15.75,-84.4833333 ],
    [ u"hn",u"Buenos Aires",1131,15.0333333,-88.9666667 ],
    [ u"hn",u"Buenos Aires",979,15.4833333,-88.1833333 ],
    [ u"hn",u"Buenos Aires",980,15.35,-86.7333333 ],
    [ u"hn",u"Callejones",1033,15.1666667,-88.65 ],
    [ u"hn",u"Camalote",1319,15.3333333,-88.3333333 ],
    [ u"hn",u"Camasca",1150,14.0,-88.3833333 ],
    [ u"hn",u"Campamento",6560,14.55,-86.65 ],
    [ u"hn",u"Cañaveral",2137,14.9833333,-88.0166667 ],
    [ u"hn",u"Cane",2190,14.2833333,-87.6666667 ],
    [ u"hn",u"Carbajales",1102,15.5166667,-86.35 ],
    [ u"hn",u"Casa Quemada",3036,15.1166667,-88.0833333 ],
    [ u"hn",u"Casa Quemada",1030,15.2666667,-88.55 ],
    [ u"hn",u"Catacamas",33052,14.8,-85.9 ],
    [ u"hn",u"Cedeño",1503,13.1727778,-87.4316667 ],
    [ u"hn",u"Cedros",1041,14.6,-87.1166667 ],
    [ u"hn",u"Ceguaca",1239,14.8,-88.2 ],
    [ u"hn",u"Cerro Blanco",1169,14.6666667,-87.7833333 ],
    [ u"hn",u"Cerro Grande",1093,13.8166667,-87.25 ],
    [ u"hn",u"Chalmeca",2008,15.1,-88.6833333 ],
    [ u"hn",u"Chiquila",983,15.2333333,-88.5833333 ],
    [ u"hn",u"Chirinos",921,15.4,-86.5833333 ],
    [ u"hn",u"Chivana",1018,15.75,-87.9833333 ],
    [ u"hn",u"Choloma",139117,15.6166667,-87.95 ],
    [ u"hn",u"Choluteca",75880,13.3002778,-87.1908333 ],
    [ u"hn",u"Chotepe",1564,15.4166667,-87.9833333 ],
    [ u"hn",u"Cofradía",20353,15.4,-88.15 ],
    [ u"hn",u"Cofradía",1301,14.2166667,-87.1833333 ],
    [ u"hn",u"Cololaca",1014,14.3,-88.8833333 ],
    [ u"hn",u"Comayagua",58791,14.45,-87.6333333 ],
    [ u"hn",u"Concepción de Guasistagua",1470,14.6,-87.65 ],
    [ u"hn",u"Concepción del Norte",946,15.1666667,-88.1333333 ],
    [ u"hn",u"Concepción del Sur",1049,14.8,-88.1666667 ],
    [ u"hn",u"Concepción de María",923,13.2166667,-87.0 ],
    [ u"hn",u"Concordia",1272,14.6166667,-86.65 ],
    [ u"hn",u"Copán",6337,14.8333333,-89.15 ],
    [ u"hn",u"Corinto",954,15.5833333,-88.3666667 ],
    [ u"hn",u"Corocito",2855,15.75,-85.7833333 ],
    [ u"hn",u"Corozal",2261,15.8,-86.7166667 ],
    [ u"hn",u"Corquín",4753,14.5666667,-88.8666667 ],
    [ u"hn",u"Correderos",1162,15.4166667,-88.45 ],
    [ u"hn",u"Coyoles Central",1144,15.4,-86.6666667 ],
    [ u"hn",u"Coyoles",949,15.4666667,-86.6833333 ],
    [ u"hn",u"Cubulero",1286,13.4833333,-87.6833333 ],
    [ u"hn",u"Cucuyagua",2939,14.65,-88.8666667 ],
    [ u"hn",u"Cusuna",1441,15.85,-85.2333333 ],
    [ u"hn",u"Cuyalí",1572,13.8833333,-86.55 ],
    [ u"hn",u"Cuyamel",5022,15.6666667,-88.2 ],
    [ u"hn",u"Danlí",44805,14.0333333,-86.5833333 ],
    [ u"hn",u"Dolores",1107,14.8666667,-88.8333333 ],
    [ u"hn",u"Dulce Nombre de Culmí",2091,15.1,-85.5333333 ],
    [ u"hn",u"Dulce Nombre",3590,14.85,-88.8333333 ],
    [ u"hn",u"Duyure",1164,13.6333333,-86.8166667 ],
    [ u"hn",u"El Bálsamo",1741,15.0666667,-87.4666667 ],
    [ u"hn",u"El Benque",1101,14.0333333,-86.4666667 ],
    [ u"hn",u"El Buen Pastor",942,14.8666667,-87.65 ],
    [ u"hn",u"El Caimito",832,13.4463889,-87.475 ],
    [ u"hn",u"El Chichicaste",1671,14.0666667,-86.3 ],
    [ u"hn",u"El Chimbo",1145,14.1333333,-87.1166667 ],
    [ u"hn",u"El Ciruelo",2980,15.3,-88.5 ],
    [ u"hn",u"El Corozal",1039,15.0666667,-88.6166667 ],
    [ u"hn",u"El Corpus",1199,13.2888889,-87.0347222 ],
    [ u"hn",u"El Corpus",1193,14.7,-88.9166667 ],
    [ u"hn",u"El Derrumbo",929,14.75,-88.7833333 ],
    [ u"hn",u"El Durazno",923,14.1333333,-87.2666667 ],
    [ u"hn",u"El Edén",954,14.95,-88.0166667 ],
    [ u"hn",u"El Ermitano",947,15.25,-88.6833333 ],
    [ u"hn",u"El Escanito",1184,14.6666667,-87.1 ],
    [ u"hn",u"El Escaño de Tepale",1026,14.75,-87.0666667 ],
    [ u"hn",u"El Granzal",876,14.4,-88.8666667 ],
    [ u"hn",u"El Guante",1082,14.55,-87.1 ],
    [ u"hn",u"El Guantillo",1223,14.6,-87.3 ],
    [ u"hn",u"El Guapinol",1817,13.7666667,-87.4666667 ],
    [ u"hn",u"El Guayabito",1404,14.8333333,-86.0333333 ],
    [ u"hn",u"El Guayabo",889,13.4894444,-87.4438889 ],
    [ u"hn",u"El Higuero",1052,14.5666667,-87.7166667 ],
    [ u"hn",u"Elíxir",3079,15.4833333,-86.3 ],
    [ u"hn",u"El Juncal",1286,15.45,-86.4333333 ],
    [ u"hn",u"El Llano",1923,15.15,-87.8833333 ],
    [ u"hn",u"El Lolo",1438,14.1166667,-87.2666667 ],
    [ u"hn",u"El Marañón",1836,15.4,-88.05 ],
    [ u"hn",u"El Milagro",1916,15.4,-87.9666667 ],
    [ u"hn",u"El Mochito",1950,14.8666667,-88.0833333 ],
    [ u"hn",u"El Negrito",9304,15.3166667,-87.7 ],
    [ u"hn",u"El Níspero",2474,14.7666667,-88.3333333 ],
    [ u"hn",u"El Obraje",1172,13.1541667,-87.1308333 ],
    [ u"hn",u"El Obraje",1703,14.0,-86.4333333 ],
    [ u"hn",u"El Ocote",1908,15.4166667,-86.5666667 ],
    [ u"hn",u"El Ocotón",1038,15.0333333,-88.8833333 ],
    [ u"hn",u"El Olivar",1279,15.0833333,-87.8833333 ],
    [ u"hn",u"El Paraíso",18782,13.8666667,-86.55 ],
    [ u"hn",u"El Paraíso",4126,14.4833333,-88.7833333 ],
    [ u"hn",u"El Pedernal",1648,14.7,-87.1166667 ],
    [ u"hn",u"El Perico",957,13.1388889,-87.0322222 ],
    [ u"hn",u"El Perico",1141,15.0833333,-88.1 ],
    [ u"hn",u"El Pescadero",909,13.9333333,-86.55 ],
    [ u"hn",u"El Pino",3004,15.7,-86.9333333 ],
    [ u"hn",u"El Plan",2176,15.2833333,-87.9666667 ],
    [ u"hn",u"El Porvenir",2269,15.75,-86.9333333 ],
    [ u"hn",u"El Porvenir",1337,14.5833333,-87.8833333 ],
    [ u"hn",u"El Porvenir",2940,15.8333333,-87.9333333 ],
    [ u"hn",u"El Porvenir",3153,13.7616667,-87.3458333 ],
    [ u"hn",u"El Progreso",100821,15.4,-87.8 ],
    [ u"hn",u"El Puente",1325,13.2833333,-87.1166667 ],
    [ u"hn",u"El Rancho",1101,15.6666667,-87.95 ],
    [ u"hn",u"El Rincón",1522,14.5833333,-87.9333333 ],
    [ u"hn",u"El Rodeo",893,14.2833333,-86.6 ],
    [ u"hn",u"El Rosario",2575,14.5833333,-87.7333333 ],
    [ u"hn",u"El Rosario",962,14.9,-86.6833333 ],
    [ u"hn",u"El Rusio",1016,14.4666667,-86.3666667 ],
    [ u"hn",u"El Sauce",1389,14.4,-87.7833333 ],
    [ u"hn",u"El Socorro",1092,14.6333333,-87.9166667 ],
    [ u"hn",u"El Suyatal",2027,14.5166667,-87.2166667 ],
    [ u"hn",u"El Tablón",1121,14.0333333,-87.1666667 ],
    [ u"hn",u"El Terrero",1087,14.0666667,-87.0666667 ],
    [ u"hn",u"El Tigre",1435,14.9333333,-87.9833333 ],
    [ u"hn",u"El Tizatillo",798,13.9994444,-87.195 ],
    [ u"hn",u"El Tránsito",1025,14.3833333,-88.9166667 ],
    [ u"hn",u"El Triunfo",7183,13.1166667,-87.0 ],
    [ u"hn",u"El Tular",1927,13.45,-87.5166667 ],
    [ u"hn",u"El Zapote",970,15.0166667,-87.85 ],
    [ u"hn",u"Erandique",1882,14.2333333,-88.4666667 ],
    [ u"hn",u"Esparta",1115,15.7166667,-87.2 ],
    [ u"hn",u"Esquías",1339,14.7333333,-87.3666667 ],
    [ u"hn",u"Flores",3018,14.2833333,-87.5666667 ],
    [ u"hn",u"Florida",5340,15.0333333,-88.8333333 ],
    [ u"hn",u"Francia",1331,15.85,-85.5833333 ],
    [ u"hn",u"French Harbor",2698,16.35,-86.4333333 ],
    [ u"hn",u"Goascorán",1350,13.5833333,-87.6166667 ],
    [ u"hn",u"Gracias",7910,14.5833333,-88.5833333 ],
    [ u"hn",u"Guacamaya",1250,15.0166667,-88.15 ],
    [ u"hn",u"Guaimaca",12901,14.5333333,-86.8166667 ],
    [ u"hn",u"Gualaco",3601,15.05,-86.05 ],
    [ u"hn",u"Gualjoco",1432,14.95,-88.2333333 ],
    [ u"hn",u"Guanaja",1942,16.4,-85.9 ],
    [ u"hn",u"Guarizama",1300,14.9166667,-86.3333333 ],
    [ u"hn",u"Guata",1217,15.0833333,-86.3833333 ],
    [ u"hn",u"Guatemalita",950,14.1166667,-88.6166667 ],
    [ u"hn",u"Guayape",1703,14.7166667,-86.8333333 ],
    [ u"hn",u"Guaymitas",2321,15.5,-87.7166667 ],
    [ u"hn",u"Güinope",2716,13.8833333,-86.9333333 ],
    [ u"hn",u"Hicaque",903,15.6666667,-87.3833333 ],
    [ u"hn",u"Ilama",1811,15.0666667,-88.2166667 ],
    [ u"hn",u"Intibucá",13743,14.3166667,-88.1666667 ],
    [ u"hn",u"Iralaya",1520,15.0,-83.2333333 ],
    [ u"hn",u"Jacaleapa",2578,14.0166667,-86.6666667 ],
    [ u"hn",u"Jamalteca",1107,14.7,-87.5833333 ],
    [ u"hn",u"Jardines",953,14.7,-87.9833333 ],
    [ u"hn",u"Jericó",2364,15.95,-85.9666667 ],
    [ u"hn",u"Jesús de Otoro",6988,14.4833333,-87.9833333 ],
    [ u"hn",u"Jícaro Galán",1370,13.5316667,-87.4388889 ],
    [ u"hn",u"Jiquinlaca",1248,14.0,-88.35 ],
    [ u"hn",u"Joconal",1206,15.3544444,-88.6355556 ],
    [ u"hn",u"Jocón",1731,15.2833333,-86.9666667 ],
    [ u"hn",u"Jutiapa",2815,15.7666667,-86.5166667 ],
    [ u"hn",u"Jutiapa",1153,13.9833333,-86.4 ],
    [ u"hn",u"Juticalpa",33690,14.65,-86.2 ],
    [ u"hn",u"Jutiquile",3585,14.7166667,-86.0833333 ],
    [ u"hn",u"La Brea",1055,15.8,-85.9666667 ],
    [ u"hn",u"La Bueso",1139,15.5833333,-87.8833333 ],
    [ u"hn",u"La Campana",2268,13.8833333,-87.4 ],
    [ u"hn",u"La Ceiba",130230,15.7833333,-86.8 ],
    [ u"hn",u"La Colorada",979,15.6166667,-86.8166667 ],
    [ u"hn",u"La Concepción",1985,14.7,-86.2333333 ],
    [ u"hn",u"La Criba",1001,13.4536111,-87.4133333 ],
    [ u"hn",u"La Curva",981,15.8,-85.7666667 ],
    [ u"hn",u"La Empalizada",933,14.65,-86.1333333 ],
    [ u"hn",u"La Encarnación",1484,14.6666667,-89.0833333 ],
    [ u"hn",u"La Entrada",14705,15.05,-88.7333333 ],
    [ u"hn",u"La Ermita",2495,14.4166667,-87.1 ],
    [ u"hn",u"La Esperanza",2014,15.6333333,-85.7666667 ],
    [ u"hn",u"La Esperanza",919,15.05,-89.1 ],
    [ u"hn",u"La Esperanza",985,15.4166667,-88.1833333 ],
    [ u"hn",u"La Esperanza",5319,14.3,-88.1833333 ],
    [ u"hn",u"La Estancia",1508,15.05,-86.35 ],
    [ u"hn",u"La Estancia",1668,15.2833333,-87.55 ],
    [ u"hn",u"La Flecha",2136,15.2833333,-88.4833333 ],
    [ u"hn",u"La Florida",899,14.0166667,-87.9666667 ],
    [ u"hn",u"La Guacamaya",2525,15.25,-87.8 ],
    [ u"hn",u"La Guama",1242,14.8833333,-87.9333333 ],
    [ u"hn",u"Laguna Seca",1131,14.7,-86.1 ],
    [ u"hn",u"Lagunas",986,14.6166667,-88.4833333 ],
    [ u"hn",u"Laguna Verde",1460,15.2,-88.1666667 ],
    [ u"hn",u"La Jigua",971,15.0333333,-88.8 ],
    [ u"hn",u"La Jutosa",4183,15.6333333,-88.0 ],
    [ u"hn",u"La Labor",1416,14.4833333,-89.0 ],
    [ u"hn",u"La Laguna del Pedernal",888,14.8166667,-88.5666667 ],
    [ u"hn",u"La Libertad",4673,14.45,-87.45 ],
    [ u"hn",u"La Libertad",1444,14.8,-88.5833333 ],
    [ u"hn",u"La Lima",45962,15.4333333,-87.9166667 ],
    [ u"hn",u"Lamaní",1791,14.2,-87.6166667 ],
    [ u"hn",u"La Masica",4022,15.6166667,-87.1166667 ],
    [ u"hn",u"La Mina",2690,15.3166667,-87.8333333 ],
    [ u"hn",u"Langue",3680,13.6166667,-87.65 ],
    [ u"hn",u"La Paz",17557,14.3166667,-87.6833333 ],
    [ u"hn",u"La Playona",1285,15.1166667,-88.9833333 ],
    [ u"hn",u"La Reina",954,15.1166667,-88.6333333 ],
    [ u"hn",u"La Rosa",1552,15.0666667,-87.1666667 ],
    [ u"hn",u"La Sabana",1524,15.3666667,-87.9333333 ],
    [ u"hn",u"Las Ánimas",1117,14.25,-86.5666667 ],
    [ u"hn",u"La Sarrosa",2188,15.2333333,-87.8333333 ],
    [ u"hn",u"Las Conchas",1084,13.3252778,-87.3955556 ],
    [ u"hn",u"Las Delicias",1326,14.7166667,-87.6166667 ],
    [ u"hn",u"Las Lajas",3011,14.7833333,-87.75 ],
    [ u"hn",u"Las Mercedes",1000,14.2833333,-87.5666667 ],
    [ u"hn",u"Las Tapias",814,14.0666667,-87.2833333 ],
    [ u"hn",u"Las Tejeras",1140,14.8,-88.6 ],
    [ u"hn",u"Las Vegas",7487,14.8666667,-88.0666667 ],
    [ u"hn",u"Las Vegas",1308,15.0166667,-87.45 ],
    [ u"hn",u"La Tajeada",882,13.2525,-87.0877778 ],
    [ u"hn",u"La Trinidad",880,14.7166667,-87.6666667 ],
    [ u"hn",u"La Trinidad",1314,15.1,-87.2 ],
    [ u"hn",u"La Unión",2382,15.7166667,-87.0 ],
    [ u"hn",u"La Unión",3054,14.8166667,-88.4 ],
    [ u"hn",u"La Unión",827,15.1333333,-88.55 ],
    [ u"hn",u"La Virtud",1315,14.05,-88.7 ],
    [ u"hn",u"La Zumbadora",1086,15.0166667,-88.9 ],
    [ u"hn",u"Lejamaní",3835,14.3666667,-87.7 ],
    [ u"hn",u"Lepaera",3137,14.7833333,-88.5833333 ],
    [ u"hn",u"Lepaterique",2090,14.0666667,-87.4666667 ],
    [ u"hn",u"Limón",2434,15.8666667,-85.5 ],
    [ u"hn",u"Liure",1022,13.5358333,-87.0919444 ],
    [ u"hn",u"Llano Largo",910,14.45,-88.75 ],
    [ u"hn",u"Loma Alta",1067,15.3966667,-88.5597222 ],
    [ u"hn",u"Lomitas",1552,15.1,-87.2166667 ],
    [ u"hn",u"Los Arroyos",916,14.65,-88.8833333 ],
    [ u"hn",u"Los Caminos",1146,14.95,-87.9666667 ],
    [ u"hn",u"Los Llanitos",1040,13.25,-87.0 ],
    [ u"hn",u"Los Naranjos",1684,14.9,-88.05 ],
    [ u"hn",u"Los Planes",1320,14.05,-88.0166667 ],
    [ u"hn",u"Los Tangos",1424,15.15,-88.6833333 ],
    [ u"hn",u"Lucerna",1452,14.55,-88.9333333 ],
    [ u"hn",u"Macholoa",989,14.9166667,-88.3 ],
    [ u"hn",u"Macuelizo",2867,15.3,-88.5333333 ],
    [ u"hn",u"Magdalena",966,13.8666667,-88.3 ],
    [ u"hn",u"Mandasta",940,13.7333333,-86.9166667 ],
    [ u"hn",u"Mangulile",1263,15.0666667,-86.8 ],
    [ u"hn",u"Manto",1098,14.9166667,-86.3833333 ],
    [ u"hn",u"Marale",1523,14.8833333,-87.15 ],
    [ u"hn",u"Marcala",10055,14.15,-88.0333333 ],
    [ u"hn",u"Marcovia",1928,13.2880556,-87.3097222 ],
    [ u"hn",u"Mata de Plátano",1151,14.6,-87.2833333 ],
    [ u"hn",u"Mateo",1021,14.0833333,-87.3166667 ],
    [ u"hn",u"Meámbar",902,14.7833333,-87.7666667 ],
    [ u"hn",u"Mercedes",984,14.3166667,-88.9833333 ],
    [ u"hn",u"Mezapa",6324,15.5833333,-87.65 ],
    [ u"hn",u"Minas de Oro",3554,14.8,-87.35 ],
    [ u"hn",u"Mojimán",1498,15.2666667,-87.6 ],
    [ u"hn",u"Monjarás",6772,13.2005556,-87.3741667 ],
    [ u"hn",u"Monterrey",2234,15.5833333,-87.8833333 ],
    [ u"hn",u"Morazán",11077,15.3166667,-87.6 ],
    [ u"hn",u"Morocelí",2984,14.1166667,-86.8666667 ],
    [ u"hn",u"Morolica",973,13.5666667,-86.9 ],
    [ u"hn",u"Nacaome",13931,13.5361111,-87.4875 ],
    [ u"hn",u"Naco",3966,15.3833333,-88.1833333 ],
    [ u"hn",u"Namasigüe",1804,13.2047222,-87.1388889 ],
    [ u"hn",u"Naranjito",3814,14.95,-88.6833333 ],
    [ u"hn",u"Nombre de Jesús",1250,15.35,-86.6833333 ],
    [ u"hn",u"Nueva Armenia",1392,15.8166667,-86.5 ],
    [ u"hn",u"Nueva Armenia",875,15.0333333,-89.1 ],
    [ u"hn",u"Nueva Esperanza",2121,15.2666667,-87.6 ],
    [ u"hn",u"Nueva Florida",904,15.4666667,-87.5 ],
    [ u"hn",u"Nueva Granada",939,15.1166667,-88.1 ],
    [ u"hn",u"Nuevo Celilac",950,14.9833333,-88.3333333 ],
    [ u"hn",u"Nuevo Chamelecón",2098,15.3833333,-88.0166667 ],
    [ u"hn",u"Nuevo Jalapa",1094,14.9166667,-88.3333333 ],
    [ u"hn",u"Ocote Paulino",1697,15.4166667,-87.6 ],
    [ u"hn",u"Ocotepeque",8781,14.4333333,-89.1833333 ],
    [ u"hn",u"Ojo de Agua",2330,14.0166667,-86.35 ],
    [ u"hn",u"Ojojona",2790,13.9338889,-87.2958333 ],
    [ u"hn",u"Ojos de Agua",1146,14.6,-87.9333333 ],
    [ u"hn",u"Ojos de Agua",1340,14.7,-88.8166667 ],
    [ u"hn",u"Olanchito",25972,15.5,-86.5666667 ],
    [ u"hn",u"Omoa",4763,15.7666667,-88.0333333 ],
    [ u"hn",u"Orica",2342,14.7,-86.95 ],
    [ u"hn",u"Orocuina",1655,13.4816667,-87.105 ],
    [ u"hn",u"Oropéndolas",1333,15.0166667,-87.9333333 ],
    [ u"hn",u"Oropolí",1412,13.8166667,-86.8166667 ],
    [ u"hn",u"Ostumán",862,14.8333333,-89.1666667 ],
    [ u"hn",u"Palkaka",909,15.3166667,-83.8666667 ],
    [ u"hn",u"Palo Pintado",909,14.5166667,-87.6833333 ],
    [ u"hn",u"Paptalaya",1227,15.5,-84.3166667 ],
    [ u"hn",u"Paujiles",1244,15.1,-87.35 ],
    [ u"hn",u"Peña Blanca",3552,15.5333333,-88.05 ],
    [ u"hn",u"Pespire",3172,13.5922222,-87.3616667 ],
    [ u"hn",u"Petoa",1067,15.2666667,-88.2833333 ],
    [ u"hn",u"Piedras Amarillas",999,15.6833333,-86.5666667 ],
    [ u"hn",u"Pimienta",8761,15.2833333,-87.9666667 ],
    [ u"hn",u"Pinalejo",3767,15.3833333,-88.4 ],
    [ u"hn",u"Portillo de Gonzalez",958,15.2833333,-87.6 ],
    [ u"hn",u"Potrerillos",1334,14.55,-87.8666667 ],
    [ u"hn",u"Potrerillos",1102,15.6333333,-88.3 ],
    [ u"hn",u"Potrerillos",900,15.2666667,-88.4333333 ],
    [ u"hn",u"Prieta",1103,15.5833333,-86.1833333 ],
    [ u"hn",u"Protección",2101,15.0333333,-88.65 ],
    [ u"hn",u"Pueblo Nuevo",1053,15.0,-88.75 ],
    [ u"hn",u"Pueblo Nuevo",3556,15.2833333,-88.0166667 ],
    [ u"hn",u"Pueblo Nuevo",958,14.3833333,-87.2833333 ],
    [ u"hn",u"Puente Alto",1385,15.7,-87.8666667 ],
    [ u"hn",u"Puerto Castilla",1220,16.0166667,-85.9666667 ],
    [ u"hn",u"Puerto Cortés",48020,15.8833333,-87.95 ],
    [ u"hn",u"Puerto Lempira",4857,15.2666667,-83.7666667 ],
    [ u"hn",u"Punta de Piedra",1188,15.9,-85.2833333 ],
    [ u"hn",u"Punta Ocote",1399,15.2,-87.2833333 ],
    [ u"hn",u"Punuare",1905,14.7333333,-85.9666667 ],
    [ u"hn",u"Quebrada de Arena",2723,15.7666667,-85.9166667 ],
    [ u"hn",u"Quebrada de Yoro",896,15.4333333,-87.7833333 ],
    [ u"hn",u"Quebrada Larga",1217,14.1,-86.3666667 ],
    [ u"hn",u"Quebrada Seca",2248,15.6666667,-87.95 ],
    [ u"hn",u"Quezailica",1115,14.8833333,-88.7333333 ],
    [ u"hn",u"Quimistán",3517,15.35,-88.4 ],
    [ u"hn",u"Rancho Grande",1484,14.6833333,-87.5 ],
    [ u"hn",u"Reitoca",1094,13.8258333,-87.4652778 ],
    [ u"hn",u"Río Abajo",2055,14.1666667,-87.2166667 ],
    [ u"hn",u"Río Amarillo",1000,14.9666667,-89.1333333 ],
    [ u"hn",u"Río Arriba",995,13.1763889,-87.0486111 ],
    [ u"hn",u"Río Blanquito",2458,15.7333333,-87.9 ],
    [ u"hn",u"Río Bonito",1054,14.7666667,-87.8833333 ],
    [ u"hn",u"Río Chiquito",1405,15.6333333,-88.25 ],
    [ u"hn",u"Río Esteban",1208,15.8333333,-86.3 ],
    [ u"hn",u"Río Lindo",3479,15.0333333,-87.9833333 ],
    [ u"hn",u"Roatán",7515,16.3,-86.55 ],
    [ u"hn",u"Sabana Abajo",884,14.6,-86.5833333 ],
    [ u"hn",u"Sabanagrande",2056,13.8077778,-87.2591667 ],
    [ u"hn",u"Sabá",9666,15.4666667,-86.25 ],
    [ u"hn",u"Salamá",1737,15.75,-85.9666667 ],
    [ u"hn",u"Salamá",2820,14.8333333,-86.5833333 ],
    [ u"hn",u"Sambo Creek",2532,15.8166667,-86.6833333 ],
    [ u"hn",u"San Agustín",938,13.2,-87.1166667 ],
    [ u"hn",u"San Agustín",1777,14.8166667,-88.9333333 ],
    [ u"hn",u"San Antonio de Cortés",4955,15.1166667,-88.0333333 ],
    [ u"hn",u"San Antonio del Norte",1002,13.8833333,-87.7 ],
    [ u"hn",u"San Antonio",1151,15.6,-87.15 ],
    [ u"hn",u"San Antonio",1638,14.4333333,-88.5833333 ],
    [ u"hn",u"San Antonio",962,14.3,-89.0 ],
    [ u"hn",u"San Antonio",1711,15.3333333,-87.15 ],
    [ u"hn",u"San Buenaventura",1452,15.0166667,-88.0 ],
    [ u"hn",u"San Diego",1306,14.05,-86.4666667 ],
    [ u"hn",u"Sandy Bay",1072,16.3166667,-86.5666667 ],
    [ u"hn",u"San Esteban",3439,15.2,-85.75 ],
    [ u"hn",u"San Fernando",1026,14.6833333,-89.1166667 ],
    [ u"hn",u"San Francisco de Becerra",2411,14.6333333,-86.1 ],
    [ u"hn",u"San Francisco de Cones",1066,14.5166667,-88.9 ],
    [ u"hn",u"San Francisco de Coray",1330,13.65,-87.5333333 ],
    [ u"hn",u"San Francisco del Valle",1878,14.4333333,-88.95 ],
    [ u"hn",u"San Francisco de Ojuera",853,14.75,-88.1833333 ],
    [ u"hn",u"San Francisco de Yojoa",1946,15.0166667,-87.9666667 ],
    [ u"hn",u"San Francisco",2806,15.65,-87.05 ],
    [ u"hn",u"San Francisco",883,13.1808333,-87.0983333 ],
    [ u"hn",u"San Ignacio",2330,14.65,-87.0333333 ],
    [ u"hn",u"San Jerónimo",2381,13.1766667,-87.1363889 ],
    [ u"hn",u"San Jerónimo",1789,14.6333333,-87.6 ],
    [ u"hn",u"San Jerónimo",1046,14.9666667,-88.8666667 ],
    [ u"hn",u"San Joaquín",1130,15.05,-88.9 ],
    [ u"hn",u"San José de Colinas",3985,15.0333333,-88.3 ],
    [ u"hn",u"San José de Comayagua",1066,14.7333333,-88.0333333 ],
    [ u"hn",u"San José del Boquerón",1432,15.4833333,-87.8666667 ],
    [ u"hn",u"San José del Potrero",1091,14.8333333,-87.2833333 ],
    [ u"hn",u"San José de Oriente",888,15.0333333,-88.1166667 ],
    [ u"hn",u"San José de Pane",958,14.4833333,-87.8333333 ],
    [ u"hn",u"San José de Río Tinto",1071,14.9333333,-85.7 ],
    [ u"hn",u"San José de Tarros",1634,15.3,-88.7 ],
    [ u"hn",u"San José",1789,14.9,-88.7166667 ],
    [ u"hn",u"San José",1463,14.1166667,-87.9166667 ],
    [ u"hn",u"San José",1897,15.1166667,-87.3166667 ],
    [ u"hn",u"San Juancito",895,14.2166667,-87.0666667 ],
    [ u"hn",u"San Juan de Flores",3633,14.2666667,-87.0333333 ],
    [ u"hn",u"San Juan de Opoa",1636,14.7833333,-88.7 ],
    [ u"hn",u"San Juan de Planes",1048,14.9333333,-88.7833333 ],
    [ u"hn",u"San Juan Pueblo",5735,15.5833333,-87.2333333 ],
    [ u"hn",u"San Juan",1512,15.7333333,-87.5 ],
    [ u"hn",u"San Lorenzo",22291,13.4241667,-87.4472222 ],
    [ u"hn",u"San Lucas",1307,13.7333333,-86.95 ],
    [ u"hn",u"San Luis de Planes",1111,14.9833333,-88.1333333 ],
    [ u"hn",u"San Luis",1967,14.75,-87.4166667 ],
    [ u"hn",u"San Luis",5733,15.0833333,-88.3833333 ],
    [ u"hn",u"San Manuel",6389,15.3333333,-87.9166667 ],
    [ u"hn",u"San Marcos de Colón",8821,13.4333333,-86.8 ],
    [ u"hn",u"San Marcos",5346,14.4,-88.95 ],
    [ u"hn",u"San Marcos",3924,15.3,-88.4166667 ],
    [ u"hn",u"San Matías",1251,13.9833333,-86.6333333 ],
    [ u"hn",u"San Nicolás",976,14.7166667,-87.35 ],
    [ u"hn",u"San Nicolás",2231,15.0,-88.75 ],
    [ u"hn",u"San Nicolás",1313,14.55,-86.25 ],
    [ u"hn",u"San Nicolás",3523,14.9333333,-88.3166667 ],
    [ u"hn",u"San Pedro de Tutule",1876,14.25,-87.85 ],
    [ u"hn",u"San Pedro Sula",489506,15.5,-88.0333333 ],
    [ u"hn",u"San Pedro Zacapa",1065,14.75,-88.1166667 ],
    [ u"hn",u"San Sebastián",1471,14.25,-87.6333333 ],
    [ u"hn",u"Santa Ana de Yusguare",1823,13.3005556,-87.1138889 ],
    [ u"hn",u"Santa Ana",3579,15.65,-87.0666667 ],
    [ u"hn",u"Santa Ana",1052,13.9316667,-87.2713889 ],
    [ u"hn",u"Santa Bárbara",15121,14.9166667,-88.2333333 ],
    [ u"hn",u"Santa Cruz de Yojoa",10230,14.9833333,-87.9 ],
    [ u"hn",u"Santa Cruz",1174,13.2580556,-87.3483333 ],
    [ u"hn",u"Santa Cruz",863,14.75,-88.9833333 ],
    [ u"hn",u"Santa Cruz",1430,13.8666667,-86.6333333 ],
    [ u"hn",u"Santa Elena",1361,15.3833333,-88.1333333 ],
    [ u"hn",u"Santa Fe",915,14.5166667,-89.2333333 ],
    [ u"hn",u"Santa Lucía",2288,14.1,-87.1166667 ],
    [ u"hn",u"Santa Lucía",1224,14.4166667,-89.2 ],
    [ u"hn",u"Santa María del Real",4587,14.7666667,-85.95 ],
    [ u"hn",u"Santa Rita",2704,14.8666667,-89.1 ],
    [ u"hn",u"Santa Rita",1687,14.9166667,-88.2166667 ],
    [ u"hn",u"Santa Rita",12871,15.1666667,-87.2833333 ],
    [ u"hn",u"Santa Rosa de Aguán",1304,15.95,-85.7166667 ],
    [ u"hn",u"Santa Rosa de Copán",27756,14.7666667,-88.7833333 ],
    [ u"hn",u"Santa Teresa",914,14.3833333,-89.0 ],
    [ u"hn",u"Santiago de Puringla",2433,14.35,-87.9 ],
    [ u"hn",u"San Vicente Centenario",2430,14.8833333,-88.2833333 ],
    [ u"hn",u"Savannah Bight",1031,16.45,-85.85 ],
    [ u"hn",u"Sensenti",1551,14.4833333,-88.9333333 ],
    [ u"hn",u"Siguatepeque",43146,14.6,-87.8333333 ],
    [ u"hn",u"Silca",1112,14.8333333,-86.5333333 ],
    [ u"hn",u"Sinuapa",2389,14.45,-89.1833333 ],
    [ u"hn",u"Sonaguera",11444,15.6333333,-86.3333333 ],
    [ u"hn",u"Subirana",1362,15.2,-87.45 ],
    [ u"hn",u"Sulaco",2760,14.9166667,-87.2666667 ],
    [ u"hn",u"Sula",2502,15.25,-88.5666667 ],
    [ u"hn",u"Suyapa de Lean",941,15.5166667,-87.4 ],
    [ u"hn",u"Talanga",13492,14.4,-87.0833333 ],
    [ u"hn",u"Támara",2683,14.15,-87.3333333 ],
    [ u"hn",u"Taragual",1043,14.75,-88.4833333 ],
    [ u"hn",u"Taujica",1271,15.7,-85.9166667 ],
    [ u"hn",u"Taulabé",4660,14.7,-87.9666667 ],
    [ u"hn",u"Teguajinal",1117,15.3666667,-86.6 ],
    [ u"hn",u"Tegucigalpa",850961,14.1,-87.2166667 ],
    [ u"hn",u"Tela",29329,15.7833333,-87.45 ],
    [ u"hn",u"Tepanguare",1040,14.3333333,-87.75 ],
    [ u"hn",u"Tepusteca",1638,15.4166667,-86.3166667 ],
    [ u"hn",u"Teupasenti",4208,14.2166667,-86.7 ],
    [ u"hn",u"Texíguat",1012,13.6497222,-87.0225 ],
    [ u"hn",u"Tocoa",30789,15.6833333,-86.0 ],
    [ u"hn",u"Toloa Adentro",981,15.6166667,-87.7166667 ],
    [ u"hn",u"Tornabé",1452,15.75,-87.55 ],
    [ u"hn",u"Toyós",2530,15.55,-87.65 ],
    [ u"hn",u"Travesía",1283,15.8666667,-87.9 ],
    [ u"hn",u"Trinidad de Copán",2232,14.95,-88.75 ],
    [ u"hn",u"Trinidad de Quebradas",1405,14.5,-87.35 ],
    [ u"hn",u"Trinidad",4276,15.1333333,-88.2333333 ],
    [ u"hn",u"Trojas",1068,15.35,-86.7 ],
    [ u"hn",u"Trojes",6253,14.0666667,-85.9833333 ],
    [ u"hn",u"Trujillo",9647,15.9166667,-86.0 ],
    [ u"hn",u"Urraco",5711,15.2333333,-87.85 ],
    [ u"hn",u"Urrutia",799,14.75,-87.0333333 ],
    [ u"hn",u"Utilá",1834,15.65,-86.35 ],
    [ u"hn",u"Vallecillo",1986,14.5166667,-87.4 ],
    [ u"hn",u"Valle de Ángeles",1101,14.5,-87.6333333 ],
    [ u"hn",u"Valle de Ángeles",4649,14.15,-87.0333333 ],
    [ u"hn",u"Veracruz",1045,14.9166667,-88.7833333 ],
    [ u"hn",u"Victoria",2884,15.4833333,-87.8166667 ],
    [ u"hn",u"Villa de San Antonio",5390,14.3166667,-87.6166667 ],
    [ u"hn",u"Villa de San Francisco",5914,14.1666667,-86.9666667 ],
    [ u"hn",u"Villanueva",31570,15.3166667,-88.0 ],
    [ u"hn",u"Villa Nueva",2295,14.0166667,-87.15 ],
    [ u"hn",u"Vivistorio",949,14.9,-88.7333333 ],
    [ u"hn",u"Waksma",969,15.4333333,-84.4 ],
    [ u"hn",u"Wampusirpi",1462,15.1833333,-84.6166667 ],
    [ u"hn",u"Wawina",1481,15.4166667,-84.4333333 ],
    [ u"hn",u"Yaguacire",1449,14.0166667,-87.2166667 ],
    [ u"hn",u"Yamaranguila",1187,14.2833333,-88.25 ],
    [ u"hn",u"Yaruchel",1105,14.5333333,-88.8166667 ],
    [ u"hn",u"Yarumela",3059,14.3333333,-87.6333333 ],
    [ u"hn",u"Yorito",2169,15.0666667,-87.2833333 ],
    [ u"hn",u"Yoro",15776,15.1333333,-87.1333333 ],
    [ u"hn",u"Yuscarán",2371,13.9333333,-86.85 ],
    [ u"hn",u"Zambrano",3873,14.2666667,-87.4 ],
    [ u"hn",u"Zamora",2999,15.6333333,-86.0666667 ],
    [ u"hn",u"Zapotal del Norte",2507,15.5166667,-88.05 ],
    [ u"hn",u"Zopilotepe",1300,14.6,-86.2666667 ],
    [ u"hr",u"Beli Manastir",8713,45.77,18.6036111 ],
    [ u"hr",u"Biograd na Moru",5285,43.9433333,15.4519444 ],
    [ u"hr",u"Bjelovar",28275,45.8986111,16.8488889 ],
    [ u"hr",u"Buje",3016,45.41,13.6619444 ],
    [ u"hr",u"Cakovec",15867,46.3844444,16.4338889 ],
    [ u"hr",u"Dubrovnik",28428,42.6505556,18.0913889 ],
    [ u"hr",u"Gospic",6118,44.5461111,15.3747222 ],
    [ u"hr",u"Gracac",2702,44.2986111,15.8444444 ],
    [ u"hr",u"Karlovac",48123,45.4872222,15.5477778 ],
    [ u"hr",u"Knin",11182,44.0438889,16.2 ],
    [ u"hr",u"Koprivnica",25579,46.1627778,16.8275 ],
    [ u"hr",u"Korcula",3141,42.9622222,17.1369444 ],
    [ u"hr",u"Krapina",4725,46.1608333,15.8788889 ],
    [ u"hr",u"Krizevci",11597,46.0219444,16.5425 ],
    [ u"hr",u"Krk",3380,45.0258333,14.5730556 ],
    [ u"hr",u"Kutina",14886,45.475,16.7819444 ],
    [ u"hr",u"Makarska",13446,43.2969444,17.0177778 ],
    [ u"hr",u"Metkovic",13941,43.0541667,17.6483333 ],
    [ u"hr",u"Nasice",8213,45.4886111,18.0877778 ],
    [ u"hr",u"Nova Gradiska",13329,45.255,17.3830556 ],
    [ u"hr",u"Novska",7306,45.3405556,16.9769444 ],
    [ u"hr",u"Ogulin",8755,45.2661111,15.2286111 ],
    [ u"hr",u"Omis",6597,43.4447222,16.6886111 ],
    [ u"hr",u"Opatija",7888,45.3391667,14.3083333 ],
    [ u"hr",u"Osijek",88141,45.5511111,18.6938889 ],
    [ u"hr",u"Pag",2714,44.445,15.0575 ],
    [ u"hr",u"Petrinja",13868,45.4375,16.29 ],
    [ u"hr",u"Porec",10499,45.2258333,13.5938889 ],
    [ u"hr",u"Pozega",21153,45.3402778,17.6852778 ],
    [ u"hr",u"Pula",59079,44.8683333,13.8480556 ],
    [ u"hr",u"Rab",557,44.7569444,14.7608333 ],
    [ u"hr",u"Rijeka",141173,45.3430556,14.4091667 ],
    [ u"hr",u"Rovinj",13533,45.08,13.64 ],
    [ u"hr",u"Senj",5518,44.9894444,14.9058333 ],
    [ u"hr",u"Sesvete",52412,45.8311111,16.1163889 ],
    [ u"hr",u"Sibenik",37113,43.7272222,15.9058333 ],
    [ u"hr",u"Sinj",11524,43.7036111,16.6394444 ],
    [ u"hr",u"Sisak",35749,45.4661111,16.3783333 ],
    [ u"hr",u"Slatina",10973,45.7033333,17.7027778 ],
    [ u"hr",u"Slavonski Brod",60742,45.1602778,18.0155556 ],
    [ u"hr",u"Solin",15927,43.55,16.5 ],
    [ u"hr",u"Split",176315,43.5138889,16.4558333 ],
    [ u"hr",u"Trogir",10960,43.5125,16.2516667 ],
    [ u"hr",u"Varazdin",41808,46.3044444,16.3377778 ],
    [ u"hr",u"Velika Gorica",35073,45.7125,16.0755556 ],
    [ u"hr",u"Vinkovci",33315,45.2883333,18.8047222 ],
    [ u"hr",u"Virovitica",15665,45.8319444,17.3838889 ],
    [ u"hr",u"Vukovar",29584,45.3433333,18.9997222 ],
    [ u"hr",u"Zadar",71258,44.1197222,15.2422222 ],
    [ u"hr",u"Zagreb",698967,45.8,16.0 ],
    [ u"hr",u"Zapresic",17624,45.8563889,15.8077778 ],
    [ u"hr",u"Zupanja",13842,45.0775,18.6975 ],
    [ u"ht",u"Aquin",5219,18.2833333,-73.4 ],
    [ u"ht",u"Cap-Haïtien",134823,19.7577778,-72.2041667 ],
    [ u"ht",u"Carrefour",439590,18.5383333,-72.4122222 ],
    [ u"ht",u"Delmas",377194,18.5447222,-72.3027778 ],
    [ u"ht",u"Dérac",1808,19.65,-71.8166667 ],
    [ u"ht",u"Desdunes",12990,19.2833333,-72.65 ],
    [ u"ht",u"Dessalines",12313,19.2833333,-72.5 ],
    [ u"ht",u"Gonaïves",84966,19.45,-72.6833333 ],
    [ u"ht",u"Grande Rivière du Nord",8826,19.5833333,-72.1833333 ],
    [ u"ht",u"Hinche",18580,19.15,-72.0166667 ],
    [ u"ht",u"Jacmel",33569,18.2341667,-72.5347222 ],
    [ u"ht",u"Jeremie",30920,18.6166667,-74.0833333 ],
    [ u"ht",u"Kenscoff",5176,18.4505556,-72.2869444 ],
    [ u"ht",u"Lascahobas",7564,18.8294444,-71.9363889 ],
    [ u"ht",u"Léogâne",11545,18.5108333,-72.6338889 ],
    [ u"ht",u"Les Cayes",59323,18.2,-73.75 ],
    [ u"ht",u"Limbé",32652,19.7,-72.4 ],
    [ u"ht",u"Miragoâne",6009,18.45,-73.1 ],
    [ u"ht",u"Mirebalais",9088,18.8333333,-72.1052778 ],
    [ u"ht",u"Ouanaminthe",10152,19.55,-71.7333333 ],
    [ u"ht",u"Pétionville",108235,18.5125,-72.2852778 ],
    [ u"ht",u"Petit Goâve",14531,18.4313889,-72.8669444 ],
    [ u"ht",u"Pignon",6766,19.3333333,-72.1166667 ],
    [ u"ht",u"Port-au-Prince",1234750,18.5391667,-72.335 ],
    [ u"ht",u"Port-de-Paix",34659,19.95,-72.8333333 ],
    [ u"ht",u"Saint-Marc",66230,19.1166667,-72.7 ],
    [ u"ht",u"Saint-Raphaël",6002,19.4333333,-72.2 ],
    [ u"ht",u"Verrettes",48811,19.05,-72.4666667 ],
    [ u"hu",u"Aba",4479,47.029072,18.521721 ],
    [ u"hu",u"Abádszalók",4654,47.466667,20.6 ],
    [ u"hu",u"Abasár",3189,47.797049,20.003236 ],
    [ u"hu",u"Abaújszántó",3366,48.283333,21.2 ],
    [ u"hu",u"Abda",2997,47.694641,17.544885 ],
    [ u"hu",u"Abony",16342,47.1899,20.004759 ],
    [ u"hu",u"Ács",7180,47.712314,18.011313 ],
    [ u"hu",u"Adács",2890,47.6921,19.976956 ],
    [ u"hu",u"Ádánd",2306,46.85931,18.164423 ],
    [ u"hu",u"Adony",3812,47.119398,18.864929 ],
    [ u"hu",u"Ágasegyháza",1898,46.840255,19.452077 ],
    [ u"hu",u"Ágfalva",1971,47.68991,16.516576 ],
    [ u"hu",u"Ajak",3983,48.176636,22.062734 ],
    [ u"hu",u"Ajka",31407,47.101963,17.558923 ],
    [ u"hu",u"Akasztó",3480,46.691667,19.204233 ],
    [ u"hu",u"Alap",2149,46.799145,18.689383 ],
    [ u"hu",u"Alattyán",2004,47.427051,20.042195 ],
    [ u"hu",u"Albertirsa",11864,47.243147,19.616858 ],
    [ u"hu",u"Almasfuzito",2348,47.727519,18.265382 ],
    [ u"hu",u"Alsónémedi",4974,47.315243,19.158426 ],
    [ u"hu",u"Alsózsolca",6107,48.066667,20.883333 ],
    [ u"hu",u"Anarcs",2021,48.176423,22.111671 ],
    [ u"hu",u"Andornaktálya",2636,47.85,20.416667 ],
    [ u"hu",u"Apagy",2348,47.964305,21.935387 ],
    [ u"hu",u"Apátfalva",3268,46.166667,20.583333 ],
    [ u"hu",u"Apc",2754,47.794194,19.694289 ],
    [ u"hu",u"Apostag",2099,46.882079,18.962102 ],
    [ u"hu",u"Aranyosapáti",2142,48.205949,22.259163 ],
    [ u"hu",u"Arló",4129,48.183333,20.266667 ],
    [ u"hu",u"Arnót",2493,48.133333,20.866667 ],
    [ u"hu",u"Ásotthalom",4134,46.198752,19.783342 ],
    [ u"hu",u"Ásványráró",1985,47.832358,17.503532 ],
    [ u"hu",u"Aszaló",2008,48.216667,20.966667 ],
    [ u"hu",u"Aszód",6184,47.653902,19.498001 ],
    [ u"hu",u"Babócsa",1877,46.041546,17.343316 ],
    [ u"hu",u"Bábolna",3885,47.643612,17.977979 ],
    [ u"hu",u"Bácsalmás",7608,46.12648,19.332596 ],
    [ u"hu",u"Bácsbokod",3077,46.124996,19.156207 ],
    [ u"hu",u"Badacsonytomaj",2271,46.807114,17.513846 ],
    [ u"hu",u"Bagamér",2433,47.448816,21.989005 ],
    [ u"hu",u"Bag",4071,47.633333,19.483333 ],
    [ u"hu",u"Baja",37714,46.174957,18.956388 ],
    [ u"hu",u"Baj",2664,47.645931,18.364097 ],
    [ u"hu",u"Bajna",2024,47.654002,18.597205 ],
    [ u"hu",u"Bakonycsernye",3177,47.323948,18.075088 ],
    [ u"hu",u"Bakonyszentlászló",1913,47.389008,17.803212 ],
    [ u"hu",u"Baks",2292,46.54297,20.102127 ],
    [ u"hu",u"Baktalórántháza",4265,48,22.083333 ],
    [ u"hu",u"Balassagyarmat",17541,48.07296,19.296138 ],
    [ u"hu",u"Balástya",3564,46.422772,20.008158 ],
    [ u"hu",u"Balatonalmádi",8364,47.03526,18.020763 ],
    [ u"hu",u"Balatonboglár",5964,46.775247,17.644145 ],
    [ u"hu",u"Balatonfenyves",1885,46.715423,17.492226 ],
    [ u"hu",u"Balatonföldvár",2069,46.852549,17.881227 ],
    [ u"hu",u"Balatonfüred",13054,46.96188,17.871866 ],
    [ u"hu",u"Balatonfuzfo",4260,47.063241,18.046895 ],
    [ u"hu",u"Balatonkenese",3326,47.040186,18.106709 ],
    [ u"hu",u"Balatonlelle",4910,46.783182,17.694983 ],
    [ u"hu",u"Balatonszabadi",2838,46.893975,18.137375 ],
    [ u"hu",u"Balatonszárszó",1992,46.829455,17.824258 ],
    [ u"hu",u"Balkány",6798,47.766667,21.866667 ],
    [ u"hu",u"Ballószög",2753,46.862155,19.570924 ],
    [ u"hu",u"Balmazújváros",18012,47.616667,21.35 ],
    [ u"hu",u"Bánd",641,47.123235,17.776729 ],
    [ u"hu",u"Baracs",3294,46.882015,18.906583 ],
    [ u"hu",u"Baracska",2701,47.282249,18.758535 ],
    [ u"hu",u"Báránd",2728,47.3,21.233333 ],
    [ u"hu",u"Barcs",12116,45.96,17.458611 ],
    [ u"hu",u"Báta",1891,46.128641,18.770267 ],
    [ u"hu",u"Bátaszék",6820,46.193726,18.723074 ],
    [ u"hu",u"Bátonyterenye",14214,47.969618,19.840757 ],
    [ u"hu",u"Battonya",6604,46.283333,21.016667 ],
    [ u"hu",u"Bátya",2190,46.487997,18.954188 ],
    [ u"hu",u"Becsehely",2255,46.447551,16.777103 ],
    [ u"hu",u"Bekecs",2446,48.15,21.183333 ],
    [ u"hu",u"Békés",21198,46.766667,21.133333 ],
    [ u"hu",u"Békéscsaba",65956,46.683333,21.1 ],
    [ u"hu",u"Békéssámson",2581,46.416667,20.633333 ],
    [ u"hu",u"Békésszentandrás",4103,46.866667,20.483333 ],
    [ u"hu",u"Bélapátfalva",3401,48.05,20.366667 ],
    [ u"hu",u"Beled",2933,47.465936,17.092936 ],
    [ u"hu",u"Bercel",1991,47.87057,19.407149 ],
    [ u"hu",u"Beremend",2775,45.791084,18.432628 ],
    [ u"hu",u"Berettyóújfalu",16090,47.216667,21.55 ],
    [ u"hu",u"Berhida",5822,47.111313,18.129478 ],
    [ u"hu",u"Berzence",2694,46.209075,17.148103 ],
    [ u"hu",u"Besenyotelek",2847,47.7,20.433333 ],
    [ u"hu",u"Besenyszög",3460,47.3,20.266667 ],
    [ u"hu",u"Biatorbágy",8632,47.4706,18.818915 ],
    [ u"hu",u"Bicske",11072,47.484189,18.644038 ],
    [ u"hu",u"Biharkeresztes",4237,47.133333,21.716667 ],
    [ u"hu",u"Biharnagybajom",2936,47.216667,21.233333 ],
    [ u"hu",u"Bocs",2677,48.05,20.966667 ],
    [ u"hu",u"Bodajk",4069,47.32352,18.233119 ],
    [ u"hu",u"Bogács",2112,47.9,20.533333 ],
    [ u"hu",u"Bogyiszló",2348,46.386378,18.829621 ],
    [ u"hu",u"Böhönye",2437,46.413447,17.380365 ],
    [ u"hu",u"Bokod",2229,47.491862,18.24743 ],
    [ u"hu",u"Bököny",3310,47.733333,21.75 ],
    [ u"hu",u"Bölcske",2946,46.741023,18.967357 ],
    [ u"hu",u"Boldog",3131,47.602855,19.688388 ],
    [ u"hu",u"Boldva",2456,48.216667,20.8 ],
    [ u"hu",u"Bóly",3642,45.967222,18.518333 ],
    [ u"hu",u"Bony",2225,47.65,17.869772 ],
    [ u"hu",u"Bonyhád",14184,46.3,18.52905 ],
    [ u"hu",u"Bordány",3097,46.31843,19.923058 ],
    [ u"hu",u"Borsodnádasd",3546,48.116667,20.25 ],
    [ u"hu",u"Bosarkany",2208,47.688205,17.25 ],
    [ u"hu",u"Bucsa",2479,47.2,21 ],
    [ u"hu",u"Budakalász",9696,47.616667,19.05 ],
    [ u"hu",u"Budakeszi",13248,47.510832,18.927171 ],
    [ u"hu",u"Budaörs",25089,47.460614,18.96434 ],
    [ u"hu",u"Budapest",1708088,47.5,19.083333 ],
    [ u"hu",u"Bugac",3066,46.687039,19.680739 ],
    [ u"hu",u"Bugyi",5412,47.227478,19.146645 ],
    [ u"hu",u"Buják",2343,47.883523,19.543813 ],
    [ u"hu",u"Buj",2496,48.1,21.65 ],
    [ u"hu",u"Bük",3174,47.38486,16.750654 ],
    [ u"hu",u"Cece",2843,46.76885,18.633219 ],
    [ u"hu",u"Ceglédbercel",4710,47.223696,19.66828 ],
    [ u"hu",u"Cegléd",39287,47.172663,19.799524 ],
    [ u"hu",u"Celldömölk",11421,47.257125,17.150274 ],
    [ u"hu",u"Cibakháza",4565,46.959761,20.197533 ],
    [ u"hu",u"Cigánd",3245,48.255613,21.891946 ],
    [ u"hu",u"Csabacsud",2085,46.833333,20.65 ],
    [ u"hu",u"Csabrendek",2948,47.013558,17.291083 ],
    [ u"hu",u"Csákvár",5259,47.393174,18.46044 ],
    [ u"hu",u"Csanádapáca",2811,46.55,20.883333 ],
    [ u"hu",u"Csanádpalota",3224,46.25,20.733333 ],
    [ u"hu",u"Csány",2279,47.648287,19.829716 ],
    [ u"hu",u"Csanytelek",2937,46.595005,20.123419 ],
    [ u"hu",u"Császár",1922,47.498001,18.142719 ],
    [ u"hu",u"Császártöltés",2649,46.421944,19.183611 ],
    [ u"hu",u"Csávoly",2080,46.189167,19.146667 ],
    [ u"hu",u"Csemo",4411,47.117993,19.690923 ],
    [ u"hu",u"Csengele",2004,46.542336,19.863584 ],
    [ u"hu",u"Csenger",5225,47.835822,22.680956 ],
    [ u"hu",u"Csengod",2291,46.715434,19.268024 ],
    [ u"hu",u"Csepreg",3568,47.400982,16.708814 ],
    [ u"hu",u"Cserkeszolo",2182,46.863199,20.187009 ],
    [ u"hu",u"Cserszegtomaj",1941,46.80165,17.220957 ],
    [ u"hu",u"Csetény",2039,47.318059,17.992076 ],
    [ u"hu",u"Csobánka",2881,47.644599,18.967226 ],
    [ u"hu",u"Csokmo",2170,47.033333,21.3 ],
    [ u"hu",u"Csolnok",3381,47.691155,18.716109 ],
    [ u"hu",u"Csömör",7544,47.55,19.233333 ],
    [ u"hu",u"Csongrád",18580,46.713319,20.142415 ],
    [ u"hu",u"Csorna",10825,47.611552,17.250122 ],
    [ u"hu",u"Csorvás",5643,46.633333,20.833333 ],
    [ u"hu",u"Csurgó",5682,46.253139,17.100604 ],
    [ u"hu",u"Dabas",16590,47.185938,19.310908 ],
    [ u"hu",u"Dánszentmiklós",2838,47.214859,19.546954 ],
    [ u"hu",u"Dány",4378,47.519998,19.544004 ],
    [ u"hu",u"Dávod",2240,45.995,18.917222 ],
    [ u"hu",u"Debrecen",204825,47.533333,21.633333 ],
    [ u"hu",u"Decs",4210,46.284285,18.760005 ],
    [ u"hu",u"Dég",2354,46.868068,18.45042 ],
    [ u"hu",u"Délegyháza",2506,47.241351,19.090186 ],
    [ u"hu",u"Demecser",4558,48.111085,21.917491 ],
    [ u"hu",u"Derecske",9207,47.35,21.566667 ],
    [ u"hu",u"Deszk",3245,46.218024,20.243217 ],
    [ u"hu",u"Dévaványa",8796,47.033333,20.966667 ],
    [ u"hu",u"Devecser",5140,47.103163,17.438023 ],
    [ u"hu",u"Diósd",6168,47.409497,18.948976 ],
    [ u"hu",u"Diosjeno",2746,47.939683,19.043174 ],
    [ u"hu",u"Doboz",4466,46.733333,21.25 ],
    [ u"hu",u"Döbrököz",2120,46.42178,18.239525 ],
    [ u"hu",u"Döge",2181,48.262459,22.063388 ],
    [ u"hu",u"Domaszék",4242,46.249167,20.011111 ],
    [ u"hu",u"Dombegyház",2380,46.333333,21.133333 ],
    [ u"hu",u"Dombóvár",20748,46.376568,18.136962 ],
    [ u"hu",u"Dombrád",4276,48.233333,21.933333 ],
    [ u"hu",u"Domony",2031,47.65552,19.432286 ],
    [ u"hu",u"Domoszló",2105,47.833333,20.116667 ],
    [ u"hu",u"Dömsöd",5942,47.090047,19.011058 ],
    [ u"hu",u"Dorog",12658,47.72095,18.736405 ],
    [ u"hu",u"Dunabogdány",3059,47.790517,19.041247 ],
    [ u"hu",u"Dunaföldvár",9073,46.807995,18.926385 ],
    [ u"hu",u"Dunaharaszti",16973,47.354495,19.098223 ],
    [ u"hu",u"Dunakeszi",30246,47.636405,19.13864 ],
    [ u"hu",u"Dunapataj",3693,46.643997,18.996321 ],
    [ u"hu",u"Dunaszekcso",2151,46.086631,18.758647 ],
    [ u"hu",u"Dunaszentgyörgy",2624,46.528522,18.81771 ],
    [ u"hu",u"Dunaújváros",53396,46.980651,18.932674 ],
    [ u"hu",u"Dunavarsány",6016,47.278588,19.066168 ],
    [ u"hu",u"Dunavecse",4201,46.914068,18.974332 ],
    [ u"hu",u"Dusnok",3284,46.390852,18.962955 ],
    [ u"hu",u"Ebes",4468,47.466667,21.5 ],
    [ u"hu",u"Ecséd",3457,47.732667,19.766962 ],
    [ u"hu",u"Ecser",3333,47.443893,19.324505 ],
    [ u"hu",u"Edelény",11037,48.3,20.733333 ],
    [ u"hu",u"Eger",56302,47.9,20.383333 ],
    [ u"hu",u"Egerszalók",1952,47.866667,20.333333 ],
    [ u"hu",u"Egyek",5573,47.633333,20.9 ],
    [ u"hu",u"Elek",5465,46.533333,21.25 ],
    [ u"hu",u"Eloszallas",2556,46.830945,18.834809 ],
    [ u"hu",u"Emod",5382,47.933333,20.816667 ],
    [ u"hu",u"Encs",6886,48.333333,21.133333 ],
    [ u"hu",u"Encsencs",2087,47.733333,22.116667 ],
    [ u"hu",u"Enying",7171,46.930465,18.242019 ],
    [ u"hu",u"Ercsi",8383,47.251944,18.89623 ],
    [ u"hu",u"Érd",59242,47.394886,18.913605 ],
    [ u"hu",u"Erdokertes",5996,47.672609,19.30786 ],
    [ u"hu",u"Erdotelek",3443,47.683333,20.316667 ],
    [ u"hu",u"Érsekcsanád",2863,46.253522,18.98457 ],
    [ u"hu",u"Érsekvadkert",3762,47.996187,19.202312 ],
    [ u"hu",u"Esztergom",28785,47.7928,18.741476 ],
    [ u"hu",u"Etyek",3626,47.44794,18.753278 ],
    [ u"hu",u"Fábiánháza",1919,47.847591,22.35346 ],
    [ u"hu",u"Fábiánsebestyén",2276,46.683333,20.466667 ],
    [ u"hu",u"Fadd",4442,46.464764,18.819246 ],
    [ u"hu",u"Farád",1936,47.606333,17.200244 ],
    [ u"hu",u"Farkaslyuk",1922,48.183333,20.316667 ],
    [ u"hu",u"Farmos",3793,47.360671,19.846193 ],
    [ u"hu",u"Fegyvernek",6972,47.266667,20.533333 ],
    [ u"hu",u"Fehérgyarmat",9031,47.983333,22.516667 ],
    [ u"hu",u"Fehérvárcsurgó",1886,47.293147,18.26474 ],
    [ u"hu",u"Felsopakony",3040,47.343285,19.236984 ],
    [ u"hu",u"Felsoszentivan",1998,46.197127,19.186855 ],
    [ u"hu",u"Felsotarkany",3223,47.966667,20.416667 ],
    [ u"hu",u"Felsozsolca",7040,48.1,20.866667 ],
    [ u"hu",u"Fényeslitke",2425,48.271333,22.100091 ],
    [ u"hu",u"Fertod",3396,47.619469,16.886764 ],
    [ u"hu",u"Fertorakos",2179,47.71411,16.655207 ],
    [ u"hu",u"Fertoszentmiklos",3877,47.583476,16.879679 ],
    [ u"hu",u"Földeák",3255,46.316667,20.5 ],
    [ u"hu",u"Földes",4345,47.3,21.366667 ],
    [ u"hu",u"Fonyód",5199,46.755525,17.579452 ],
    [ u"hu",u"Forráskút",2287,46.36528,19.90973 ],
    [ u"hu",u"Forró",2473,47.455044,19.660005 ],
    [ u"hu",u"Fót",16770,47.617703,19.188701 ],
    [ u"hu",u"Fülöpszállás",2503,46.820752,19.237483 ],
    [ u"hu",u"Füzesabony",8182,47.75,20.416667 ],
    [ u"hu",u"Füzesgyarmat",6426,47.1,21.216667 ],
    [ u"hu",u"Gádoros",4008,46.666667,20.6 ],
    [ u"hu",u"Galgahéviz",2641,47.616667,19.566667 ],
    [ u"hu",u"Galgamácsa",2061,47.695622,19.387235 ],
    [ u"hu",u"Gara",2656,46.031944,19.042778 ],
    [ u"hu",u"Gárdony",8105,47.209063,18.64491 ],
    [ u"hu",u"Gégény",2093,48.15,21.95 ],
    [ u"hu",u"Gencsapáti",2580,47.281478,16.597928 ],
    [ u"hu",u"Gesztely",2839,48.1,20.966667 ],
    [ u"hu",u"Göd",15874,47.683241,19.134171 ],
    [ u"hu",u"Godollo",32374,47.596574,19.355151 ],
    [ u"hu",u"Gödre",957,46.286117,17.972883 ],
    [ u"hu",u"Gomba",2861,47.37095,19.530573 ],
    [ u"hu",u"Gönc",2217,48.466667,21.283333 ],
    [ u"hu",u"Gonyu",3021,47.733654,17.828836 ],
    [ u"hu",u"Görbeháza",2626,47.833333,21.233333 ],
    [ u"hu",u"Gyál",21937,47.384493,19.221395 ],
    [ u"hu",u"Gyenesdiás",2796,46.770585,17.286603 ],
    [ u"hu",u"Gyomaendrod",15194,46.933333,20.833333 ],
    [ u"hu",u"Gyomro",14155,47.427327,19.401333 ],
    [ u"hu",u"Gyöngyös",32938,47.782571,19.928003 ],
    [ u"hu",u"Gyöngyöshalász",2585,47.741613,19.928764 ],
    [ u"hu",u"Gyöngyöspata",2724,47.815049,19.789245 ],
    [ u"hu",u"Gyöngyössolymos",3160,47.817238,19.936188 ],
    [ u"hu",u"Gyöngyöstarján",2463,47.813688,19.867242 ],
    [ u"hu",u"Gyönk",2148,46.557145,18.477029 ],
    [ u"hu",u"Gyor",129009,47.687281,17.637616 ],
    [ u"hu",u"Gyorszemere",2964,47.552558,17.563561 ],
    [ u"hu",u"Gyorujbarat",4603,47.606425,17.648751 ],
    [ u"hu",u"Gyula",32269,46.65,21.283333 ],
    [ u"hu",u"Gyulaháza",2059,48.133333,22.116667 ],
    [ u"hu",u"Hajdubagos",1959,47.4,21.666667 ],
    [ u"hu",u"Hajdúböszörmény",31957,47.666667,21.516667 ],
    [ u"hu",u"Hajdúdorog",9514,47.816667,21.5 ],
    [ u"hu",u"Hajdúhadház",12892,47.683333,21.666667 ],
    [ u"hu",u"Hajdúnánás",18032,47.85,21.433333 ],
    [ u"hu",u"Hajdúsámson",10854,47.6,21.766667 ],
    [ u"hu",u"Hajdúszoboszló",23496,47.45,21.4 ],
    [ u"hu",u"Hajdúszovát",3167,47.383333,21.483333 ],
    [ u"hu",u"Hajmáskér",2793,47.147189,18.022931 ],
    [ u"hu",u"Hajós",3520,46.398611,19.120556 ],
    [ u"hu",u"Halászi",2850,47.889301,17.326147 ],
    [ u"hu",u"Halásztelek",7245,47.361733,18.981191 ],
    [ u"hu",u"Halmaj",1869,48.25,21 ],
    [ u"hu",u"Harkány",3450,45.850016,18.236679 ],
    [ u"hu",u"Harsány",2059,47.966667,20.75 ],
    [ u"hu",u"Harta",3716,46.698465,19.030532 ],
    [ u"hu",u"Hatvan",22710,47.666667,19.683333 ],
    [ u"hu",u"Hegyeshalom",3507,47.508101,20.032932 ],
    [ u"hu",u"Hejobaba",1949,47.9,20.95 ],
    [ u"hu",u"Helvécia",3918,46.836614,19.622512 ],
    [ u"hu",u"Hercegszántó",2308,45.95,18.939167 ],
    [ u"hu",u"Heréd",2039,47.706377,19.633142 ],
    [ u"hu",u"Herend",3385,47.133333,17.75 ],
    [ u"hu",u"Hernád",3689,47.162384,19.432952 ],
    [ u"hu",u"Hernádnémeti",3629,48.066667,20.983333 ],
    [ u"hu",u"Heves",11311,47.6,20.283333 ],
    [ u"hu",u"Hévizgyörk",3101,47.627241,19.521141 ],
    [ u"hu",u"Hévíz",4439,46.788778,17.183333 ],
    [ u"hu",u"Hidas",2274,46.257763,18.49526 ],
    [ u"hu",u"Hodász",3489,47.918339,22.201534 ],
    [ u"hu",u"Hodmezovasarhely",47699,46.416667,20.333333 ],
    [ u"hu",u"Hogyesz",3029,46.495902,18.420875 ],
    [ u"hu",u"Hort",3797,47.689435,19.788663 ],
    [ u"hu",u"Hortobágy",1745,47.583333,21.166667 ],
    [ u"hu",u"Hosszúhetény",3299,46.161214,18.354379 ],
    [ u"hu",u"Hosszúpályi",5478,47.4,21.75 ],
    [ u"hu",u"Ibrány",6880,48.133333,21.716667 ],
    [ u"hu",u"Iklad",2194,47.665335,19.436104 ],
    [ u"hu",u"Inárcs",4262,47.262001,19.327 ],
    [ u"hu",u"Iregszemcse",2772,46.692857,18.185813 ],
    [ u"hu",u"Isaszeg",10754,47.530111,19.402054 ],
    [ u"hu",u"Iváncsa",2807,47.156704,18.820298 ],
    [ u"hu",u"Izsák",6117,46.804542,19.351723 ],
    [ u"hu",u"Izsófalva",1871,48.3,20.666667 ],
    [ u"hu",u"Ják",2310,47.142495,16.581478 ],
    [ u"hu",u"Jánoshalma",9755,46.298611,19.325833 ],
    [ u"hu",u"Jánosháza",2754,47.119367,17.165031 ],
    [ u"hu",u"Jánoshida",2709,47.383333,20.066667 ],
    [ u"hu",u"Jánossomorja",5985,47.786207,17.136033 ],
    [ u"hu",u"Járdánháza",1938,48.15,20.25 ],
    [ u"hu",u"Jászalsószentgyörgy",3777,47.366667,20.1 ],
    [ u"hu",u"Jászapáti",9806,47.516667,20.15 ],
    [ u"hu",u"Jászárokszállás",8107,47.642375,19.980382 ],
    [ u"hu",u"Jászberény",27835,47.5,19.916667 ],
    [ u"hu",u"Jászdózsa",2225,47.566096,20.015335 ],
    [ u"hu",u"Jászjákóhalma",3088,47.520379,19.990863 ],
    [ u"hu",u"Jaszkarajeno",3125,47.05,20.066667 ],
    [ u"hu",u"Jászkisér",5741,47.45,20.216667 ],
    [ u"hu",u"Jászladány",6215,47.366667,20.166667 ],
    [ u"hu",u"Jászszentandrás",2640,47.583333,20.183333 ],
    [ u"hu",u"Jászszentlászló",2602,46.566854,19.760649 ],
    [ u"hu",u"Jobbágyi",2329,47.832381,19.677622 ],
    [ u"hu",u"Kaba",6392,47.35,21.283333 ],
    [ u"hu",u"Kadarkút",2740,46.236232,17.620138 ],
    [ u"hu",u"Kakucs",2707,47.242005,19.364668 ],
    [ u"hu",u"Kál",3683,47.733333,20.266667 ],
    [ u"hu",u"Kállósemjén",3968,47.86081,21.939285 ],
    [ u"hu",u"Kálmánháza",2086,47.883333,21.583333 ],
    [ u"hu",u"Kalocsa",18242,46.526389,18.985833 ],
    [ u"hu",u"Káloz",2527,46.954645,18.482588 ],
    [ u"hu",u"Kántorjánosi",2244,47.933333,22.15 ],
    [ u"hu",u"Kápolnásnyék",3224,47.240037,18.675636 ],
    [ u"hu",u"Kaposmero",2506,46.361672,17.703997 ],
    [ u"hu",u"Kaposvár",66947,46.366667,17.8 ],
    [ u"hu",u"Kapuvár",10661,47.592235,17.028857 ],
    [ u"hu",u"Karácsond",3132,47.729621,20.030763 ],
    [ u"hu",u"Karád",1733,46.690758,17.841356 ],
    [ u"hu",u"Karancskeszi",1924,48.163526,19.696859 ],
    [ u"hu",u"Karancslapujto",2845,48.15,19.733333 ],
    [ u"hu",u"Karcag",22370,47.316667,20.933333 ],
    [ u"hu",u"Karcsa",1984,48.311298,21.805369 ],
    [ u"hu",u"Kartal",6017,47.671331,19.542005 ],
    [ u"hu",u"Kaszaper",2063,46.466667,20.833333 ],
    [ u"hu",u"Katymár",2374,46.03398,19.209353 ],
    [ u"hu",u"Kazár",2080,48.049524,19.861432 ],
    [ u"hu",u"Kazincbarcika",32396,48.25,20.633333 ],
    [ u"hu",u"Kecel",9155,46.525278,19.251944 ],
    [ u"hu",u"Kecskéd",1908,47.522985,18.309386 ],
    [ u"hu",u"Kecskemét",106062,46.9,19.783333 ],
    [ u"hu",u"Kék",2044,48.116667,21.883333 ],
    [ u"hu",u"Kelebia",2985,46.196802,19.616592 ],
    [ u"hu",u"Kemecse",5029,48.075319,21.806253 ],
    [ u"hu",u"Kenderes",5243,47.25,20.683333 ],
    [ u"hu",u"Kengyel",4299,47.083333,20.333333 ],
    [ u"hu",u"Kerecsend",2217,47.8,20.35 ],
    [ u"hu",u"Kerekegyháza",5983,46.937222,19.478056 ],
    [ u"hu",u"Kerepes",8755,47.542839,19.263312 ],
    [ u"hu",u"Keszthely",21534,46.768121,17.24317 ],
    [ u"hu",u"Kesztölc",2559,47.712664,18.801769 ],
    [ u"hu",u"Kétegyháza",4331,46.533333,21.183333 ],
    [ u"hu",u"Kéthely",2408,46.646051,17.393616 ],
    [ u"hu",u"Kevermes",2401,46.416667,21.183333 ],
    [ u"hu",u"Kimle",2312,47.817256,17.366424 ],
    [ u"hu",u"Kisbér",5850,47.502891,18.036652 ],
    [ u"hu",u"Kisköre",3038,47.5,20.5 ],
    [ u"hu",u"Kiskoros",15091,46.621389,19.285281 ],
    [ u"hu",u"Kiskunfélegyháza",31721,46.712131,19.844576 ],
    [ u"hu",u"Kiskunhalas",29354,46.434025,19.484795 ],
    [ u"hu",u"Kiskunlacháza",8980,47.188388,19.0093 ],
    [ u"hu",u"Kiskunmajsa",11955,46.490278,19.74 ],
    [ u"hu",u"Kisláng",2641,46.957438,18.388127 ],
    [ u"hu",u"Kisléta",1944,47.842438,22.003931 ],
    [ u"hu",u"Kisszállás",2846,46.28009,19.489544 ],
    [ u"hu",u"Kistarcsa",9637,47.542839,19.263312 ],
    [ u"hu",u"Kistelek",7430,46.4725,19.979722 ],
    [ u"hu",u"Kisújszállás",12661,47.216667,20.766667 ],
    [ u"hu",u"Kisvárda",18190,48.216667,22.083333 ],
    [ u"hu",u"Kiszombor",4131,46.183333,20.433333 ],
    [ u"hu",u"Kocsér",2096,47.001654,19.920666 ],
    [ u"hu",u"Kocs",2655,47.607495,18.215168 ],
    [ u"hu",u"Kocsord",3054,47.939115,22.383333 ],
    [ u"hu",u"Kóka",4376,47.485522,19.578764 ],
    [ u"hu",u"Komádi",6091,47,21.5 ],
    [ u"hu",u"Komárom",19646,47.743184,18.11913 ],
    [ u"hu",u"Komló",26924,46.188855,18.260645 ],
    [ u"hu",u"Kompolt",2166,47.733333,20.25 ],
    [ u"hu",u"Kondoros",5793,46.766667,20.8 ],
    [ u"hu",u"Konyár",2257,47.316667,21.666667 ],
    [ u"hu",u"Kóny",2609,47.630531,17.357167 ],
    [ u"hu",u"Körmend",12368,47.014377,16.599673 ],
    [ u"hu",u"Környe",4359,47.546681,18.320805 ],
    [ u"hu",u"Körösladány",5006,46.966667,21.083333 ],
    [ u"hu",u"Köröstarcsa",2786,46.883333,21.033333 ],
    [ u"hu",u"Kosd",2371,47.807912,19.178213 ],
    [ u"hu",u"Koszeg",11500,47.389223,16.541001 ],
    [ u"hu",u"Kótaj",4553,48.05,21.716667 ],
    [ u"hu",u"Kozármisleny",4093,46.029669,18.292097 ],
    [ u"hu",u"Kunágota",2951,46.433333,21.05 ],
    [ u"hu",u"Kunfehértó",2281,46.360914,19.41454 ],
    [ u"hu",u"Kunhegyes",8462,47.366667,20.633333 ],
    [ u"hu",u"Kunmadaras",5826,47.433333,20.8 ],
    [ u"hu",u"Kunszentmárton",9606,46.83916,20.28879 ],
    [ u"hu",u"Kunszentmiklós",8976,47.026995,19.125753 ],
    [ u"hu",u"Lábatlan",5357,47.74735,18.496226 ],
    [ u"hu",u"Lábod",2244,46.205351,17.454187 ],
    [ u"hu",u"Lajoskomárom",2365,46.842005,18.337627 ],
    [ u"hu",u"Lajosmizse",11034,47.021331,19.561707 ],
    [ u"hu",u"Lakitelek",4435,46.876009,19.995042 ],
    [ u"hu",u"Lánycsók",2707,46.011699,18.621176 ],
    [ u"hu",u"Leányfalu",2534,47.717785,19.085847 ],
    [ u"hu",u"Lébény",3161,47.736073,17.391554 ],
    [ u"hu",u"Lengyeltóti",3380,46.670132,17.643978 ],
    [ u"hu",u"Lenti",8399,46.624027,16.538631 ],
    [ u"hu",u"Lepsény",3224,46.990363,18.243575 ],
    [ u"hu",u"Létavértes",7157,47.383333,21.9 ],
    [ u"hu",u"Letenye",4527,46.433013,16.725832 ],
    [ u"hu",u"Levelek",2948,47.962816,21.985367 ],
    [ u"hu",u"Litér",2010,47.101044,18.004541 ],
    [ u"hu",u"Lokoshaza",2017,46.433333,21.233333 ],
    [ u"hu",u"Lorinci",6089,47.732952,19.678669 ],
    [ u"hu",u"Lovasberény",2674,47.309972,18.551771 ],
    [ u"hu",u"Madaras",3246,46.0587,19.26121 ],
    [ u"hu",u"Mád",2589,48.2,21.283333 ],
    [ u"hu",u"Madocsa",1935,46.687901,18.957911 ],
    [ u"hu",u"Maglód",10144,47.442576,19.364383 ],
    [ u"hu",u"Mágocs",2652,46.349983,18.232405 ],
    [ u"hu",u"Magyarbánhegyes",2634,46.45,20.966667 ],
    [ u"hu",u"Maklár",2340,47.8,20.416667 ],
    [ u"hu",u"Makó",25135,46.216667,20.483333 ],
    [ u"hu",u"Mályi",4128,48.016667,20.833333 ],
    [ u"hu",u"Mándok",4566,48.321494,22.191066 ],
    [ u"hu",u"Mány",2294,47.53352,18.656273 ],
    [ u"hu",u"Marcali",12344,46.584983,17.411965 ],
    [ u"hu",u"Máriapócs",2182,47.883025,22.025015 ],
    [ u"hu",u"Maroslele",2157,46.266667,20.35 ],
    [ u"hu",u"Martfu",7247,47.016667,20.283333 ],
    [ u"hu",u"Martonvásár",5166,47.316012,18.79045 ],
    [ u"hu",u"Mátészalka",18718,47.955279,22.323478 ],
    [ u"hu",u"Mátraderecske",2232,47.95,20.083333 ],
    [ u"hu",u"Mátranovák",1972,48.038092,19.982571 ],
    [ u"hu",u"Mátraterenye",1995,48.032667,19.947621 ],
    [ u"hu",u"Mátraverebély",2197,47.974209,19.78049 ],
    [ u"hu",u"Medgyesegyháza",4037,46.5,21.033333 ],
    [ u"hu",u"Megyaszó",3072,48.183333,21.05 ],
    [ u"hu",u"Méhkerék",2274,46.783333,21.45 ],
    [ u"hu",u"Mélykút",5766,46.215088,19.381024 ],
    [ u"hu",u"Mende",4250,47.431325,19.456282 ],
    [ u"hu",u"Mérk",2335,47.788236,22.380375 ],
    [ u"hu",u"Mezobereny",11306,46.816667,21.033333 ],
    [ u"hu",u"Mezocsat",6519,47.816667,20.916667 ],
    [ u"hu",u"Mezofalva",4910,46.93184,18.771774 ],
    [ u"hu",u"Mezohegyes",6220,46.316667,20.816667 ],
    [ u"hu",u"Mezokeresztes",4116,47.833333,20.7 ],
    [ u"hu",u"Mezokovacshaza",6877,46.4,20.916667 ],
    [ u"hu",u"Mezokovesd",17701,47.816667,20.583333 ],
    [ u"hu",u"Mezoszilas",2309,46.811093,18.477891 ],
    [ u"hu",u"Mezotur",19168,47,20.633333 ],
    [ u"hu",u"Mezozombor",2549,48.15,21.266667 ],
    [ u"hu",u"Mihályi",1137,47.513835,17.095067 ],
    [ u"hu",u"Mikepércs",3430,47.45,21.633333 ],
    [ u"hu",u"Mindszent",7243,46.523621,20.190381 ],
    [ u"hu",u"Miskolc",179430,48.1,20.783333 ],
    [ u"hu",u"Mocsa",2265,47.669987,18.185046 ],
    [ u"hu",u"Mogyoród",4949,47.597484,19.240703 ],
    [ u"hu",u"Mohács",18711,45.993056,18.683056 ],
    [ u"hu",u"Monok",1786,48.216667,21.15 ],
    [ u"hu",u"Monor",21720,47.351333,19.447335 ],
    [ u"hu",u"Monostorpályi",2221,47.4,21.783333 ],
    [ u"hu",u"Mórahalom",5445,46.218056,19.885099 ],
    [ u"hu",u"Mór",14690,47.377872,18.203534 ],
    [ u"hu",u"Mosonmagyaróvár",30359,47.867885,17.269935 ],
    [ u"hu",u"Mosonszentmiklós",2517,47.736073,17.391554 ],
    [ u"hu",u"Múcsony",3486,48.266667,20.683333 ],
    [ u"hu",u"Murakeresztúr",1969,46.364215,16.881767 ],
    [ u"hu",u"Nádudvar",9135,47.416667,21.166667 ],
    [ u"hu",u"Nagyatád",11843,46.228066,17.360968 ],
    [ u"hu",u"Nagybajom",3532,46.392325,17.51147 ],
    [ u"hu",u"Nagybaracska",2445,46.042481,18.905901 ],
    [ u"hu",u"Nagycserkesz",1907,47.966667,21.533333 ],
    [ u"hu",u"Nagydobos",2282,48.05759,22.304235 ],
    [ u"hu",u"Nagydorog",2787,46.627488,18.655647 ],
    [ u"hu",u"Nagyecsed",6919,47.865467,22.391595 ],
    [ u"hu",u"Nagyhalász",5924,48.133333,21.766667 ],
    [ u"hu",u"Nagyhegyes",2683,47.516667,21.416667 ],
    [ u"hu",u"Nagyigmánd",3132,47.640935,18.081298 ],
    [ u"hu",u"Nagykálló",10796,47.875124,21.84536 ],
    [ u"hu",u"Nagykanizsa",51383,46.514167,16.971667 ],
    [ u"hu",u"Nagykáta",13322,47.415144,19.744099 ],
    [ u"hu",u"Nagykoros",26711,47.034189,19.778574 ],
    [ u"hu",u"Nagykovácsi",4861,47.575232,18.87337 ],
    [ u"hu",u"Nagymányok",2504,46.284123,18.461961 ],
    [ u"hu",u"Nagymaros",4629,47.792797,18.959841 ],
    [ u"hu",u"Nagyoroszi",2250,48.005028,19.090503 ],
    [ u"hu",u"Nagyrábé",2380,47.2,21.333333 ],
    [ u"hu",u"Nagyréde",3308,47.76543,19.848192 ],
    [ u"hu",u"Nagyszénás",5617,46.683333,20.666667 ],
    [ u"hu",u"Nagytarcsa",2846,47.531282,19.283426 ],
    [ u"hu",u"Nagyvenyim",3949,46.956673,18.857805 ],
    [ u"hu",u"Napkor",3786,47.937973,21.867628 ],
    [ u"hu",u"Naszály",2239,47.703293,18.257512 ],
    [ u"hu",u"Nemesnádudvar",2041,46.340505,19.051153 ],
    [ u"hu",u"Nemesvámos",2508,47.05514,17.874767 ],
    [ u"hu",u"Németkér",1901,46.716371,18.763114 ],
    [ u"hu",u"Nyáregyháza",3770,47.261751,19.501458 ],
    [ u"hu",u"Nyarlorinc",2384,46.860171,19.878358 ],
    [ u"hu",u"Nyékládháza",4939,47.983333,20.833333 ],
    [ u"hu",u"Nyergesújfalu",7667,47.757627,18.557456 ],
    [ u"hu",u"Nyírábrány",3940,47.553108,22.024008 ],
    [ u"hu",u"Nyíracsád",4047,47.603298,21.972084 ],
    [ u"hu",u"Nyíradony",7827,47.697457,21.918782 ],
    [ u"hu",u"Nyírbátor",13434,47.833333,22.133333 ],
    [ u"hu",u"Nyírbéltek",3021,47.7,22.133333 ],
    [ u"hu",u"Nyírbogát",3336,47.803395,22.065606 ],
    [ u"hu",u"Nyírbogdány",3039,48.05723,21.882418 ],
    [ u"hu",u"Nyírcsaholy",2251,47.903827,22.336302 ],
    [ u"hu",u"Nyíregyháza",116809,47.95,21.716667 ],
    [ u"hu",u"Nyírgyulaj",2130,47.886218,22.097814 ],
    [ u"hu",u"Nyírkarász",2395,48.101669,22.097939 ],
    [ u"hu",u"Nyírlugos",3004,47.693149,22.044756 ],
    [ u"hu",u"Nyírmada",4743,48.066667,22.2 ],
    [ u"hu",u"Nyírmártonfalva",2130,47.583333,21.9 ],
    [ u"hu",u"Nyírmeggyes",2757,47.916667,22.266667 ],
    [ u"hu",u"Nyírmihálydi",1997,47.739755,21.964446 ],
    [ u"hu",u"Nyírpazony",3162,47.983333,21.8 ],
    [ u"hu",u"Nyírtass",2194,48.116667,22.033333 ],
    [ u"hu",u"Nyírtelek",7138,48.016667,21.633333 ],
    [ u"hu",u"Nyírvasvári",1971,47.816667,22.186829 ],
    [ u"hu",u"Nyúl",3816,47.590471,17.689043 ],
    [ u"hu",u"Ócsa",9097,47.299862,19.230569 ],
    [ u"hu",u"Ocseny",2536,46.313697,18.757493 ],
    [ u"hu",u"Öcsöd",3730,46.9,20.4 ],
    [ u"hu",u"Ófehértó",2727,47.933333,22.05 ],
    [ u"hu",u"Okány",2930,46.9,21.35 ],
    [ u"hu",u"Ököritófülpös",2034,47.918619,22.508095 ],
    [ u"hu",u"Olaszliszka",1799,48.25,21.433333 ],
    [ u"hu",u"Onga",4697,48.116667,20.916667 ],
    [ u"hu",u"Ónod",2461,48,20.916667 ],
    [ u"hu",u"Ópályi",3035,47.997712,22.32617 ],
    [ u"hu",u"Ópusztaszer",2260,46.485923,20.087218 ],
    [ u"hu",u"Orbottyan",5495,47.687107,19.282394 ],
    [ u"hu",u"Orgovány",3472,46.750867,19.472586 ],
    [ u"hu",u"Örkény",5119,47.129906,19.433238 ],
    [ u"hu",u"Orosháza",31373,46.566667,20.666667 ],
    [ u"hu",u"Oroszlány",20271,47.486706,18.31225 ],
    [ u"hu",u"Osi",2146,47.147216,18.188329 ],
    [ u"hu",u"Öskü",2272,47.160029,18.073268 ],
    [ u"hu",u"Ostoros",2362,47.866667,20.433333 ],
    [ u"hu",u"Öttevény",2725,47.724807,17.491006 ],
    [ u"hu",u"Ózd",38475,48.216667,20.3 ],
    [ u"hu",u"Ozora",1742,46.751333,18.400095 ],
    [ u"hu",u"Pacsa",1878,46.719808,17.01401 ],
    [ u"hu",u"Pákozd",2721,47.213694,18.533055 ],
    [ u"hu",u"Paks",20638,46.62648,18.859624 ],
    [ u"hu",u"Pálmonostora",2052,46.624171,19.951564 ],
    [ u"hu",u"Pánd",2041,47.353331,19.635712 ],
    [ u"hu",u"Pannonhalma",4089,47.549465,17.755354 ],
    [ u"hu",u"Pápa",32990,47.330044,17.467398 ],
    [ u"hu",u"Parád",2111,47.923235,20.029716 ],
    [ u"hu",u"Pásztó",10119,47.920189,19.698287 ],
    [ u"hu",u"Pátroha",2976,48.166667,22 ],
    [ u"hu",u"Páty",5475,47.517086,18.828514 ],
    [ u"hu",u"Pázmánd",1985,47.287547,18.653557 ],
    [ u"hu",u"Pécel",13193,47.489615,19.341624 ],
    [ u"hu",u"Pécs",156661,46.075363,18.232845 ],
    [ u"hu",u"Pécsvárad",4024,46.161732,18.427501 ],
    [ u"hu",u"Pellérd",1881,46.03438,18.154026 ],
    [ u"hu",u"Perbál",2167,47.589572,18.760988 ],
    [ u"hu",u"Perkáta",4166,47.047006,18.787336 ],
    [ u"hu",u"Pér",2372,47.611528,17.806317 ],
    [ u"hu",u"Péteri",1970,47.391042,19.409814 ],
    [ u"hu",u"Pétervására",2568,48.016667,20.1 ],
    [ u"hu",u"Petfurdo",4877,47.159814,18.119772 ],
    [ u"hu",u"Petneháza",1993,48.060842,22.074852 ],
    [ u"hu",u"Petofibanya",3061,47.779425,19.705504 ],
    [ u"hu",u"Pilisborosjeno",3180,47.60866,18.991062 ],
    [ u"hu",u"Piliscsaba",6468,47.634172,18.828864 ],
    [ u"hu",u"Piliscsév",2310,47.679236,18.818716 ],
    [ u"hu",u"Pilismarót",1952,47.784636,18.875388 ],
    [ u"hu",u"Pilis",11102,47.289043,19.548477 ],
    [ u"hu",u"Pilisszántó",2245,47.669088,18.887617 ],
    [ u"hu",u"Pilisszentiván",4218,47.609405,18.8973 ],
    [ u"hu",u"Pilisszentkereszt",2224,47.691434,18.905028 ],
    [ u"hu",u"Pilisvörösvár",13150,47.617785,18.911081 ],
    [ u"hu",u"Pincehely",2548,46.680951,18.439353 ],
    [ u"hu",u"Pocsaj",2709,47.283333,21.816667 ],
    [ u"hu",u"Polgárdi",6564,47.060993,18.301999 ],
    [ u"hu",u"Polgár",8347,47.866667,21.116667 ],
    [ u"hu",u"Pomáz",14917,47.642272,19.027839 ],
    [ u"hu",u"Porcsalma",2770,47.883333,22.566667 ],
    [ u"hu",u"Poroszló",3030,47.65,20.666667 ],
    [ u"hu",u"Prügy",2568,48.083333,21.25 ],
    [ u"hu",u"Püspökladány",15990,47.316667,21.116667 ],
    [ u"hu",u"Pusztaföldvár",1887,46.533333,20.8 ],
    [ u"hu",u"Pusztaszabolcs",6355,47.137181,18.76704 ],
    [ u"hu",u"Pusztaszer",1642,46.550832,19.988235 ],
    [ u"hu",u"Pusztavám",2521,47.429478,18.22648 ],
    [ u"hu",u"Putnok",7501,48.3,20.433333 ],
    [ u"hu",u"Rábapatona",2497,47.632237,17.480044 ],
    [ u"hu",u"Rácalmás",4148,47.022632,18.940556 ],
    [ u"hu",u"Ráckeresztúr",3117,47.273597,18.833426 ],
    [ u"hu",u"Ráckeve",9229,47.160951,18.944781 ],
    [ u"hu",u"Rajka",2601,47.996427,17.198214 ],
    [ u"hu",u"Rakamaz",5197,48.133333,21.466667 ],
    [ u"hu",u"Rákóczifalva",5481,47.083333,20.233333 ],
    [ u"hu",u"Rákócziújfalu",2012,47.066667,20.266667 ],
    [ u"hu",u"Recsk",2992,47.933333,20.116667 ],
    [ u"hu",u"Répcelak",2644,47.421052,17.017946 ],
    [ u"hu",u"Rétság",3004,47.927612,19.13669 ],
    [ u"hu",u"Ricse",1907,48.325645,21.970694 ],
    [ u"hu",u"Rimóc",1874,48.03695,19.530097 ],
    [ u"hu",u"Romhány",2421,47.919296,19.263627 ],
    [ u"hu",u"Röszke",3241,46.187957,20.033721 ],
    [ u"hu",u"Rózsaszentmárton",2028,47.782,19.7421 ],
    [ u"hu",u"Rudabánya",2941,48.383333,20.633333 ],
    [ u"hu",u"Ruzsa",2764,46.288057,19.747137 ],
    [ u"hu",u"Sajóbábony",3113,48.166667,20.733333 ],
    [ u"hu",u"Sajókaza",3494,48.283333,20.583333 ],
    [ u"hu",u"Sajólád",3001,48.05,20.9 ],
    [ u"hu",u"Sajószentpéter",13125,48.216667,20.716667 ],
    [ u"hu",u"Sajószöged",2289,47.95,21 ],
    [ u"hu",u"Sajóvámos",2206,48.183333,20.85 ],
    [ u"hu",u"Salgótarján",44289,48.103363,19.805237 ],
    [ u"hu",u"Sály",2174,47.95,20.666667 ],
    [ u"hu",u"Sándorfalva",7738,46.360871,20.09889 ],
    [ u"hu",u"Sáránd",2322,47.4,21.633333 ],
    [ u"hu",u"Sárbogárd",13424,46.886555,18.619464 ],
    [ u"hu",u"Sárisáp",2911,47.677001,18.679329 ],
    [ u"hu",u"Sarkad",10698,46.75,21.383333 ],
    [ u"hu",u"Sárkeresztúr",2443,47.005401,18.543906 ],
    [ u"hu",u"Sármellék",1836,46.712212,17.168647 ],
    [ u"hu",u"Sárosd",3474,47.042731,18.643569 ],
    [ u"hu",u"Sárospatak",14478,48.316667,21.583333 ],
    [ u"hu",u"Sárrétudvari",3023,47.233333,21.2 ],
    [ u"hu",u"Sárszentmihály",2824,47.153212,18.338794 ],
    [ u"hu",u"Sárvár",15343,47.255481,16.93041 ],
    [ u"hu",u"Sásd",3500,46.255197,18.107757 ],
    [ u"hu",u"Sátoraljaújhely",18052,48.4,21.666667 ],
    [ u"hu",u"Segesd",2674,46.34142,17.35132 ],
    [ u"hu",u"Sellye",3184,45.872468,17.84711 ],
    [ u"hu",u"Seregélyes",4539,47.110504,18.565 ],
    [ u"hu",u"Siklós",10180,45.854992,18.297523 ],
    [ u"hu",u"Simontornya",4536,46.754623,18.554903 ],
    [ u"hu",u"Siófok",23028,46.904125,18.058002 ],
    [ u"hu",u"Sirok",2068,47.933333,20.2 ],
    [ u"hu",u"Solt",6984,46.800674,18.999931 ],
    [ u"hu",u"Soltvadkert",7695,46.578889,19.39389 ],
    [ u"hu",u"Solymár",9242,47.592457,18.932122 ],
    [ u"hu",u"Somogyvár",2023,46.581404,17.662886 ],
    [ u"hu",u"Soponya",1996,47.014847,18.453426 ],
    [ u"hu",u"Sopron",55623,47.683333,16.6 ],
    [ u"hu",u"Sóskút",2998,47.406649,18.82247 ],
    [ u"hu",u"Sükösd",3987,46.28181,18.995241 ],
    [ u"hu",u"Sümeg",6726,46.97957,17.280388 ],
    [ u"hu",u"Sutto",1998,47.758865,18.448728 ],
    [ u"hu",u"Szabadbattyán",4492,47.119023,18.368235 ],
    [ u"hu",u"Szabadkígyós",2959,46.616667,21.1 ],
    [ u"hu",u"Szabadszállás",6605,46.875752,19.223244 ],
    [ u"hu",u"Szada",3370,47.633333,19.316667 ],
    [ u"hu",u"Szajol",3991,47.183333,20.3 ],
    [ u"hu",u"Szakoly",2925,47.766667,21.916667 ],
    [ u"hu",u"Szalkszentmárton",2982,46.975654,19.011775 ],
    [ u"hu",u"Szamosszeg",2084,48.04561,22.36582 ],
    [ u"hu",u"Szank",2506,46.557126,19.66103 ],
    [ u"hu",u"Szany",2300,47.464231,17.304019 ],
    [ u"hu",u"Szarvas",18170,46.866667,20.55 ],
    [ u"hu",u"Szászvár",2684,46.277561,18.376198 ],
    [ u"hu",u"Szatymaz",4187,46.343063,20.040196 ],
    [ u"hu",u"Százhalombatta",17566,47.325791,18.921415 ],
    [ u"hu",u"Szécsény",6446,48.080573,19.520189 ],
    [ u"hu",u"Szedres",2478,46.47551,18.683052 ],
    [ u"hu",u"Szeged",160609,46.25,20.166667 ],
    [ u"hu",u"Szeghalom",9985,47.033333,21.166667 ],
    [ u"hu",u"Szegvár",4897,46.587403,20.224083 ],
    [ u"hu",u"Székesfehérvár",103772,47.195503,18.4096 ],
    [ u"hu",u"Székkutas",2586,46.5,20.533333 ],
    [ u"hu",u"Szekszárd",35327,46.350137,18.709051 ],
    [ u"hu",u"Szendro",4284,48.4,20.733333 ],
    [ u"hu",u"Szentendre",23606,47.664712,19.068063 ],
    [ u"hu",u"Szentes",30495,46.65,20.266667 ],
    [ u"hu",u"Szentgál",2815,46.374791,18.626006 ],
    [ u"hu",u"Szentgotthárd",8911,46.946513,16.315555 ],
    [ u"hu",u"Szentistván",2629,47.766667,20.666667 ],
    [ u"hu",u"Szentkirályszabadja",2042,47.057602,17.970522 ],
    [ u"hu",u"Szentkirály",1965,46.918923,19.918463 ],
    [ u"hu",u"Szentlorinckata",2005,47.519474,19.752865 ],
    [ u"hu",u"Szentlorinc",7123,46.040164,17.987194 ],
    [ u"hu",u"Szentmártonkáta",4868,47.454188,19.701428 ],
    [ u"hu",u"Szerencs",10046,48.166667,21.2 ],
    [ u"hu",u"Szigetcsép",2455,47.264921,18.970484 ],
    [ u"hu",u"Szigethalom",13092,47.322283,19.002622 ],
    [ u"hu",u"Szigetszentmiklós",24874,47.343819,19.043351 ],
    [ u"hu",u"Szigetújfalu",2158,47.234172,18.927461 ],
    [ u"hu",u"Szigetvár",11267,46.04865,17.805536 ],
    [ u"hu",u"Szihalom",2120,47.766667,20.483333 ],
    [ u"hu",u"Szikszó",5963,48.2,20.933333 ],
    [ u"hu",u"Szilvásvárad",1885,48.1,20.4 ],
    [ u"hu",u"Szirmabesenyo",4697,48.15,20.8 ],
    [ u"hu",u"Szob",3065,47.819212,18.870205 ],
    [ u"hu",u"Szodliget",4350,47.732588,19.147486 ],
    [ u"hu",u"Szod",3059,47.724394,19.170458 ],
    [ u"hu",u"Szolnok",75998,47.183333,20.2 ],
    [ u"hu",u"Szombathely",80210,47.233333,16.616667 ],
    [ u"hu",u"Szomód",2020,47.684919,18.34061 ],
    [ u"hu",u"Szurdokpüspöki",1947,47.859232,19.692184 ],
    [ u"hu",u"Táborfalva",3509,47.099418,19.478374 ],
    [ u"hu",u"Tab",4824,46.731353,18.032013 ],
    [ u"hu",u"Tahitófalu",4677,47.753025,19.091234 ],
    [ u"hu",u"Taksony",6129,47.329681,19.066945 ],
    [ u"hu",u"Taktaharkány",4076,48.083333,21.133333 ],
    [ u"hu",u"Taktaszada",2067,48.116667,21.183333 ],
    [ u"hu",u"Tállya",2169,48.233333,21.233333 ],
    [ u"hu",u"Tamási",9682,46.633333,18.283333 ],
    [ u"hu",u"Tápióbicske",3514,47.360957,19.686093 ],
    [ u"hu",u"Tápiógyörgye",3817,47.335046,19.95276 ],
    [ u"hu",u"Tápióság",2760,47.401999,19.630468 ],
    [ u"hu",u"Tapioszecso",6628,47.45,19.609232 ],
    [ u"hu",u"Tápiószele",6214,47.336093,19.877241 ],
    [ u"hu",u"Tápiószentmárton",5596,47.3399,19.746478 ],
    [ u"hu",u"Tapioszolos",3155,47.302475,19.851333 ],
    [ u"hu",u"Táplánszentkereszt",2342,47.198582,16.694219 ],
    [ u"hu",u"Tapolca",17598,46.881518,17.44117 ],
    [ u"hu",u"Tarcal",3283,48.133333,21.35 ],
    [ u"hu",u"Tarján",2825,47.610423,18.510703 ],
    [ u"hu",u"Tarnalelesz",1805,48.05,20.183333 ],
    [ u"hu",u"Tárnok",7990,47.373269,18.845786 ],
    [ u"hu",u"Tarpa",2331,48.104797,22.537444 ],
    [ u"hu",u"Tar",1972,47.953712,19.746098 ],
    [ u"hu",u"Tass",2963,47.020954,19.029884 ],
    [ u"hu",u"Taszár",2013,46.37467,17.905942 ],
    [ u"hu",u"Tatabánya",71527,47.584941,18.393253 ],
    [ u"hu",u"Tata",23868,47.652891,18.31838 ],
    [ u"hu",u"Tát",5575,47.741478,18.648127 ],
    [ u"hu",u"Tázlár",1984,46.548241,19.514358 ],
    [ u"hu",u"Téglás",6285,47.716667,21.683333 ],
    [ u"hu",u"Telki",2071,47.547905,18.828165 ],
    [ u"hu",u"Tengelic",2445,46.528784,18.711166 ],
    [ u"hu",u"Tét",4104,47.519225,17.50802 ],
    [ u"hu",u"Tiszaalpár",5070,46.812788,19.998411 ],
    [ u"hu",u"Tiszabercel",2047,48.15,21.65 ],
    [ u"hu",u"Tiszabezdéd",2054,48.366667,22.15 ],
    [ u"hu",u"Tiszabo",2000,47.3,20.483333 ],
    [ u"hu",u"Tiszabura",2730,47.45,20.466667 ],
    [ u"hu",u"Tiszacsege",4961,47.7,21 ],
    [ u"hu",u"Tiszadada",2505,48.033333,21.25 ],
    [ u"hu",u"Tiszadob",3311,48.016667,21.166667 ],
    [ u"hu",u"Tiszaeszlár",2857,48.05,21.466667 ],
    [ u"hu",u"Tiszaföldvár",11873,46.983333,20.25 ],
    [ u"hu",u"Tiszafüred",12000,47.616667,20.766667 ],
    [ u"hu",u"Tiszakarád",2522,48.2,21.716667 ],
    [ u"hu",u"Tiszakécske",11745,46.932615,20.103487 ],
    [ u"hu",u"Tiszakeszi",2692,47.783333,21 ],
    [ u"hu",u"Tiszalök",6122,48.016667,21.383333 ],
    [ u"hu",u"Tiszalúc",5551,48.033333,21.083333 ],
    [ u"hu",u"Tiszanagyfalu",2010,48.1,21.483333 ],
    [ u"hu",u"Tiszanána",2607,47.566667,20.533333 ],
    [ u"hu",u"Tiszapüspöki",2096,47.216667,20.316667 ],
    [ u"hu",u"Tiszaroff",1874,47.4,20.45 ],
    [ u"hu",u"Tiszasüly",1737,47.383333,20.4 ],
    [ u"hu",u"Tiszaszentimre",2340,47.483333,20.733333 ],
    [ u"hu",u"Tiszaújváros",17294,47.933333,21.083333 ],
    [ u"hu",u"Tiszavasvári",13631,47.966667,21.35 ],
    [ u"hu",u"Tóalmás",3434,47.507816,19.666572 ],
    [ u"hu",u"Tokaj",5071,48.116667,21.416667 ],
    [ u"hu",u"Tokod",4271,47.722768,18.658887 ],
    [ u"hu",u"Tököl",9112,47.31854,18.967791 ],
    [ u"hu",u"Tolcsva",1860,48.283333,21.45 ],
    [ u"hu",u"Tolna",12011,46.426765,18.782476 ],
    [ u"hu",u"Töltéstava",1902,47.62609,17.733761 ],
    [ u"hu",u"Tömörkény",1944,46.617161,20.043569 ],
    [ u"hu",u"Tompa",4844,46.206054,19.539101 ],
    [ u"hu",u"Tornyospálca",2725,48.266667,22.183333 ],
    [ u"hu",u"Törökbálint",11658,47.436454,18.912422 ],
    [ u"hu",u"Törökszentmiklós",22770,47.183333,20.416667 ],
    [ u"hu",u"Törtel",4733,47.122092,19.93714 ],
    [ u"hu",u"Tószeg",4621,47.1,20.15 ],
    [ u"hu",u"Tótkomlós",6497,46.416667,20.733333 ],
    [ u"hu",u"Tunyogmatolcs",2629,47.966667,22.466667 ],
    [ u"hu",u"Tura",8294,47.609242,19.60279 ],
    [ u"hu",u"Türje",1868,46.98366,17.107417 ],
    [ u"hu",u"Túrkeve",10016,47.1,20.75 ],
    [ u"hu",u"Tuzsér",3332,48.34407,22.117621 ],
    [ u"hu",u"Tyukod",2188,47.853778,22.5633 ],
    [ u"hu",u"Újfehértó",13542,47.8,21.683333 ],
    [ u"hu",u"Újhartyán",2852,47.219808,19.386378 ],
    [ u"hu",u"Újkígyós",5602,46.583333,21.033333 ],
    [ u"hu",u"Újszász",6855,47.3,20.083333 ],
    [ u"hu",u"Újszilvás",2722,47.274767,19.924767 ],
    [ u"hu",u"Üllés",3145,46.336114,19.844544 ],
    [ u"hu",u"Ullo",10232,47.387711,19.35533 ],
    [ u"hu",u"Úri",2718,47.414288,19.527622 ],
    [ u"hu",u"Úrkút",2178,47.085046,17.643933 ],
    [ u"hu",u"Üröm",4753,47.596741,19.015829 ],
    [ u"hu",u"Vácszentlászló",2085,47.574005,19.537711 ],
    [ u"hu",u"Vác",35108,47.780715,19.131006 ],
    [ u"hu",u"Vaja",3774,48.005739,22.167609 ],
    [ u"hu",u"Vajszló",1888,45.859575,17.984056 ],
    [ u"hu",u"Valkó",2461,47.563907,19.51267 ],
    [ u"hu",u"Vál",2348,47.36264,18.679306 ],
    [ u"hu",u"Vámosgyörk",2020,47.684285,19.92924 ],
    [ u"hu",u"Vámospércs",5451,47.533333,21.9 ],
    [ u"hu",u"Városföld",2248,46.817206,19.759822 ],
    [ u"hu",u"Várpalota",21299,47.199358,18.139543 ],
    [ u"hu",u"Vásárosnamény",9310,48.133333,22.316667 ],
    [ u"hu",u"Vaskút",3613,46.107816,18.985141 ],
    [ u"hu",u"Vasvár",4613,47.049018,16.804145 ],
    [ u"hu",u"Vecsés",19327,47.407047,19.286483 ],
    [ u"hu",u"Velence",4832,47.238547,18.654842 ],
    [ u"hu",u"Vép",3460,47.22537,16.716098 ],
    [ u"hu",u"Veresegyház",11087,47.645899,19.295355 ],
    [ u"hu",u"Veroce",3087,47.828517,19.014648 ],
    [ u"hu",u"Verpelét",4016,47.85,20.233333 ],
    [ u"hu",u"Vertesszolos",2747,47.621057,18.381298 ],
    [ u"hu",u"Veszprém",60387,47.094289,17.911956 ],
    [ u"hu",u"Veszto",7494,46.916667,21.266667 ],
    [ u"hu",u"Villány",2738,45.868889,18.453889 ],
    [ u"hu",u"Visegrád",1713,47.78526,18.970897 ],
    [ u"hu",u"Vonyarcvashegy",1902,46.757425,17.311717 ],
    [ u"hu",u"Zagyvarékas",3700,47.266667,20.133333 ],
    [ u"hu",u"Zagyvaszántó",2067,47.777031,19.670922 ],
    [ u"hu",u"Záhony",4807,48.409062,22.176139 ],
    [ u"hu",u"Zákányszék",2747,46.274529,19.889751 ],
    [ u"hu",u"Zalaegerszeg",60919,46.84,16.843889 ],
    [ u"hu",u"Zalakomár",3103,46.537955,17.18094 ],
    [ u"hu",u"Zalalovo",3195,46.848016,16.587496 ],
    [ u"hu",u"Zalaszentgrót",7796,46.944739,17.079253 ],
    [ u"hu",u"Zamárdi",2211,46.884884,17.953657 ],
    [ u"hu",u"Zámoly",2194,47.316667,18.408101 ],
    [ u"hu",u"Zirc",7314,47.262384,17.870522 ],
    [ u"hu",u"Zomba",2286,46.410838,18.565767 ],
    [ u"hu",u"Zsámbék",4791,47.548138,18.720112 ],
    [ u"hu",u"Zsámbok",2474,47.543813,19.610481 ],
    [ u"hu",u"Zsombó",3268,46.325656,19.974638 ],
    [ u"id",u"Adiwerna",134202,-6.9375,109.1325 ],
    [ u"id",u"Amahai",47651,-3.333333,128.916667 ],
    [ u"id",u"Ambarawa",84380,-7.263333,110.3975 ],
    [ u"id",u"Ambon",355607,-3.695426,128.181405 ],
    [ u"id",u"Ambulu",27503,-8.3504,113.6069 ],
    [ u"id",u"Amuntai",55596,-2.433333,115.25 ],
    [ u"id",u"Arjawinangun",105852,-6.645278,108.410278 ],
    [ u"id",u"Astanajapura",148055,-6.8017,108.6311 ],
    [ u"id",u"Atambua",35794,-9.106111,124.8925 ],
    [ u"id",u"Babakan",124801,-6.8275,108.498333 ],
    [ u"id",u"Babat",27039,-7.075,112.304 ],
    [ u"id",u"Bae",57927,-6.7674,110.8541 ],
    [ u"id",u"Baki",58916,-7.612778,110.783889 ],
    [ u"id",u"Balaipungut",56453,1.05,101.283333 ],
    [ u"id",u"Balapulang",28484,-7.05,109.083333 ],
    [ u"id",u"Balikpapan",433939,-1.283333,116.833333 ],
    [ u"id",u"Balung",47631,-7.733333,113.916667 ],
    [ u"id",u"Bambanglipuro",44717,-7.95,110.283333 ],
    [ u"id",u"Banda Aceh",250796,5.5577,95.3222 ],
    [ u"id",u"Bandar",31443,2.05,99.75 ],
    [ u"id",u"Bandung",1699822,-6.903889,107.618611 ],
    [ u"id",u"Bangil",62513,-7.5993,112.784 ],
    [ u"id",u"Bangkalan",62185,-7.0455,112.7351 ],
    [ u"id",u"Banjaran",165136,-6.871667,107.77 ],
    [ u"id",u"Banjar",37282,-7.1955,107.4313 ],
    [ u"id",u"Banjarmasin",572910,-3.333333,114.583333 ],
    [ u"id",u"Bantul",58658,-7.888056,110.328889 ],
    [ u"id",u"Banyumas",48379,-7.514167,109.294167 ],
    [ u"id",u"Banyuwangi",108178,-8.2215,114.3646 ],
    [ u"id",u"Barabai",60231,-2.583333,115.383333 ],
    [ u"id",u"Batu",75640,-7.87,112.528333 ],
    [ u"id",u"Baturaden",42395,-7.3,109.216667 ],
    [ u"id",u"Baturaja",134824,-4.133333,104.166667 ],
    [ u"id",u"Bekasi",1520204,-6.2349,106.9896 ],
    [ u"id",u"Belawan",102709,3.7755,98.6832 ],
    [ u"id",u"Bengkalis",41705,1.466667,102.133333 ],
    [ u"id",u"Bengkulu",309759,-3.8,102.266667 ],
    [ u"id",u"Besuki",55466,-7.75,113.683333 ],
    [ u"id",u"Biak",40907,-1.166007,136.09717 ],
    [ u"id",u"Bima",66972,-8.466667,118.716667 ],
    [ u"id",u"Binjai",228794,3.564,98.724 ],
    [ u"id",u"Bireun",25794,5.203,96.7009 ],
    [ u"id",u"Bitung",137361,1.4451,125.1824 ],
    [ u"id",u"Blitar",132431,-8.0983,112.1681 ],
    [ u"id",u"Blora",51812,-6.9698,111.4186 ],
    [ u"id",u"Bogor",769328,-6.594444,106.789167 ],
    [ u"id",u"Bojonegoro",86578,-7.1502,111.8817 ],
    [ u"id",u"Bondowoso",69791,-7.9159,113.8256 ],
    [ u"id",u"Bone",81631,-4.5386,120.3279 ],
    [ u"id",u"Bontang",101693,.133333,117.5 ],
    [ u"id",u"Boyolali",59852,-7.533056,110.595833 ],
    [ u"id",u"Boyolangu",32287,-8.1181,111.8935 ],
    [ u"id",u"Brebes",186936,-6.8691,109.0378 ],
    [ u"id",u"Buaran",38774,-6.915162,109.657035 ],
    [ u"id",u"Buduran",48152,-7.270278,112.561111 ],
    [ u"id",u"Bulakamba",27367,-6.8748,108.9559 ],
    [ u"id",u"Bumiayu",54044,-7.25,109 ],
    [ u"id",u"Ceper",28647,-7.674167,110.678889 ],
    [ u"id",u"Cepu",55056,-7.1475,111.5906 ],
    [ u"id",u"Ciamis",123631,-7.3257,108.3534 ],
    [ u"id",u"Ciampea",207445,-6.540278,106.695556 ],
    [ u"id",u"Cianjur",146883,-6.822222,107.139444 ],
    [ u"id",u"Ciawi",67902,-6.525278,106.579722 ],
    [ u"id",u"Cibadak",229745,-6.536389,106.770278 ],
    [ u"id",u"Cibeureum",52774,-7.0218,108.3031 ],
    [ u"id",u"Cibinong",188674,-6.398611,106.688611 ],
    [ u"id",u"Cibitung",198119,-6.272222,107.103611 ],
    [ u"id",u"Cicalengka",158211,-6.932222,107.470278 ],
    [ u"id",u"Cidahu",50240,-6.769444,106.758889 ],
    [ u"id",u"Cikampek",145613,-6.419722,107.455833 ],
    [ u"id",u"Cikarang",106486,-6.261111,107.152778 ],
    [ u"id",u"Cikeruh",85328,-6.933056,107.774722 ],
    [ u"id",u"Cikupa",174184,-6.228889,106.519444 ],
    [ u"id",u"Cikupa",174184,-6.3724,106.1945 ],
    [ u"id",u"Ciledug",98524,-6.9142,108.7343 ],
    [ u"id",u"Cilegon",299790,-6.0144,106.0542 ],
    [ u"id",u"Cileungsi",202360,-6.394722,106.959167 ],
    [ u"id",u"Cileunyi",111570,-6.793889,107.851944 ],
    [ u"id",u"Cimahi",378027,-6.698333,107.275278 ],
    [ u"id",u"Ciomas",152335,-6.601389,106.771389 ],
    [ u"id",u"Ciparay",114226,-6.941667,107.349167 ],
    [ u"id",u"Ciputat",207848,-6.2375,106.695556 ],
    [ u"id",u"Ciranjang",77755,-6.813333,107.26 ],
    [ u"id",u"Cirebon",254314,-6.7063,108.557 ],
    [ u"id",u"Cisaat",141005,-6.775278,106.771389 ],
    [ u"id",u"Cisarua",103933,-6.448333,107.120556 ],
    [ u"id",u"Citeureup",110162,-6.362778,106.675278 ],
    [ u"id",u"Comal",51092,-6.9053,109.5347 ],
    [ u"id",u"Curug",191617,-6.253333,106.617222 ],
    [ u"id",u"Curug",191617,-6.3367,106.2256 ],
    [ u"id",u"Curup",46246,-3.466667,102.533333 ],
    [ u"id",u"Dampit",23094,-8.042222,112.515278 ],
    [ u"id",u"Delanggu",24440,-7.616667,110.683333 ],
    [ u"id",u"Deli Tua",27944,3.5078,98.6839 ],
    [ u"id",u"Demak",27251,-6.8909,110.6396 ],
    [ u"id",u"Denpasar",405959,-8.65,115.216667 ],
    [ u"id",u"Depok",104537,-7.696667,110.2175 ],
    [ u"id",u"Depok",1198195,-6.343333,106.498889 ],
    [ u"id",u"Diwek",41719,-7.583333,112.233333 ],
    [ u"id",u"Driyorejo",26827,-7.3659,112.6219 ],
    [ u"id",u"Dukuhturi",98084,-6.8865,108.8432 ],
    [ u"id",u"Dumai",143775,1.683333,101.45 ],
    [ u"id",u"Ende",77212,-8.8432,121.6623 ],
    [ u"id",u"Galesong",83052,-5.3166,119.3661 ],
    [ u"id",u"Gambiran",22525,-8.3939,114.1464 ],
    [ u"id",u"Gampengrejo",49119,-7.7087,112.1008 ],
    [ u"id",u"Gamping",66116,-7.783333,110.316667 ],
    [ u"id",u"Garut",122421,-7.2024,107.8878 ],
    [ u"id",u"Gatak",48964,-7.4475,110.554167 ],
    [ u"id",u"Gebog",43757,-6.735,110.8444 ],
    [ u"id",u"Gedangan",79239,-7.390833,112.726667 ],
    [ u"id",u"Gempol",31151,-7.252778,112.591389 ],
    [ u"id",u"Genteng",79653,-8.366667,114.15 ],
    [ u"id",u"Godean",63170,-7.769722,110.293889 ],
    [ u"id",u"Gombong",31965,-7.607222,109.514167 ],
    [ u"id",u"Gondang",24616,-7.8779,112.1148 ],
    [ u"id",u"Gondanglegi",22468,-8.175288,112.635935 ],
    [ u"id",u"Gorontalo",144202,.5412,123.0595 ],
    [ u"id",u"Gresik",73638,-7.153889,112.656111 ],
    [ u"id",u"Grogol",100624,-7.296389,110.746944 ],
    [ u"id",u"Indramayu",123271,-6.326389,108.32 ],
    [ u"id",u"Jakarta",8540306,-6.174444,106.829444 ],
    [ u"id",u"Jambi",420391,-1.6,103.616667 ],
    [ u"id",u"Jaten",32379,-7.344444,110.8875 ],
    [ u"id",u"Jatibarang",28817,-6.9658,109.055 ],
    [ u"id",u"Jatibarang",73006,-6.474722,108.315278 ],
    [ u"id",u"Jati",85816,-6.5198,110.9306 ],
    [ u"id",u"Jatiroto",50065,-7.883333,111.116667 ],
    [ u"id",u"Jatiwangi",57970,-6.722778,108.2475 ],
    [ u"id",u"Jeluko",37522,-6.5855,110.9897 ],
    [ u"id",u"Jember",298620,-8.1705,113.702 ],
    [ u"id",u"Jepara",54324,-6.5924,110.671 ],
    [ u"id",u"Jetis",49292,-7.642778,110.278611 ],
    [ u"id",u"Jetis",49292,-7.668333,110.463056 ],
    [ u"id",u"Jogonalan",28114,-7.703611,110.536111 ],
    [ u"id",u"Jombang",126479,-7.55,112.233333 ],
    [ u"id",u"Juwana",40178,-6.715,111.1514 ],
    [ u"id",u"Kabanjahe",57160,3.1001,98.4908 ],
    [ u"id",u"Kadipaten",26970,-6.760833,108.166111 ],
    [ u"id",u"Kadungora",77255,-6.994722,107.837778 ],
    [ u"id",u"Kalianget",23897,-7.05,113.933333 ],
    [ u"id",u"Kaliwungu",48916,-6.95,110.233333 ],
    [ u"id",u"Kamal",22515,-7.167778,112.719167 ],
    [ u"id",u"Kanigoro",36467,-8.130027,112.218962 ],
    [ u"id",u"Karangampel",31232,-6.462222,108.451944 ],
    [ u"id",u"Karanganom",50671,-7.608889,110.976667 ],
    [ u"id",u"Karanganyar",34923,-7.293889,109.576667 ],
    [ u"id",u"Karangasem",31869,-8.4994,115.5465 ],
    [ u"id",u"Karangsembung",75852,-6.8487,108.6422 ],
    [ u"id",u"Karang Tengah",138471,-6.908611,106.910556 ],
    [ u"id",u"Karawang",198894,-6.303333,107.305556 ],
    [ u"id",u"Kasihan",86242,-7.826944,110.329167 ],
    [ u"id",u"Katobu",42751,-4.9186,122.5218 ],
    [ u"id",u"Kawalu",50538,-7.3817,108.2082 ],
    [ u"id",u"Kebomas",75990,-7.166667,112.633333 ],
    [ u"id",u"Kebonarum",21745,-7.553333,110.594722 ],
    [ u"id",u"Kebumen",144457,-7.323333,109.600833 ],
    [ u"id",u"Kediri",235171,-7.816667,112.016667 ],
    [ u"id",u"Kedungwaru",80267,-8.0348,112.2037 ],
    [ u"id",u"Kedungwuni",117262,-6.970383,109.647942 ],
    [ u"id",u"Kefamenanu",29491,-9.446667,124.478056 ],
    [ u"id",u"Kemang",111027,-6.741389,107.019167 ],
    [ u"id",u"Kembaran",77977,-7.373889,109.316944 ],
    [ u"id",u"Kencong",43047,-8.2726,113.3651 ],
    [ u"id",u"Kendal",50637,-6.9213,110.2022 ],
    [ u"id",u"Kendari",235329,-3.945,122.498889 ],
    [ u"id",u"Kepanjen",51920,-8.1303,112.5727 ],
    [ u"id",u"Kertosono",60789,-7.5946,112.1059 ],
    [ u"id",u"Ketanggungan",44288,-6.9158,109.0965 ],
    [ u"id",u"Kijang",41343,.9,104.633333 ],
    [ u"id",u"Kisaran",129928,2.9845,99.6158 ],
    [ u"id",u"Klangenan",88373,-6.709444,108.44 ],
    [ u"id",u"Klaten",126845,-7.705833,110.606389 ],
    [ u"id",u"Klungkung",27837,-8.533333,115.4 ],
    [ u"id",u"Kraksaan",28249,-7.760384,113.413192 ],
    [ u"id",u"Kramat",48074,-6.8688,109.2074 ],
    [ u"id",u"Kresek",110304,-6.131389,106.379722 ],
    [ u"id",u"Krian",38604,-7.1163,112.4194 ],
    [ u"id",u"Kroya",23255,-7.483889,108.923611 ],
    [ u"id",u"Kualakapuas",35632,-3.1,114.35 ],
    [ u"id",u"Kudus",92166,-6.8048,110.8405 ],
    [ u"id",u"Kuningan",72090,-6.975833,108.483056 ],
    [ u"id",u"Kupang",282421,-10.166667,123.583333 ],
    [ u"id",u"Kutoarjo",31353,-7.716944,109.912778 ],
    [ u"id",u"Labuhan Deli",49675,3.7278,98.6738 ],
    [ u"id",u"Labuhan",33574,-6.3784,105.83 ],
    [ u"id",u"Lahat",65903,-3.8,103.533333 ],
    [ u"id",u"Lamongan",59224,-7.1194,112.4172 ],
    [ u"id",u"Langsa",54466,4.4683,97.9683 ],
    [ u"id",u"Lasem",28948,-6.6922,111.4527 ],
    [ u"id",u"Lawang",159517,-7.8353,112.6947 ],
    [ u"id",u"Lebaksiu",33607,-7.0496,109.1441 ],
    [ u"id",u"Lembang",183283,-6.786389,107.7025 ],
    [ u"id",u"Leuwiliang",191992,-6.575833,106.636944 ],
    [ u"id",u"Lhokseumawe",88976,5.1801,97.1507 ],
    [ u"id",u"Loa Janan",212820,-.583333,117.083333 ],
    [ u"id",u"Lubuk Pakam",87457,3.5592,98.8733 ],
    [ u"id",u"Lumajang",123640,-8.1335,113.2248 ],
    [ u"id",u"Luwuk",47779,-.9516,122.7875 ],
    [ u"id",u"Madiun",186116,-7.6298,111.5239 ],
    [ u"id",u"Magelang",111470,-7.470556,110.217778 ],
    [ u"id",u"Magetan",79716,-7.656667,111.331389 ],
    [ u"id",u"Majalaya",226720,-7.0485,107.7631 ],
    [ u"id",u"Majalengka",87775,-6.836111,108.227778 ],
    [ u"id",u"Majenang",38898,-7.2975,108.7642 ],
    [ u"id",u"Majene",37716,-3.5403,118.9707 ],
    [ u"id",u"Makasar",1321832,-5.14,119.4221 ],
    [ u"id",u"Malang",746780,-7.9797,112.6304 ],
    [ u"id",u"Manado",451910,1.487,124.8455 ],
    [ u"id",u"Manggar",34522,-2.883333,108.266667 ],
    [ u"id",u"Manokwari",53191,-.866667,134.083333 ],
    [ u"id",u"Margahayu",83124,-6.970833,107.5675 ],
    [ u"id",u"Margasari",27814,-7.1,109.016667 ],
    [ u"id",u"Martapura",131452,-3.416667,114.85 ],
    [ u"id",u"Mataram",318712,-8.583333,116.116667 ],
    [ u"id",u"Maumere",47599,-8.6199,122.2111 ],
    [ u"id",u"Mayong",24176,-6.75,110.75 ],
    [ u"id",u"Medan",1751190,3.583333,98.666667 ],
    [ u"id",u"Mendahara",56269,-1.033333,103.583333 ],
    [ u"id",u"Mentok",26708,-2.066667,105.183333 ],
    [ u"id",u"Merauke",49079,-8.466667,140.333333 ],
    [ u"id",u"Mertoyudan",69872,-7.52,110.226389 ],
    [ u"id",u"Metro",149552,-5.113056,105.306667 ],
    [ u"id",u"Meulaboh",35063,4.1363,96.1285 ],
    [ u"id",u"Mlati",67092,-7.733333,110.366667 ],
    [ u"id",u"Mlonggo",33543,-6.533333,110.7 ],
    [ u"id",u"Mojoagung",23534,-7.5684,112.3344 ],
    [ u"id",u"Mojokerto",112570,-7.4664,112.4338 ],
    [ u"id",u"Mojosari",36298,-7.3503,112.5946 ],
    [ u"id",u"Mranggen",28026,-6.9688,110.2524 ],
    [ u"id",u"Muncar",64538,-8.4365,114.3391 ],
    [ u"id",u"Mundu",50426,-6.463611,108.3925 ],
    [ u"id",u"Muntilan",44859,-7.581111,110.292778 ],
    [ u"id",u"Nabire",43899,-3.366667,135.483333 ],
    [ u"id",u"Negara",33192,-8.3601,114.631 ],
    [ u"id",u"Ngaglik",34328,-7.684167,110.326111 ],
    [ u"id",u"Ngaglik",34328,-7.654167,110.448333 ],
    [ u"id",u"Nganjuk",69019,-7.6051,111.9035 ],
    [ u"id",u"Ngawen",44401,-7.834722,110.685556 ],
    [ u"id",u"Ngawi",22412,-7.4038,111.4461 ],
    [ u"id",u"Ngemplak",23751,-7.216667,110.631111 ],
    [ u"id",u"Ngoro",22871,-7.6899,112.2709 ],
    [ u"id",u"Ngunut",26297,-7.9598,112.1984 ],
    [ u"id",u"Pacet",328324,-6.750278,107.046667 ],
    [ u"id",u"Paciran",27072,-6.866667,112.333333 ],
    [ u"id",u"Padalarang",124953,-6.8425,107.484722 ],
    [ u"id",u"Padang",840458,-.953154,100.367659 ],
    [ u"id",u"Pakisaji",30214,-8.0665,112.5981 ],
    [ u"id",u"Palabuhanratu",42999,-6.9875,106.551389 ],
    [ u"id",u"Palembang",1241334,-2.916667,104.75 ],
    [ u"id",u"Palimanan",92606,-6.706944,108.424167 ],
    [ u"id",u"Palu",282461,-.8917,119.8707 ],
    [ u"id",u"Pamanukan",114386,-6.284167,107.810556 ],
    [ u"id",u"Pamekasan",92457,-7.1568,113.4746 ],
    [ u"id",u"Pameungpeuk",48297,-6.669167,107.549722 ],
    [ u"id",u"Pamulang",174549,-6.342778,106.738333 ],
    [ u"id",u"Panarukan",30749,-7.7008,113.9529 ],
    [ u"id",u"Pandaan",34184,-7.586,112.5015 ],
    [ u"id",u"Pandak",56048,-7.913056,110.293611 ],
    [ u"id",u"Pandegelang",92361,-6.3084,106.1067 ],
    [ u"id",u"Pangkah",113387,-6.9745,109.1732 ],
    [ u"id",u"Pangkalanbuun",38058,-2.683333,111.616667 ],
    [ u"id",u"Panji",42789,-7.695,114.0317 ],
    [ u"id",u"Parakan",23795,-6.9517,110.0676 ],
    [ u"id",u"Pare",56700,-7.6823,111.8866 ],
    [ u"id",u"Parung",193991,-6.3276,106.9715 ],
    [ u"id",u"Pasarkemis",154227,-6.170278,106.530278 ],
    [ u"id",u"Paseh",126287,-6.803889,107.867222 ],
    [ u"id",u"Pasuruan",158618,-7.6453,112.9075 ],
    [ u"id",u"Pati",122798,-6.7559,111.038 ],
    [ u"id",u"Payakumbuh",121652,-.22019,100.630781 ],
    [ u"id",u"Pecangakan",61047,-6.6978,110.7107 ],
    [ u"id",u"Pedan",28738,-7.688333,110.697222 ],
    [ u"id",u"Pekalongan",257973,-6.8886,109.6753 ],
    [ u"id",u"Pemalang",184169,-6.9,109.366667 ],
    [ u"id",u"Pemangkat",34030,1.166667,108.966667 ],
    [ u"id",u"Perbaungan",157378,3.5679,98.956 ],
    [ u"id",u"Peterongan",22726,-7.1988,112.2022 ],
    [ u"id",u"Plered",25122,-6.640556,107.386389 ],
    [ u"id",u"Plumbon",167187,-6.576944,108.317778 ],
    [ u"id",u"Polewali",58191,-3.4324,119.3435 ],
    [ u"id",u"Ponorogo",79034,-7.8685,111.462 ],
    [ u"id",u"Pontianak",455226,-.033333,109.333333 ],
    [ u"id",u"Porong",54698,-7.5406,112.6888 ],
    [ u"id",u"Poso",47115,-1.3959,120.7524 ],
    [ u"id",u"Prabumulih",103476,-3.45,104.25 ],
    [ u"id",u"Prambanan",44926,-7.75,110.494167 ],
    [ u"id",u"Praya",35184,-8.705362,116.270357 ],
    [ u"id",u"Prigen",24164,-7.6816,112.6393 ],
    [ u"id",u"Pringsewu",124791,-5.358215,104.974407 ],
    [ u"id",u"Probolinggo",181678,-7.7543,113.2159 ],
    [ u"id",u"Pundong",24082,-7.765833,110.330833 ],
    [ u"id",u"Purbalingga",56909,-7.388056,109.363889 ],
    [ u"id",u"Purwakarta",215816,-6.556944,107.443333 ],
    [ u"id",u"Purwodadi",150278,-7.0868,110.9158 ],
    [ u"id",u"Purwokerto",217245,-7.421389,109.234444 ],
    [ u"id",u"Purworejo",105077,-7.763611,112.738889 ],
    [ u"id",u"Rajapolah",39838,-7.221,108.1896 ],
    [ u"id",u"Rancaekek",152108,-6.960278,107.7575 ],
    [ u"id",u"Randudongkal",28532,-7.0981,109.3243 ],
    [ u"id",u"Rangkasbitung",126904,-6.3591,106.2494 ],
    [ u"id",u"Rantauprapat",103011,2.1,99.833333 ],
    [ u"id",u"Rantepao",40439,-2.9701,119.8978 ],
    [ u"id",u"Rembang",44030,-6.7036,111.3416 ],
    [ u"id",u"Rengasdengklok",201687,-6.159167,107.298056 ],
    [ u"id",u"Ruteng",34570,-8.6136,120.4721 ],
    [ u"id",u"Sabang",24519,5.893333,95.321389 ],
    [ u"id",u"Salatiga",172664,-7.321389,110.507778 ],
    [ u"id",u"Samarinda",355223,-.5,117.15 ],
    [ u"id",u"Sampang",53270,-7.1872,113.2394 ],
    [ u"id",u"Sampit",66054,-2.533333,112.95 ],
    [ u"id",u"Sawangan",114063,-6.2775,106.529444 ],
    [ u"id",u"Selogiri",30180,-7.783333,110.866667 ],
    [ u"id",u"Semarang",1288221,-6.9932,110.4203 ],
    [ u"id",u"Sembakung",8098,3.816667,117.25 ],
    [ u"id",u"Sepatan",118434,-6.118889,106.575 ],
    [ u"id",u"Serang",164777,-6.1149,106.1502 ],
    [ u"id",u"Serpong",80189,-6.316944,106.664167 ],
    [ u"id",u"Sewon",73592,-7.684722,110.466389 ],
    [ u"id",u"Seyegan",23427,-7.720278,110.299167 ],
    [ u"id",u"Sibolga",79725,1.7427,98.7792 ],
    [ u"id",u"Sidareja",30314,-7.239167,108.964444 ],
    [ u"id",u"Sidoarjo",139205,-7.4478,112.7183 ],
    [ u"id",u"Sigli",17505,5.3848,95.9609 ],
    [ u"id",u"Sijunjung",27787,-.687623,100.953652 ],
    [ u"id",u"Simpang",36653,-1.266667,104.083333 ],
    [ u"id",u"Sindang",27957,-6.334167,108.316111 ],
    [ u"id",u"Singaparna",48880,-7.3515,108.111 ],
    [ u"id",u"Singaraja",133796,-8.1127,115.0949 ],
    [ u"id",u"Singkang",59524,-4.1279,120.0297 ],
    [ u"id",u"Singkawang",101851,.9,109 ],
    [ u"id",u"Singojuruh",29418,-8.3097,114.2394 ],
    [ u"id",u"Singosari",57794,-7.8924,112.6658 ],
    [ u"id",u"Sinjai",40798,-5.1241,120.253 ],
    [ u"id",u"Situbondo",51058,-7.7082,114.0008 ],
    [ u"id",u"Slawi",61213,-6.9816,109.1407 ],
    [ u"id",u"Sleman",56216,-7.715556,110.355556 ],
    [ u"id",u"Soe",27718,-9.866667,124.283333 ],
    [ u"id",u"Solok",48373,-.791834,100.659315 ],
    [ u"id",u"Sooko",25494,-7.3532,112.5203 ],
    [ u"id",u"Soreang",151135,-7.033056,107.518333 ],
    [ u"id",u"Sorong",125538,-.883333,131.25 ],
    [ u"id",u"Sragen",71530,-7.426389,111.022222 ],
    [ u"id",u"Srandakan",29532,-7.938611,110.250556 ],
    [ u"id",u"Srono",36260,-8.4023,114.264 ],
    [ u"id",u"Stabat",26863,3.761,98.4513 ],
    [ u"id",u"Subang",129009,-6.57,107.756667 ],
    [ u"id",u"Sukabumi",276431,-6.918056,106.926667 ],
    [ u"id",u"Sukaraja",66489,-7.458056,109.288056 ],
    [ u"id",u"Sukaraja",157205,-6.587778,106.8375 ],
    [ u"id",u"Sumbawa",52655,-8.5,117.433333 ],
    [ u"id",u"Sumber",93466,-6.760278,108.483056 ],
    [ u"id",u"Sumedang",206919,-6.858611,107.916389 ],
    [ u"id",u"Sumenep",84665,-7.016667,113.866667 ],
    [ u"id",u"Sungaipenuh",95990,-2.083333,101.383333 ],
    [ u"id",u"Sungairaya",47736,.7,108.9 ],
    [ u"id",u"Sunggal",157936,3.5765,98.6151 ],
    [ u"id",u"Surabaya",2374920,-7.249167,112.750833 ],
    [ u"id",u"Surakarta",555368,-7.556111,110.831667 ],
    [ u"id",u"Tabanan",33668,-8.5384,115.1282 ],
    [ u"id",u"Talang",98971,-6.9,109.133333 ],
    [ u"id",u"Taman",181626,-6.9,109.383333 ],
    [ u"id",u"Taman",126875,-7.1785,112.8978 ],
    [ u"id",u"Tambun",314271,-6.105278,107.222222 ],
    [ u"id",u"Tanete",105109,-5.3306,120.1371 ],
    [ u"id",u"Tangerang",1372185,-6.178056,106.63 ],
    [ u"id",u"Tanggulangin",32867,-7.2409,112.4642 ],
    [ u"id",u"Tanggul",35909,-8.1645,113.4525 ],
    [ u"id",u"Tanjung Morawa",157908,3.5193,98.7914 ],
    [ u"id",u"Tarakan",97496,3.3,117.633333 ],
    [ u"id",u"Tarogong",77165,-7.056389,107.636667 ],
    [ u"id",u"Tarub",75740,-6.933333,109.166667 ],
    [ u"id",u"Tasikmalaya",271160,-7.3274,108.2207 ],
    [ u"id",u"Tayu",26414,-6.5397,111.0518 ],
    [ u"id",u"Tebingtinggi",117547,3.3285,99.1625 ],
    [ u"id",u"Tegal",237110,-6.8694,109.1402 ],
    [ u"id",u"Teluknaga",128336,-6.065,106.644167 ],
    [ u"id",u"Teluk Nibung",25146,3.001,99.8164 ],
    [ u"id",u"Temanggung",42081,-7.175556,110.258333 ],
    [ u"id",u"Ternate",101736,.8,127.4 ],
    [ u"id",u"Tidore",46146,.666667,127.433333 ],
    [ u"id",u"Tomohon",27623,1.3346,124.8392 ],
    [ u"id",u"Tondano",33315,1.3038,124.9112 ],
    [ u"id",u"Trenggalek",29083,-8.05,111.716667 ],
    [ u"id",u"Trucuk",23584,-7.689167,110.341389 ],
    [ u"id",u"Tual",39501,-5.666667,132.75 ],
    [ u"id",u"Tuban",76251,-6.8976,112.0649 ],
    [ u"id",u"Tulangan",63890,-7.4737,112.6505 ],
    [ u"id",u"Tulungagung",65270,-8.0657,111.9025 ],
    [ u"id",u"Ubud",28373,-8.4203,115.223 ],
    [ u"id",u"Ungaran",127873,-7.139722,110.405 ],
    [ u"id",u"Waingapu",48829,-9.6567,120.2641 ],
    [ u"id",u"Wanaraja",26239,-7.1749,107.9808 ],
    [ u"id",u"Wanasari",25892,-6.8884,109.0283 ],
    [ u"id",u"Waru",147506,-7.36,112.724722 ],
    [ u"id",u"Wates",22916,-7.6072,112.0505 ],
    [ u"id",u"Wedi",55300,-7.743056,110.579444 ],
    [ u"id",u"Welahan",26163,-6.8,110.716667 ],
    [ u"id",u"Weleri",58454,-6.9713,110.0666 ],
    [ u"id",u"Weru",139013,-6.711,108.5037 ],
    [ u"id",u"Wlingi",29582,-8.0776,112.3311 ],
    [ u"id",u"Wonogiri",38623,-7.814444,110.920556 ],
    [ u"id",u"Wonopringgo",38430,-6.983333,109.616667 ],
    [ u"id",u"Wonosari",62961,-7.306111,110.773889 ],
    [ u"id",u"Wonosari",27458,-7.688056,110.391389 ],
    [ u"id",u"Wonosobo",93000,-7.0425,109.8851 ],
    [ u"id",u"Yogyakarta",636711,-7.782778,110.360833 ],
    [ u"ie",u"Abbeyfeale",1734,52.3813889,-9.3025 ],
    [ u"ie",u"Abbeyleix",1711,52.8991667,-7.3575 ],
    [ u"ie",u"Ardee",4008,53.8597222,-6.5405556 ],
    [ u"ie",u"Arklow",10622,52.7930556,-6.1413889 ],
    [ u"ie",u"Ashbourne",7001,53.5108333,-6.4272222 ],
    [ u"ie",u"Athboy",1656,53.6186111,-6.9205556 ],
    [ u"ie",u"Athenry",2419,53.2963889,-8.7430556 ],
    [ u"ie",u"Athlone",15951,53.4227778,-7.9372222 ],
    [ u"ie",u"Athy",6382,52.9913889,-6.9802778 ],
    [ u"ie",u"Bagenalstown",3033,52.6958333,-6.9897222 ],
    [ u"ie",u"Bailieborough",1703,53.9166667,-6.9666667 ],
    [ u"ie",u"Balbriggan",11293,53.6127778,-6.1819444 ],
    [ u"ie",u"Ballaghaderreen",1389,53.9,-8.5833333 ],
    [ u"ie",u"Ballina",10087,54.1166667,-9.1666667 ],
    [ u"ie",u"Ballinasloe",6388,53.3275,-8.2194444 ],
    [ u"ie",u"Ballinrobe",1707,53.6333333,-9.2333333 ],
    [ u"ie",u"Ballybofey",3848,54.8,-7.7833333 ],
    [ u"ie",u"Ballyhaunis",1344,53.7666667,-8.7666667 ],
    [ u"ie",u"Ballyshannon",2683,54.5,-8.1833333 ],
    [ u"ie",u"Banagher",1586,53.1886111,-7.9866667 ],
    [ u"ie",u"Bandon",5493,51.7469444,-8.7425 ],
    [ u"ie",u"Bantry",3234,51.6833333,-9.45 ],
    [ u"ie",u"Belturbet",1277,54.1,-7.45 ],
    [ u"ie",u"Birr",4549,53.0913889,-7.9133333 ],
    [ u"ie",u"Blarney",2215,51.9333333,-8.5666667 ],
    [ u"ie",u"Blessington",2874,53.17,-6.5325 ],
    [ u"ie",u"Boyle",2199,53.9666667,-8.3 ],
    [ u"ie",u"Bray",32317,53.2027778,-6.0983333 ],
    [ u"ie",u"Buncrana",5546,55.1333333,-7.45 ],
    [ u"ie",u"Bundoran",1865,54.4666667,-8.2833333 ],
    [ u"ie",u"Cahir",3057,52.3769444,-7.9216667 ],
    [ u"ie",u"Carlow",20055,52.8408333,-6.9261111 ],
    [ u"ie",u"Carndonagh",1581,55.25,-7.2666667 ],
    [ u"ie",u"Carrickmacross",3995,53.9727778,-6.7188889 ],
    [ u"ie",u"Carrick-on-Suir",5710,52.3491667,-7.4130556 ],
    [ u"ie",u"Carrigaline",12902,51.8116667,-8.3986111 ],
    [ u"ie",u"Cashel",2798,52.5158333,-7.8855556 ],
    [ u"ie",u"Castlebar",12874,53.85,-9.3 ],
    [ u"ie",u"Castleblayney",3006,54.1166667,-6.7333333 ],
    [ u"ie",u"Castlecomer",1686,52.8061111,-7.2105556 ],
    [ u"ie",u"Castleisland",2122,52.2333333,-9.4666667 ],
    [ u"ie",u"Castlerea",1770,53.7666667,-8.5 ],
    [ u"ie",u"Cavan",6388,53.9908333,-7.3605556 ],
    [ u"ie",u"Celbridge",18167,53.3386111,-6.5436111 ],
    [ u"ie",u"Charleville",2674,52.35,-8.6833333 ],
    [ u"ie",u"Clane",5155,53.2913889,-6.6891667 ],
    [ u"ie",u"Clara",2783,53.3425,-7.6138889 ],
    [ u"ie",u"Claremorris",2168,53.7166667,-9.0 ],
    [ u"ie",u"Clonakilty",4065,51.6230556,-8.8705556 ],
    [ u"ie",u"Clones",1834,54.1833333,-7.2333333 ],
    [ u"ie",u"Clonmel",17394,52.355,-7.7038889 ],
    [ u"ie",u"Cobh",10501,51.8572222,-8.2991667 ],
    [ u"ie",u"Cootehill",1713,54.0725,-7.0819444 ],
    [ u"ie",u"Cork",188908,51.8986111,-8.4958333 ],
    [ u"ie",u"Dingle",1971,52.1408333,-10.2688889 ],
    [ u"ie",u"Donabate",3936,53.4872222,-6.1519444 ],
    [ u"ie",u"Donegal",2513,54.65,-8.1166667 ],
    [ u"ie",u"Drogheda",33441,53.7188889,-6.3477778 ],
    [ u"ie",u"Dublin",1024027,53.3330556,-6.2488889 ],
    [ u"ie",u"Duleek",2376,53.6566667,-6.4191667 ],
    [ u"ie",u"Dunboyne",6718,53.4,-6.4666667 ],
    [ u"ie",u"Dundalk",33428,54.0,-6.4166667 ],
    [ u"ie",u"Dungarvan",7551,52.0880556,-7.6252778 ],
    [ u"ie",u"Dunmanway",1566,51.7166667,-9.1166667 ],
    [ u"ie",u"Dunmore East",1795,52.1513889,-6.9861111 ],
    [ u"ie",u"Dunshaughlin",3567,53.5125,-6.54 ],
    [ u"ie",u"Edenderry",4890,53.3452778,-7.0497222 ],
    [ u"ie",u"Enniscorthy",9709,52.5008333,-6.5577778 ],
    [ u"ie",u"Ennis",24427,52.8436111,-8.9863889 ],
    [ u"ie",u"Enniskerry",1990,53.1925,-6.1691667 ],
    [ u"ie",u"Fermoy",4933,52.1358333,-8.2758333 ],
    [ u"ie",u"Galway",70686,53.2719444,-9.0488889 ],
    [ u"ie",u"Gorey",6040,52.6747222,-6.2925 ],
    [ u"ie",u"Gort",2098,53.0663889,-8.8166667 ],
    [ u"ie",u"Granard",1292,53.7666667,-7.5 ],
    [ u"ie",u"Greystones",12260,53.1408333,-6.0630556 ],
    [ u"ie",u"Kanturk",1628,52.1666667,-8.9 ],
    [ u"ie",u"Kells",4820,53.7263889,-6.8791667 ],
    [ u"ie",u"Kenmare",2023,51.8833333,-9.5833333 ],
    [ u"ie",u"Kilcock",3293,53.4022222,-6.6708333 ],
    [ u"ie",u"Kilcoole",2869,53.1027778,-6.065 ],
    [ u"ie",u"Kilcormac",1200,53.1741667,-7.7255556 ],
    [ u"ie",u"Kilcullen",2110,53.1302778,-6.7444444 ],
    [ u"ie",u"Kildare",6380,53.1561111,-6.9144444 ],
    [ u"ie",u"Kilkenny",21589,52.6541667,-7.2522222 ],
    [ u"ie",u"Kill",2304,52.1761111,-7.335 ],
    [ u"ie",u"Killorglin",1409,52.1,-9.7833333 ],
    [ u"ie",u"Killybegs",1725,54.6333333,-8.45 ],
    [ u"ie",u"Kilmallock",1523,52.4,-8.5772222 ],
    [ u"ie",u"Kilrush",2712,52.6397222,-9.4833333 ],
    [ u"ie",u"Kinsale",3843,51.7075,-8.5305556 ],
    [ u"ie",u"Laytown",6342,53.6819444,-6.2391667 ],
    [ u"ie",u"Leixlip",15729,53.3658333,-6.4955556 ],
    [ u"ie",u"Letterkenny",16903,54.95,-7.7333333 ],
    [ u"ie",u"Lifford",1617,54.8319444,-7.4836111 ],
    [ u"ie",u"Limerick",90054,52.6647222,-8.6230556 ],
    [ u"ie",u"Listowel",4143,52.4463889,-9.485 ],
    [ u"ie",u"Longford",7787,53.7333333,-7.8 ],
    [ u"ie",u"Loughrea",4296,53.1969444,-8.5669444 ],
    [ u"ie",u"Lusk",2508,53.5280556,-6.1691667 ],
    [ u"ie",u"Macroom",3169,51.9,-8.95 ],
    [ u"ie",u"Malahide",14057,53.4508333,-6.1544444 ],
    [ u"ie",u"Mallow",9495,52.1333333,-8.6333333 ],
    [ u"ie",u"Maynooth",11318,53.385,-6.5936111 ],
    [ u"ie",u"Midleton",8891,51.9094444,-8.1736111 ],
    [ u"ie",u"Mitchelstown",3357,52.2658333,-8.2680556 ],
    [ u"ie",u"Moate",1504,53.55,-7.7166667 ],
    [ u"ie",u"Monaghan",5937,54.25,-6.9666667 ],
    [ u"ie",u"Monasterevan",2704,53.1405556,-7.0663889 ],
    [ u"ie",u"Mountmellick",3547,53.1136111,-7.32 ],
    [ u"ie",u"Mountrath",1597,52.9988889,-7.4727778 ],
    [ u"ie",u"Moville",1402,55.1833333,-7.05 ],
    [ u"ie",u"Mullingar",17262,53.5333333,-7.35 ],
    [ u"ie",u"Naas",20554,53.2158333,-6.6669444 ],
    [ u"ie",u"Navan",24545,53.6527778,-6.6813889 ],
    [ u"ie",u"Nenagh",6672,52.8619444,-8.1966667 ],
    [ u"ie",u"Newbridge",18860,53.1819444,-6.7966667 ],
    [ u"ie",u"Newcastle",4184,52.4491667,-9.0611111 ],
    [ u"ie",u"New Ross",6695,52.3966667,-6.9366667 ],
    [ u"ie",u"Oranmore",1758,53.2683333,-8.92 ],
    [ u"ie",u"Passage West",4907,51.8738889,-8.3444444 ],
    [ u"ie",u"Portarlington",4293,53.1622222,-7.1911111 ],
    [ u"ie",u"Portmarnock",8037,53.4230556,-6.1375 ],
    [ u"ie",u"Prosperous",1649,53.2902778,-6.7538889 ],
    [ u"ie",u"Rathangan",1961,53.2213889,-6.995 ],
    [ u"ie",u"Rathcoole",2443,53.2827778,-6.4727778 ],
    [ u"ie",u"Rathdrum",1649,52.9263889,-6.2355556 ],
    [ u"ie",u"Rathkeale",1470,52.5244444,-8.9380556 ],
    [ u"ie",u"Ratoath",4084,53.5080556,-6.4625 ],
    [ u"ie",u"Roscommon",4860,53.6333333,-8.1833333 ],
    [ u"ie",u"Roscrea",4721,52.9511111,-7.8016667 ],
    [ u"ie",u"Rush",7294,53.5247222,-6.1097222 ],
    [ u"ie",u"Sallins",3164,53.2488889,-6.6661111 ],
    [ u"ie",u"Shannon",8781,52.7038889,-8.8641667 ],
    [ u"ie",u"Skerries",10014,53.5827778,-6.1083333 ],
    [ u"ie",u"Skibbereen",2098,51.55,-9.2666667 ],
    [ u"ie",u"Sligo",20228,54.2666667,-8.4833333 ],
    [ u"ie",u"Swinford",1241,53.95,-8.95 ],
    [ u"ie",u"Swords",29816,53.4597222,-6.2180556 ],
    [ u"ie",u"Templemore",2264,52.7947222,-7.8338889 ],
    [ u"ie",u"Thomastown",1603,52.5266667,-7.1372222 ],
    [ u"ie",u"Thurles",7588,52.6819444,-7.8022222 ],
    [ u"ie",u"Tipperary",4976,52.4733333,-8.1558333 ],
    [ u"ie",u"Tower",3099,51.9166667,-8.6 ],
    [ u"ie",u"Tralee",22941,52.2666667,-9.7166667 ],
    [ u"ie",u"Tramore",9164,52.1588889,-7.1463889 ],
    [ u"ie",u"Trim",6781,53.555,-6.7916667 ],
    [ u"ie",u"Tuam",6130,53.5166667,-8.85 ],
    [ u"ie",u"Tullamore",11575,53.2738889,-7.4888889 ],
    [ u"ie",u"Tullow",2424,52.8002778,-6.7369444 ],
    [ u"ie",u"Waterford",47904,52.2583333,-7.1119444 ],
    [ u"ie",u"Westport",6200,53.8,-9.5166667 ],
    [ u"ie",u"Wexford",17708,52.3341667,-6.4575 ],
    [ u"ie",u"Wicklow",10461,52.975,-6.0494444 ],
    [ u"ie",u"Youghal",6868,51.95,-7.8505556 ],
    [ u"il",u"Abu Ghosh",5570,31.805925,35.1093 ],
    [ u"il",u"Ashdod",202681,31.736056,34.655944 ],
    [ u"il",u"Ashdod",202681,31.792133,34.649656 ],
    [ u"il",u"Ashqelon",108342,31.669256,34.57149 ],
    [ u"il",u"Azur",10338,32.019167,34.810556 ],
    [ u"il",u"Bat Yam",130973,32.023056,34.750278 ],
    [ u"il",u"Beit Jann",10001,32.964638,35.381522 ],
    [ u"il",u"Bene Ayish",8193,31.789593,34.760655 ],
    [ u"il",u"Bene Beraq",140849,32.090278,34.839722 ],
    [ u"il",u"Bet Dagan",5990,32.001389,34.830278 ],
    [ u"il",u"Bet Shemesh",64838,31.749587,34.988768 ],
    [ u"il",u"Bet Yizhaq",1674,32.327511,34.88878 ],
    [ u"il",u"Deir Hanna",8658,32.861963,35.363652 ],
    [ u"il",u"Dimona",33354,31.066667,35.033333 ],
    [ u"il",u"Elat",46707,29.558049,34.948212 ],
    [ u"il",u"Elyakhin",2728,32.407931,34.924332 ],
    [ u"il",u"Even Yehuda",9091,32.269593,34.887592 ],
    [ u"il",u"Fassuta",2985,33.048952,35.308935 ],
    [ u"il",u"Fureidis",9805,32.6,34.95 ],
    [ u"il",u"Ganne Tiqwa",12408,32.060278,34.874722 ],
    [ u"il",u"Gan Yavne",14830,31.787373,34.706592 ],
    [ u"il",u"Gedera",14267,31.814561,34.779979 ],
    [ u"il",u"Haifa",269961,32.815556,34.989167 ],
    [ u"il",u"Hod HaSharon",42996,32.150833,34.888333 ],
    [ u"il",u"Hurfeish",5252,33.017108,35.348352 ],
    [ u"il",u"Ibtin",2020,32.761667,35.100833 ],
    [ u"il",u"Iksal",11213,32.68164,35.323646 ],
    [ u"il",u"Jaljulye",7580,32.155833,34.952778 ],
    [ u"il",u"Jerusalem",714685,31.78,35.23 ],
    [ u"il",u"Jish",2684,33.022157,35.446941 ],
    [ u"il",u"Kabul",9301,32.866667,35.213056 ],
    [ u"il",u"Kafar Kama",2990,32.721288,35.441217 ],
    [ u"il",u"Kafar Manda",14771,32.807222,35.260278 ],
    [ u"il",u"Kafar Qasem",17189,32.114167,34.973889 ],
    [ u"il",u"Kefar Habad",4771,31.986667,34.851111 ],
    [ u"il",u"Kefar Sava",80922,32.175,34.906944 ],
    [ u"il",u"Kefar Shemaryahu",1774,32.185556,34.821944 ],
    [ u"il",u"Kefar Tavor",2323,32.686555,35.421177 ],
    [ u"il",u"Kefar Weradim",5559,32.993849,35.277933 ],
    [ u"il",u"Kefar Yona",12771,32.316692,34.935073 ],
    [ u"il",u"Lod",68095,31.951389,34.895278 ],
    [ u"il",u"Mazkeret Batya",8283,31.853889,34.838611 ],
    [ u"il",u"Mizpe Ramon",4769,30.609444,34.801111 ],
    [ u"il",u"Nahariyya",50881,33.005855,35.094087 ],
    [ u"il",u"Nahef",10077,32.933333,35.316667 ],
    [ u"il",u"Nehalim",2061,32.061944,34.913889 ],
    [ u"il",u"Nein",1588,32.630634,35.348847 ],
    [ u"il",u"Nesher",21811,32.765,35.05 ],
    [ u"il",u"Netanya",172405,32.332915,34.859918 ],
    [ u"il",u"Netivot",24933,31.42215,34.588581 ],
    [ u"il",u"Nordiyya",2264,32.314697,34.89617 ],
    [ u"il",u"Ofaqim",24633,31.314099,34.620254 ],
    [ u"il",u"Or Yehuda",30977,32.031111,34.845833 ],
    [ u"il",u"Pardesiyya",6348,32.305774,34.909111 ],
    [ u"il",u"Qesarya",4300,32.507982,34.904867 ],
    [ u"il",u"Qiryat Atta",49548,32.800556,35.106389 ],
    [ u"il",u"Qiryat Bialik",37385,32.8275,35.085833 ],
    [ u"il",u"Qiryat Gat",48946,31.609981,34.764224 ],
    [ u"il",u"Qiryat Motzkin",40694,32.836389,35.075278 ],
    [ u"il",u"Qiryat Ono",24907,32.063611,34.855278 ],
    [ u"il",u"Qiryat Ono",24907,32.022222,34.866667 ],
    [ u"il",u"Qiryat Shemona",22738,33.207334,35.572118 ],
    [ u"il",u"Qiryat Yam",38122,32.850833,35.070278 ],
    [ u"il",u"Ramat Gan",126864,32.080556,34.814167 ],
    [ u"il",u"Ramat HaSharon",35556,32.147222,34.841667 ],
    [ u"il",u"Ramat Yishay",5722,32.700556,35.179722 ],
    [ u"il",u"Ramla",63837,31.925278,34.866944 ],
    [ u"il",u"Reine",16157,32.723611,35.3125 ],
    [ u"il",u"Rekhasim",8521,32.75,35.1 ],
    [ u"il",u"Rosh Pinna",2492,32.968938,35.542584 ],
    [ u"il",u"Rumat Heib",1588,32.779167,35.306944 ],
    [ u"il",u"Sajur",3547,32.942661,35.341358 ],
    [ u"il",u"Sakhnin",24401,32.862222,35.293333 ],
    [ u"il",u"Sallama",1800,32.89443,35.369313 ],
    [ u"il",u"Savyon",3434,32.053056,34.877778 ],
    [ u"il",u"Sederot",20865,31.524995,34.59693 ],
    [ u"il",u"Sheikh Dannun",2305,32.992306,35.147901 ],
    [ u"il",u"Shelomi",5784,33.074719,35.146075 ],
    [ u"il",u"Sulam",2426,32.606057,35.334078 ],
    [ u"il",u"Tamra",25839,32.848611,35.204722 ],
    [ u"il",u"Tayibe",32736,32.266161,35.008932 ],
    [ u"il",u"Tel Aviv-Yafo",370480,32.067778,34.764722 ],
    [ u"il",u"Tel Mond",8939,32.249947,34.917368 ],
    [ u"il",u"Tiberias",41029,32.792205,35.531244 ],
    [ u"il",u"Timrat",1789,32.703611,35.226667 ],
    [ u"il",u"Tirat Karmel",19234,32.761667,34.971944 ],
    [ u"il",u"Uzeir",2591,32.792124,35.329841 ],
    [ u"il",u"Yavne",32394,31.81555,34.7208 ],
    [ u"il",u"Yeroham",9148,30.987222,34.931389 ],
    [ u"in",u"Abhayapuri",15803,26.333333,90.666667 ],
    [ u"in",u"Abiramam",6837,9.466667,78.45 ],
    [ u"in",u"Abohar",130613,30.15,74.183333 ],
    [ u"in",u"Abu Road",50266,24.483333,72.783333 ],
    [ u"in",u"Achalpur",111287,21.257222,77.508611 ],
    [ u"in",u"Achhnera",20534,27.183333,77.766667 ],
    [ u"in",u"Adalaj",10423,23.166667,72.583333 ],
    [ u"in",u"Addanki",28547,15.816667,79.983333 ],
    [ u"in",u"Adilabad",118539,19.666667,78.533333 ],
    [ u"in",u"Adoni",163649,15.633333,77.283333 ],
    [ u"in",u"Adra",22183,23.5,86.666667 ],
    [ u"in",u"Adur",29655,9.166667,76.733333 ],
    [ u"in",u"Aduturai",11434,11.033333,79.483333 ],
    [ u"in",u"Afzalgarh",27756,29.4,78.683333 ],
    [ u"in",u"Afzalpur",20094,17.2,76.35 ],
    [ u"in",u"Agar",34536,23.7,76.016667 ],
    [ u"in",u"Agartala",203292,23.836389,91.275 ],
    [ u"in",u"Agra",1430194,27.183333,78.016667 ],
    [ u"in",u"Ahmadabad",3719933,23.033333,72.616667 ],
    [ u"in",u"Ahmadnagar",367168,19.083333,74.733333 ],
    [ u"in",u"Ahmadpur",40221,18.7,76.933333 ],
    [ u"in",u"Ahmadpur",8855,23.833333,87.7 ],
    [ u"in",u"Ahraura",25078,25.016667,83.016667 ],
    [ u"in",u"Ahwa",14321,20.75,73.683333 ],
    [ u"in",u"Aizawl",265353,23.724444,92.7175 ],
    [ u"in",u"Ajaigarh",14642,24.9,80.266667 ],
    [ u"in",u"Ajjampur",10795,13.728056,76.009444 ],
    [ u"in",u"Ajmer",517947,26.45,74.633333 ],
    [ u"in",u"Ajnala",19691,31.8425,74.758889 ],
    [ u"in",u"Ajra",15864,16.116667,74.2 ],
    [ u"in",u"Akalgarh",6993,29.816667,75.883333 ],
    [ u"in",u"Akalkot",39229,17.533333,76.216667 ],
    [ u"in",u"Akaltara",21335,22.016667,82.433333 ],
    [ u"in",u"Akbarpur",18837,26.383333,79.95 ],
    [ u"in",u"Akhnur",12803,32.866667,74.733333 ],
    [ u"in",u"Akividu",40421,16.6,81.383333 ],
    [ u"in",u"Aklera",19684,24.416667,76.566667 ],
    [ u"in",u"Akodia",11280,23.383333,76.6 ],
    [ u"in",u"Akola",428892,20.733333,77 ],
    [ u"in",u"Akot",86924,21.096389,77.058611 ],
    [ u"in",u"Alampur",14060,15.883333,78.15 ],
    [ u"in",u"Alampur",10020,26.024444,78.7925 ],
    [ u"in",u"Aland",39067,17.566667,76.566667 ],
    [ u"in",u"Alandi",21385,18.666667,73.9 ],
    [ u"in",u"Alandur",153789,13.0025,80.206111 ],
    [ u"in",u"Alanganallur",11400,10.066667,78.05 ],
    [ u"in",u"Alangayam",17357,12.6,78.75 ],
    [ u"in",u"Alangudi",10618,10.366667,78.983333 ],
    [ u"in",u"Alangulam",28585,8.866667,77.5 ],
    [ u"in",u"Alappuzha",176799,9.494167,76.3275 ],
    [ u"in",u"Alapur",22622,27.9136,79.2458 ],
    [ u"in",u"Alawalpur",7411,31.432778,75.650833 ],
    [ u"in",u"Aldona",6606,15.583333,73.866667 ],
    [ u"in",u"Alibag",20754,18.641111,72.879167 ],
    [ u"in",u"Aliganj",26655,27.5,79.183333 ],
    [ u"in",u"Aligarh",753280,27.883333,78.083333 ],
    [ u"in",u"Alipur",20738,28.8,77.15 ],
    [ u"in",u"Alipur Duar",75936,26.483333,89.566667 ],
    [ u"in",u"Alirajpur",26446,22.3,74.35 ],
    [ u"in",u"Allahabad",1073544,25.45,81.85 ],
    [ u"in",u"Allahganj",13825,27.5461,79.6878 ],
    [ u"in",u"Allapalli",10772,19.416667,80.066667 ],
    [ u"in",u"Almora",32446,29.616667,79.666667 ],
    [ u"in",u"Alnavar",16928,15.433333,74.733333 ],
    [ u"in",u"Along",18427,28.166667,94.766667 ],
    [ u"in",u"Alot",23136,23.766667,75.55 ],
    [ u"in",u"Alur",6605,12.983333,75.983333 ],
    [ u"in",u"Alwar",283248,27.566667,76.6 ],
    [ u"in",u"Alwar Tirunagari",8888,8.6,77.95 ],
    [ u"in",u"Alwaye",23705,10.109167,76.364444 ],
    [ u"in",u"Amalapuram",52696,16.583333,82.016667 ],
    [ u"in",u"Amalner",97377,21.05,75.066667 ],
    [ u"in",u"Amanganj",13169,24.433333,80.033333 ],
    [ u"in",u"Amanpur",10363,27.716667,78.75 ],
    [ u"in",u"Amarkantak",7613,22.666667,81.75 ],
    [ u"in",u"Amarpatan",16860,24.316667,80.983333 ],
    [ u"in",u"Amarpur",11908,23.53,91.644722 ],
    [ u"in",u"Amarpur",22796,25.033333,86.9 ],
    [ u"in",u"Amarwara",13259,22.3,79.166667 ],
    [ u"in",u"Ambad",29849,19.616667,75.8 ],
    [ u"in",u"Ambagarh Chauki",9266,20.783333,80.716667 ],
    [ u"in",u"Ambah",40528,26.7075,78.226111 ],
    [ u"in",u"Ambahta",14304,29.85,77.333333 ],
    [ u"in",u"Ambajogai",74120,18.733333,76.383333 ],
    [ u"in",u"Ambala",146797,30.378333,76.780833 ],
    [ u"in",u"Ambarnath",217778,19.2,73.166667 ],
    [ u"in",u"Ambasamudram",32022,8.7,77.466667 ],
    [ u"in",u"Ambattur",341078,13.076667,80.088611 ],
    [ u"in",u"Ambikapur",72829,23.116667,83.2 ],
    [ u"in",u"Ambur",109883,12.783333,78.7 ],
    [ u"in",u"Amet",17435,25.3,73.933333 ],
    [ u"in",u"Amethi",12207,28.016667,81.05 ],
    [ u"in",u"Amguri",8496,26.8,94.533333 ],
    [ u"in",u"Amla",29998,21.933333,78.116667 ],
    [ u"in",u"Amlagora",19038,22.833333,87.333333 ],
    [ u"in",u"Amli",33368,20.283333,73.016667 ],
    [ u"in",u"Amloh",13860,30.6084,76.2319 ],
    [ u"in",u"Ammapettai",14529,10.8,79.333333 ],
    [ u"in",u"Amod",18742,21.983333,72.9 ],
    [ u"in",u"Amravati",603885,20.933333,77.75 ],
    [ u"in",u"Amreli",99748,21.616667,71.233333 ],
    [ u"in",u"Amritsar",1092528,31.633056,74.865556 ],
    [ u"in",u"Amroha",176271,28.916667,78.466667 ],
    [ u"in",u"Amroli",17082,21.3,72.85 ],
    [ u"in",u"Amta",16753,22.58,88.008333 ],
    [ u"in",u"Amtala",8267,22.371389,88.294444 ],
    [ u"in",u"Amudalavalasa",39129,18.416667,83.9 ],
    [ u"in",u"Amur",40811,18.8,78.283333 ],
    [ u"in",u"Anaimalai",16132,10.583333,76.933333 ],
    [ u"in",u"Anakapalle",84367,17.683333,83.016667 ],
    [ u"in",u"Anand",138018,22.566667,72.933333 ],
    [ u"in",u"Anandnagar",11221,27.1,83.283333 ],
    [ u"in",u"Anandpur Sahib",15230,31.25,76.5 ],
    [ u"in",u"Anantapur",240469,14.683333,77.6 ],
    [ u"in",u"Anantnag",79827,33.733333,75.15 ],
    [ u"in",u"Andippatti",24450,9.983333,77.633333 ],
    [ u"in",u"Anekal",36696,12.7,77.7 ],
    [ u"in",u"Angamali",34402,10.2,76.4 ],
    [ u"in",u"Angul",44390,20.85,85.1 ],
    [ u"in",u"Anjad",24289,22.033333,75.05 ],
    [ u"in",u"Anjangaon",55003,21.163056,77.309444 ],
    [ u"in",u"Anjar",66887,23.133333,70.016667 ],
    [ u"in",u"Anklesvar",74747,21.6,73 ],
    [ u"in",u"Ankola",14541,14.666667,74.3 ],
    [ u"in",u"Annamalainagar",8828,11.4,79.733333 ],
    [ u"in",u"Annavasal",7861,10.466667,78.7 ],
    [ u"in",u"Annigeri",25755,15.433333,75.433333 ],
    [ u"in",u"Annur",19964,11.233333,77.133333 ],
    [ u"in",u"Antri",9788,26.056667,78.214444 ],
    [ u"in",u"Antu",8317,26.05,81.916667 ],
    [ u"in",u"Anupgarh",33311,29.191111,73.208611 ],
    [ u"in",u"Anuppur",18124,23.1,81.683333 ],
    [ u"in",u"Anupshahr",25308,28.366667,78.266667 ],
    [ u"in",u"Aonla",50016,28.283333,79.15 ],
    [ u"in",u"Ara",223700,25.566667,84.666667 ],
    [ u"in",u"Arambagh",60644,22.883333,87.783333 ],
    [ u"in",u"Arang",17505,21.2,81.966667 ],
    [ u"in",u"Arani",62863,12.666667,79.283333 ],
    [ u"in",u"Arantangi",35624,10.166667,78.983333 ],
    [ u"in",u"Araria",67482,26.15,87.516667 ],
    [ u"in",u"Aravankadu",5176,11.366667,76.766667 ],
    [ u"in",u"Arcot",51948,12.9,79.333333 ],
    [ u"in",u"Arimalam",8048,10.266667,78.9 ],
    [ u"in",u"Ariyalur",29146,11.133333,79.083333 ],
    [ u"in",u"Arkalgud",15803,12.765,76.056944 ],
    [ u"in",u"Arki",3293,31.15,76.966667 ],
    [ u"in",u"Arnia",9662,32.516667,74.8 ],
    [ u"in",u"Aron",24277,24.383333,77.416667 ],
    [ u"in",u"Arsikere",44272,13.313889,76.256111 ],
    [ u"in",u"Arukutti",17945,9.866667,76.35 ],
    [ u"in",u"Arumbavur",11419,11.383333,78.733333 ],
    [ u"in",u"Arumuganeri",25154,8.566667,78.116667 ],
    [ u"in",u"Aruppukkottai",85377,9.516667,78.1 ],
    [ u"in",u"Arvi",41840,20.983333,78.233333 ],
    [ u"in",u"Asandh",25325,29.516667,76.6 ],
    [ u"in",u"Asansol",504320,23.683333,86.983333 ],
    [ u"in",u"Asarganj",6020,25.15,86.683333 ],
    [ u"in",u"Ashoknagar",64729,24.566667,77.716667 ],
    [ u"in",u"Ashta",35500,16.95,74.4 ],
    [ u"in",u"Ashta",45370,23.016667,76.716667 ],
    [ u"in",u"Ashti",13083,19.383333,76.233333 ],
    [ u"in",u"Asifabad",21216,19.366667,79.283333 ],
    [ u"in",u"Asind",15390,25.733333,74.333333 ],
    [ u"in",u"Aska",21136,19.6,84.65 ],
    [ u"in",u"Atarra",46173,25.283333,80.566667 ],
    [ u"in",u"Ateli",6177,28.1,76.283333 ],
    [ u"in",u"Athgarh",16667,20.533333,85.616667 ],
    [ u"in",u"Athmallik",11918,20.716667,84.533333 ],
    [ u"in",u"Athni",42051,16.733333,75.066667 ],
    [ u"in",u"Atmakur",35137,15.883333,78.583333 ],
    [ u"in",u"Atraulia",11849,26.333333,82.95 ],
    [ u"in",u"Atrauli",47516,28.033333,78.283333 ],
    [ u"in",u"Attayyampatti",13628,11.533333,78.066667 ],
    [ u"in",u"Attingal",36599,8.683333,76.833333 ],
    [ u"in",u"Attur",58707,11.6,78.616667 ],
    [ u"in",u"Aurad",17019,18.25,77.433333 ],
    [ u"in",u"Auraiya",70515,26.466667,79.516667 ],
    [ u"in",u"Aurangabad",22108,28.033333,77.333333 ],
    [ u"in",u"Aurangabad",1016520,19.883333,75.333333 ],
    [ u"in",u"Aurangabad",95939,24.75,84.366667 ],
    [ u"in",u"Auras",6592,26.916667,80.516667 ],
    [ u"in",u"Ausa",34164,18.25,76.5 ],
    [ u"in",u"Avadi",250066,13.115556,80.101667 ],
    [ u"in",u"Avanashi",24329,11.2,77.283333 ],
    [ u"in",u"Avanigadda",25761,16.016667,80.916667 ],
    [ u"in",u"Ayakudi",24120,10.45,77.55 ],
    [ u"in",u"Ayodhya",53298,26.8,82.2 ],
    [ u"in",u"Ayyampettai",14704,10.9,79.183333 ],
    [ u"in",u"Azamgarh",116655,26.06,83.186111 ],
    [ u"in",u"Babai",16177,22.7,77.933333 ],
    [ u"in",u"Baberu",15608,25.55,80.716667 ],
    [ u"in",u"Babina",35542,25.25,78.466667 ],
    [ u"in",u"Babra",18993,21.85,71.3 ],
    [ u"in",u"Babrala",16671,28.266667,78.4 ],
    [ u"in",u"Babugarh",7156,28.716667,77.85 ],
    [ u"in",u"Bachhraon",29235,28.933333,78.216667 ],
    [ u"in",u"Badami",28316,15.916667,75.683333 ],
    [ u"in",u"Badarpur",11033,24.9,92.6 ],
    [ u"in",u"Badarwas",11135,24.966667,77.566667 ],
    [ u"in",u"Badgam",20948,34.016667,74.716667 ],
    [ u"in",u"Badhni Kalan",6072,30.683333,75.283333 ],
    [ u"in",u"Badlapur",104636,19.15,73.266667 ],
    [ u"in",u"Badnawar",18792,23.016667,75.216667 ],
    [ u"in",u"Baduria",49552,22.741667,88.785833 ],
    [ u"in",u"Badvel",16238,14.75,79.05 ],
    [ u"in",u"Bagaha",103866,27.1,84.083333 ],
    [ u"in",u"Bagalkot",97277,16.183333,75.7 ],
    [ u"in",u"Bagar",15671,28.1874,75.5005 ],
    [ u"in",u"Bagasara",32946,21.483333,70.95 ],
    [ u"in",u"Bagepalli",24033,13.784722,77.793056 ],
    [ u"in",u"Bageshwar",8708,29.85,79.766667 ],
    [ u"in",u"Bagh",7764,22.366667,74.766667 ],
    [ u"in",u"Baghdogra",17373,26.7,88.316667 ],
    [ u"in",u"Baghmara",9950,22.253611,88.870556 ],
    [ u"in",u"Baghpat",41770,28.95,77.216667 ],
    [ u"in",u"Bagli",10765,22.65,76.35 ],
    [ u"in",u"Bagnan",8501,22.924167,88.14 ],
    [ u"in",u"Bagra",11364,23.733333,86.316667 ],
    [ u"in",u"Bagru",25102,26.8084,75.5435 ],
    [ u"in",u"Bagula",20999,23.316667,88.65 ],
    [ u"in",u"Bahadurganj",31408,26.266667,87.816667 ],
    [ u"in",u"Bahadurgarh",153666,28.683333,76.916667 ],
    [ u"in",u"Baharampur",180564,24.1,88.25 ],
    [ u"in",u"Bah",15360,26.87,78.5975 ],
    [ u"in",u"Baheri",63959,28.783333,79.5 ],
    [ u"in",u"Bahjoi",33756,28.4,78.616667 ],
    [ u"in",u"Bahraich",182236,27.583333,81.6 ],
    [ u"in",u"Bahsuma",11158,29.216667,77.966667 ],
    [ u"in",u"Bahua",10244,25.85,80.633333 ],
    [ u"in",u"Baidyabati",115515,22.785,88.324722 ],
    [ u"in",u"Baihar",16170,22.1,80.55 ],
    [ u"in",u"Baikunthpur",10180,24.716667,81.416667 ],
    [ u"in",u"Baikunthpur",10791,23.25,82.55 ],
    [ u"in",u"Bail Hongal",47067,15.816667,74.866667 ],
    [ u"in",u"Baindur",20322,13.866667,74.633333 ],
    [ u"in",u"Baj Baj",76166,22.474722,88.170278 ],
    [ u"in",u"Bajna",7674,27.9,77.683333 ],
    [ u"in",u"Bakani",8621,24.283333,76.233333 ],
    [ u"in",u"Bakewar",14219,26.666667,79.183333 ],
    [ u"in",u"Bakhtiyarpur",34537,25.466667,85.516667 ],
    [ u"in",u"Bakloh",1737,32.466667,75.916667 ],
    [ u"in",u"Bakreswar",1739,23.883333,87.366667 ],
    [ u"in",u"Balaghat",80368,21.783333,80.25 ],
    [ u"in",u"Balangir",91249,20.716667,83.483333 ],
    [ u"in",u"Balapur",42404,20.666667,76.766667 ],
    [ u"in",u"Balarampur",22849,23.116667,86.216667 ],
    [ u"in",u"Balasinor",35151,22.95,73.333333 ],
    [ u"in",u"Baldeo",10537,27.416667,77.816667 ],
    [ u"in",u"Baldeogarh",8283,24.755,79.0681 ],
    [ u"in",u"Baleshwar",114331,21.494167,86.931667 ],
    [ u"in",u"Bali",19260,25.183333,73.283333 ],
    [ u"in",u"Bali Chak",12958,22.366667,87.55 ],
    [ u"in",u"Ballarpur",92154,19.833333,79.35 ],
    [ u"in",u"Ballia",109722,25.75,84.166667 ],
    [ u"in",u"Bally",297001,22.646111,88.340278 ],
    [ u"in",u"Baloda",12039,22.15,82.483333 ],
    [ u"in",u"Baloda Bazar",25238,21.666667,82.166667 ],
    [ u"in",u"Balod",22277,20.73,81.204722 ],
    [ u"in",u"Balotra",68125,25.833333,72.233333 ],
    [ u"in",u"Balrampur",77404,27.433333,82.183333 ],
    [ u"in",u"Balugaon",17240,20.166667,85.1 ],
    [ u"in",u"Balurghat",141418,25.216667,88.766667 ],
    [ u"in",u"Bambolim",5441,15.45,73.85 ],
    [ u"in",u"Bamora",7981,24.0552,78.0909 ],
    [ u"in",u"Banapur",17501,19.783333,85.183333 ],
    [ u"in",u"Banat",21582,29.466667,77.35 ],
    [ u"in",u"Banavar",7827,13.413611,76.168333 ],
    [ u"in",u"Banda",28981,24.0448,78.9626 ],
    [ u"in",u"Banda",152233,25.483333,80.333333 ],
    [ u"in",u"Bandikui",16166,27.05,76.566667 ],
    [ u"in",u"Bandipur",31980,34.416667,74.65 ],
    [ u"in",u"Bandora",12819,15.4,73.966667 ],
    [ u"in",u"Banga",19236,31.186944,75.992222 ],
    [ u"in",u"Bangalore",4931603,12.983333,77.583333 ],
    [ u"in",u"Banganapalle",25325,15.316667,78.233333 ],
    [ u"in",u"Bangaon",111704,23.066667,88.816667 ],
    [ u"in",u"Bangarapet",42793,12.966667,78.2 ],
    [ u"in",u"Bangarmau",37429,26.9,80.216667 ],
    [ u"in",u"Banihal",3278,33.416667,75.2 ],
    [ u"in",u"Banjar",1351,31.633333,77.35 ],
    [ u"in",u"Banka",38943,24.883333,86.916667 ],
    [ u"in",u"Banki",16557,20.383333,85.533333 ],
    [ u"in",u"Bankra",56278,22.6275,88.298056 ],
    [ u"in",u"Bankura",133979,23.25,87.066667 ],
    [ u"in",u"Banmankhi",26809,25.883333,87.183333 ],
    [ u"in",u"Bannur",25457,12.330833,76.863056 ],
    [ u"in",u"Banposh",10431,22.25,84.8 ],
    [ u"in",u"Bansbaria",108485,22.971944,88.399444 ],
    [ u"in",u"Bansda",12702,20.75,73.366667 ],
    [ u"in",u"Bansdih",21459,25.883333,84.216667 ],
    [ u"in",u"Bansgaon",14284,26.558611,83.348056 ],
    [ u"in",u"Bansi",39930,27.183333,82.933333 ],
    [ u"in",u"Banswada",22665,18.383333,77.883333 ],
    [ u"in",u"Banswara",93654,23.55,74.45 ],
    [ u"in",u"Bantva",15052,21.486389,70.068889 ],
    [ u"in",u"Bapatla",70125,15.9,80.466667 ],
    [ u"in",u"Baragaon",11362,25.433333,82.816667 ],
    [ u"in",u"Barakpur",148188,22.761389,88.371944 ],
    [ u"in",u"Baramati",53923,18.15,74.583333 ],
    [ u"in",u"Baramula",77282,34.211111,74.340833 ],
    [ u"in",u"Baranagar",260097,22.643333,88.365278 ],
    [ u"in",u"Baran",87484,25.1,76.516667 ],
    [ u"in",u"Barasat",298270,22.684167,88.441111 ],
    [ u"in",u"Barauli",37306,26.4,84.583333 ],
    [ u"in",u"Baraut",93553,29.1,77.266667 ],
    [ u"in",u"Bar Bigha",41763,25.216667,85.733333 ],
    [ u"in",u"Barddhaman",301754,23.240556,87.869444 ],
    [ u"in",u"Bardoli",57814,21.116667,73.116667 ],
    [ u"in",u"Barela",11649,23.1,80.05 ],
    [ u"in",u"Bareli",745509,28.35,79.416667 ],
    [ u"in",u"Bargarh",68676,21.333333,83.616667 ],
    [ u"in",u"Barghat",11221,22.033333,79.716667 ],
    [ u"in",u"Bargi",17589,22.983333,79.866667 ],
    [ u"in",u"Bargur",12959,12.55,78.366667 ],
    [ u"in",u"Barh",49562,25.483333,85.716667 ],
    [ u"in",u"Barhi",12138,23.9,80.8 ],
    [ u"in",u"Barhi",10655,24.3,85.416667 ],
    [ u"in",u"Barhiya",43049,25.283333,86.033333 ],
    [ u"in",u"Bari",56140,26.65,77.6 ],
    [ u"in",u"Baripada",116227,21.935,86.721389 ],
    [ u"in",u"Bari Sadri",15617,24.416667,74.466667 ],
    [ u"in",u"Barjora",12296,23.433333,87.283333 ],
    [ u"in",u"Barka Kana",18184,23.616667,85.483333 ],
    [ u"in",u"Barkhera",11210,28.45,79.8 ],
    [ u"in",u"Barkot",7726,30.816667,78.2 ],
    [ u"in",u"Barmer",89493,25.75,71.383333 ],
    [ u"in",u"Barnala",105024,30.383333,75.55 ],
    [ u"in",u"Barpali",20204,21.2,83.583333 ],
    [ u"in",u"Barpathar",7445,26.3,93.866667 ],
    [ u"in",u"Barpeta",48826,26.316667,91 ],
    [ u"in",u"Barsana",9816,27.65,77.383333 ],
    [ u"in",u"Barsi",110992,18.233333,75.7 ],
    [ u"in",u"Baruipur",47878,22.349722,88.439167 ],
    [ u"in",u"Baruni",84889,25.483333,85.983333 ],
    [ u"in",u"Barwadih",7402,23.833333,84.116667 ],
    [ u"in",u"Barwaha",24423,22.266667,76.05 ],
    [ u"in",u"Barwala",36696,29.383333,75.916667 ],
    [ u"in",u"Barwani",47348,22.033333,74.9 ],
    [ u"in",u"Basar",4157,27.983333,94.666667 ],
    [ u"in",u"Basavakalyan",65810,17.866667,76.95 ],
    [ u"in",u"Basavana Bagevadi",30829,16.583333,75.966667 ],
    [ u"in",u"Basi",21096,26.833333,76.033333 ],
    [ u"in",u"Basirhat",117431,22.657222,88.894167 ],
    [ u"in",u"Basmat",63977,19.316667,77.166667 ],
    [ u"in",u"Basna",9305,21.283333,82.816667 ],
    [ u"in",u"Basoda",69285,23.6,78.183333 ],
    [ u"in",u"Basti",115126,26.8,82.716667 ],
    [ u"in",u"Basudebpur",31830,21.135278,86.738611 ],
    [ u"in",u"Basugaon",12833,26.466667,90.4 ],
    [ u"in",u"Baswa",22515,27.15,76.583333 ],
    [ u"in",u"Batala",145479,31.818611,75.202778 ],
    [ u"in",u"Batote",4209,33.1,75.316667 ],
    [ u"in",u"Baudh",18947,20.833333,84.316667 ],
    [ u"in",u"Bawal",13319,28.083333,76.583333 ],
    [ u"in",u"Bawana",24908,28.8,77.033333 ],
    [ u"in",u"Bayana",36402,26.9,77.283333 ],
    [ u"in",u"Bazpur",23902,29.15,79.116667 ],
    [ u"in",u"Beawar",130786,26.1,74.316667 ],
    [ u"in",u"Bedi",21328,22.5,70.05 ],
    [ u"in",u"Begamganj",33470,23.6,78.333333 ],
    [ u"in",u"Begampur",9832,22.741667,88.243333 ],
    [ u"in",u"Begowal",10175,31.616667,75.516667 ],
    [ u"in",u"Begun",20837,24.983333,75 ],
    [ u"in",u"Begusarai",103071,25.416667,86.133333 ],
    [ u"in",u"Behat",18225,30.166667,77.616667 ],
    [ u"in",u"Bela",74000,25.933333,81.983333 ],
    [ u"in",u"Belaguntha",10361,19.883333,84.65 ],
    [ u"in",u"Beldanga",27491,23.933333,88.25 ],
    [ u"in",u"Belgaum",428756,15.866667,74.5 ],
    [ u"in",u"Beliator",6014,23.333333,87.216667 ],
    [ u"in",u"Bellary",336710,15.15,76.933333 ],
    [ u"in",u"Belluru",7626,12.991111,76.744444 ],
    [ u"in",u"Belonia",16737,23.252778,91.451389 ],
    [ u"in",u"Belsand",19398,26.45,85.4 ],
    [ u"in",u"Beltangadi",7676,13.983333,75.3 ],
    [ u"in",u"Belur",21553,13.166667,75.866667 ],
    [ u"in",u"Belur",9281,11.7,78.416667 ],
    [ u"in",u"Benaulim",10225,15.25,73.916667 ],
    [ u"in",u"Beniganj",10419,27.283333,80.45 ],
    [ u"in",u"Beohari",22110,24.05,81.383333 ],
    [ u"in",u"Berasia",27093,23.633333,77.433333 ],
    [ u"in",u"Beri",16729,28.7,76.583333 ],
    [ u"in",u"Beswan",5897,27.65,77.883333 ],
    [ u"in",u"Betamcherla",35421,15.466667,78.166667 ],
    [ u"in",u"Betma",13818,22.683333,75.616667 ],
    [ u"in",u"Bettiah",127022,26.8,84.5 ],
    [ u"in",u"Betul Bazar",9641,21.856111,77.9275 ],
    [ u"in",u"Betul",91963,21.856111,77.9275 ],
    [ u"in",u"Bewar",23283,27.2184,79.3005 ],
    [ u"in",u"Beypur",70758,11.183333,75.816667 ],
    [ u"in",u"Bhabua",48646,25.05,83.616667 ],
    [ u"in",u"Bhachau",24044,23.283333,70.35 ],
    [ u"in",u"Bhadasar",33009,28.283333,74.316667 ],
    [ u"in",u"Bhaderwah",13430,32.983333,75.716667 ],
    [ u"in",u"Bhadohi",78576,25.416667,82.566667 ],
    [ u"in",u"Bhadra",37632,29.116667,75.166667 ],
    [ u"in",u"Bhadrachalam",45661,17.666667,80.883333 ],
    [ u"in",u"Bhadrak",98657,21.052778,86.52 ],
    [ u"in",u"Bhadravati",163917,13.866667,75.716667 ],
    [ u"in",u"Bhadreswar",121674,22.824444,88.350556 ],
    [ u"in",u"Bhagalpur",361587,25.25,87 ],
    [ u"in",u"Bhagwantnagar",6597,26.233333,80.75 ],
    [ u"in",u"Bhainsa",46125,19.1,77.966667 ],
    [ u"in",u"Bhainsdehi",16402,21.646667,77.6325 ],
    [ u"in",u"Bhalki",38586,18.033333,77.216667 ],
    [ u"in",u"Bhandara",90190,21.166667,79.65 ],
    [ u"in",u"Bhandardaha",5079,22.616944,88.214444 ],
    [ u"in",u"Bhander",22484,25.733333,78.75 ],
    [ u"in",u"Bhanjanagar",20649,19.933333,84.583333 ],
    [ u"in",u"Bhanpura",17084,24.513,75.7469 ],
    [ u"in",u"Bhanpuri",17270,21.1,80.916667 ],
    [ u"in",u"Bhanvad",20824,21.926389,69.773611 ],
    [ u"in",u"Bharatpur",229400,27.216667,77.483333 ],
    [ u"in",u"Bharthana",41059,26.7571,79.2248 ],
    [ u"in",u"Bharuch",153538,21.7,72.966667 ],
    [ u"in",u"Bharwari",16413,25.55,81.5 ],
    [ u"in",u"Bhasawar",18997,27.033333,77.033333 ],
    [ u"in",u"Bhatapara",51756,21.733333,81.933333 ],
    [ u"in",u"Bhatgaon",8045,21.15,81.7 ],
    [ u"in",u"Bhatkal",31738,13.966667,74.566667 ],
    [ u"in",u"Bhatpara",483175,22.871389,88.408889 ],
    [ u"in",u"Bhattiprolu",18001,16.1,80.783333 ],
    [ u"in",u"Bhavani",39748,11.45,77.683333 ],
    [ u"in",u"Bhavnagar",555014,21.766667,72.15 ],
    [ u"in",u"Bhawanigarh",19377,30.266667,76.035 ],
    [ u"in",u"Bhawanipatna",64474,19.9,83.166667 ],
    [ u"in",u"Bhayavadar",19458,21.85,70.25 ],
    [ u"in",u"Bhigvan",8753,18.316667,74.766667 ],
    [ u"in",u"Bhikangaon",15323,21.866667,75.95 ],
    [ u"in",u"Bhikhi",15960,30.066667,75.533333 ],
    [ u"in",u"Bhilai",625203,21.216667,81.433333 ],
    [ u"in",u"Bhilwara",326454,25.35,74.633333 ],
    [ u"in",u"Bhimavaram",142979,16.533333,81.533333 ],
    [ u"in",u"Bhim Tal",6626,29.35,79.566667 ],
    [ u"in",u"Bhimunipatnam",44848,17.883333,83.433333 ],
    [ u"in",u"Bhindar",16946,24.5,74.183333 ],
    [ u"in",u"Bhind",174053,26.564167,78.788333 ],
    [ u"in",u"Bhinga",22018,27.716667,81.933333 ],
    [ u"in",u"Bhinmal",42866,25,72.25 ],
    [ u"in",u"Bhitarwar",17681,25.8,78.116667 ],
    [ u"in",u"Bhiwandi",707090,19.3,73.066667 ],
    [ u"in",u"Bhiwani",190868,28.783333,76.133333 ],
    [ u"in",u"Bhojudih",9110,23.633333,86.45 ],
    [ u"in",u"Bhongaon",29914,27.25,79.183333 ],
    [ u"in",u"Bhongir",50100,17.510833,78.888889 ],
    [ u"in",u"Bhopal",1600080,23.266667,77.4 ],
    [ u"in",u"Bhor",18984,18.166667,73.85 ],
    [ u"in",u"Bhowali",5686,29.383333,79.516667 ],
    [ u"in",u"Bhuban",20480,20.883333,85.833333 ],
    [ u"in",u"Bhubaneswar",762307,20.233333,85.833333 ],
    [ u"in",u"Bhuj",133458,23.266667,69.666667 ],
    [ u"in",u"Bhum",18545,18.466667,75.666667 ],
    [ u"in",u"Bhusawal",183016,21.05,75.766667 ],
    [ u"in",u"Bhuvanagiri",20658,11.466667,79.633333 ],
    [ u"in",u"Biaora",41993,23.866667,76.916667 ],
    [ u"in",u"Bicholim",15317,15.6,73.95 ],
    [ u"in",u"Bidar",204088,17.9,77.55 ],
    [ u"in",u"Bid",148477,18.983333,75.766667 ],
    [ u"in",u"Bidhuna",27161,26.8022,79.5088 ],
    [ u"in",u"Bighapur",6409,26.35,80.683333 ],
    [ u"in",u"Bihar",244256,25.183333,85.516667 ],
    [ u"in",u"Bihariganj",32806,25.733333,86.983333 ],
    [ u"in",u"Bijapur",271087,16.833333,75.7 ],
    [ u"in",u"Bijawar",19470,24.633333,79.5 ],
    [ u"in",u"Bijbiara",24592,33.8,75.1 ],
    [ u"in",u"Bijni",12991,26.495883,90.702977 ],
    [ u"in",u"Bijnor",84601,29.15,78.266667 ],
    [ u"in",u"Bikaner",576056,28.016667,73.3 ],
    [ u"in",u"Bikapur",13179,26.6,82.133333 ],
    [ u"in",u"Bikramganj",42631,25.2,84.25 ],
    [ u"in",u"Bilara",41713,26.179167,73.705556 ],
    [ u"in",u"Bilari",29669,28.633333,78.8 ],
    [ u"in",u"Bilasipara",37741,26.231954,90.234747 ],
    [ u"in",u"Bilaspur",10710,30.316667,77.316667 ],
    [ u"in",u"Bilaspur",14038,31.333333,76.75 ],
    [ u"in",u"Bilaspur",39877,28.883333,79.266667 ],
    [ u"in",u"Bilaspur",282736,22.083333,82.15 ],
    [ u"in",u"Bilaua",11996,26.033333,78.259722 ],
    [ u"in",u"Bilgi",16257,16.35,75.616667 ],
    [ u"in",u"Bilgram",27176,27.183333,80.033333 ],
    [ u"in",u"Bilhaur",19335,26.85,80.083333 ],
    [ u"in",u"Bilimora",54582,20.75,72.95 ],
    [ u"in",u"Bilkha",14421,21.433333,70.6 ],
    [ u"in",u"Biloli",14717,18.766667,77.733333 ],
    [ u"in",u"Bilsanda",15540,28.25,79.95 ],
    [ u"in",u"Bilsi",26323,28.133333,78.916667 ],
    [ u"in",u"Bina-Etawa",55191,24.1855,78.2031 ],
    [ u"in",u"Bindki",36062,26.033333,80.6 ],
    [ u"in",u"Binika",15096,21.033333,83.8 ],
    [ u"in",u"Birmitrapur",27882,22.4,84.766667 ],
    [ u"in",u"Birpur",18970,26.516667,87.016667 ],
    [ u"in",u"Birur",23495,13.616667,75.966667 ],
    [ u"in",u"Bisalpur",68362,28.3,79.8 ],
    [ u"in",u"Bisauli",32158,28.316667,78.933333 ],
    [ u"in",u"Bishna",11646,32.616667,74.866667 ],
    [ u"in",u"Bishnupur",4429,22.383333,88.266667 ],
    [ u"in",u"Bissau",22622,28.25,75.083333 ],
    [ u"in",u"Biswan",52522,27.5,81 ],
    [ u"in",u"Bithur",10603,26.633333,80.283333 ],
    [ u"in",u"Bobbili",52849,18.566667,83.366667 ],
    [ u"in",u"Bodhan",73946,18.666667,77.9 ],
    [ u"in",u"Bodh Gaya",35192,24.7,84.983333 ],
    [ u"in",u"Bodinayakkanur",75687,10.016667,77.35 ],
    [ u"in",u"Bodri",14493,23.166667,81.433333 ],
    [ u"in",u"Boisar",15692,19.8,72.75 ],
    [ u"in",u"Bokajan",16561,26.016667,93.783333 ],
    [ u"in",u"Bokaro",418578,23.783333,85.966667 ],
    [ u"in",u"Bolpur",71005,23.666667,87.716667 ],
    [ u"in",u"Bombay",12692717,18.975,72.825833 ],
    [ u"in",u"Bongaigaon",64905,26.478224,90.556764 ],
    [ u"in",u"Borsad",60275,22.416667,72.9 ],
    [ u"in",u"Botad",117060,22.166667,71.666667 ],
    [ u"in",u"Brahmapur",324753,19.316667,84.783333 ],
    [ u"in",u"Brahmapuri",32961,20.6,79.866667 ],
    [ u"in",u"Brajrajnagar",79428,21.816667,83.916667 ],
    [ u"in",u"Budaun",161571,28.05,79.116667 ],
    [ u"in",u"Budhgaon",15737,16.9,74.6 ],
    [ u"in",u"Budhlada",25433,29.933333,75.566667 ],
    [ u"in",u"Buguda",14298,19.816667,84.8 ],
    [ u"in",u"Bulandshahr",198631,28.4,77.85 ],
    [ u"in",u"Buldana",66996,20.533333,76.183333 ],
    [ u"in",u"Bundi",98576,25.441667,75.641667 ],
    [ u"in",u"Bundu",19469,23.183333,85.583333 ],
    [ u"in",u"Burhanpur",202717,21.3,76.233333 ],
    [ u"in",u"Burhar",18193,23.216667,81.533333 ],
    [ u"in",u"Burla",40820,21.5,83.866667 ],
    [ u"in",u"Buxar",96130,25.583333,83.983333 ],
    [ u"in",u"Byadgi",27722,14.683333,75.483333 ],
    [ u"in",u"Calcutta",4631819,22.569722,88.369722 ],
    [ u"in",u"Candolim",9198,15.516667,73.75 ],
    [ u"in",u"Canning",42132,22.318889,88.671389 ],
    [ u"in",u"Carapur",5576,15.55,73.966667 ],
    [ u"in",u"Chabua",7623,27.4825,95.173611 ],
    [ u"in",u"Chaibasa",66259,22.566667,85.816667 ],
    [ u"in",u"Chail",8408,25.433333,81.633333 ],
    [ u"in",u"Chakan",23161,18.75,73.85 ],
    [ u"in",u"Chakia",17833,26.416667,85.05 ],
    [ u"in",u"Chakia",15000,25.05,83.216667 ],
    [ u"in",u"Chaklasi",38434,22.65,72.933333 ],
    [ u"in",u"Chakradharpur",40604,22.7,85.633333 ],
    [ u"in",u"Chakrata",3349,30.7,77.85 ],
    [ u"in",u"Chakulia",14953,22.483333,86.716667 ],
    [ u"in",u"Chalakudi",49335,10.3,76.35 ],
    [ u"in",u"Chalala",17082,21.416667,71.166667 ],
    [ u"in",u"Chalisgaon",96389,20.466667,75.016667 ],
    [ u"in",u"Challakere",53510,14.316667,76.65 ],
    [ u"in",u"Challapalle",16841,16.116667,80.933333 ],
    [ u"in",u"Chamba",21504,32.566667,76.133333 ],
    [ u"in",u"Champa",41257,22.05,82.65 ],
    [ u"in",u"Champahati",8922,22.395833,88.484722 ],
    [ u"in",u"Champawat",4669,29.333333,80.1 ],
    [ u"in",u"Champdani",103699,22.797778,88.365833 ],
    [ u"in",u"Champua",9488,22.083333,85.666667 ],
    [ u"in",u"Chamrajnagar",67998,11.916667,76.95 ],
    [ u"in",u"Chanasma",15573,23.716667,72.116667 ],
    [ u"in",u"Chandannagar",180640,22.869167,88.377222 ],
    [ u"in",u"Chandauli",25038,25.266667,83.266667 ],
    [ u"in",u"Chandausi",112646,28.45,78.766667 ],
    [ u"in",u"Chandbali",9918,20.783333,86.766667 ],
    [ u"in",u"Chanderi",32552,24.716667,78.133333 ],
    [ u"in",u"Chandia",13100,23.65,80.7 ],
    [ u"in",u"Chandigarh",914374,30.7343,76.7933 ],
    [ u"in",u"Chandil",4657,22.966667,86.05 ],
    [ u"in",u"Chandla",11196,25.083333,80.2 ],
    [ u"in",u"Chandpur",73562,29.15,78.266667 ],
    [ u"in",u"Chandrakona",21858,22.733333,87.516667 ],
    [ u"in",u"Chandrapur",328377,19.95,79.3 ],
    [ u"in",u"Chandur Bazar",18781,21.241667,77.745556 ],
    [ u"in",u"Chandur",19165,20.816667,77.966667 ],
    [ u"in",u"Chandvad",19592,20.333333,74.25 ],
    [ u"in",u"Changanacheri",51435,9.466667,76.55 ],
    [ u"in",u"Channagiri",20378,14.033333,75.933333 ],
    [ u"in",u"Channapatna",66652,12.65,77.216667 ],
    [ u"in",u"Channarayapatna",37684,12.904444,76.391667 ],
    [ u"in",u"Chapar",19302,26.266667,90.466667 ],
    [ u"in",u"Charkhari",24883,25.4,79.75 ],
    [ u"in",u"Charkhi Dadri",50562,28.6,76.266667 ],
    [ u"in",u"Charthawal",19944,29.55,77.583333 ],
    [ u"in",u"Chas",112153,23.633333,86.166667 ],
    [ u"in",u"Chatakonda",2816,17.55,80.65 ],
    [ u"in",u"Chatra",46849,24.216667,84.866667 ],
    [ u"in",u"Chatrapur",21125,19.35,84.983333 ],
    [ u"in",u"Chatsu",33100,26.6,75.95 ],
    [ u"in",u"Chaupal",1701,30.95,77.583333 ],
    [ u"in",u"Chavakkad",38014,10.533333,76.05 ],
    [ u"in",u"Chechat",11138,24.766667,75.883333 ],
    [ u"in",u"Chengalpattu",65695,12.7,79.983333 ],
    [ u"in",u"Chengam",23904,12.3,78.8 ],
    [ u"in",u"Chengannur",25046,9.333333,76.633333 ],
    [ u"in",u"Cherrapunji",11090,25.3,91.7 ],
    [ u"in",u"Chetpet",18326,13.07,80.240833 ],
    [ u"in",u"Chettipalaiyam",24091,10.9,77.066667 ],
    [ u"in",u"Cheyur",11060,12.348056,80.004722 ],
    [ u"in",u"Chhabra",25678,24.666667,76.833333 ],
    [ u"in",u"Chhachhrauli",10751,30.25,77.366667 ],
    [ u"in",u"Chhapar",18729,27.816667,74.4 ],
    [ u"in",u"Chhapra",197350,25.766667,84.75 ],
    [ u"in",u"Chhaprauli",19224,29.216667,77.183333 ],
    [ u"in",u"Chhata",21262,27.716667,77.5 ],
    [ u"in",u"Chhatapur",23425,26.216667,87.016667 ],
    [ u"in",u"Chhatarpur",111606,24.9,79.6 ],
    [ u"in",u"Chhibramau",57076,27.1483,79.4979 ],
    [ u"in",u"Chhindwara",134862,22.066667,78.933333 ],
    [ u"in",u"Chhoti Sadri",17336,24.383333,74.7 ],
    [ u"in",u"Chhuikhadan",6485,21.533333,80.983333 ],
    [ u"in",u"Chicalim",7787,15.4,73.833333 ],
    [ u"in",u"Chichli",10226,22.833333,78.816667 ],
    [ u"in",u"Chicholi",18866,21.466667,79.683333 ],
    [ u"in",u"Chidambaram",58655,11.4,79.7 ],
    [ u"in",u"Chik Ballapur",57836,13.434167,77.724167 ],
    [ u"in",u"Chikhli",7487,20.75,73.066667 ],
    [ u"in",u"Chikhli",52845,20.35,76.25 ],
    [ u"in",u"Chikitigarh",11056,19.2,84.616667 ],
    [ u"in",u"Chikmagalur",121494,13.316667,75.783333 ],
    [ u"in",u"Chiknayakanhalli",24294,13.417222,76.622778 ],
    [ u"in",u"Chikodi",34987,16.433333,74.6 ],
    [ u"in",u"Chilakalurupet",94021,16.083333,80.166667 ],
    [ u"in",u"Chinchani",14357,19.866667,72.7 ],
    [ u"in",u"Chinchinim",7356,15.2,73.966667 ],
    [ u"in",u"Chincholi",20449,17.466667,77.433333 ],
    [ u"in",u"Chinnammanur",39217,9.833333,77.383333 ],
    [ u"in",u"Chinna Salem",20111,11.65,78.9 ],
    [ u"in",u"Chintamani",71804,13.4,78.066667 ],
    [ u"in",u"Chiplun",51441,17.533333,73.516667 ],
    [ u"in",u"Chipurupalle",25904,18.3,83.566667 ],
    [ u"in",u"Chirala",87011,15.816667,80.35 ],
    [ u"in",u"Chirawa",41322,28.2401,75.6456 ],
    [ u"in",u"Chirgaon",14149,25.583333,78.816667 ],
    [ u"in",u"Chiria",3947,22.3,85.266667 ],
    [ u"in",u"Chitapur",30141,17.116667,77.083333 ],
    [ u"in",u"Chit Baragaon",21659,25.75,84.016667 ],
    [ u"in",u"Chitradurga",138599,14.233333,76.4 ],
    [ u"in",u"Chitrakonda",7260,18.116667,82.083333 ],
    [ u"in",u"Chittaranjan",45309,23.866667,86.866667 ],
    [ u"in",u"Chittaurgarh",106718,24.883333,74.633333 ],
    [ u"in",u"Chittur",31611,10.7,76.75 ],
    [ u"in",u"Chodavaram",25074,17.45,81.766667 ],
    [ u"in",u"Chomun",55965,27.166667,75.716667 ],
    [ u"in",u"Chopan",13587,24.516667,83.033333 ],
    [ u"in",u"Chopda",65603,21.25,75.3 ],
    [ u"in",u"Chotila",15197,22.416667,71.183333 ],
    [ u"in",u"Chuari Khas",3431,32.433333,76.016667 ],
    [ u"in",u"Chunar",36462,25.133333,82.9 ],
    [ u"in",u"Churachandpur",47774,24.333333,93.666667 ],
    [ u"in",u"Churhat",14101,24.433333,81.683333 ],
    [ u"in",u"Churu",103541,28.3,74.95 ],
    [ u"in",u"Clement Town",20807,30.266667,78.066667 ],
    [ u"in",u"Colgong",24081,25.266667,87.216667 ],
    [ u"in",u"Colonelganj",25506,27.133333,81.7 ],
    [ u"in",u"Colvale",5723,15.616667,73.833333 ],
    [ u"in",u"Contai",88710,21.778611,87.753611 ],
    [ u"in",u"Cortalim",7564,15.383333,73.883333 ],
    [ u"in",u"Courtalam",2440,8.916667,77.283333 ],
    [ u"in",u"Cuddapah",127024,14.466667,78.816667 ],
    [ u"in",u"Cumbum",15212,15.566667,79.116667 ],
    [ u"in",u"Cuncolim",16124,15.166667,73.983333 ],
    [ u"in",u"Curchorem",22512,15.25,74.1 ],
    [ u"in",u"Curti",13662,15.416667,74.016667 ],
    [ u"in",u"Dabhoi",56257,22.183333,73.433333 ],
    [ u"in",u"Dabhol",9142,17.6,73.166667 ],
    [ u"in",u"Daboh",18299,26.0025,78.876111 ],
    [ u"in",u"Dabra",60842,25.9,78.333333 ],
    [ u"in",u"Dabwali",62118,29.95,74.733333 ],
    [ u"in",u"Dadri",70616,28.566667,77.55 ],
    [ u"in",u"Dagshai",2994,30.883333,77.05 ],
    [ u"in",u"Dahanu",49052,19.966667,72.733333 ],
    [ u"in",u"Dahegam",40674,23.166667,72.816667 ],
    [ u"in",u"Dahod",83972,22.833333,74.266667 ],
    [ u"in",u"Daitari",4147,21.1,85.75 ],
    [ u"in",u"Dakor",25020,22.75,73.15 ],
    [ u"in",u"Dalhousie",7602,32.533333,75.983333 ],
    [ u"in",u"Dalkola",15287,25.85,87.85 ],
    [ u"in",u"Dalmau",11433,26.066667,81.033333 ],
    [ u"in",u"Dalsingh Sarai",21613,25.666667,85.833333 ],
    [ u"in",u"Daltenganj",77712,24.033333,84.066667 ],
    [ u"in",u"Daman",39741,20.416667,72.85 ],
    [ u"in",u"Damnagar",17767,21.7,71.516667 ],
    [ u"in",u"Damoh",118789,23.833333,79.45 ],
    [ u"in",u"Dandeli",52300,15.266667,74.616667 ],
    [ u"in",u"Dankaur",13021,28.35,77.55 ],
    [ u"in",u"Daosa",73039,26.883333,76.333333 ],
    [ u"in",u"Darbhanga",287180,26.166667,85.9 ],
    [ u"in",u"Dariba",3076,24.95,74.133333 ],
    [ u"in",u"Darjiling",123808,27.033333,88.266667 ],
    [ u"in",u"Darlawn",3962,24.016667,92.9 ],
    [ u"in",u"Daryapur",35784,20.933333,77.333333 ],
    [ u"in",u"Dasna",27928,28.683333,77.533333 ],
    [ u"in",u"Dasuya",20699,31.818333,75.659722 ],
    [ u"in",u"Dataganj",24564,28.033333,79.4 ],
    [ u"in",u"Datia",90638,25.666667,78.466667 ],
    [ u"in",u"Dattapur",21765,20.766667,78.166667 ],
    [ u"in",u"Daudnagar",41240,25.033333,84.4 ],
    [ u"in",u"Daulatpur",3592,32.066667,76.25 ],
    [ u"in",u"Daund",45444,18.466667,74.6 ],
    [ u"in",u"Daurala",10917,29.116667,77.683333 ],
    [ u"in",u"Davorlim",11418,15.25,73.983333 ],
    [ u"in",u"Dayal Bagh",3369,27.216667,78.016667 ],
    [ u"in",u"Dehra Dun",522135,30.316667,78.033333 ],
    [ u"in",u"Dehri",129952,24.866667,84.183333 ],
    [ u"in",u"Dehu",5604,18.716667,73.766667 ],
    [ u"in",u"Delhi",10928270,28.666667,77.216667 ],
    [ u"in",u"Delvada",11912,20.766667,71.033333 ],
    [ u"in",u"Deoband",88180,29.7,77.683333 ],
    [ u"in",u"Deogarh",21136,21.533333,84.733333 ],
    [ u"in",u"Deolali",52962,19.95,73.833333 ],
    [ u"in",u"Deoli",16687,20.666667,78.483333 ],
    [ u"in",u"Deoranian",19790,28.633333,79.483333 ],
    [ u"in",u"Deoria",113638,26.504722,83.787222 ],
    [ u"in",u"Deori",12286,21.45,82.616667 ],
    [ u"in",u"Deori Khas",24937,23.4,79.016667 ],
    [ u"in",u"Depalpur",16938,22.85,75.55 ],
    [ u"in",u"Dera Baba Nanak",7492,32.033333,75.016667 ],
    [ u"in",u"Dera Gopipur",4735,31.9,76.216667 ],
    [ u"in",u"Dergaon",13366,26.7,93.966667 ],
    [ u"in",u"Deshnok",16721,27.8,73.35 ],
    [ u"in",u"Desur",5312,12.433333,79.483333 ],
    [ u"in",u"Deulgaon Raja",26690,20.016667,76.033333 ],
    [ u"in",u"Devadanapatti",14190,10.15,77.65 ],
    [ u"in",u"Devanhalli",25230,13.2325,77.699167 ],
    [ u"in",u"Devaprayag",2131,30.15,78.616667 ],
    [ u"in",u"Devarkonda",29730,16.7,78.933333 ],
    [ u"in",u"Devgarh",17502,25.533333,73.9 ],
    [ u"in",u"Devli",21299,25.75,75.383333 ],
    [ u"in",u"Dewa",14377,27.033333,81.166667 ],
    [ u"in",u"Dewas",261245,22.966667,76.066667 ],
    [ u"in",u"Dhaka",36115,26.683333,85.166667 ],
    [ u"in",u"Dhali",6494,10.5,77.166667 ],
    [ u"in",u"Dhamnod",29684,22.216667,75.466667 ],
    [ u"in",u"Dhampur",49978,29.316667,78.516667 ],
    [ u"in",u"Dhamtari",87161,20.707222,81.549722 ],
    [ u"in",u"Dhana",10642,23.75,78.85 ],
    [ u"in",u"Dhanaula",19283,30.283333,75.583333 ],
    [ u"in",u"Dhanaura",28288,28.966667,78.25 ],
    [ u"in",u"Dhanbad",219660,23.8,86.45 ],
    [ u"in",u"Dhandhuka",30051,22.366667,71.983333 ],
    [ u"in",u"Dhanera",23656,24.516667,72.016667 ],
    [ u"in",u"Dhanwar",8512,24.416667,85.983333 ],
    [ u"in",u"Dharampur",21209,20.533333,73.183333 ],
    [ u"in",u"Dharampuri",14179,22.166667,75.35 ],
    [ u"in",u"Dharangaon",33721,21.016667,75.266667 ],
    [ u"in",u"Dharapuram",72297,10.733333,77.516667 ],
    [ u"in",u"Dharchula",7332,29.85,80.533333 ],
    [ u"in",u"Dhar",82447,22.6,75.3 ],
    [ u"in",u"Dhari",29346,21.333333,71.016667 ],
    [ u"in",u"Dhariwal",20605,31.954167,75.319167 ],
    [ u"in",u"Dharmabad",32354,18.9,77.85 ],
    [ u"in",u"Dharmadam",29946,11.783333,75.433333 ],
    [ u"in",u"Dharmanagar",32917,24.366667,92.166667 ],
    [ u"in",u"Dharmapuri",66022,12.133333,78.166667 ],
    [ u"in",u"Dharmavaram",114062,14.433333,77.716667 ],
    [ u"in",u"Dharur",19062,18.816667,76.116667 ],
    [ u"in",u"Dhaulpur",102469,26.7,77.9 ],
    [ u"in",u"Dhekiajuli",21272,26.7,92.5 ],
    [ u"in",u"Dhemaji",13059,27.483333,94.583333 ],
    [ u"in",u"Dhenkanal",62235,20.666667,85.6 ],
    [ u"in",u"Dhilwan",8447,31.516944,75.35 ],
    [ u"in",u"Dhing",20827,26.466667,92.466667 ],
    [ u"in",u"Dhola",8206,21.883333,71.783333 ],
    [ u"in",u"Dholka",54981,22.716667,72.466667 ],
    [ u"in",u"Dhone",39689,15.416667,77.883333 ],
    [ u"in",u"Dhoraji",81450,21.733333,70.45 ],
    [ u"in",u"Dhrangadhra",75582,22.983333,71.466667 ],
    [ u"in",u"Dhrol",26497,22.566667,70.416667 ],
    [ u"in",u"Dhuburi",62528,26.033333,89.966667 ],
    [ u"in",u"Dhulagari",21080,22.586944,88.173056 ],
    [ u"in",u"Dhule",367010,20.9,74.783333 ],
    [ u"in",u"Dhulian",77078,24.683333,87.966667 ],
    [ u"in",u"Dhupgari",41172,26.585747,89.014496 ],
    [ u"in",u"Dhuri",54306,30.366667,75.866667 ],
    [ u"in",u"Dhuwaran",11473,22.233333,72.8 ],
    [ u"in",u"Diamond Harbour",40099,22.191667,88.184722 ],
    [ u"in",u"Dibai",37877,28.216667,78.25 ],
    [ u"in",u"Dibrugarh",122160,27.481667,94.902778 ],
    [ u"in",u"Didwana",49856,27.4,74.566667 ],
    [ u"in",u"Digapahandi",11167,19.366667,84.583333 ],
    [ u"in",u"Digboi",20685,27.383333,95.618056 ],
    [ u"in",u"Dig",43489,27.466667,77.333333 ],
    [ u"in",u"Digha",3667,21.683333,87.55 ],
    [ u"in",u"Dighwara",29273,25.733333,85 ],
    [ u"in",u"Diglur",52600,18.55,77.6 ],
    [ u"in",u"Digras",41557,20.116667,77.716667 ],
    [ u"in",u"Dimapur",135866,25.9,93.733333 ],
    [ u"in",u"Dinanagar",23341,32.15,75.466667 ],
    [ u"in",u"Dindigul",200814,10.35,77.95 ],
    [ u"in",u"Dindori",19265,22.95,81.083333 ],
    [ u"in",u"Dinhata",42401,26.133333,89.466667 ],
    [ u"in",u"Diphu",57099,25.833333,93.433333 ],
    [ u"in",u"Dirba",13838,30.066667,75.983333 ],
    [ u"in",u"Disa",92230,24.25,72.166667 ],
    [ u"in",u"Dispur",8282,26.1425,91.788889 ],
    [ u"in",u"Diu",23790,20.7,70.983333 ],
    [ u"in",u"Doda",17755,33.133333,75.566667 ],
    [ u"in",u"Dod Ballapur",78682,13.291944,77.543056 ],
    [ u"in",u"Dohrighat",11182,26.264444,83.516389 ],
    [ u"in",u"Doiwala",8248,30.183333,78.116667 ],
    [ u"in",u"Dondaicha",46021,21.333333,74.566667 ],
    [ u"in",u"Dongargaon",12507,20.966667,80.85 ],
    [ u"in",u"Doraha",23553,30.816667,76.016667 ],
    [ u"in",u"Dostpur",12689,26.283333,82.466667 ],
    [ u"in",u"Dubrajpur",35090,23.8,87.383333 ],
    [ u"in",u"Dudhani",12736,17.366667,76.366667 ],
    [ u"in",u"Dugda",20402,23.75,86.166667 ],
    [ u"in",u"Duliagaon",23530,27.366667,95.316667 ],
    [ u"in",u"Dum Duma",21707,27.566667,95.566667 ],
    [ u"in",u"Dum Dum",122731,22.622222,88.416944 ],
    [ u"in",u"Dumjor",17973,22.640833,88.220278 ],
    [ u"in",u"Dumka",47668,24.266667,87.25 ],
    [ u"in",u"Dumra",15780,26.566667,85.516667 ],
    [ u"in",u"Dumraon",50529,25.55,84.15 ],
    [ u"in",u"Dundwaraganj",46319,27.733333,78.95 ],
    [ u"in",u"Dungarpur",6105,21.283333,71.733333 ],
    [ u"in",u"Dungarpur",45198,23.833333,73.716667 ],
    [ u"in",u"Durgapur",18561,20,79.3 ],
    [ u"in",u"Durgapur",518922,23.483333,87.316667 ],
    [ u"in",u"Durg",255310,21.183333,81.283333 ],
    [ u"in",u"Dusi",5257,12.766667,79.683333 ],
    [ u"in",u"Dwarahat",2443,29.783333,79.433333 ],
    [ u"in",u"Dwarka",35839,22.239444,68.967778 ],
    [ u"in",u"Egra",32866,21.9,87.533333 ],
    [ u"in",u"Elayirampannai",6473,9.266667,77.833333 ],
    [ u"in",u"Ellenabad",37683,29.45,74.65 ],
    [ u"in",u"Elumalai",14456,9.866667,77.7 ],
    [ u"in",u"Elur",30832,10.066667,76.283333 ],
    [ u"in",u"Eluru",183401,16.7,81.1 ],
    [ u"in",u"Eral",9188,8.633333,78.016667 ],
    [ u"in",u"Eraniel",9844,8.2,77.3 ],
    [ u"in",u"Erattupetta",33411,9.7,76.783333 ],
    [ u"in",u"Erode",147283,11.35,77.733333 ],
    [ u"in",u"Etah",120020,27.633333,78.666667 ],
    [ u"in",u"Etawah",257472,26.7769,79.0239 ],
    [ u"in",u"Ettaiyapuram",12957,9.15,77.983333 ],
    [ u"in",u"Faizabad",153062,26.783333,82.133333 ],
    [ u"in",u"Faizpur",24536,21.166667,75.85 ],
    [ u"in",u"Falakata",20120,26.520841,89.205448 ],
    [ u"in",u"Farah",9236,27.333333,77.766667 ],
    [ u"in",u"Farakka",21836,24.816667,87.9 ],
    [ u"in",u"Faridabad",1280909,28.433333,77.316667 ],
    [ u"in",u"Faridkot",77455,30.666667,74.75 ],
    [ u"in",u"Faridnagar",11372,28.766667,77.616667 ],
    [ u"in",u"Faridpur",71790,28.216667,79.55 ],
    [ u"in",u"Farrukhabad",241176,27.4,79.566667 ],
    [ u"in",u"Farrukhnagar",39771,17.077778,78.201111 ],
    [ u"in",u"Farrukhnagar",10092,28.45,76.816667 ],
    [ u"in",u"Fatehabad",66017,29.516667,75.45 ],
    [ u"in",u"Fatehabad",21959,27.016667,78.316667 ],
    [ u"in",u"Fatehgarh Churian",18053,31.862071,74.955344 ],
    [ u"in",u"Fatehgarh",14849,27.366667,79.633333 ],
    [ u"in",u"Fatehpur Chaurasi",5932,26.783333,80.266667 ],
    [ u"in",u"Fatehpur",83176,27.983333,74.95 ],
    [ u"in",u"Fatehpur",166496,25.933333,80.8 ],
    [ u"in",u"Fatehpur Sikri",30029,27.1,77.666667 ],
    [ u"in",u"Fatwa",41652,25.516667,85.316667 ],
    [ u"in",u"Fazilka",70893,30.4,74.033333 ],
    [ u"in",u"Feroke",30229,11.183333,75.85 ],
    [ u"in",u"Firozabad",306439,27.15,78.416667 ],
    [ u"in",u"Firozpur",102138,30.916667,74.6 ],
    [ u"in",u"Firozpur Jhirka",20196,27.8,76.95 ],
    [ u"in",u"Forbesganj",45103,26.3,87.25 ],
    [ u"in",u"Fort Gloster",18349,22.504444,88.183333 ],
    [ u"in",u"Gadag",162583,15.416667,75.616667 ],
    [ u"in",u"Gadarwara",41424,22.916667,78.783333 ],
    [ u"in",u"Gadwal",55958,16.233333,77.8 ],
    [ u"in",u"Gagret",3026,31.666667,76.066667 ],
    [ u"in",u"Gairatganj",8779,23.4,78.216667 ],
    [ u"in",u"Gajendragarh",29752,15.733333,75.983333 ],
    [ u"in",u"Gajraula",50385,28.85,78.233333 ],
    [ u"in",u"Galiakot",6907,23.516667,74 ],
    [ u"in",u"Gandai",12477,21.666667,81.1 ],
    [ u"in",u"Gandevi",16241,20.816667,72.983333 ],
    [ u"in",u"Gandhidham",136605,23.083333,70.133333 ],
    [ u"in",u"Gandhinagar",231314,23.216667,72.683333 ],
    [ u"in",u"Gangakher",46369,18.95,76.75 ],
    [ u"in",u"Ganganagar",231855,29.916667,73.883333 ],
    [ u"in",u"Gangapur",24120,19.683333,75.016667 ],
    [ u"in",u"Gangapur",120123,26.483333,76.716667 ],
    [ u"in",u"Gangarampur",65323,25.4,88.516667 ],
    [ u"in",u"Gangavalli",10905,11.483333,78.65 ],
    [ u"in",u"Gangawati",106259,15.433333,76.533333 ],
    [ u"in",u"Gangoh",59525,29.766667,77.25 ],
    [ u"in",u"Gangotri",811,30.983333,78.933333 ],
    [ u"in",u"Gangtok",30702,27.333333,88.616667 ],
    [ u"in",u"Ganjam",11430,19.316667,84.783333 ],
    [ u"in",u"Ganj Muradabad",9971,26.966667,80.183333 ],
    [ u"in",u"Gannavaram",19410,16.533333,80.8 ],
    [ u"in",u"Garautha",9490,25.566667,79.3 ],
    [ u"in",u"Gardhiwala",6694,31.7325,75.750556 ],
    [ u"in",u"Garhakota",28117,23.766667,79.15 ],
    [ u"in",u"Garhshankar",16471,31.216667,76.133333 ],
    [ u"in",u"Gariaband",10416,20.635,82.061389 ],
    [ u"in",u"Gariadhar",35695,21.533333,71.583333 ],
    [ u"in",u"Garui",16499,22.633333,88.4 ],
    [ u"in",u"Garulia",74404,22.821111,88.374444 ],
    [ u"in",u"Garwa",40666,24.183333,83.816667 ],
    [ u"in",u"Gaurela",14593,22.75,81.9 ],
    [ u"in",u"Gauribidanur",32450,13.611111,77.516667 ],
    [ u"in",u"Gauripur",24695,26.083524,89.961584 ],
    [ u"in",u"Gawan",8745,28.433333,78.35 ],
    [ u"in",u"Gaya",423737,24.783333,85 ],
    [ u"in",u"Gevrai",30408,19.266667,75.75 ],
    [ u"in",u"Gezing",869,27.283333,88.266667 ],
    [ u"in",u"Ghamarwin",6691,31.45,76.716667 ],
    [ u"in",u"Ghanaur",6091,30.332222,76.607222 ],
    [ u"in",u"Ghansor",6597,22.65,79.95 ],
    [ u"in",u"Gharghoda",8513,22.166667,83.35 ],
    [ u"in",u"Ghatal",54663,22.666667,87.716667 ],
    [ u"in",u"Ghatampur",40439,26.166667,80.166667 ],
    [ u"in",u"Ghatanji",20786,20.133333,78.316667 ],
    [ u"in",u"Ghatsila",40022,22.6,86.483333 ],
    [ u"in",u"Ghaziabad",1199306,28.666667,77.433333 ],
    [ u"in",u"Ghazipur",103105,25.583333,83.566667 ],
    [ u"in",u"Ghiror",14012,27.183333,78.8 ],
    [ u"in",u"Ghogha",11362,21.683333,72.283333 ],
    [ u"in",u"Ghorawal",7493,24.766667,82.783333 ],
    [ u"in",u"Ghosi",39142,26.108333,83.543611 ],
    [ u"in",u"Ghoti",22097,19.716667,73.633333 ],
    [ u"in",u"Ghugus",31861,19.933333,79.133333 ],
    [ u"in",u"Gidam",6228,18.983333,81.4 ],
    [ u"in",u"Giddalur",28142,15.35,78.916667 ],
    [ u"in",u"Giddarbaha",39246,30.2,74.666667 ],
    [ u"in",u"Goalpara",50761,26.166667,90.616667 ],
    [ u"in",u"Goa Velha",5656,15.433333,73.866667 ],
    [ u"in",u"Gobardanga",43812,22.874722,88.758611 ],
    [ u"in",u"Gobindapur",11781,22.593056,88.091389 ],
    [ u"in",u"Gobindpur",27069,22.633333,86.066667 ],
    [ u"in",u"Godda",43663,24.833333,87.216667 ],
    [ u"in",u"Godhra",131921,22.75,73.633333 ],
    [ u"in",u"Gogapur",6857,23.55,75.516667 ],
    [ u"in",u"Gohad",51640,26.426111,78.444722 ],
    [ u"in",u"Gohana",56097,29.133333,76.7 ],
    [ u"in",u"Gohand",7287,25.7,79.55 ],
    [ u"in",u"Gohpur",9896,26.883333,93.633333 ],
    [ u"in",u"Gokak",73484,16.166667,74.833333 ],
    [ u"in",u"Gokul",4351,27.45,77.716667 ],
    [ u"in",u"Gola Bazar",10937,26.343056,83.355278 ],
    [ u"in",u"Golaghat",34374,26.516667,93.966667 ],
    [ u"in",u"Gola Gokarannath",58992,28.083333,80.466667 ],
    [ u"in",u"Golakganj",8125,26.1,89.833333 ],
    [ u"in",u"Gomoh",31398,23.866667,86.166667 ],
    [ u"in",u"Gonda",133596,27.133333,81.933333 ],
    [ u"in",u"Gondal",101808,21.966667,70.8 ],
    [ u"in",u"Gopalganj",63731,26.466667,84.433333 ],
    [ u"in",u"Gopalpur",7163,19.266667,84.916667 ],
    [ u"in",u"Gopalpur",6900,22.614444,88.751389 ],
    [ u"in",u"Gopalur",3324,16.616667,77.8 ],
    [ u"in",u"Gopamau",13582,27.55,80.283333 ],
    [ u"in",u"Gopichettipalaiyam",57532,11.466667,77.45 ],
    [ u"in",u"Gopinathpur",5255,22.65,86.066667 ],
    [ u"in",u"Gorakhpur",674312,26.755,83.373889 ],
    [ u"in",u"Goregaon",6946,18.166667,73.3 ],
    [ u"in",u"Gormi",16889,26.599444,78.515 ],
    [ u"in",u"Gorur",6192,12.819444,76.071667 ],
    [ u"in",u"Gosainganj",13177,26.583333,82.383333 ],
    [ u"in",u"Gossaigaon",13933,26.437868,89.97882 ],
    [ u"in",u"Govardhan",20046,27.5,77.466667 ],
    [ u"in",u"Govindgarh",10956,27.5,76.983333 ],
    [ u"in",u"Govindgarh",10194,24.383333,81.3 ],
    [ u"in",u"Gua",11390,22.2,85.383333 ],
    [ u"in",u"Gubbi",17985,13.310556,76.944444 ],
    [ u"in",u"Gudalur",160993,11.75,79.75 ],
    [ u"in",u"Gudari",6895,19.35,83.783333 ],
    [ u"in",u"Gudibanda",9256,13.669444,77.698333 ],
    [ u"in",u"Gudivada",116174,16.45,80.983333 ],
    [ u"in",u"Gudiyattam",93981,12.95,78.866667 ],
    [ u"in",u"Gudur",5647,17.483333,78.816667 ],
    [ u"in",u"Guhagar",3425,17.466667,73.2 ],
    [ u"in",u"Guirim",7058,15.583333,73.8 ],
    [ u"in",u"Gulabpura",26469,25.9,74.666667 ],
    [ u"in",u"Gulaothi",46652,28.6,77.783333 ],
    [ u"in",u"Gulbarga",483655,17.333333,76.833333 ],
    [ u"in",u"Gulmarg",730,34.05,74.383333 ],
    [ u"in",u"Gumia",47127,23.783333,85.816667 ],
    [ u"in",u"Gumla",44956,23.05,84.55 ],
    [ u"in",u"Gummidipundi",16605,13.4,80.15 ],
    [ u"in",u"Guna",153705,24.65,77.316667 ],
    [ u"in",u"Gundlupet",27200,11.8,76.683333 ],
    [ u"in",u"Gunnaur",20982,28.25,78.433333 ],
    [ u"in",u"Guntakal",120978,15.166667,77.383333 ],
    [ u"in",u"Guntur",530636,16.3,80.45 ],
    [ u"in",u"Gunupur",22266,19.083333,83.816667 ],
    [ u"in",u"Gurdaha",13103,22.734722,88.759444 ],
    [ u"in",u"Gurdaspur",72503,32.033333,75.516667 ],
    [ u"in",u"Gurgaon",197353,28.466667,77.033333 ],
    [ u"in",u"Gurh",13104,24.516667,81.516667 ],
    [ u"in",u"Gurmatkal",18238,16.866667,77.4 ],
    [ u"in",u"Gursahaiganj",40217,27.116667,79.716667 ],
    [ u"in",u"Gursarai",25193,25.6148,79.1788 ],
    [ u"in",u"Guru Har Sahai",16029,30.716667,74.416667 ],
    [ u"in",u"Guruvayur",21418,10.6,76.05 ],
    [ u"in",u"Guskhara",33783,23.5,87.75 ],
    [ u"in",u"Guwahati",899132,26.183333,91.733333 ],
    [ u"in",u"Gwalior",882551,26.223611,78.179167 ],
    [ u"in",u"Gyanpur",13468,25.35,82.466667 ],
    [ u"in",u"Habra",139310,22.834444,88.6275 ],
    [ u"in",u"Hadgaon",26453,19.5,77.666667 ],
    [ u"in",u"Haflong",39983,25.183333,93.033333 ],
    [ u"in",u"Hailakandi",31032,24.683333,92.566667 ],
    [ u"in",u"Hajan",10800,34.35,74.301389 ],
    [ u"in",u"Hajipur",5680,31.975556,75.757778 ],
    [ u"in",u"Hajipur",133621,25.683333,85.216667 ],
    [ u"in",u"Haldaur",18688,29.3,78.283333 ],
    [ u"in",u"Haldia",207466,22.025278,88.058333 ],
    [ u"in",u"Haldibari",14101,26.333333,88.766667 ],
    [ u"in",u"Haldwani",139512,29.216667,79.516667 ],
    [ u"in",u"Halisahar",128184,22.949722,88.419444 ],
    [ u"in",u"Haliyal",21627,15.333333,74.766667 ],
    [ u"in",u"Halol",45744,22.5,73.466667 ],
    [ u"in",u"Halvad",26207,23.016667,71.183333 ],
    [ u"in",u"Hamirpur",19281,31.683333,76.516667 ],
    [ u"in",u"Hamirpur",34148,25.95,80.15 ],
    [ u"in",u"Handia",17862,25.383333,82.183333 ],
    [ u"in",u"Handwara",12639,34.4,74.283333 ],
    [ u"in",u"Hangal",26607,14.766667,75.133333 ],
    [ u"in",u"Hansi",82412,29.1,75.966667 ],
    [ u"in",u"Hansot",12525,21.583333,72.8 ],
    [ u"in",u"Hanumangarh",155698,29.583333,74.316667 ],
    [ u"in",u"Haora",1027771,22.589167,88.310278 ],
    [ u"in",u"Hapur",242944,28.716667,77.783333 ],
    [ u"in",u"Harda",67394,22.333333,77.1 ],
    [ u"in",u"Hardoi",122647,27.116667,80.15 ],
    [ u"in",u"Harduaganj",12329,27.95,78.166667 ],
    [ u"in",u"Hariana",8333,31.637778,75.840833 ],
    [ u"in",u"Haridwar",186099,29.966667,78.166667 ],
    [ u"in",u"Harihar",78041,14.516667,75.8 ],
    [ u"in",u"Harij",18965,23.7,71.9 ],
    [ u"in",u"Harindanga",6254,22.038333,88.321389 ],
    [ u"in",u"Haringhata",9705,22.95,88.566667 ],
    [ u"in",u"Haripur",7327,22.936111,88.231944 ],
    [ u"in",u"Harpalpur",17733,25.2884,79.3347 ],
    [ u"in",u"Harpanahalli",44981,14.8,75.983333 ],
    [ u"in",u"Harrai",10251,22.616667,79.216667 ],
    [ u"in",u"Harsud",16738,22.1,76.733333 ],
    [ u"in",u"Harur",20407,12.066667,78.5 ],
    [ u"in",u"Hasanpur",9906,27.966667,77.5 ],
    [ u"in",u"Hasanpur",57487,28.716667,78.283333 ],
    [ u"in",u"Hassan",128542,13.000556,76.099444 ],
    [ u"in",u"Hastinapur",24095,29.166667,78.016667 ],
    [ u"in",u"Hata",12051,26.746111,83.740278 ],
    [ u"in",u"Hathras",126895,27.6,78.05 ],
    [ u"in",u"Hatod",9350,22.8,75.733333 ],
    [ u"in",u"Hatta",30858,24.116667,79.6 ],
    [ u"in",u"Haveri",60161,14.8,75.4 ],
    [ u"in",u"Hazaribag",140079,23.983333,85.35 ],
    [ u"in",u"Herbertpur",9479,30.45,77.733333 ],
    [ u"in",u"Hesla",6286,24.066667,85.883333 ],
    [ u"in",u"Hilsa",41115,25.316667,85.283333 ],
    [ u"in",u"Himatnagar",60638,23.6,72.95 ],
    [ u"in",u"Hindaun",95600,26.716667,77.016667 ],
    [ u"in",u"Hindoria",15144,23.9,79.566667 ],
    [ u"in",u"Hindupur",133313,13.828889,77.493333 ],
    [ u"in",u"Hinganghat",97576,20.566667,78.833333 ],
    [ u"in",u"Hingoli",75884,19.716667,77.15 ],
    [ u"in",u"Hinjilikatu",22781,19.483333,84.75 ],
    [ u"in",u"Hirakud",27279,21.516667,83.866667 ],
    [ u"in",u"Hiranagar",9447,32.45,75.266667 ],
    [ u"in",u"Hirapur",6069,21.533333,79.766667 ],
    [ u"in",u"Hirekerur",16688,14.466667,75.383333 ],
    [ u"in",u"Hiriyur",53524,13.945556,76.619167 ],
    [ u"in",u"Hisar",296456,29.166667,75.716667 ],
    [ u"in",u"Hisua",27946,24.833333,85.416667 ],
    [ u"in",u"Hodal",44304,27.9,77.366667 ],
    [ u"in",u"Hojai",36871,26,92.866667 ],
    [ u"in",u"Holalkere",15481,14.033333,76.183333 ],
    [ u"in",u"Hole Narsipur",28288,12.782778,76.243056 ],
    [ u"in",u"Homnabad",41489,17.766667,77.133333 ],
    [ u"in",u"Honavar",18393,14.283333,74.45 ],
    [ u"in",u"Honnali",16755,14.25,75.666667 ],
    [ u"in",u"Hosakote",11692,14.283333,77.183333 ],
    [ u"in",u"Hosanagara",5188,13.916667,75.066667 ],
    [ u"in",u"Hosangadi",2609,13.7,74.95 ],
    [ u"in",u"Hosdurga",24687,13.798056,76.286111 ],
    [ u"in",u"Hoshangabad",109370,22.75,77.716667 ],
    [ u"in",u"Hoshiarpur",158154,31.532222,75.917222 ],
    [ u"in",u"Hoskote",41240,13.066944,77.798333 ],
    [ u"in",u"Hospet",197862,15.266667,76.4 ],
    [ u"in",u"Hosur",103769,12.716667,77.816667 ],
    [ u"in",u"Hubli",840285,15.35,75.166667 ],
    [ u"in",u"Hukeri",20826,16.233333,74.6 ],
    [ u"in",u"Hungund",19037,16.066667,76.05 ],
    [ u"in",u"Hunsur",47648,12.3075,76.287778 ],
    [ u"in",u"Husainabad",26187,24.533333,84.016667 ],
    [ u"in",u"Hyderabad",3598199,17.375278,78.474444 ],
    [ u"in",u"Ichalkaranji",274405,16.7,74.466667 ],
    [ u"in",u"Ichchapuram",33757,19.116667,84.7 ],
    [ u"in",u"Ichhawar",13657,23.016667,77.016667 ],
    [ u"in",u"Idappadi",51647,11.583333,77.85 ],
    [ u"in",u"Ïdar",31316,23.833333,73 ],
    [ u"in",u"Idukki",11249,9.85,76.966667 ],
    [ u"in",u"Igatpuri",35463,19.7,73.55 ],
    [ u"in",u"Iglas",13748,27.716667,77.933333 ],
    [ u"in",u"Ikauna",14218,27.55,81.966667 ],
    [ u"in",u"Ilampillai",11309,11.6,78 ],
    [ u"in",u"Ilkal",56941,15.966667,76.133333 ],
    [ u"in",u"Iluppur",12472,10.516667,78.633333 ],
    [ u"in",u"Imphal",223537,24.816667,93.95 ],
    [ u"in",u"Indapur",26754,18.3,73.25 ],
    [ u"in",u"Indergarh",17368,26.9352,79.6724 ],
    [ u"in",u"Indi",34078,17.166667,75.966667 ],
    [ u"in",u"Indore",1837230,22.716667,75.833333 ],
    [ u"in",u"Indri",15955,29.88,77.071111 ],
    [ u"in",u"Ingraj Bazar",170056,25,88.15 ],
    [ u"in",u"Irinjalakuda",29211,10.333333,76.233333 ],
    [ u"in",u"Irugur",19166,11.016667,77.066667 ],
    [ u"in",u"Isagarh",10370,24.833333,77.883333 ],
    [ u"in",u"Islamnagar",29147,28.333333,78.716667 ],
    [ u"in",u"Islampur",55696,26.266667,88.2 ],
    [ u"in",u"Islampur",31879,25.15,85.2 ],
    [ u"in",u"Itanagar",44995,27.1,93.616667 ],
    [ u"in",u"Itarsi",100585,22.616667,77.75 ],
    [ u"in",u"Itaunja",6727,27.083333,80.916667 ],
    [ u"in",u"Itimadpur",22700,27.25,78.2 ],
    [ u"in",u"Jabalpur",1030276,23.166667,79.95 ],
    [ u"in",u"Jafarpur",14798,22.320833,88.230556 ],
    [ u"in",u"Jagadhri",112590,30.166667,77.3 ],
    [ u"in",u"Jagalur",15789,14.533333,76.35 ],
    [ u"in",u"Jagannathpur",7020,22.233333,85.65 ],
    [ u"in",u"Jagatsinghapur",32948,20.266667,86.166667 ],
    [ u"in",u"Jagdalpur",76473,19.066667,82.033333 ],
    [ u"in",u"Jagdispur",31032,25.483333,84.416667 ],
    [ u"in",u"Jaggayyapeta",41185,16.9,80.1 ],
    [ u"in",u"Jagraon",65310,30.783333,75.483333 ],
    [ u"in",u"Jagtial",99046,18.8,78.933333 ],
    [ u"in",u"Jahanabad",96397,25.216667,84.983333 ],
    [ u"in",u"Jahanabad",13619,28.633333,79.716667 ],
    [ u"in",u"Jahangirabad",57369,28.416667,78.1 ],
    [ u"in",u"Jahangirpur",10043,28.183333,77.716667 ],
    [ u"in",u"Jahazpur",20351,25.616667,75.283333 ],
    [ u"in",u"Jaipur",2711937,26.916667,75.816667 ],
    [ u"in",u"Jaisalmer",67609,26.916667,70.9 ],
    [ u"in",u"Jaisinghnagar",7601,23.7,81.383333 ],
    [ u"in",u"Jais",25729,26.25,81.533333 ],
    [ u"in",u"Jaitaran",21405,26.203056,73.936389 ],
    [ u"in",u"Jakhal Mandi",7411,29.8,75.833333 ],
    [ u"in",u"Jalakandapuram",14530,11.7,77.883333 ],
    [ u"in",u"Jalalabad",29826,30.616667,74.25 ],
    [ u"in",u"Jalalabad",25305,29.618611,77.438333 ],
    [ u"in",u"Jalali",18179,27.866667,78.266667 ],
    [ u"in",u"Jalalpore",17325,20.966667,72.9 ],
    [ u"in",u"Jalalpur",31391,26.316667,82.733333 ],
    [ u"in",u"Jalandhar",785234,31.325556,75.579167 ],
    [ u"in",u"Jalaun",55304,26.1451,79.3366 ],
    [ u"in",u"Jalesar",38618,27.483333,78.316667 ],
    [ u"in",u"Jaleswar",23282,21.816667,87.216667 ],
    [ u"in",u"Jalgaon",27796,21.048611,76.534444 ],
    [ u"in",u"Jalna",262055,19.833333,75.883333 ],
    [ u"in",u"Jalor",49686,25.35,72.616667 ],
    [ u"in",u"Jalpaiguri",107843,26.516667,88.733333 ],
    [ u"in",u"Jamadoba",34778,23.716667,86.4 ],
    [ u"in",u"Jamai",22590,22.2,78.583333 ],
    [ u"in",u"Jamalpur",100791,25.3,86.5 ],
    [ u"in",u"Jambusar",41596,22.05,72.8 ],
    [ u"in",u"Jamkhandi",61696,16.516667,75.3 ],
    [ u"in",u"Jamkhed",29591,18.666667,75.183333 ],
    [ u"in",u"Jammalamadugu",43875,14.833333,78.4 ],
    [ u"in",u"Jammu",465600,32.733333,74.866667 ],
    [ u"in",u"Jamnagar",492087,22.466667,70.066667 ],
    [ u"in",u"Jamshedpur",616404,22.8,86.183333 ],
    [ u"in",u"Jamtara",24391,23.95,86.8 ],
    [ u"in",u"Jamui",78189,24.916667,86.216667 ],
    [ u"in",u"Jamuria",160257,23.7,87.083333 ],
    [ u"in",u"Janakpur Road",15071,26.483333,85.716667 ],
    [ u"in",u"Jandiala",25633,31.166667,75.616667 ],
    [ u"in",u"Jangaon",47563,17.5975,78.876111 ],
    [ u"in",u"Jangipur",82555,24.466667,88.066667 ],
    [ u"in",u"Jansath",19469,29.333333,77.85 ],
    [ u"in",u"Jaora",67210,23.633333,75.133333 ],
    [ u"in",u"Jarwal",17577,27.166667,81.55 ],
    [ u"in",u"Jasdan",43864,22.033333,71.2 ],
    [ u"in",u"Jashpurnagar",22609,22.9,84.15 ],
    [ u"in",u"Jasidih",16339,24.516667,86.65 ],
    [ u"in",u"Jaspur",42529,29.283333,78.816667 ],
    [ u"in",u"Jasrana",9884,27.25,78.683333 ],
    [ u"in",u"Jaswantnagar",27780,26.878611,78.902778 ],
    [ u"in",u"Jatara",17003,25.016667,79.05 ],
    [ u"in",u"Jatni",56008,20.166667,85.7 ],
    [ u"in",u"Jaunpur",169589,25.733333,82.683333 ],
    [ u"in",u"Jawad",16889,24.6,74.85 ],
    [ u"in",u"Jawala Mukhi",5281,31.883333,76.316667 ],
    [ u"in",u"Jawar",7753,23,76.5 ],
    [ u"in",u"Jawhar",12083,19.916667,73.233333 ],
    [ u"in",u"Jaynagar",20498,26.583333,86.15 ],
    [ u"in",u"Jaynagar-Majilpur",24512,22.175833,88.417778 ],
    [ u"in",u"Jaypur",80844,18.85,82.583333 ],
    [ u"in",u"Jaysingpur",46946,16.8,74.566667 ],
    [ u"in",u"Jejuri",14064,18.283333,74.166667 ],
    [ u"in",u"Jetalsar",14771,21.7,70.583333 ],
    [ u"in",u"Jetpur",118076,21.733333,70.616667 ],
    [ u"in",u"Jevargi",20157,17.016667,76.766667 ],
    [ u"in",u"Jewar",29319,28.133333,77.55 ],
    [ u"in",u"Jhabua",34138,22.766667,74.6 ],
    [ u"in",u"Jha Jha",38628,24.766667,86.366667 ],
    [ u"in",u"Jhajjar",44125,28.616667,76.65 ],
    [ u"in",u"Jhalawar",51888,24.6,76.15 ],
    [ u"in",u"Jhalida",18059,23.366667,85.966667 ],
    [ u"in",u"Jhalrapatan",33123,24.55,76.166667 ],
    [ u"in",u"Jhalu",20358,29.35,78.25 ],
    [ u"in",u"Jhanjharpur",31323,26.266667,86.283333 ],
    [ u"in",u"Jhansi",412968,25.433333,78.583333 ],
    [ u"in",u"Jhargram",57802,22.45,86.983333 ],
    [ u"in",u"Jharia",86947,23.75,86.4 ],
    [ u"in",u"Jharsuguda",79499,21.85,84.033333 ],
    [ u"in",u"Jhinjhak",23501,26.566667,79.733333 ],
    [ u"in",u"Jhinjhana",19713,29.516667,77.216667 ],
    [ u"in",u"Jhunjhunun",113201,28.1307,75.4014 ],
    [ u"in",u"Jhusi",16644,25.433333,81.933333 ],
    [ u"in",u"Jind",161271,29.316667,76.316667 ],
    [ u"in",u"Jintur",42423,19.616667,76.7 ],
    [ u"in",u"Jiran",10983,24.316667,74.883333 ],
    [ u"in",u"Jobat",10786,22.416667,74.566667 ],
    [ u"in",u"Jobner",10829,26.966667,75.383333 ],
    [ u"in",u"Jodhpur",921540,26.286667,73.03 ],
    [ u"in",u"Jodiya",15788,22.716667,70.283333 ],
    [ u"in",u"Jogbani",33303,26.416667,87.25 ],
    [ u"in",u"Jogighopa",2415,26.233333,90.583333 ],
    [ u"in",u"Jogindarnagar",5234,31.983333,76.766667 ],
    [ u"in",u"Jorhat",69036,26.75,94.216667 ],
    [ u"in",u"Joshimath",13866,30.566667,79.566667 ],
    [ u"in",u"Joura",26341,26.333333,77.816667 ],
    [ u"in",u"Jua",5470,15.533333,73.933333 ],
    [ u"in",u"Jubbal",1327,31.116667,77.666667 ],
    [ u"in",u"Jugsalai",49411,22.766667,86.183333 ],
    [ u"in",u"Julana",14509,29.133333,76.416667 ],
    [ u"in",u"Junagadh",184459,21.516667,70.466667 ],
    [ u"in",u"Junagarh",16857,19.866667,82.933333 ],
    [ u"in",u"Junnar",25999,19.2,73.883333 ],
    [ u"in",u"Jutogh",2470,31.1,77.116667 ],
    [ u"in",u"Kabrai",24774,25.416667,80.016667 ],
    [ u"in",u"Kachhwa",15383,25.216667,82.716667 ],
    [ u"in",u"Kadambur",4512,8.983333,77.866667 ],
    [ u"in",u"Kadaura",13785,25.983333,79.85 ],
    [ u"in",u"Kadayanallur",77779,9.083333,77.35 ],
    [ u"in",u"Kadi",58070,23.3,72.333333 ],
    [ u"in",u"Kadipur",7473,26.166667,82.383333 ],
    [ u"in",u"Kadiri",81507,14.116667,78.166667 ],
    [ u"in",u"Kadur",32938,13.553333,76.013056 ],
    [ u"in",u"Kagal",25481,16.583333,74.316667 ],
    [ u"in",u"Kagaznagar",60163,19.333333,79.483333 ],
    [ u"in",u"Kaikalur",20763,16.566667,81.2 ],
    [ u"in",u"Kailaras",24542,26.316667,77.616667 ],
    [ u"in",u"Kailasahar",22124,24.333333,92.016667 ],
    [ u"in",u"Kaimganj",32861,27.566667,79.35 ],
    [ u"in",u"Kaimur",20156,23.383333,79.75 ],
    [ u"in",u"Kairana",80440,29.4,77.2 ],
    [ u"in",u"Kaithal",140614,29.8,76.383333 ],
    [ u"in",u"Kakching",30420,24.483333,93.983333 ],
    [ u"in",u"Kakinada",292956,16.933333,82.216667 ],
    [ u"in",u"Kakori",18334,26.883333,80.8 ],
    [ u"in",u"Kakrala",35694,27.8927,79.1965 ],
    [ u"in",u"Kalagarh",13298,29.5,78.75 ],
    [ u"in",u"Kalaikunda",3232,22.35,87.25 ],
    [ u"in",u"Kalamb",27287,19.05,73.95 ],
    [ u"in",u"Kalamnuri",22709,19.666667,77.333333 ],
    [ u"in",u"Kalanaur",13671,32.016667,75.15 ],
    [ u"in",u"Kalanwali",27357,29.85,74.95 ],
    [ u"in",u"Kalas",14858,18.166667,74.8 ],
    [ u"in",u"Kalavad",26289,22.216667,70.383333 ],
    [ u"in",u"Kalavai",10057,12.766667,79.416667 ],
    [ u"in",u"Kalghatgi",15428,15.183333,74.966667 ],
    [ u"in",u"Kalikapur",4061,22.616667,86.283333 ],
    [ u"in",u"Kalinagar",10729,28.616667,80.1 ],
    [ u"in",u"Kaliyaganj",51753,25.633333,88.316667 ],
    [ u"in",u"Kalka",32207,30.834444,76.933333 ],
    [ u"in",u"Kallidaikurichchi",25515,8.666667,77.483333 ],
    [ u"in",u"Kallupatti",9725,9.716667,77.866667 ],
    [ u"in",u"Kalmeshwar",19387,21.233333,78.9 ],
    [ u"in",u"Kalna",53969,23.216667,88.366667 ],
    [ u"in",u"Kalol",106958,23.25,72.483333 ],
    [ u"in",u"Kalpi",44343,26.116667,79.733333 ],
    [ u"in",u"Kalugumalai",15425,9.15,77.716667 ],
    [ u"in",u"Kalyani",93193,22.983333,88.483333 ],
    [ u"in",u"Kalyan",1262355,19.25,73.15 ],
    [ u"in",u"Kamakhyanagar",15820,20.933333,85.55 ],
    [ u"in",u"Kamalapuram",14677,14.583333,78.65 ],
    [ u"in",u"Kamalganj",16223,27.266667,79.65 ],
    [ u"in",u"Kamalpur",5509,24.2,91.833333 ],
    [ u"in",u"Kaman",33527,27.65,77.266667 ],
    [ u"in",u"Kamareddi",71049,18.316667,78.35 ],
    [ u"in",u"Kamarhati",332997,22.671111,88.374722 ],
    [ u"in",u"Kambam",60834,9.733333,77.3 ],
    [ u"in",u"Kampil",9201,27.616667,79.283333 ],
    [ u"in",u"Kampli",36644,15.4,76.616667 ],
    [ u"in",u"Kamthi",86220,21.233333,79.2 ],
    [ u"in",u"Kanadukathan",4814,10.166667,78.783333 ],
    [ u"in",u"Kanakapura",50757,12.55,77.416667 ],
    [ u"in",u"Kanchipuram",155043,12.833333,79.716667 ],
    [ u"in",u"Kanchrapara",136967,22.97,88.431944 ],
    [ u"in",u"Kandhla",43391,29.316667,77.266667 ],
    [ u"in",u"Kandi",54853,23.95,88.033333 ],
    [ u"in",u"Kandla",25845,23.033333,70.216667 ],
    [ u"in",u"Kandra",6902,22.85,86.05 ],
    [ u"in",u"Kandri",8323,21.416667,79.266667 ],
    [ u"in",u"Kangayam",31367,11,77.566667 ],
    [ u"in",u"Kangra",9159,32.1,76.266667 ],
    [ u"in",u"Kanigiri",25045,15.4,79.516667 ],
    [ u"in",u"Kanina",10816,28.333333,76.316667 ],
    [ u"in",u"Kankavli",15735,16.266667,73.7 ],
    [ u"in",u"Kanke",16714,23.433333,85.316667 ],
    [ u"in",u"Kanker",25987,20.271944,81.493056 ],
    [ u"in",u"Kankipadu",14249,16.45,80.783333 ],
    [ u"in",u"Kankon",12446,15.016667,74.016667 ],
    [ u"in",u"Kannad",42059,20.266667,75.133333 ],
    [ u"in",u"Kannangad",68456,12.316667,75.066667 ],
    [ u"in",u"Kannauj",76721,27.0546,79.922 ],
    [ u"in",u"Kanniyakumari",20542,8.076111,77.548333 ],
    [ u"in",u"Kannod",15872,22.666667,76.733333 ],
    [ u"in",u"Kannur",7625,11.866667,75.365278 ],
    [ u"in",u"Kanodar",11954,24.1,72.383333 ],
    [ u"in",u"Kanor",13090,24.433333,74.266667 ],
    [ u"in",u"Kanpur",2823523,26.466667,80.35 ],
    [ u"in",u"Kantabanji",21026,20.483333,82.916667 ],
    [ u"in",u"Kanth",24886,29.066667,78.633333 ],
    [ u"in",u"Kantilo",8862,20.35,85.183333 ],
    [ u"in",u"Kant",24432,27.8,79.8 ],
    [ u"in",u"Kapasan",19732,24.9,74.333333 ],
    [ u"in",u"Kapra",198349,17.486667,78.566111 ],
    [ u"in",u"Kaptanganj",12300,26.926667,83.715278 ],
    [ u"in",u"Kapurthala",92674,31.379444,75.384722 ],
    [ u"in",u"Karad",55667,17.283333,74.2 ],
    [ u"in",u"Karaikkudi",91916,10.066667,78.783333 ],
    [ u"in",u"Karamadai",31190,11.266667,76.966667 ],
    [ u"in",u"Karambakkudi",12371,10.466667,79.133333 ],
    [ u"in",u"Karamsad",32382,22.55,72.9 ],
    [ u"in",u"Karanja",64740,20.483333,77.483333 ],
    [ u"in",u"Karanpura",21606,29.841944,73.454167 ],
    [ u"in",u"Karari",14404,25.45,81.433333 ],
    [ u"in",u"Karauli",73722,26.5,77.016667 ],
    [ u"in",u"Kareli",27811,22.916667,79.066667 ],
    [ u"in",u"Karera",26215,25.466667,78.15 ],
    [ u"in",u"Kargil",13843,34.566667,76.1 ],
    [ u"in",u"Karhal",26696,27.000278,78.941389 ],
    [ u"in",u"Kariapatti",14398,9.7,78.1 ],
    [ u"in",u"Karimganj",55293,24.866667,92.35 ],
    [ u"in",u"Karimnagar",228770,18.433333,79.15 ],
    [ u"in",u"Karimpur",9565,23.966667,88.616667 ],
    [ u"in",u"Karjat",34577,18.916667,73.333333 ],
    [ u"in",u"Karkal",25376,13.2,74.983333 ],
    [ u"in",u"Karmala",22811,18.416667,75.2 ],
    [ u"in",u"Karnal",225064,29.683333,76.983333 ],
    [ u"in",u"Karrapur",9993,23.95,78.85 ],
    [ u"in",u"Karsiyang",46431,26.882511,88.27729 ],
    [ u"in",u"Kartarpur",26703,31.44,75.499722 ],
    [ u"in",u"Karumbakkam",11992,12.699167,80.093333 ],
    [ u"in",u"Karur",76922,10.95,78.083333 ],
    [ u"in",u"Karwar",64462,14.813611,74.129722 ],
    [ u"in",u"Kasaragod",53313,12.5,75 ],
    [ u"in",u"Kasauli",5215,30.898889,76.964722 ],
    [ u"in",u"Kasba",26940,25.85,87.55 ],
    [ u"in",u"Kasganj",99472,27.816667,78.65 ],
    [ u"in",u"Kashipur",103149,29.216667,78.95 ],
    [ u"in",u"Kasimbazar",10727,24.116667,88.283333 ],
    [ u"in",u"Kasrawad",21486,22.133333,75.6 ],
    [ u"in",u"Katangi",15323,21.783333,79.783333 ],
    [ u"in",u"Katghora",20115,22.5,82.55 ],
    [ u"in",u"Kathor",15311,21.3,72.933333 ],
    [ u"in",u"Kathua",48555,32.366667,75.516667 ],
    [ u"in",u"Katihar",192575,25.533333,87.583333 ],
    [ u"in",u"Katol",41896,21.266667,78.583333 ],
    [ u"in",u"Katpadi",16408,12.983333,79.133333 ],
    [ u"in",u"Katra",9107,32.983333,74.95 ],
    [ u"in",u"Katra",6853,27.516667,82.016667 ],
    [ u"in",u"Katras",57355,23.8,86.283333 ],
    [ u"in",u"Kattivakkam",34598,13.216667,80.316667 ],
    [ u"in",u"Katwa",78416,23.65,88.133333 ],
    [ u"in",u"Kavali",83361,14.916667,79.983333 ],
    [ u"in",u"Kavant",8618,22.1,74.05 ],
    [ u"in",u"Kavaratti",10689,10.566667,72.616667 ],
    [ u"in",u"Kaveripattinam",14209,12.416667,78.233333 ],
    [ u"in",u"Kawardha",35241,22.016667,81.25 ],
    [ u"in",u"Kayalpattinam",36178,8.566667,78.116667 ],
    [ u"in",u"Kayankulam",64189,9.183333,76.5 ],
    [ u"in",u"Kayattar",10008,8.95,77.8 ],
    [ u"in",u"Kedarnath",508,30.733333,79.066667 ],
    [ u"in",u"Kekri",37853,25.966667,75.15 ],
    [ u"in",u"Kelamangalam",11328,12.6,77.85 ],
    [ u"in",u"Kemri",26729,28.816667,79.216667 ],
    [ u"in",u"Kenda",15132,23.2,86.533333 ],
    [ u"in",u"Kendrapara",43847,20.5,86.416667 ],
    [ u"in",u"Kenduadih",9033,23.783333,86.383333 ],
    [ u"in",u"Kerur",17930,16.016667,75.566667 ],
    [ u"in",u"Kesabpur",10921,22.968333,88.262778 ],
    [ u"in",u"Keshod",68523,21.3,70.25 ],
    [ u"in",u"Keshorai Patan",23466,25.3,75.933333 ],
    [ u"in",u"Kesinga",17995,20.2,83.233333 ],
    [ u"in",u"Khachrod",31829,23.416667,75.283333 ],
    [ u"in",u"Khadki",75660,18.566667,73.866667 ],
    [ u"in",u"Khaga",13339,25.783333,81.116667 ],
    [ u"in",u"Khagaria",49988,25.5,86.483333 ],
    [ u"in",u"Khagaul",51583,25.583333,85.05 ],
    [ u"in",u"Khailar",13334,25.35,78.533333 ],
    [ u"in",u"Khairabad",42129,27.533333,80.75 ],
    [ u"in",u"Khairagarh",20097,26.95,77.816667 ],
    [ u"in",u"Khairagarh",15736,21.416667,80.966667 ],
    [ u"in",u"Khair",30176,27.95,77.833333 ],
    [ u"in",u"Khajuraho",25681,24.85,79.933333 ],
    [ u"in",u"Khalilabad",45325,26.775,83.073611 ],
    [ u"in",u"Khamanon",9395,30.818611,76.350833 ],
    [ u"in",u"Khamaria",15034,23.216667,79.883333 ],
    [ u"in",u"Khambhaliya",38123,22.207222,69.668333 ],
    [ u"in",u"Khambhat",81334,22.3,72.616667 ],
    [ u"in",u"Khamgaon",94612,20.683333,76.566667 ],
    [ u"in",u"Khammam",170522,17.25,80.15 ],
    [ u"in",u"Khanapur",17217,15.633333,74.516667 ],
    [ u"in",u"Khandela",23165,27.6,75.5 ],
    [ u"in",u"Khandwa",182860,21.833333,76.333333 ],
    [ u"in",u"Khanna",117146,30.704444,76.223056 ],
    [ u"in",u"Khanpur",14854,24.716667,76.383333 ],
    [ u"in",u"Khanpur",14689,28.533333,78.05 ],
    [ u"in",u"Khapa",15176,21.433333,78.966667 ],
    [ u"in",u"Kharagpur",219686,22.333333,87.333333 ],
    [ u"in",u"Kharagpur",27495,25.116667,86.55 ],
    [ u"in",u"Kharakvasla",23677,18.433333,73.766667 ],
    [ u"in",u"Kharar",45694,30.744444,76.647778 ],
    [ u"in",u"Kharar",12051,22.7,87.683333 ],
    [ u"in",u"Khardaha",128358,22.718611,88.378056 ],
    [ u"in",u"Kharela",13800,25.55,79.816667 ],
    [ u"in",u"Khargapur",13508,24.823,79.144 ],
    [ u"in",u"Khargone",94995,21.816667,75.6 ],
    [ u"in",u"Khargupur",9577,27.383333,81.983333 ],
    [ u"in",u"Kharhial",14008,20.283333,82.766667 ],
    [ u"in",u"Kharod",8927,21.75,82.566667 ],
    [ u"in",u"Kharsawan",7217,22.8,85.833333 ],
    [ u"in",u"Kharsia",18258,21.966667,83.116667 ],
    [ u"in",u"Khatauli",64737,29.283333,77.716667 ],
    [ u"in",u"Khategaon",23407,22.6,76.916667 ],
    [ u"in",u"Khatima",15716,28.916667,79.966667 ],
    [ u"in",u"Khatra",16484,22.983333,86.85 ],
    [ u"in",u"Khawhai",2537,23.366667,93.116667 ],
    [ u"in",u"Kheda",24768,22.75,72.683333 ],
    [ u"in",u"Khed Brahma",29404,24.033333,73.05 ],
    [ u"in",u"Khed",14830,17.716667,73.383333 ],
    [ u"in",u"Khekra",42412,28.866667,77.283333 ],
    [ u"in",u"Khem Karan",12637,31.142778,74.566667 ],
    [ u"in",u"Kheralu",20757,23.883333,72.616667 ],
    [ u"in",u"Kheri",26330,27.9,80.8 ],
    [ u"in",u"Khetia",15022,21.666667,74.583333 ],
    [ u"in",u"Khetri",17178,27.983333,75.8 ],
    [ u"in",u"Khilchipur",16412,24.033333,76.566667 ],
    [ u"in",u"Khirkiya",18500,22.166667,76.85 ],
    [ u"in",u"Khonsa",10188,27.016667,95.566667 ],
    [ u"in",u"Khopoli",64465,18.783333,73.333333 ],
    [ u"in",u"Khour",6690,32.6,74.8 ],
    [ u"in",u"Khowai",20049,24.1,91.633333 ],
    [ u"in",u"Khudaganj",12638,28.15,79.716667 ],
    [ u"in",u"Khujner",9951,23.783333,76.6 ],
    [ u"in",u"Khuldabad",14415,20.05,75.183333 ],
    [ u"in",u"Khunti",31370,23.083333,85.283333 ],
    [ u"in",u"Khurai",31617,24.0436,78.3319 ],
    [ u"in",u"Khurda",42530,20.183333,85.616667 ],
    [ u"in",u"Khurja",105920,28.25,77.85 ],
    [ u"in",u"Khutar",15620,28.2,80.283333 ],
    [ u"in",u"Kichha",34908,28.916667,79.5 ],
    [ u"in",u"Kilakarai",30471,9.233333,78.783333 ],
    [ u"in",u"Kilvelur",7629,10.766667,79.733333 ],
    [ u"in",u"Kinwat",25958,19.633333,78.2 ],
    [ u"in",u"Kiranur",10134,10.566667,78.783333 ],
    [ u"in",u"Kiraoli",21026,27.15,77.783333 ],
    [ u"in",u"Kiratpur",60229,29.516667,78.2 ],
    [ u"in",u"Kiri Buru",9720,22.083333,85.35 ],
    [ u"in",u"Kishanganj",94817,26.116667,87.933333 ],
    [ u"in",u"Kishangarh",10288,27.816667,76.716667 ],
    [ u"in",u"Kishanpur",6105,25.65,81.016667 ],
    [ u"in",u"Kishni",9853,27.0247,79.2634 ],
    [ u"in",u"Kishtwar",20561,33.316667,75.766667 ],
    [ u"in",u"Koath",16727,25.316667,84.266667 ],
    [ u"in",u"Koch Bihar",78744,26.316667,89.433333 ],
    [ u"in",u"Kochi",604751,9.966667,76.233333 ],
    [ u"in",u"Kochinda",14083,21.733333,84.35 ],
    [ u"in",u"Kodaikanal",35024,10.233333,77.483333 ],
    [ u"in",u"Kodala",13188,19.633333,84.95 ],
    [ u"in",u"Kodar",59182,16.983333,79.966667 ],
    [ u"in",u"Kodarma",19182,24.433333,85.516667 ],
    [ u"in",u"Kodigenahalli",5727,13.72,77.390278 ],
    [ u"in",u"Kodinar",34933,20.790278,70.703056 ],
    [ u"in",u"Kodlipet",2686,12.8,75.883333 ],
    [ u"in",u"Kodoli",17537,16.883333,74.2 ],
    [ u"in",u"Kodumudi",13053,11.083333,77.883333 ],
    [ u"in",u"Kodungallur",34213,10.222222,76.199167 ],
    [ u"in",u"Kohima",92117,25.666667,94.116667 ],
    [ u"in",u"Kokrajhar",31972,26.399042,90.271819 ],
    [ u"in",u"Kolaras",17176,25.233333,77.6 ],
    [ u"in",u"Kolar",126452,13.133333,78.133333 ],
    [ u"in",u"Kolhapur",516184,16.7,74.216667 ],
    [ u"in",u"Kollam",394198,8.880556,76.591667 ],
    [ u"in",u"Kollegal",56502,12.15,77.116667 ],
    [ u"in",u"Kombai",13209,9.833333,77.316667 ],
    [ u"in",u"Konanur",9555,12.626389,76.054167 ],
    [ u"in",u"Konch",52778,25.983333,79.15 ],
    [ u"in",u"Kondagaon",27630,19.6,81.666667 ],
    [ u"in",u"Kondapalle",38722,16.616667,80.533333 ],
    [ u"in",u"Konganapuram",8331,11.583333,77.916667 ],
    [ u"in",u"Konnagar",76090,22.7,88.3475 ],
    [ u"in",u"Konnur",19168,16.2,74.75 ],
    [ u"in",u"Kopaganj",33543,26.023333,83.565833 ],
    [ u"in",u"Kopargaon",65121,19.883333,74.483333 ],
    [ u"in",u"Koppa",5124,13.55,75.35 ],
    [ u"in",u"Koppal",60873,15.35,76.15 ],
    [ u"in",u"Koradacheri",6151,10.766667,79.483333 ],
    [ u"in",u"Korampallam",3228,8.766667,78.1 ],
    [ u"in",u"Koraput",41174,18.816667,82.716667 ],
    [ u"in",u"Koratagere",14446,13.522778,77.233056 ],
    [ u"in",u"Koratla",60238,18.816667,78.716667 ],
    [ u"in",u"Korba",419326,22.35,82.683333 ],
    [ u"in",u"Koregaon",25846,18.65,74.083333 ],
    [ u"in",u"Kosamba",33221,21.483333,72.95 ],
    [ u"in",u"Kosgi",15455,15.85,77.266667 ],
    [ u"in",u"Kotagiri",28850,11.433333,76.883333 ],
    [ u"in",u"Kota",763141,25.183333,75.833333 ],
    [ u"in",u"Kota",14632,24.45,83.133333 ],
    [ u"in",u"Kota",15584,22.3,82.033333 ],
    [ u"in",u"Kotaparh",15480,19.15,82.35 ],
    [ u"in",u"Kotar",6959,24.716667,80.983333 ],
    [ u"in",u"Kotdwara",27012,29.75,78.533333 ],
    [ u"in",u"Kothapet",4266,19.333333,79.483333 ],
    [ u"in",u"Kothi",7796,24.75,80.783333 ],
    [ u"in",u"Kot Isa Khan",9639,30.95,75.133333 ],
    [ u"in",u"Kot Kapura",88360,30.583333,74.9 ],
    [ u"in",u"Kot Khai",1253,31.116667,77.533333 ],
    [ u"in",u"Kotma",31759,23.2,81.966667 ],
    [ u"in",u"Kot Putli",43654,27.716667,76.2 ],
    [ u"in",u"Kotra",8535,25.816667,79.316667 ],
    [ u"in",u"Kottagudem",79255,17.55,80.633333 ],
    [ u"in",u"Kottaiyur",11520,10.116667,78.816667 ],
    [ u"in",u"Kottapalli",9901,18.483333,79.1 ],
    [ u"in",u"Kottayam",59442,9.583333,76.516667 ],
    [ u"in",u"Kotturu",24006,14.816667,76.216667 ],
    [ u"in",u"Kovilpatti",90304,9.166667,77.866667 ],
    [ u"in",u"Kovur",35607,14.483333,79.983333 ],
    [ u"in",u"Kovvur",40383,17.016667,81.733333 ],
    [ u"in",u"Koyilandi",70666,11.433333,75.7 ],
    [ u"in",u"Krishnagiri",66425,12.533333,78.233333 ],
    [ u"in",u"Krishnanagar",145941,23.4,88.5 ],
    [ u"in",u"Krishnapur",7336,22.670278,88.269444 ],
    [ u"in",u"Krishnarajasagara",8713,12.436667,76.382778 ],
    [ u"in",u"Krishnarajpet",24291,12.655,76.488333 ],
    [ u"in",u"Kuchaman",56729,27.15,74.85 ],
    [ u"in",u"Kuchera",21798,26.983889,73.971944 ],
    [ u"in",u"Kudal",14433,16.033333,73.683333 ],
    [ u"in",u"Kudchi",19274,16.633333,74.85 ],
    [ u"in",u"Kud",1242,33.083333,75.283333 ],
    [ u"in",u"Kudligi",22975,14.9,76.383333 ],
    [ u"in",u"Kuju",19392,23.716667,85.5 ],
    [ u"in",u"Kukshi",26185,22.2,74.75 ],
    [ u"in",u"Kulgam",16247,33.65,75.016667 ],
    [ u"in",u"Kulpahar",18978,25.316667,79.65 ],
    [ u"in",u"Kulti",305434,23.733333,86.85 ],
    [ u"in",u"Kulu",19832,31.966667,77.1 ],
    [ u"in",u"Kumbakonam",139276,10.966667,79.383333 ],
    [ u"in",u"Kumbhraj",16393,24.366667,77.05 ],
    [ u"in",u"Kumhari",38351,21.266667,81.516667 ],
    [ u"in",u"Kumher",21904,27.316667,77.366667 ],
    [ u"in",u"Kumsi",6468,14.066667,75.4 ],
    [ u"in",u"Kumta",28002,14.416667,74.4 ],
    [ u"in",u"Kunda",24951,25.716667,81.516667 ],
    [ u"in",u"Kundarki",27200,28.7,78.783333 ],
    [ u"in",u"Kundgol",17618,15.25,75.25 ],
    [ u"in",u"Kundla",76814,21.333333,71.3 ],
    [ u"in",u"Kunigal",33276,13.022222,77.026667 ],
    [ u"in",u"Kunnamangalam",38372,11.316667,75.883333 ],
    [ u"in",u"Kunnamkulam",63950,10.65,76.083333 ],
    [ u"in",u"Kuppam",19856,12.75,78.366667 ],
    [ u"in",u"Kurali",25332,30.833056,76.573333 ],
    [ u"in",u"Kurandvad",21389,16.683333,74.583333 ],
    [ u"in",u"Kurara",12731,25.983333,79.983333 ],
    [ u"in",u"Kurduvadi",23132,18.083333,75.433333 ],
    [ u"in",u"Kurgunta",8682,17.2,77.35 ],
    [ u"in",u"Kurinjippadi",23019,11.566667,79.6 ],
    [ u"in",u"Kurud",11296,20.832222,81.721389 ],
    [ u"in",u"Kushalgarh",10350,23.166667,74.45 ],
    [ u"in",u"Kushalnagar",14962,12.466667,75.966667 ],
    [ u"in",u"Kushtagi",24182,15.766667,76.2 ],
    [ u"in",u"Kutiyana",16879,21.623333,69.981667 ],
    [ u"in",u"Kuttanallur",23260,10.7,79.533333 ],
    [ u"in",u"Kuzhithurai",20613,8.316667,77.183333 ],
    [ u"in",u"Lachhmangarh",48145,27.816667,75.033333 ],
    [ u"in",u"Ladnun",60494,27.65,74.383333 ],
    [ u"in",u"Ladwa",23567,29.994444,77.044444 ],
    [ u"in",u"Lahar",32889,26.198333,78.945 ],
    [ u"in",u"Laharpur",55917,27.716667,80.9 ],
    [ u"in",u"Lakheri",28466,25.666667,76.166667 ],
    [ u"in",u"Lakhimpur",59844,27.233333,94.116667 ],
    [ u"in",u"Lakhimpur",140237,27.95,80.766667 ],
    [ u"in",u"Lakhipur",12873,24.8,93.016667 ],
    [ u"in",u"Lakhisarai",89509,25.183333,86.083333 ],
    [ u"in",u"Lakhnadon",15591,22.6,79.6 ],
    [ u"in",u"Lakhna",11390,26.65,79.15 ],
    [ u"in",u"Lakhnau",2472250,26.85,80.916667 ],
    [ u"in",u"Lakhtar",14534,22.85,71.783333 ],
    [ u"in",u"Laksar",19272,29.766667,78.05 ],
    [ u"in",u"Lakshettipet",11164,18.866667,79.216667 ],
    [ u"in",u"Lakshmeshwar",35143,15.133333,75.466667 ],
    [ u"in",u"Lala",10942,24.55,92.6 ],
    [ u"in",u"Lalganj",31882,25.866667,85.183333 ],
    [ u"in",u"Lalganj",23730,25.933333,81.7 ],
    [ u"in",u"Lalgudi",20918,10.866667,78.833333 ],
    [ u"in",u"Lalitpur",126487,24.683333,78.416667 ],
    [ u"in",u"Lalpur",15076,22.2,69.966667 ],
    [ u"in",u"Lalsot",31482,26.566667,76.333333 ],
    [ u"in",u"Lanja",13120,16.85,73.55 ],
    [ u"in",u"Lar",26691,26.203889,83.971667 ],
    [ u"in",u"Lasalgaon",13666,20.15,74.233333 ],
    [ u"in",u"Latehar",20771,23.75,84.5 ],
    [ u"in",u"Lathi",22747,21.716667,71.383333 ],
    [ u"in",u"Latur",348994,18.4,76.583333 ],
    [ u"in",u"Lawar",19558,29.116667,77.766667 ],
    [ u"in",u"Leh",37498,34.166667,77.583333 ],
    [ u"in",u"Limbdi",41743,22.566667,71.8 ],
    [ u"in",u"Lingsugur",29785,16.166667,76.516667 ],
    [ u"in",u"Lodhikheda",9995,21.583333,78.833333 ],
    [ u"in",u"Lohardaga",53037,23.433333,84.683333 ],
    [ u"in",u"Loharu",12411,28.45,75.816667 ],
    [ u"in",u"Lonar",21767,19.983333,76.533333 ],
    [ u"in",u"Lonavale",58567,18.75,73.416667 ],
    [ u"in",u"Londa",6132,15.466667,74.516667 ],
    [ u"in",u"Loni",164927,28.75,77.283333 ],
    [ u"in",u"Lormi",12858,22.283333,81.733333 ],
    [ u"in",u"Losal",27966,27.4,74.916667 ],
    [ u"in",u"Loyabad",33165,23.666667,86.666667 ],
    [ u"in",u"Ludhiana",1545476,30.9,75.85 ],
    [ u"in",u"Lumding",25777,25.75,93.166667 ],
    [ u"in",u"Lunavada",35433,23.133333,73.616667 ],
    [ u"in",u"Lunglei",52734,22.883333,92.733333 ],
    [ u"in",u"Machalpur",8557,24.133333,76.3 ],
    [ u"in",u"Macherla",51044,16.483333,79.433333 ],
    [ u"in",u"Machhiwara",20448,30.914722,76.198333 ],
    [ u"in",u"Machhlishahr",25250,25.683333,82.416667 ],
    [ u"in",u"Machilipatnam",192848,16.166667,81.133333 ],
    [ u"in",u"Madanapalle",108605,13.55,78.5 ],
    [ u"in",u"Madanpur",12960,23.016667,88.483333 ],
    [ u"in",u"Maddur",28143,12.6,77.066667 ],
    [ u"in",u"Madgaon",86827,15.3,73.95 ],
    [ u"in",u"Madhavaram",90052,13.149167,80.236667 ],
    [ u"in",u"Madhipura",50575,25.916667,86.783333 ],
    [ u"in",u"Madhoganj",10300,27.116667,80.15 ],
    [ u"in",u"Madhogarh",5052,24.566667,80.9 ],
    [ u"in",u"Madhogarh",10531,26.276,79.1869 ],
    [ u"in",u"Madhubani",71590,26.366667,86.083333 ],
    [ u"in",u"Madhugiri",28127,13.660556,77.209167 ],
    [ u"in",u"Madhupur",50677,24.25,86.65 ],
    [ u"in",u"Madhyamgram",161142,22.7,88.45 ],
    [ u"in",u"Madikeri",33543,12.416667,75.733333 ],
    [ u"in",u"Madras",4328416,13.083333,80.283333 ],
    [ u"in",u"Madukkarai",29147,10.9,76.966667 ],
    [ u"in",u"Madukkur",15631,10.483333,79.4 ],
    [ u"in",u"Madurai",909988,9.933333,78.116667 ],
    [ u"in",u"Magadi",27215,12.966667,77.233333 ],
    [ u"in",u"Magam",4690,34.083333,74.583333 ],
    [ u"in",u"Maghar",17013,26.757222,83.127778 ],
    [ u"in",u"Mahabaleshwar",13599,17.916667,73.666667 ],
    [ u"in",u"Mahaban",9515,27.433333,77.75 ],
    [ u"in",u"Mahad",26667,18.083333,73.416667 ],
    [ u"in",u"Mahalingpur",32702,16.383333,75.116667 ],
    [ u"in",u"Maham",19385,28.983333,76.3 ],
    [ u"in",u"Maharajganj",22433,26.116667,84.483333 ],
    [ u"in",u"Maharajganj",30551,27.133333,83.566667 ],
    [ u"in",u"Mahasamund",50447,21.1,82.1 ],
    [ u"in",u"Mahbubabad",37957,17.616667,80.016667 ],
    [ u"in",u"Mahbubnagar",136150,16.733333,77.983333 ],
    [ u"in",u"Mahe",38188,11.7,75.533333 ],
    [ u"in",u"Mahemdavad",32506,22.833333,72.766667 ],
    [ u"in",u"Mahendragarh",25730,28.283333,76.15 ],
    [ u"in",u"Mahesana",102675,23.6,72.4 ],
    [ u"in",u"Maheshwar",21502,22.183333,75.583333 ],
    [ u"in",u"Mahiari",17053,22.592222,88.237778 ],
    [ u"in",u"Mahishadal",17988,22.183333,87.983333 ],
    [ u"in",u"Mahmudabad",45925,27.3,81.116667 ],
    [ u"in",u"Mahoba",89179,25.283333,79.866667 ],
    [ u"in",u"Maholi",19345,27.666667,80.466667 ],
    [ u"in",u"Mahroni",8899,24.5862,78.7288 ],
    [ u"in",u"Mahudha",16828,22.816667,72.933333 ],
    [ u"in",u"Mahur",7178,25.166667,93.116667 ],
    [ u"in",u"Mahuva",74625,21.083333,71.8 ],
    [ u"in",u"Mahwa",22626,27.05,76.933333 ],
    [ u"in",u"Maibong",8365,25.3,93.166667 ],
    [ u"in",u"Maihar",37917,24.266667,80.75 ],
    [ u"in",u"Mailani",14213,28.283333,80.35 ],
    [ u"in",u"Mainaguri",29462,26.566667,88.816667 ],
    [ u"in",u"Maindargi",11445,17.466667,76.3 ],
    [ u"in",u"Mainpuri",94629,27.233333,79.016667 ],
    [ u"in",u"Mairang",12586,25.566667,91.633333 ],
    [ u"in",u"Mairwa",20165,26.233333,84.15 ],
    [ u"in",u"Maisuru",868385,12.307222,76.649722 ],
    [ u"in",u"Majalgaon",47848,19.15,76.233333 ],
    [ u"in",u"Majholi",11554,23.5,79.916667 ],
    [ u"in",u"Majitha",13901,31.758333,74.954444 ],
    [ u"in",u"Makhu",12885,31.103333,74.997778 ],
    [ u"in",u"Makrana",93911,27.05,74.716667 ],
    [ u"in",u"Maksi",20096,23.266667,76.15 ],
    [ u"in",u"Makum",16226,27.5,95.45 ],
    [ u"in",u"Malappuram",61749,11.066667,76.066667 ],
    [ u"in",u"Malaut",76621,30.216667,74.483333 ],
    [ u"in",u"Malavalli",38132,12.383333,77.083333 ],
    [ u"in",u"Malegaon",435397,20.55,74.533333 ],
    [ u"in",u"Maler Kotla",113848,30.516667,75.883333 ],
    [ u"in",u"Malhargarh",7621,24.283333,74.983333 ],
    [ u"in",u"Malia",14423,23.083333,70.766667 ],
    [ u"in",u"Malihabad",16651,26.916667,80.716667 ],
    [ u"in",u"Malkangiri",25056,18.35,81.9 ],
    [ u"in",u"Malkapur",5582,16.933333,73.916667 ],
    [ u"in",u"Malkera",12593,23.783333,86.3 ],
    [ u"in",u"Mallapuram",11837,11.966667,78.25 ],
    [ u"in",u"Mallasamudram",18822,11.483333,78.033333 ],
    [ u"in",u"Mallur",10525,11.55,78.133333 ],
    [ u"in",u"Malpe",23496,13.35,74.716667 ],
    [ u"in",u"Malpura",28602,26.283333,75.383333 ],
    [ u"in",u"Malpur",6972,23.35,73.45 ],
    [ u"in",u"Malur",30680,13.0075,77.937778 ],
    [ u"in",u"Malwan",18860,16.066667,73.466667 ],
    [ u"in",u"Mamallapuram",12415,12.626389,80.172222 ],
    [ u"in",u"Mamit",6104,23.933333,92.483333 ],
    [ u"in",u"Manali",8344,32.266667,77.166667 ],
    [ u"in",u"Manali",32366,13.166667,80.266667 ],
    [ u"in",u"Manalurpet",7626,12.016667,79.1 ],
    [ u"in",u"Manamadurai",27496,9.7,78.483333 ],
    [ u"in",u"Manapparai",36930,10.6,78.416667 ],
    [ u"in",u"Manasa",24081,24.483333,75.15 ],
    [ u"in",u"Manavadar",29107,21.5,70.133333 ],
    [ u"in",u"Manavalakurichi",10720,8.133333,77.3 ],
    [ u"in",u"Manawar",27640,22.233333,75.083333 ],
    [ u"in",u"Manchar",14739,19,73.933333 ],
    [ u"in",u"Mancheral",78006,18.866667,79.433333 ],
    [ u"in",u"Mandalgarh",21570,25.2,75.1 ],
    [ u"in",u"Mandal",13345,23.3,71.916667 ],
    [ u"in",u"Mandal",23478,25.45,74.566667 ],
    [ u"in",u"Mandapam",15080,9.283333,79.116667 ],
    [ u"in",u"Mandapeta",48858,16.866667,81.933333 ],
    [ u"in",u"Mandasa",9289,18.866667,84.466667 ],
    [ u"in",u"Mandawar",10979,27.866667,76.55 ],
    [ u"in",u"Mandawar",21341,29.5,78.133333 ],
    [ u"in",u"Mandi",28219,31.716667,76.916667 ],
    [ u"in",u"Mandla",45189,22.6,80.383333 ],
    [ u"in",u"Mandleshwar",12051,22.183333,75.666667 ],
    [ u"in",u"Mandsaur",125002,24.066667,75.066667 ],
    [ u"in",u"Mandvi",18669,21.25,73.3 ],
    [ u"in",u"Mandya",134857,12.524167,76.895833 ],
    [ u"in",u"Maner",27904,25.65,84.883333 ],
    [ u"in",u"Mangalagiri",59398,16.433333,80.55 ],
    [ u"in",u"Mangalam",11379,9.766667,78.666667 ],
    [ u"in",u"Mangaldai",24872,26.433333,92.033333 ],
    [ u"in",u"Mangaluru",417423,12.863889,74.835278 ],
    [ u"in",u"Mangan",1464,27.516667,88.533333 ],
    [ u"in",u"Mangawan",12504,24.683333,81.55 ],
    [ u"in",u"Manglaur",46400,29.8,77.866667 ],
    [ u"in",u"Mangrol",58993,21.116667,70.116667 ],
    [ u"in",u"Mangrol",23897,25.333333,76.516667 ],
    [ u"in",u"Mangrul Pir",29200,20.316667,77.35 ],
    [ u"in",u"Manihari",23734,25.35,87.633333 ],
    [ u"in",u"Manikpur",14417,25.066667,81.116667 ],
    [ u"in",u"Manjeri",89209,11.116667,76.116667 ],
    [ u"in",u"Manjeshwar",8928,12.7,74.883333 ],
    [ u"in",u"Manjhanpur",16940,25.533333,81.383333 ],
    [ u"in",u"Mankachar",31092,25.533333,89.866667 ],
    [ u"in",u"Mankapur",9747,27.033333,82.233333 ],
    [ u"in",u"Manmad",76729,20.25,74.45 ],
    [ u"in",u"Mannarakkat",50921,10.983333,76.466667 ],
    [ u"in",u"Mannargudi",63154,10.666667,79.433333 ],
    [ u"in",u"Manoharpur",28928,27.3,75.95 ],
    [ u"in",u"Manoharpur",13190,22.383333,85.2 ],
    [ u"in",u"Manohar Thana",10100,24.233333,76.8 ],
    [ u"in",u"Manor",8918,19.75,72.916667 ],
    [ u"in",u"Manpur",6639,22.433333,75.616667 ],
    [ u"in",u"Mansa",29553,23.433333,72.666667 ],
    [ u"in",u"Mansa",80024,29.983333,75.383333 ],
    [ u"in",u"Mansar",6901,21.4,79.25 ],
    [ u"in",u"Manthani",15665,18.65,79.666667 ],
    [ u"in",u"Manvi",41650,15.983333,77.05 ],
    [ u"in",u"Manwath",30626,19.3,76.5 ],
    [ u"in",u"Marakkanam",19734,12.2,79.95 ],
    [ u"in",u"Marandahalli",10480,12.4,78 ],
    [ u"in",u"Margherita",24430,27.283333,95.683333 ],
    [ u"in",u"Marhaura",26140,25.966667,84.866667 ],
    [ u"in",u"Mariahu",22251,25.616667,82.616667 ],
    [ u"in",u"Mariani",23641,26.666667,94.333333 ],
    [ u"in",u"Markapur",63990,15.733333,79.283333 ],
    [ u"in",u"Masaurhi",53446,25.35,85.033333 ],
    [ u"in",u"Masila",11461,22.580833,88.232778 ],
    [ u"in",u"Masinigudi",9642,11.566667,76.666667 ],
    [ u"in",u"Masuri",25756,30.45,78.083333 ],
    [ u"in",u"Mataundh",8592,25.45,80.15 ],
    [ u"in",u"Matheran",5288,18.983333,73.266667 ],
    [ u"in",u"Mathura",330543,27.5,77.683333 ],
    [ u"in",u"Mau Aima",20125,25.7,81.916667 ],
    [ u"in",u"Maudaha",37848,25.683333,80.116667 ],
    [ u"in",u"Mauganj",25540,24.683333,81.883333 ],
    [ u"in",u"Mau",19301,26.043611,78.984722 ],
    [ u"in",u"Mau",246074,25.941667,83.561111 ],
    [ u"in",u"Maurawan",14918,26.433333,80.883333 ],
    [ u"in",u"Maur",28298,30.083333,75.25 ],
    [ u"in",u"Mavelikara",28303,9.266667,76.55 ],
    [ u"in",u"Mavur",28316,11.266667,75.916667 ],
    [ u"in",u"Mawana",76981,29.083333,77.866667 ],
    [ u"in",u"Mayakonda",6445,14.283333,76.083333 ],
    [ u"in",u"Mayang Imphal",22160,24.616667,93.883333 ],
    [ u"in",u"Medak",44356,18.033333,78.266667 ],
    [ u"in",u"Meghraj",10498,23.5,73.5 ],
    [ u"in",u"Mehkar",41140,20.15,76.566667 ],
    [ u"in",u"Mehnagar",14898,25.883333,83.116667 ],
    [ u"in",u"Mehndawal",25498,26.975278,83.111667 ],
    [ u"in",u"Melukote",4011,12.658889,76.650556 ],
    [ u"in",u"Melur",33842,10.05,78.333333 ],
    [ u"in",u"Memari",44452,23.2,88.116667 ],
    [ u"in",u"Merta",43761,26.65,74.033333 ],
    [ u"in",u"Methala",42444,10.222222,76.199167 ],
    [ u"in",u"Mettupalayam",9587,11.166667,78.45 ],
    [ u"in",u"Mettur",56748,11.8,77.8 ],
    [ u"in",u"Mhasla",9332,18.133333,73.116667 ],
    [ u"in",u"Mihijam",37259,23.866667,86.866667 ],
    [ u"in",u"Mihona",15832,26.284444,78.981667 ],
    [ u"in",u"Milak",28508,28.616667,79.183333 ],
    [ u"in",u"Minjur",24674,13.266667,80.266667 ],
    [ u"in",u"Miranpur",27392,29.3,77.933333 ],
    [ u"in",u"Mirganj",15336,28.55,79.2 ],
    [ u"in",u"Mirik",10110,26.894527,88.18484 ],
    [ u"in",u"Mirzapur",220051,25.15,82.583333 ],
    [ u"in",u"Misrikh",15014,27.45,80.516667 ],
    [ u"in",u"Modasa",58974,23.466667,73.3 ],
    [ u"in",u"Moga",130559,30.8,75.166667 ],
    [ u"in",u"Mohan",14710,26.783333,80.65 ],
    [ u"in",u"Mohanur",12846,11.083333,78.166667 ],
    [ u"in",u"Mohgaon",10447,21.65,78.716667 ],
    [ u"in",u"Mohiuddinagar",14940,25.583333,85.666667 ],
    [ u"in",u"Mohpa",7141,21.316667,78.816667 ],
    [ u"in",u"Moirang",17104,24.5,93.766667 ],
    [ u"in",u"Mokama",55209,25.4,85.916667 ],
    [ u"in",u"Mokokchung",34023,26.333333,94.533333 ],
    [ u"in",u"Mon",18743,26.75,95.1 ],
    [ u"in",u"Monoharpur",23364,22.108333,88.078889 ],
    [ u"in",u"Moradabad",721210,28.833333,78.783333 ],
    [ u"in",u"Moram",17697,17.8,76.466667 ],
    [ u"in",u"Morar",44456,26.226111,78.226111 ],
    [ u"in",u"Morena",152020,26.496944,78 ],
    [ u"in",u"Mormugao",102355,15.4,73.8 ],
    [ u"in",u"Morvi",118021,22.816667,70.833333 ],
    [ u"in",u"Morwa",20169,22.9,73.833333 ],
    [ u"in",u"Moth",14078,25.716667,78.95 ],
    [ u"in",u"Motihari",112156,26.65,84.916667 ],
    [ u"in",u"Mount Abu",24982,24.6,72.7 ],
    [ u"in",u"Mubarakpur",53268,26.09,83.292222 ],
    [ u"in",u"Mudbidri",30635,13.083333,74.983333 ],
    [ u"in",u"Muddebihal",31898,16.333333,76.133333 ],
    [ u"in",u"Mudgal",21007,16.016667,76.433333 ],
    [ u"in",u"Mudhol",47431,16.35,75.283333 ],
    [ u"in",u"Mudigere",9323,13.133333,75.633333 ],
    [ u"in",u"Mudkhed",20777,19.166667,77.516667 ],
    [ u"in",u"Mughal Sarai",98053,25.3,83.116667 ],
    [ u"in",u"Mugma",3195,23.766667,86.733333 ],
    [ u"in",u"Muhammadabad",22151,27.316667,79.45 ],
    [ u"in",u"Mukerian",22753,31.950556,75.615833 ],
    [ u"in",u"Muktsar",89840,30.483333,74.516667 ],
    [ u"in",u"Mulanur",12264,10.766667,77.716667 ],
    [ u"in",u"Mulbagal",47466,13.166667,78.4 ],
    [ u"in",u"Mulgund",18930,15.25,75.533333 ],
    [ u"in",u"Mulki",17260,13.1,74.8 ],
    [ u"in",u"Mul",23986,20.066667,79.666667 ],
    [ u"in",u"Multai",22031,21.766667,78.25 ],
    [ u"in",u"Munak",15802,29.516667,76.85 ],
    [ u"in",u"Mundargi",21828,15.216667,75.9 ],
    [ u"in",u"Mundgod",17000,14.966667,75.033333 ],
    [ u"in",u"Mundi",11410,22.066667,76.5 ],
    [ u"in",u"Mundra",15219,22.85,69.733333 ],
    [ u"in",u"Mundwa",17466,27.066667,73.816667 ],
    [ u"in",u"Mungaoli",20083,24.416667,78.1 ],
    [ u"in",u"Mungeli",27701,22.066667,81.683333 ],
    [ u"in",u"Munger",203185,25.383333,86.466667 ],
    [ u"in",u"Munirabad",8246,15.333333,76.333333 ],
    [ u"in",u"Muradnagar",89491,28.783333,77.5 ],
    [ u"in",u"Muragachha",10324,23.533333,88.4 ],
    [ u"in",u"Murbad",17495,19.25,73.4 ],
    [ u"in",u"Murgud",9396,16.4,74.2 ],
    [ u"in",u"Muri",12658,23.366667,85.866667 ],
    [ u"in",u"Murliganj",23846,25.9,86.983333 ],
    [ u"in",u"Mursan",12311,27.583333,77.933333 ],
    [ u"in",u"Murshidabad",39561,24.183333,88.266667 ],
    [ u"in",u"Murud",12666,18.325833,72.965 ],
    [ u"in",u"Murwara",195877,23.85,80.4 ],
    [ u"in",u"Musafirkhana",8082,26.366667,81.8 ],
    [ u"in",u"Mushabani",32765,22.516667,86.45 ],
    [ u"in",u"Musiri",30211,10.933333,78.45 ],
    [ u"in",u"Mustafabad",8975,30.2,77.15 ],
    [ u"in",u"Muttupet",21568,10.4,79.483333 ],
    [ u"in",u"Muvattupula",29666,9.966667,76.583333 ],
    [ u"in",u"Muzaffarnagar",349741,29.466667,77.683333 ],
    [ u"in",u"Muzaffarpur",333235,26.116667,85.4 ],
    [ u"in",u"Muzhappilangad",23033,11.8,75.45 ],
    [ u"in",u"Nabagram",34731,22.288056,88.509167 ],
    [ u"in",u"Nabha",64645,30.374722,76.148611 ],
    [ u"in",u"Nabinagar",20851,24.616667,84.116667 ],
    [ u"in",u"Nadapuram",39512,11.7,75.666667 ],
    [ u"in",u"Nadaun",4838,31.783333,76.35 ],
    [ u"in",u"Nadbai",23522,27.233333,77.2 ],
    [ u"in",u"Nadiad",202080,22.7,72.866667 ],
    [ u"in",u"Nadigaon",7598,26.116667,79.033333 ],
    [ u"in",u"Naduvattam",11675,11.483333,76.566667 ],
    [ u"in",u"Naenwa",16416,25.766667,75.85 ],
    [ u"in",u"Nagamangala",16761,12.815556,76.7575 ],
    [ u"in",u"Nagapattinam",94247,10.766667,79.833333 ],
    [ u"in",u"Nagari",25936,13.333333,79.583333 ],
    [ u"in",u"Nagar Karnul",29442,16.483333,78.333333 ],
    [ u"in",u"Nagar",23548,27.433333,77.1 ],
    [ u"in",u"Nagaur",96853,27.2,73.733333 ],
    [ u"in",u"Nagda",103513,23.45,75.416667 ],
    [ u"in",u"Nagercoil",213877,8.193889,77.431389 ],
    [ u"in",u"Nagina",76601,29.45,78.45 ],
    [ u"in",u"Nagireddipalle",10394,14.266667,79.1 ],
    [ u"in",u"Nagod",21734,24.566667,80.6 ],
    [ u"in",u"Nagothana",10866,18.533333,73.133333 ],
    [ u"in",u"Nagpur",2228191,21.15,79.1 ],
    [ u"in",u"Nagram",9859,26.616667,81.133333 ],
    [ u"in",u"Nahan",27547,30.55,77.3 ],
    [ u"in",u"Naigarhi",9392,24.783333,81.783333 ],
    [ u"in",u"Naihati",253245,22.902778,88.416944 ],
    [ u"in",u"Naini Tal",42314,29.383333,79.45 ],
    [ u"in",u"Nainpur",22338,22.433333,80.116667 ],
    [ u"in",u"Najibabad",84014,29.633333,78.333333 ],
    [ u"in",u"Nakodar",32407,31.125833,75.473333 ],
    [ u"in",u"Nakur",23086,29.916667,77.3 ],
    [ u"in",u"Nalagarh",10250,31.05,76.716667 ],
    [ u"in",u"Nalbari",24618,26.416667,91.433333 ],
    [ u"in",u"Naldurg",17262,17.816667,76.3 ],
    [ u"in",u"Nalgonda",121839,17.05,79.266667 ],
    [ u"in",u"Nalhati",25878,24.3,87.816667 ],
    [ u"in",u"Naliya",10586,23.266667,68.833333 ],
    [ u"in",u"Namagiripettai",22098,11.466667,78.266667 ],
    [ u"in",u"Namakkal",56002,11.233333,78.166667 ],
    [ u"in",u"Nambiyur",16126,11.366667,77.333333 ],
    [ u"in",u"Nambutalai",7914,9.716667,79 ],
    [ u"in",u"Namchi",1147,27.166667,88.35 ],
    [ u"in",u"Namli",9236,23.433333,75.05 ],
    [ u"in",u"Nanded",485150,19.15,77.333333 ],
    [ u"in",u"Nandgaon",24211,20.316667,74.65 ],
    [ u"in",u"Nandgaon",10450,27.716667,77.383333 ],
    [ u"in",u"Nandigama",38227,16.783333,80.3 ],
    [ u"in",u"Nandikotkur",45352,15.866667,78.266667 ],
    [ u"in",u"Nandura",39653,20.833333,76.45 ],
    [ u"in",u"Nandurbar",100711,21.366667,74.25 ],
    [ u"in",u"Nandyal",165355,15.483333,78.483333 ],
    [ u"in",u"Nangal",44179,31.366667,76.383333 ],
    [ u"in",u"Nangavalli",9902,11.75,77.883333 ],
    [ u"in",u"Nangloi Jat",194381,28.683333,77.066667 ],
    [ u"in",u"Nanguneri",6969,8.483333,77.666667 ],
    [ u"in",u"Nanjangud",50247,12.119722,76.682778 ],
    [ u"in",u"Nannilam",10180,10.883333,79.616667 ],
    [ u"in",u"Nanpara",46285,27.866667,81.5 ],
    [ u"in",u"Napasar",21749,27.966667,73.55 ],
    [ u"in",u"Naraina",17048,26.783333,75.2 ],
    [ u"in",u"Naraini",15078,25.183333,80.483333 ],
    [ u"in",u"Narasannapeta",24273,18.416667,84.05 ],
    [ u"in",u"Narasapur",59310,16.45,81.666667 ],
    [ u"in",u"Narasaraopet",97205,16.25,80.066667 ],
    [ u"in",u"Narasimharajapura",7776,13.616667,75.516667 ],
    [ u"in",u"Narasingapuram",10875,13.616667,79.333333 ],
    [ u"in",u"Narauli",17947,28.5,78.716667 ],
    [ u"in",u"Naraura",22434,28.2,78.383333 ],
    [ u"in",u"Naravarikuppam",18556,13.195556,80.174167 ],
    [ u"in",u"Narayanavanam",11432,13.416667,79.583333 ],
    [ u"in",u"Narayangarh",20087,30.2392,76.9329 ],
    [ u"in",u"Narayangarh",10234,24.283333,75.05 ],
    [ u"in",u"Narayanpet",39045,16.733333,77.5 ],
    [ u"in",u"Naregal",17405,15.583333,75.816667 ],
    [ u"in",u"Narendranagar",4734,30.166667,78.3 ],
    [ u"in",u"Narkanda",718,31.266667,77.45 ],
    [ u"in",u"Narnaul",66053,28.044444,76.108333 ],
    [ u"in",u"Narnaund",16300,29.216667,76.15 ],
    [ u"in",u"Naroda",5366,23.083333,72.666667 ],
    [ u"in",u"Narsimhapur",47516,22.95,79.2 ],
    [ u"in",u"Narsingi",6445,18.033333,78.433333 ],
    [ u"in",u"Narsipatnam",33759,17.666667,82.616667 ],
    [ u"in",u"Narwana",55854,29.616667,76.116667 ],
    [ u"in",u"Narwar",16949,25.65,77.9 ],
    [ u"in",u"Nasirabad",51751,26.3,74.733333 ],
    [ u"in",u"Naspur",15374,18.833333,79.45 ],
    [ u"in",u"Nasriganj",23287,25.05,84.333333 ],
    [ u"in",u"Nasrullaganj",18267,22.683333,77.266667 ],
    [ u"in",u"Nathdwara",39429,24.933333,73.816667 ],
    [ u"in",u"Nattam",21888,10.233333,78.233333 ],
    [ u"in",u"Nattarasankottai",5921,9.866667,78.566667 ],
    [ u"in",u"Naugachhia",41251,25.4,87.1 ],
    [ u"in",u"Nautanwa",32590,27.433333,83.416667 ],
    [ u"in",u"Navadwip",111134,23.416667,88.366667 ],
    [ u"in",u"Navalgund",23210,15.566667,75.366667 ],
    [ u"in",u"Navapur",32323,21.15,73.8 ],
    [ u"in",u"Navelim",12470,15.25,73.916667 ],
    [ u"in",u"Navsari",136204,20.85,72.916667 ],
    [ u"in",u"Nawabganj",17016,26.866667,82.133333 ],
    [ u"in",u"Nawada",96740,24.883333,85.533333 ],
    [ u"in",u"Nawalgarh",58350,27.85,75.266667 ],
    [ u"in",u"Nawa",20046,27.016667,75 ],
    [ u"in",u"Nawashahr",31123,31.116667,76.133333 ],
    [ u"in",u"Naya Bazar",1035,27.133333,88.266667 ],
    [ u"in",u"Nayagarh",16002,20.133333,85.1 ],
    [ u"in",u"Nayudupeta",45778,13.9,79.9 ],
    [ u"in",u"Nazira",14303,26.916667,94.733333 ],
    [ u"in",u"Nedumangad",58284,8.6,77 ],
    [ u"in",u"Nellikkuppam",44427,11.766667,79.683333 ],
    [ u"in",u"Nepa Nagar",32614,21.466667,76.4 ],
    [ u"in",u"Neral",16061,19.033333,73.316667 ],
    [ u"in",u"Nerkunram",47530,13.061944,80.209444 ],
    [ u"in",u"Netarhat",4424,23.483333,84.266667 ],
    [ u"in",u"New Delhi",10928270,28.6,77.2 ],
    [ u"in",u"Neyveli",131213,11.533333,79.483333 ],
    [ u"in",u"Neyyattinkara",88143,8.4,77.083333 ],
    [ u"in",u"Nichlaul",17569,27.316667,83.733333 ],
    [ u"in",u"Nidadavole",44176,16.916667,81.666667 ],
    [ u"in",u"Nidamangalam",9126,10.766667,79.416667 ],
    [ u"in",u"Nihtaur",48394,29.333333,78.383333 ],
    [ u"in",u"Nilagiri",15463,21.458056,86.766944 ],
    [ u"in",u"Nilakkottai",21685,10.166667,77.866667 ],
    [ u"in",u"Nilanga",34494,18.1,76.766667 ],
    [ u"in",u"Nileshwar",25404,12.25,75.1 ],
    [ u"in",u"Nilokheri",17361,29.833333,76.916667 ],
    [ u"in",u"Nimaj",20424,26.149722,74 ],
    [ u"in",u"Nimaparha",18224,20.066667,86.016667 ],
    [ u"in",u"Nimbahera",58089,24.616667,74.683333 ],
    [ u"in",u"Nim ka Thana",32692,27.733333,75.8 ],
    [ u"in",u"Nipani",60356,16.4,74.383333 ],
    [ u"in",u"Nirmali",17104,26.316667,86.583333 ],
    [ u"in",u"Nirmal",80991,19.1,78.35 ],
    [ u"in",u"Nirsa",14126,23.783333,86.716667 ],
    [ u"in",u"Niwari",10331,28.883333,77.533333 ],
    [ u"in",u"Nizamabad",305472,18.666667,78.116667 ],
    [ u"in",u"Nizamabad",13897,26.050556,83.058889 ],
    [ u"in",u"Noamundi",16560,22.15,85.533333 ],
    [ u"in",u"Nohar",46363,29.183333,74.766667 ],
    [ u"in",u"Nokha",55915,27.6,73.416667 ],
    [ u"in",u"Nongpoh",14387,25.9,91.883333 ],
    [ u"in",u"Nongstoin",25760,25.516667,91.266667 ],
    [ u"in",u"North Guwahati",17517,26.201389,91.723611 ],
    [ u"in",u"North Vanlaiphai",3476,23.133333,93.066667 ],
    [ u"in",u"Nuh",12699,28.116667,77.016667 ],
    [ u"in",u"Numaligarh",7386,26.633333,93.75 ],
    [ u"in",u"Nurmahal",13155,31.096389,75.596667 ],
    [ u"in",u"Nurpur",9438,31.166667,76.483333 ],
    [ u"in",u"Nurpur",39081,29.15,78.416667 ],
    [ u"in",u"Nuzvid",53397,16.783333,80.85 ],
    [ u"in",u"Nyamati",10337,14.15,75.583333 ],
    [ u"in",u"Obra",56116,24.416667,82.983333 ],
    [ u"in",u"Odlabari",12311,26.833333,88.616667 ],
    [ u"in",u"Odugathur",8282,12.766667,78.9 ],
    [ u"in",u"Ojhar",44939,20.1,73.933333 ],
    [ u"in",u"Okha",21049,22.469444,69.060556 ],
    [ u"in",u"Olpad",14091,21.333333,72.75 ],
    [ u"in",u"Omalur",12702,11.733333,78.066667 ],
    [ u"in",u"Ondal",20791,23.6,87.2 ],
    [ u"in",u"Ongole",172891,15.5,80.05 ],
    [ u"in",u"Orai",158280,25.983333,79.466667 ],
    [ u"in",u"Oran",6496,25.383333,80.75 ],
    [ u"in",u"Osmanabad",85528,18.166667,76.05 ],
    [ u"in",u"Ottappalam",50917,10.766667,76.383333 ],
    [ u"in",u"Pachmarhi",3228,22.466667,78.433333 ],
    [ u"in",u"Pachora",46827,20.666667,75.35 ],
    [ u"in",u"Pachperwa",15057,27.516667,82.65 ],
    [ u"in",u"Padampur",16389,20.983333,83.066667 ],
    [ u"in",u"Padampur",18455,29.683333,73.616667 ],
    [ u"in",u"Paddhari",9702,22.433333,70.6 ],
    [ u"in",u"Padmanabhapuram",20214,8.233333,77.333333 ],
    [ u"in",u"Padra",36501,22.233333,73.083333 ],
    [ u"in",u"Padrauna",47186,26.9025,83.981944 ],
    [ u"in",u"Pahalgam",7753,34.033333,75.333333 ],
    [ u"in",u"Pahasu",18856,28.183333,78.05 ],
    [ u"in",u"Paithan",37363,19.483333,75.383333 ],
    [ u"in",u"Pakala",24680,13.466667,79.116667 ],
    [ u"in",u"Pakaur",40450,24.633333,87.85 ],
    [ u"in",u"Palakkad",132740,10.7725,76.651389 ],
    [ u"in",u"Palakkodu",19632,12.3,78.083333 ],
    [ u"in",u"Palakollu",57346,16.533333,81.733333 ],
    [ u"in",u"Palamedu",8435,10.116667,78.116667 ],
    [ u"in",u"Palampur",4131,32.116667,76.533333 ],
    [ u"in",u"Palani",66091,10.466667,77.533333 ],
    [ u"in",u"Palanpur",123301,24.166667,72.433333 ],
    [ u"in",u"Palasa",65892,18.766667,84.416667 ],
    [ u"in",u"Palasbari",4714,26.136111,91.548611 ],
    [ u"in",u"Pale",5428,15.466667,74.083333 ],
    [ u"in",u"Palera",16555,25.016667,79.233333 ],
    [ u"in",u"Palghar",72383,19.683333,72.75 ],
    [ u"in",u"Palia Kalan",38551,28.45,80.583333 ],
    [ u"in",u"Pali",210117,25.766667,73.333333 ],
    [ u"in",u"Pali",21290,23.35,81.05 ],
    [ u"in",u"Pali",9099,24.483333,78.416667 ],
    [ u"in",u"Palitana",55916,21.516667,71.833333 ],
    [ u"in",u"Paliyad",10862,22.25,71.566667 ],
    [ u"in",u"Palkonda",29378,18.6,83.75 ],
    [ u"in",u"Palladam",31938,10.983333,77.3 ],
    [ u"in",u"Pallapatti",20283,10.7,77.883333 ],
    [ u"in",u"Pallattur",8187,10.15,78.8 ],
    [ u"in",u"Pallavaram",157158,12.976111,80.183611 ],
    [ u"in",u"Pallikonda",21337,12.916667,78.933333 ],
    [ u"in",u"Pallipattu",8912,13.333333,79.45 ],
    [ u"in",u"Palmaner",42178,13.2,78.75 ],
    [ u"in",u"Palwal",121974,28.15,77.333333 ],
    [ u"in",u"Panagar",26622,23.3,79.983333 ],
    [ u"in",u"Panaji",65593,15.483333,73.833333 ],
    [ u"in",u"Panapakkam",10611,13.5,79.216667 ],
    [ u"in",u"Panara",4097,22.066667,78.55 ],
    [ u"in",u"Panchgani",14401,17.916667,73.816667 ],
    [ u"in",u"Panchla",23528,22.543889,88.138056 ],
    [ u"in",u"Pandaria",13875,22.233333,81.416667 ],
    [ u"in",u"Pandavapura",19052,12.500556,76.673333 ],
    [ u"in",u"Pandhana",11627,21.7,76.216667 ],
    [ u"in",u"Pandharpur",95673,17.666667,75.333333 ],
    [ u"in",u"Pandhurna",43635,21.6,78.516667 ],
    [ u"in",u"Pandoh",4351,31.683333,77.05 ],
    [ u"in",u"Pandua",28208,23.083333,88.283333 ],
    [ u"in",u"Panhala",3634,16.816667,74.116667 ],
    [ u"in",u"Panihati",378741,22.694167,88.374444 ],
    [ u"in",u"Panipat",292828,29.388889,76.968056 ],
    [ u"in",u"Panna",46796,24.716667,80.2 ],
    [ u"in",u"Pansemal",11184,21.65,74.7 ],
    [ u"in",u"Panvel",128056,18.983333,73.1 ],
    [ u"in",u"Paonta Sahib",21788,30.45,77.616667 ],
    [ u"in",u"Papanasam",16839,10.933333,79.283333 ],
    [ u"in",u"Papparapatti",11617,12.216667,78.066667 ],
    [ u"in",u"Pappinisseri",34028,11.95,75.35 ],
    [ u"in",u"Paradip",3608,20.316667,86.616667 ],
    [ u"in",u"Paradwip",85875,20.316667,86.616667 ],
    [ u"in",u"Parasia",39444,22.2,78.766667 ],
    [ u"in",u"Paravur",38949,8.783333,76.7 ],
    [ u"in",u"Parbhani",289652,19.266667,76.783333 ],
    [ u"in",u"Pardi",27425,20.516667,72.95 ],
    [ u"in",u"Parichha",7399,25.516667,78.75 ],
    [ u"in",u"Parichhatgarh",18992,28.983333,77.933333 ],
    [ u"in",u"Parlakimidi",45383,18.766667,84.083333 ],
    [ u"in",u"Parli",94871,18.85,76.533333 ],
    [ u"in",u"Parnera",11435,20.55,72.95 ],
    [ u"in",u"Parola",37004,20.883333,75.116667 ],
    [ u"in",u"Parole",7801,32.35,75.433333 ],
    [ u"in",u"Partapur",10081,23.6,74.166667 ],
    [ u"in",u"Partur",30993,19.6,76.216667 ],
    [ u"in",u"Parvatipuram",52090,18.783333,83.433333 ],
    [ u"in",u"Parvatsar",15406,26.883333,74.766667 ],
    [ u"in",u"Pasan",30932,22.85,82.2 ],
    [ u"in",u"Pasighat",25584,28.066667,95.333333 ],
    [ u"in",u"Patamundai",34403,20.566667,86.566667 ],
    [ u"in",u"Patancheru",46827,17.531389,78.265 ],
    [ u"in",u"Patan",117871,23.833333,72.116667 ],
    [ u"in",u"Patan",12156,17.366667,73.9 ],
    [ u"in",u"Patan",14123,23.3,79.7 ],
    [ u"in",u"Patan",9333,21.033333,81.533333 ],
    [ u"in",u"Pathalgaon",15396,22.566667,83.466667 ],
    [ u"in",u"Pathanamthitta",38288,9.266667,76.783333 ],
    [ u"in",u"Pathankot",174319,32.283333,75.65 ],
    [ u"in",u"Pathardih",45281,23.666667,86.433333 ],
    [ u"in",u"Pathardi",24093,19.166667,75.183333 ],
    [ u"in",u"Patharia",18360,23.9,79.2 ],
    [ u"in",u"Pathri",37651,19.25,76.45 ],
    [ u"in",u"Patiala",329248,30.326667,76.400278 ],
    [ u"in",u"Patnagarh",19583,20.716667,83.15 ],
    [ u"in",u"Patna",1600085,25.6,85.116667 ],
    [ u"in",u"Patrasaer",11520,23.216667,87.516667 ],
    [ u"in",u"Patratu",31703,23.666667,85.283333 ],
    [ u"in",u"Pattan",14971,34.166667,74.566667 ],
    [ u"in",u"Patti",37090,31.280833,74.857222 ],
    [ u"in",u"Patti",9686,25.916667,82.2 ],
    [ u"in",u"Pattukkottai",67988,10.433333,79.316667 ],
    [ u"in",u"Patuli",4694,23.55,88.25 ],
    [ u"in",u"Patur",21748,20.45,76.933333 ],
    [ u"in",u"Pauri",26517,30.15,78.783333 ],
    [ u"in",u"Pavagada",32065,14.1,77.266667 ],
    [ u"in",u"Pawai",13085,24.266667,80.166667 ],
    [ u"in",u"Pawayan",25710,28.066667,80.1 ],
    [ u"in",u"Payyannur",70075,12.1,75.2 ],
    [ u"in",u"Pedana",30256,16.266667,81.166667 ],
    [ u"in",u"Peddapalli",33581,18.616667,79.366667 ],
    [ u"in",u"Peddapuram",45972,17.083333,82.133333 ],
    [ u"in",u"Pehowa",39104,29.983333,76.583333 ],
    [ u"in",u"Pendra",12638,22.766667,81.95 ],
    [ u"in",u"Pennadam",17662,11.4,79.233333 ],
    [ u"in",u"Pennagaram",15758,12.133333,77.9 ],
    [ u"in",u"Pennathur",8257,12.25,79.233333 ],
    [ u"in",u"Pen",34094,18.75,73.083333 ],
    [ u"in",u"Penugonda",23659,16.666667,81.733333 ],
    [ u"in",u"Penukonda",20220,14.083333,77.583333 ],
    [ u"in",u"Peraiyur",9245,9.716667,77.8 ],
    [ u"in",u"Perambalur",30802,11.233333,78.883333 ],
    [ u"in",u"Peranamallur",5722,12.566667,79.433333 ],
    [ u"in",u"Peravurani",21663,10.3,79.183333 ],
    [ u"in",u"Periyakulam",40134,10.116667,77.55 ],
    [ u"in",u"Periyanayakkanpalaiyam",24896,11.15,76.933333 ],
    [ u"in",u"Periyanegamam",7913,10.733333,77.1 ],
    [ u"in",u"Periyapatti",10646,10.75,77.266667 ],
    [ u"in",u"Pernem",5555,15.716667,73.8 ],
    [ u"in",u"Perumpavur",27108,10.133333,76.483333 ],
    [ u"in",u"Perundurai",17488,11.266667,77.583333 ],
    [ u"in",u"Perur",8342,10.966667,76.9 ],
    [ u"in",u"Petlad",51823,22.466667,72.8 ],
    [ u"in",u"Petlawad",13262,23,74.8 ],
    [ u"in",u"Phagwara",100154,31.217778,75.769444 ],
    [ u"in",u"Phalauda",18547,29.183333,77.816667 ],
    [ u"in",u"Phalodi",46792,27.133333,72.366667 ],
    [ u"in",u"Phaltan",53206,17.983333,74.433333 ],
    [ u"in",u"Phaphund",16677,26.6,79.466667 ],
    [ u"in",u"Phek",15119,25.666667,94.5 ],
    [ u"in",u"Phillaur",22590,31.029167,75.784167 ],
    [ u"in",u"Phirangipuram",17335,16.3,80.266667 ],
    [ u"in",u"Phulabani",36616,20.466667,84.233333 ],
    [ u"in",u"Phulera",22574,26.866667,75.233333 ],
    [ u"in",u"Phulpur",22888,25.55,82.1 ],
    [ u"in",u"Pihani",30372,27.633333,80.2 ],
    [ u"in",u"Pilani",28151,28.3684,75.6041 ],
    [ u"in",u"Pilibanga",36757,29.45,74.083333 ],
    [ u"in",u"Pilibhit",131021,28.633333,79.8 ],
    [ u"in",u"Pilkhuwa",74219,28.716667,77.65 ],
    [ u"in",u"Pimpri",1284702,18.616667,73.8 ],
    [ u"in",u"Pinahat",19513,26.883889,78.378056 ],
    [ u"in",u"Pindwara",23230,24.8,73.066667 ],
    [ u"in",u"Pinjaur",32164,30.797222,76.917222 ],
    [ u"in",u"Pipar",34633,26.385556,73.537778 ],
    [ u"in",u"Pipili",15302,20.116667,85.833333 ],
    [ u"in",u"Piploda",7720,23.35,75.433333 ],
    [ u"in",u"Pipraich",15858,26.826389,83.53 ],
    [ u"in",u"Pipri",13584,24.2,82.833333 ],
    [ u"in",u"Pipri",13584,24.183333,83 ],
    [ u"in",u"Piravam",28254,9.866667,76.5 ],
    [ u"in",u"Pirawa",11791,24.166667,76.033333 ],
    [ u"in",u"Piriyapatna",16101,12.339722,76.099167 ],
    [ u"in",u"Piro",28970,25.333333,84.416667 ],
    [ u"in",u"Pithapuram",52715,17.116667,82.266667 ],
    [ u"in",u"Pithoragarh",47576,29.583333,80.216667 ],
    [ u"in",u"Pithora",7593,21.266667,82.516667 ],
    [ u"in",u"Pokaran",21015,26.916667,71.916667 ],
    [ u"in",u"Poladpur",5660,17.983333,83.466667 ],
    [ u"in",u"Polasara",20578,19.7,84.816667 ],
    [ u"in",u"Pollachi",88221,10.666667,77.016667 ],
    [ u"in",u"Polur",26293,12.5,79.133333 ],
    [ u"in",u"Ponda",18900,15.4,74.016667 ],
    [ u"in",u"Pondicherry",227434,11.93,79.83 ],
    [ u"in",u"Ponnampet",6117,12.15,75.933333 ],
    [ u"in",u"Ponnani",105521,10.766667,75.9 ],
    [ u"in",u"Ponneri",24758,13.316667,80.2 ],
    [ u"in",u"Porbandar",138881,21.633333,69.6 ],
    [ u"in",u"Porsa",37827,26.67,78.374722 ],
    [ u"in",u"Port Blair",112062,11.666667,92.75 ],
    [ u"in",u"Pratapgarh",37782,24.033333,74.783333 ],
    [ u"in",u"Pratapgarh",13673,25.933333,81.983333 ],
    [ u"in",u"Proddatur",177816,14.733333,78.55 ],
    [ u"in",u"Pudukkottai",112128,10.383333,78.816667 ],
    [ u"in",u"Pudur",11432,13,79.15 ],
    [ u"in",u"Pujali",45415,22.465278,88.151667 ],
    [ u"in",u"Pukhrayan",22557,26.233333,79.85 ],
    [ u"in",u"Pulgaon",35241,20.733333,78.333333 ],
    [ u"in",u"Pulivendla",33615,14.416667,78.233333 ],
    [ u"in",u"Puliyankudi",62499,9.166667,77.416667 ],
    [ u"in",u"Puliyur",11174,10.633333,78.833333 ],
    [ u"in",u"Pullampadi",10288,10.966667,78.916667 ],
    [ u"in",u"Pulwama",20073,33.883333,74.916667 ],
    [ u"in",u"Punahana",15333,27.866667,77.2 ],
    [ u"in",u"Punalur",47267,9,76.933333 ],
    [ u"in",u"Pundri",17534,29.75,76.55 ],
    [ u"in",u"Pune",2935968,18.533333,73.866667 ],
    [ u"in",u"Punganuru",48870,13.366667,78.583333 ],
    [ u"in",u"Punjai Puliyampatti",15068,11.35,77.2 ],
    [ u"in",u"Puranpur",39992,28.516667,80.15 ],
    [ u"in",u"Puri",170856,19.8,85.85 ],
    [ u"in",u"Purna",34891,19.183333,77.05 ],
    [ u"in",u"Purnia",198474,25.783333,87.466667 ],
    [ u"in",u"Puruliya",122544,23.333333,86.366667 ],
    [ u"in",u"Purushottampur",14709,19.533333,84.883333 ],
    [ u"in",u"Purwa",22223,26.466667,80.783333 ],
    [ u"in",u"Pusad",71593,19.9,77.583333 ],
    [ u"in",u"Pushkar",16174,26.5,74.55 ],
    [ u"in",u"Puttur",30990,13.45,79.55 ],
    [ u"in",u"Puttur",53336,12.766667,75.216667 ],
    [ u"in",u"Qadian",21016,31.817778,75.391944 ],
    [ u"in",u"Qazigund",5578,33.633333,75.15 ],
    [ u"in",u"Quepem",13042,15.216667,74.066667 ],
    [ u"in",u"Queula",5699,15.383333,73.966667 ],
    [ u"in",u"Rabkavi",73841,16.466667,75.1 ],
    [ u"in",u"Rabupura",13950,28.25,77.6 ],
    [ u"in",u"Radaur",12329,30.033333,77.15 ],
    [ u"in",u"Radha Kund",6421,27.533333,77.483333 ],
    [ u"in",u"Radhanpur",35459,23.833333,71.6 ],
    [ u"in",u"Rae Bareli",186451,26.216667,81.233333 ],
    [ u"in",u"Rafiganj",26231,24.816667,84.65 ],
    [ u"in",u"Raghogarh",63880,24.45,77.2 ],
    [ u"in",u"Raghudebbati",12834,22.525556,88.195833 ],
    [ u"in",u"Raghunathpur",22804,23.55,86.666667 ],
    [ u"in",u"Raghunathpur",6100,25.633333,87.9 ],
    [ u"in",u"Raha",4724,26.233333,92.516667 ],
    [ u"in",u"Rahatgarh",27465,23.783333,78.366667 ],
    [ u"in",u"Rahimatpur",17261,17.6,74.2 ],
    [ u"in",u"Rahon",12486,31.05,76.116667 ],
    [ u"in",u"Rahuri",36888,19.383333,74.65 ],
    [ u"in",u"Raia",9421,15.3,73.966667 ],
    [ u"in",u"Raichur",225981,16.2,77.366667 ],
    [ u"in",u"Raiganj",170268,25.616667,88.116667 ],
    [ u"in",u"Raigarh",121291,21.9,83.4 ],
    [ u"in",u"Raikot",26116,30.65,75.6 ],
    [ u"in",u"Raipur",17537,26.05,74.016667 ],
    [ u"in",u"Raipur",680066,21.233333,81.633333 ],
    [ u"in",u"Raipur",27705,30.316667,78.1 ],
    [ u"in",u"Rairangpur",23074,22.266667,86.166667 ],
    [ u"in",u"Raisen",40982,23.333333,77.8 ],
    [ u"in",u"Raisinghnagar",29628,29.535833,73.449167 ],
    [ u"in",u"Raiwala",5198,30.016667,78.216667 ],
    [ u"in",u"Rajakhera",30630,26.896111,78.171389 ],
    [ u"in",u"Rajaldesar",24105,28.033333,74.466667 ],
    [ u"in",u"Rajamahendri",304838,16.983333,81.783333 ],
    [ u"in",u"Rajampet",31079,14.183333,79.166667 ],
    [ u"in",u"Rajapalaiyam",124179,9.45,77.566667 ],
    [ u"in",u"Rajapur",10718,16.666667,73.516667 ],
    [ u"in",u"Rajapur",13963,25.383333,81.15 ],
    [ u"in",u"Raja Sansi",12958,31.719167,74.797778 ],
    [ u"in",u"Rajauri",27803,33.383333,74.3 ],
    [ u"in",u"Rajgarh",2866,30.85,77.3 ],
    [ u"in",u"Rajgarh",26955,27.233333,76.633333 ],
    [ u"in",u"Rajgarh",17115,22.683333,74.95 ],
    [ u"in",u"Rajgir",38352,25.033333,85.416667 ],
    [ u"in",u"Rajgurunagar",18846,18.866667,73.9 ],
    [ u"in",u"Rajkot",1177434,22.3,70.783333 ],
    [ u"in",u"Rajmahal",19713,25.05,87.833333 ],
    [ u"in",u"Rajnagar",13391,24.733333,79.95 ],
    [ u"in",u"Rajpipla",35394,21.783333,73.566667 ],
    [ u"in",u"Rajpura",86827,30.483056,76.595 ],
    [ u"in",u"Rajpur",444549,22.4125,88.418056 ],
    [ u"in",u"Rajpur",19398,21.933333,75.133333 ],
    [ u"in",u"Rajsamand",63419,25.066667,73.883333 ],
    [ u"in",u"Rajula",34655,21.05,71.433333 ],
    [ u"in",u"Rajura",28883,19.783333,79.366667 ],
    [ u"in",u"Rajur",11935,20.116667,78.916667 ],
    [ u"in",u"Ramachandrapuram",42982,16.85,82.016667 ],
    [ u"in",u"Ramanagaram",93535,12.716667,77.3 ],
    [ u"in",u"Ramanathapuram",65320,9.383333,78.833333 ],
    [ u"in",u"Ramanuj Ganj",10702,23.8,83.7 ],
    [ u"in",u"Ramapuram",31169,13.116667,79.2 ],
    [ u"in",u"Ramban",7320,33.25,75.25 ],
    [ u"in",u"Rambha",11277,19.516667,85.1 ],
    [ u"in",u"Ramchandrapur",9665,22.896389,88.475278 ],
    [ u"in",u"Ram Das",6191,31.966111,74.904722 ],
    [ u"in",u"Rameswaram",39964,9.283333,79.3 ],
    [ u"in",u"Ramganj Mandi",35757,24.65,75.933333 ],
    [ u"in",u"Ramgarh",4945,33.4,74.2 ],
    [ u"in",u"Ramgarh",29836,27.25,75.183333 ],
    [ u"in",u"Ramgarh",83842,23.633333,85.516667 ],
    [ u"in",u"Ramjibanpur",18319,22.833333,87.616667 ],
    [ u"in",u"Ramkola",13950,26.904167,83.841111 ],
    [ u"in",u"Ramnagar",8167,32.816667,75.316667 ],
    [ u"in",u"Ramnagar",5195,22.777778,88.246389 ],
    [ u"in",u"Ramnagar",43502,27.166667,84.316667 ],
    [ u"in",u"Ramnagar",13491,27.083333,81.416667 ],
    [ u"in",u"Ramnagar",51249,29.4,79.116667 ],
    [ u"in",u"Rampura",45642,30.25,75.233333 ],
    [ u"in",u"Rampura",18497,24.466667,75.433333 ],
    [ u"in",u"Rampura",11348,26.3497,79.1833 ],
    [ u"in",u"Rampur Hat",53473,24.166667,87.783333 ],
    [ u"in",u"Rampur",6206,31.45,77.633333 ],
    [ u"in",u"Rampur",296447,28.816667,79.033333 ],
    [ u"in",u"Ramtek",23405,21.4,79.333333 ],
    [ u"in",u"Ranaghat",70991,23.183333,88.583333 ],
    [ u"in",u"Ranapur",10677,22.65,74.533333 ],
    [ u"in",u"Ranavav",26012,21.684167,69.740833 ],
    [ u"in",u"Ranchi",945079,23.35,85.333333 ],
    [ u"in",u"Rangapara",18740,26.816667,92.65 ],
    [ u"in",u"Rangia",26389,26.466667,91.633333 ],
    [ u"in",u"Rangpo",4026,27.183333,88.533333 ],
    [ u"in",u"Rania",22741,29.533333,74.833333 ],
    [ u"in",u"Ranibennur",99113,14.616667,75.616667 ],
    [ u"in",u"Raniganj",131274,23.616667,87.133333 ],
    [ u"in",u"Ranikhet",19875,29.65,79.416667 ],
    [ u"in",u"Ranipur",18822,25.25,79.066667 ],
    [ u"in",u"Rani",13573,25.366667,73.3 ],
    [ u"in",u"Ranir Bazar",11811,23.833333,91.366667 ],
    [ u"in",u"Rapar",21507,23.566667,70.633333 ],
    [ u"in",u"Rasipuram",48954,11.466667,78.166667 ],
    [ u"in",u"Rasra",31879,25.85,83.85 ],
    [ u"in",u"Rasulabad",7801,26.75,80.483333 ],
    [ u"in",u"Ratangarh",66630,28.083333,74.6 ],
    [ u"in",u"Ratangarh",7495,24.816667,75.116667 ],
    [ u"in",u"Ratanpur",21395,22.3,82.166667 ],
    [ u"in",u"Rath",61734,25.583333,79.566667 ],
    [ u"in",u"Ratlam",236868,23.316667,75.066667 ],
    [ u"in",u"Ratnagiri",75993,16.983333,73.3 ],
    [ u"in",u"Raurkela",226886,22.2,84.883333 ],
    [ u"in",u"Raver",26637,21.25,76.033333 ],
    [ u"in",u"Rawatbhata",36874,24.933333,75.583333 ],
    [ u"in",u"Rawatsar",31018,29.283333,74.383333 ],
    [ u"in",u"Raxaul",47970,26.983333,84.85 ],
    [ u"in",u"Rayachoti",81442,14.05,78.75 ],
    [ u"in",u"Rayadrug",59975,14.7,76.866667 ],
    [ u"in",u"Rayagada",61410,19.166667,83.416667 ],
    [ u"in",u"Raya",20010,27.566667,77.783333 ],
    [ u"in",u"Raybag",17390,16.483333,74.783333 ],
    [ u"in",u"Raypur",6907,22.410833,88.509444 ],
    [ u"in",u"Ray",5949,23.683333,85.05 ],
    [ u"in",u"Razam",27835,18.466667,83.666667 ],
    [ u"in",u"Razole",14203,16.483333,81.833333 ],
    [ u"in",u"Redhakhol",14367,21.066667,84.35 ],
    [ u"in",u"Rehli",27708,23.633333,79.083333 ],
    [ u"in",u"Rehti",10718,22.733333,77.433333 ],
    [ u"in",u"Remuna",30319,21.526111,86.872222 ],
    [ u"in",u"Rengali",7704,21.633333,84.05 ],
    [ u"in",u"Renigunta",25898,13.65,79.516667 ],
    [ u"in",u"Renukut",62419,24.2,83.033333 ],
    [ u"in",u"Reoti",23821,25.85,84.383333 ],
    [ u"in",u"Repalle",42972,16.016667,80.85 ],
    [ u"in",u"Revadanda",10415,18.550278,72.927778 ],
    [ u"in",u"Revelganj",37035,25.783333,84.666667 ],
    [ u"in",u"Rewa",208483,24.533333,81.3 ],
    [ u"in",u"Rewari",112087,28.183333,76.616667 ],
    [ u"in",u"Richha",19461,28.7,79.516667 ],
    [ u"in",u"Ringas",25173,27.35,75.566667 ],
    [ u"in",u"Rishikesh",66397,30.116667,78.316667 ],
    [ u"in",u"Rishra",117026,22.714167,88.347778 ],
    [ u"in",u"Risod",30134,19.966667,76.783333 ],
    [ u"in",u"Robertsganj",37858,24.7,83.066667 ],
    [ u"in",u"Robertsonpet",135229,12.966667,78.283333 ],
    [ u"in",u"Rohru",8164,31.216667,77.75 ],
    [ u"in",u"Rohtak",317266,28.9,76.566667 ],
    [ u"in",u"Ron",22595,15.666667,75.733333 ],
    [ u"in",u"Rudarpur",30876,26.439444,83.614444 ],
    [ u"in",u"Rudraprayag",2571,30.283333,78.983333 ],
    [ u"in",u"Rupnagar",52317,30.966389,76.533056 ],
    [ u"in",u"Rura",15909,26.483333,79.9 ],
    [ u"in",u"Rusera",28784,25.75,86.033333 ],
    [ u"in",u"Sabalgarh",31035,26.25,77.4 ],
    [ u"in",u"Sabathu",6692,30.971944,76.993333 ],
    [ u"in",u"Sabrum",6206,23,91.731944 ],
    [ u"in",u"Sachin",12661,21.083333,72.883333 ],
    [ u"in",u"Sadabad",36097,27.45,78.05 ],
    [ u"in",u"Sadalgi",22137,16.566667,74.55 ],
    [ u"in",u"Sadasivpet",37249,17.616667,77.95 ],
    [ u"in",u"Sadat",11212,25.683333,83.283333 ],
    [ u"in",u"Sadri",25634,25.183333,73.433333 ],
    [ u"in",u"Safidon",30865,29.416667,76.666667 ],
    [ u"in",u"Safipur",24804,26.733333,80.35 ],
    [ u"in",u"Sagar",53155,14.166667,75.033333 ],
    [ u"in",u"Sagar",247359,23.833333,78.716667 ],
    [ u"in",u"Sagauli",34626,26.783333,84.733333 ],
    [ u"in",u"Sahapur",7883,22.524444,88.166944 ],
    [ u"in",u"Saharanpur",484921,29.966667,77.55 ],
    [ u"in",u"Saharsa",145779,25.883333,86.6 ],
    [ u"in",u"Sahaspur",24454,29.133333,78.616667 ],
    [ u"in",u"Sahaswan",60959,28.083333,78.75 ],
    [ u"in",u"Sahawar",22203,27.8,78.85 ],
    [ u"in",u"Sahibganj",95900,25.25,87.65 ],
    [ u"in",u"Saidpur",14498,28.616667,77.916667 ],
    [ u"in",u"Saiha",22657,22.483333,92.966667 ],
    [ u"in",u"Sailana",10811,23.466667,74.916667 ],
    [ u"in",u"Sainthia",43225,23.95,87.666667 ],
    [ u"in",u"Saint Thomas Mount",43227,12.996389,80.203056 ],
    [ u"in",u"Sairang",5760,23.8,92.666667 ],
    [ u"in",u"Sakit",7811,27.45,78.816667 ],
    [ u"in",u"Sakleshpur",24934,12.966667,75.783333 ],
    [ u"in",u"Sakti",21563,22.033333,82.966667 ],
    [ u"in",u"Salaya",30230,22.316667,69.6 ],
    [ u"in",u"Saligao",5804,15.55,73.766667 ],
    [ u"in",u"Salimpur",18766,26.433333,84.616667 ],
    [ u"in",u"Salon",14313,26.033333,81.45 ],
    [ u"in",u"Salumbar",16558,24.133333,74.05 ],
    [ u"in",u"Salur",50212,18.533333,83.216667 ],
    [ u"in",u"Samalkha",35622,29.233333,77.016667 ],
    [ u"in",u"Samalkot",55104,17.05,82.183333 ],
    [ u"in",u"Samana",50536,30.158333,76.193056 ],
    [ u"in",u"Samastipur",57602,25.85,85.783333 ],
    [ u"in",u"Sambalpur",162901,21.45,83.966667 ],
    [ u"in",u"Samba",26903,32.566667,75.116667 ],
    [ u"in",u"Sambhal",196129,28.583333,78.55 ],
    [ u"in",u"Sambhar",22830,26.916667,75.2 ],
    [ u"in",u"Samdari",17915,25.816667,72.583333 ],
    [ u"in",u"Samrala",18624,30.836667,76.189722 ],
    [ u"in",u"Samthar",21584,25.85,78.916667 ],
    [ u"in",u"Sanand",35035,22.983333,72.383333 ],
    [ u"in",u"Sanaur",18402,30.3025,76.455278 ],
    [ u"in",u"Sanawad",36459,22.183333,76.066667 ],
    [ u"in",u"Sanchi",7302,23.483333,77.733333 ],
    [ u"in",u"Sanchor",29024,24.755278,71.772222 ],
    [ u"in",u"Sancoale",16312,15.366667,73.9 ],
    [ u"in",u"Sandila",53188,27.083333,80.516667 ],
    [ u"in",u"Sandi",25010,27.3,79.95 ],
    [ u"in",u"Sandur",29016,15.1,76.55 ],
    [ u"in",u"Sangamner",67315,19.566667,74.216667 ],
    [ u"in",u"Sangareddi",59205,17.629444,78.091667 ],
    [ u"in",u"Sangod",19844,24.916667,76.283333 ],
    [ u"in",u"Sangrur",88622,30.233333,75.833333 ],
    [ u"in",u"Sanguem",6120,15.233333,74.166667 ],
    [ u"in",u"Sanivarsante",4432,12.733333,75.9 ],
    [ u"in",u"Sankarpur",6244,22.848056,88.455278 ],
    [ u"in",u"Sankeshwar",34552,16.266667,74.483333 ],
    [ u"in",u"Sankheda",12077,22.166667,73.583333 ],
    [ u"in",u"Sankrail",27526,22.55,88.2 ],
    [ u"in",u"Sanquelim",11698,15.583333,74 ],
    [ u"in",u"Santokhgarh",8878,31.366667,76.316667 ],
    [ u"in",u"Santoshpur",7636,22.525278,88.265 ],
    [ u"in",u"Sanvordem",5051,15.266667,74.116667 ],
    [ u"in",u"Sanwer",14216,22.983333,75.833333 ],
    [ u"in",u"Sapatgram",11714,26.333442,90.109048 ],
    [ u"in",u"Sarahan",1495,31.516667,77.8 ],
    [ u"in",u"Saraikela",12665,22.716667,85.95 ],
    [ u"in",u"Sarai Mir",17851,26.016667,82.916667 ],
    [ u"in",u"Saraipali",18396,21.333333,83 ],
    [ u"in",u"Sarangarh",14617,21.6,83.083333 ],
    [ u"in",u"Sarangpur",35831,23.566667,76.466667 ],
    [ u"in",u"Sarauli",20925,28.5,79.1 ],
    [ u"in",u"Sardarpur",6710,22.666667,74.983333 ],
    [ u"in",u"Sardarshahr",86678,28.433333,74.483333 ],
    [ u"in",u"Sardhana",49862,29.15,77.616667 ],
    [ u"in",u"Sardulgarh",17270,29.7,75.25 ],
    [ u"in",u"Sargur",10983,11.983333,76.416667 ],
    [ u"in",u"Sarila",8013,25.766667,79.683333 ],
    [ u"in",u"Sarka Ghat",3944,31.7,76.733333 ],
    [ u"in",u"Sarkhej",30350,22.983333,72.5 ],
    [ u"in",u"Sarwar",17861,26.066667,75 ],
    [ u"in",u"Sasaram",145798,24.95,84.033333 ],
    [ u"in",u"Sasni",13499,27.716667,78.083333 ],
    [ u"in",u"Sasvad",29861,18.333333,74.033333 ],
    [ u"in",u"Satana",34443,20.583333,74.2 ],
    [ u"in",u"Satara",112802,17.683333,73.983333 ],
    [ u"in",u"Satna",257805,24.583333,80.833333 ],
    [ u"in",u"Satrikh",11024,26.866667,81.2 ],
    [ u"in",u"Sattankulam",14085,8.45,77.933333 ],
    [ u"in",u"Sattenapalle",53609,16.4,80.183333 ],
    [ u"in",u"Sattur",31859,9.366667,77.933333 ],
    [ u"in",u"Satwas",12117,22.533333,76.683333 ],
    [ u"in",u"Saundatti Yellamma",40095,15.783333,75.116667 ],
    [ u"in",u"Saurikh",12056,27.029,79.4896 ],
    [ u"in",u"Sausar",26707,21.65,78.783333 ],
    [ u"in",u"Savantvadi",23386,15.9,73.816667 ],
    [ u"in",u"Savanur",37823,14.966667,75.35 ],
    [ u"in",u"Savda",19905,21.15,75.883333 ],
    [ u"in",u"Sawai Madhopur",108620,25.983333,76.366667 ],
    [ u"in",u"Sayalgudi",12415,9.183333,78.45 ],
    [ u"in",u"Sayla",15376,22.55,71.466667 ],
    [ u"in",u"Sedam",35137,17.183333,77.283333 ],
    [ u"in",u"Sehore",99294,23.2,77.083333 ],
    [ u"in",u"Selam",778462,11.65,78.166667 ],
    [ u"in",u"Selu",42882,19.466667,76.466667 ],
    [ u"in",u"Semaria",14046,24.8,81.15 ],
    [ u"in",u"Sendhwa",54535,21.683333,75.1 ],
    [ u"in",u"Seohara",46551,29.216667,78.583333 ],
    [ u"in",u"Seondha",21328,26.157778,78.779722 ],
    [ u"in",u"Seoni Malwa",28337,22.45,77.466667 ],
    [ u"in",u"Seoni",1630,31.243611,77.123056 ],
    [ u"in",u"Seoni",101389,22.083333,79.533333 ],
    [ u"in",u"Serchhip",20246,23.3,92.833333 ],
    [ u"in",u"Serula",10632,15.533333,73.833333 ],
    [ u"in",u"Shahabad",39325,30.1681,76.8715 ],
    [ u"in",u"Shahabad",52957,17.133333,76.933333 ],
    [ u"in",u"Shahabad",34966,28.566667,79.016667 ],
    [ u"in",u"Shahada",58407,21.466667,74.3 ],
    [ u"in",u"Shahapur",10966,19.45,73.333333 ],
    [ u"in",u"Shahdol",89298,23.283333,81.35 ],
    [ u"in",u"Shahganj",26513,26.05,82.683333 ],
    [ u"in",u"Shahgarh",14837,24.316667,79.133333 ],
    [ u"in",u"Shahi",16066,28.55,79.316667 ],
    [ u"in",u"Shahjahanpur",320466,27.883333,79.916667 ],
    [ u"in",u"Shahkot",13578,31.0775,75.337222 ],
    [ u"in",u"Shahpura",29261,25.633333,74.933333 ],
    [ u"in",u"Shahpura",12814,23.133333,79.666667 ],
    [ u"in",u"Shahpur",12867,22.15,70.766667 ],
    [ u"in",u"Shahpur",31425,16.7,76.833333 ],
    [ u"in",u"Shahpur",15852,25.583333,84.45 ],
    [ u"in",u"Shahpur",13068,23.883333,79.05 ],
    [ u"in",u"Shahpur",18876,29.35,77.55 ],
    [ u"in",u"Shaikhpura",46723,25.15,85.85 ],
    [ u"in",u"Shajapur",53352,23.433333,76.266667 ],
    [ u"in",u"Sham Churasi",4403,31.499722,75.749444 ],
    [ u"in",u"Shamgarh",23078,24.183333,75.633333 ],
    [ u"in",u"Shamli",97976,29.45,77.316667 ],
    [ u"in",u"Shamsabad",25268,27.533333,79.433333 ],
    [ u"in",u"Shankargarh",14139,25.183333,81.616667 ],
    [ u"in",u"Shantipur",149998,23.25,88.466667 ],
    [ u"in",u"Shegaon",56453,20.783333,76.683333 ],
    [ u"in",u"Sheoganj",26806,25.15,73.066667 ],
    [ u"in",u"Sheopur",62422,25.666667,76.7 ],
    [ u"in",u"Shergarh",14078,28.65,79.35 ],
    [ u"in",u"Sherghati",35283,24.566667,84.783333 ],
    [ u"in",u"Sherkot",57367,29.35,78.583333 ],
    [ u"in",u"Shertallai",45479,9.7,76.333333 ],
    [ u"in",u"Shiggaon",26120,15,75.233333 ],
    [ u"in",u"Shikarpur",33276,14.266667,75.35 ],
    [ u"in",u"Shikarpur",34652,28.283333,78.016667 ],
    [ u"in",u"Shikohabad",99688,27.1,78.6 ],
    [ u"in",u"Shiliguri",515623,26.716111,88.423611 ],
    [ u"in",u"Shillong",132853,25.575556,91.873056 ],
    [ u"in",u"Shimla",173517,31.103333,77.172222 ],
    [ u"in",u"Shimoga",319577,13.922222,75.573611 ],
    [ u"in",u"Shirdi",31980,19.766667,74.483333 ],
    [ u"in",u"Shirgaon",5844,19.7,72.7 ],
    [ u"in",u"Shirhatti",16605,15.233333,75.583333 ],
    [ u"in",u"Shirpur",69545,21.35,74.883333 ],
    [ u"in",u"Shirwal",12703,18.133333,73.983333 ],
    [ u"in",u"Shivrajpur",6705,22.416667,73.65 ],
    [ u"in",u"Sholapur",997358,17.683333,75.916667 ],
    [ u"in",u"Sholavandan",22318,10.016667,77.966667 ],
    [ u"in",u"Shoranur",42698,10.766667,76.283333 ],
    [ u"in",u"Shorapur",49505,16.516667,76.75 ],
    [ u"in",u"Shrigonda",28210,18.616667,74.683333 ],
    [ u"in",u"Shrirampur",226338,22.752778,88.342222 ],
    [ u"in",u"Shrirangapattana",23929,12.413611,76.704167 ],
    [ u"in",u"Shujalpur",47063,23.4,76.716667 ],
    [ u"in",u"Shupiyan",13566,33.716667,74.833333 ],
    [ u"in",u"Sibsagar",62107,26.983333,94.633333 ],
    [ u"in",u"Siddapur",14769,14.333333,74.883333 ],
    [ u"in",u"Siddhapur",54317,23.916667,72.383333 ],
    [ u"in",u"Siddipet",64569,18.1,78.85 ],
    [ u"in",u"Sidhauli",22195,27.283333,80.833333 ],
    [ u"in",u"Sidhi",54248,24.416667,81.883333 ],
    [ u"in",u"Sidhpura",14816,27.633333,78.883333 ],
    [ u"in",u"Sidlaghatta",49118,13.388056,77.862778 ],
    [ u"in",u"Sihora",41196,23.483333,80.116667 ],
    [ u"in",u"Sihor",52606,21.7,71.966667 ],
    [ u"in",u"Sijua",31540,23.783333,86.316667 ],
    [ u"in",u"Sikandarabad",73386,28.45,77.7 ],
    [ u"in",u"Sikandarpur",24179,26.05,84.05 ],
    [ u"in",u"Sikandra Rao",42233,27.7,78.4 ],
    [ u"in",u"Sikandra",12290,26.366667,79.65 ],
    [ u"in",u"Sikar",199946,27.616667,75.15 ],
    [ u"in",u"Sika",19406,22.433333,69.833333 ],
    [ u"in",u"Silao",21830,25.083333,85.416667 ],
    [ u"in",u"Silchar",152399,24.816667,92.8 ],
    [ u"in",u"Sillod",51046,20.3,75.65 ],
    [ u"in",u"Silvassa",27359,20.266667,73.016667 ],
    [ u"in",u"Simdega",38736,22.616667,84.516667 ],
    [ u"in",u"Simga",12945,21.633333,81.7 ],
    [ u"in",u"Sindgi",33773,16.916667,76.233333 ],
    [ u"in",u"Sindhnur",68799,15.783333,76.766667 ],
    [ u"in",u"Sindi",13637,20.8,78.866667 ],
    [ u"in",u"Singanallur",31239,11,77.016667 ],
    [ u"in",u"Singaperumalkoil",8301,12.761111,80.01 ],
    [ u"in",u"Singarayakonda",17798,15.25,80.033333 ],
    [ u"in",u"Singtam",6133,27.233333,88.5 ],
    [ u"in",u"Singur",19404,22.809167,88.229444 ],
    [ u"in",u"Sini",6376,22.8,85.966667 ],
    [ u"in",u"Sinnar",34098,19.85,74 ],
    [ u"in",u"Sinor",11267,21.916667,73.333333 ],
    [ u"in",u"Siolim",10481,15.616667,73.766667 ],
    [ u"in",u"Sira",57933,13.745278,76.909167 ],
    [ u"in",u"Sirathu",13599,25.65,81.316667 ],
    [ u"in",u"Sirhind",60852,30.645556,76.3825 ],
    [ u"in",u"Sirkali",33102,11.233333,79.733333 ],
    [ u"in",u"Sirmaur",11813,24.85,81.383333 ],
    [ u"in",u"Sirohi",38613,24.883333,72.866667 ],
    [ u"in",u"Sironj",45459,24.1,77.7 ],
    [ u"in",u"Sirpur",10116,19.483333,79.6 ],
    [ u"in",u"Sirsaganj",29037,27.05,78.7 ],
    [ u"in",u"Sirsa",181652,29.533333,75.016667 ],
    [ u"in",u"Sirsa",12609,25.283333,82.083333 ],
    [ u"in",u"Sirsilla",71506,18.383333,78.833333 ],
    [ u"in",u"Sirsi",61612,14.616667,74.85 ],
    [ u"in",u"Sirsi",22551,28.65,78.65 ],
    [ u"in",u"Siruguppa",47921,15.633333,76.9 ],
    [ u"in",u"Sirumugai",20066,11.333333,77.016667 ],
    [ u"in",u"Sirur",31020,18.833333,74.383333 ],
    [ u"in",u"Sisauli",15839,29.416667,77.466667 ],
    [ u"in",u"Siswa Bazar",19941,27.15,83.766667 ],
    [ u"in",u"Sitamarhi",57101,26.6,85.483333 ],
    [ u"in",u"Sitamau",13442,24.016667,75.35 ],
    [ u"in",u"Sitapur",164451,27.566667,80.683333 ],
    [ u"in",u"Sitarganj",24228,28.933333,79.7 ],
    [ u"in",u"Siuri",64665,23.916667,87.533333 ],
    [ u"in",u"Sivaganga",42789,9.866667,78.483333 ],
    [ u"in",u"Sivagiri",16779,11.116667,77.8 ],
    [ u"in",u"Sivakasi",74289,9.45,77.816667 ],
    [ u"in",u"Siwana",22067,25.633333,72.416667 ],
    [ u"in",u"Siwani",18016,28.9102,75.6154 ],
    [ u"in",u"Siwan",119194,26.216667,84.366667 ],
    [ u"in",u"Siyana",43026,28.633333,78.05 ],
    [ u"in",u"Sodpur",7038,22.708889,88.387222 ],
    [ u"in",u"Sohagpur",23852,22.7,78.2 ],
    [ u"in",u"Sohna",33363,28.25,77.066667 ],
    [ u"in",u"Sojat",42559,25.916667,73.666667 ],
    [ u"in",u"Sojitra",19403,22.55,72.716667 ],
    [ u"in",u"Solon",40286,30.916667,77.116667 ],
    [ u"in",u"Someshwar",22139,13.5,75.066667 ],
    [ u"in",u"Sompeta",17984,18.933333,84.6 ],
    [ u"in",u"Somvarpet",7228,12.6,75.866667 ],
    [ u"in",u"Sonamukhi",28337,23.3,87.416667 ],
    [ u"in",u"Sonamura",10823,23.471944,91.266389 ],
    [ u"in",u"Sonari",19673,27.066667,95.033333 ],
    [ u"in",u"Sonegaon",12614,20.65,78.683333 ],
    [ u"in",u"Sonepur",18770,20.833333,83.916667 ],
    [ u"in",u"Songadh",25270,21.166667,73.566667 ],
    [ u"in",u"Sonipat",250538,28.983333,77.016667 ],
    [ u"in",u"Sopur",63039,34.3,74.466667 ],
    [ u"in",u"Sorab",7088,14.383333,75.1 ],
    [ u"in",u"Sorada",15118,19.75,84.433333 ],
    [ u"in",u"Sorbhog",7614,26.5,90.866667 ],
    [ u"in",u"Soron",28686,27.883333,78.75 ],
    [ u"in",u"Soro",29800,21.288056,86.685833 ],
    [ u"in",u"Srikakulam",118312,18.3,83.9 ],
    [ u"in",u"Sri Madhopur",30283,27.466667,75.6 ],
    [ u"in",u"Srimushnam",12364,11.4,79.416667 ],
    [ u"in",u"Srinagar",975926,34.092222,74.802222 ],
    [ u"in",u"Srinagar",20219,30.216667,78.783333 ],
    [ u"in",u"Sringeri",4272,13.416667,75.25 ],
    [ u"in",u"Srinivaspur",25762,13.333333,78.216667 ],
    [ u"in",u"Sriperumbudur",17255,12.968889,79.948889 ],
    [ u"in",u"Srirampur",18682,22.948889,88.018889 ],
    [ u"in",u"Srisailam",24145,16.083333,78.866667 ],
    [ u"in",u"Srivaikuntam",15666,8.616667,77.933333 ],
    [ u"in",u"Srivardhan",15280,18.033333,73.016667 ],
    [ u"in",u"Srivilliputtur",74377,9.516667,77.633333 ],
    [ u"in",u"Sualkuchi",13918,26.168056,91.571111 ],
    [ u"in",u"Suar",28944,29.033333,79.05 ],
    [ u"in",u"Suchindram",12316,8.15,77.483333 ],
    [ u"in",u"Sujangarh",88861,27.7,74.466667 ],
    [ u"in",u"Suket",19852,24.65,76.033333 ],
    [ u"in",u"Sultanpur",9420,23.15,77.933333 ],
    [ u"in",u"Sultanpur",110379,26.266667,82.066667 ],
    [ u"in",u"Sultanpur",8519,29.75,78.116667 ],
    [ u"in",u"Sulurpeta",38065,13.7,80.016667 ],
    [ u"in",u"Sulur",26185,11.033333,77.133333 ],
    [ u"in",u"Sulya",18950,12.566667,75.383333 ],
    [ u"in",u"Sumbal",11694,34.233333,74.633333 ],
    [ u"in",u"Sunam",53651,30.133333,75.8 ],
    [ u"in",u"Sundargarh",41709,22.116667,84.033333 ],
    [ u"in",u"Sundarnagar",25340,31.533333,76.883333 ],
    [ u"in",u"Sunel",15840,24.333333,76 ],
    [ u"in",u"Supaul",60027,26.116667,86.6 ],
    [ u"in",u"Surajgarh",19723,28.3124,75.7347 ],
    [ u"in",u"Surandai",28989,8.966667,77.4 ],
    [ u"in",u"Suratgarh",63158,29.316667,73.9 ],
    [ u"in",u"Surat",2894675,20.966667,72.9 ],
    [ u"in",u"Surendranagar",179640,22.7,71.683333 ],
    [ u"in",u"Surgana",6566,20.566667,73.616667 ],
    [ u"in",u"Suriapet",111741,17.15,79.616667 ],
    [ u"in",u"Susner",14603,23.95,76.083333 ],
    [ u"in",u"Swamimalai",7197,10.95,79.333333 ],
    [ u"in",u"Tadepallegudem",108176,16.833333,81.5 ],
    [ u"in",u"Tadepalle",34357,16.466667,80.6 ],
    [ u"in",u"Tadpatri",93055,14.916667,78.016667 ],
    [ u"in",u"Tajpur",17529,29.166667,78.483333 ],
    [ u"in",u"Takhatgarh",17287,25.333333,73 ],
    [ u"in",u"Takhatpur",17861,22.15,81.866667 ],
    [ u"in",u"Taki",40117,22.586111,88.921389 ],
    [ u"in",u"Talaja",29950,21.35,72.05 ],
    [ u"in",u"Talbahat",13791,25.05,78.433333 ],
    [ u"in",u"Talcher",38439,20.95,85.216667 ],
    [ u"in",u"Talegaon Dabhade",47657,18.716667,73.683333 ],
    [ u"in",u"Taleigao",17148,15.466667,73.8 ],
    [ u"in",u"Talen",9819,23.566667,76.716667 ],
    [ u"in",u"Talgram",10631,27.05,79.65 ],
    [ u"in",u"Talikota",27905,16.483333,76.316667 ],
    [ u"in",u"Talipparamba",69884,12.05,75.35 ],
    [ u"in",u"Taloda",26295,21.566667,74.216667 ],
    [ u"in",u"Tal",14245,23.716667,75.383333 ],
    [ u"in",u"Talwandi Bhai",16392,30.85,74.933333 ],
    [ u"in",u"Talwara",24754,31.948611,75.866667 ],
    [ u"in",u"Tambaram",150056,12.927222,80.110556 ],
    [ u"in",u"Tamluk",48651,22.3,87.916667 ],
    [ u"in",u"Tanakpur",16907,29.083333,80.116667 ],
    [ u"in",u"Tanda",44826,28.983333,78.933333 ],
    [ u"in",u"Tandur",63246,17.233333,77.583333 ],
    [ u"in",u"Tankara",10175,22.666667,70.733333 ],
    [ u"in",u"Tanuku",68296,16.75,81.7 ],
    [ u"in",u"Taoru",19312,28.216667,76.95 ],
    [ u"in",u"Tarabha",8156,20.733333,83.65 ],
    [ u"in",u"Tarakeswar",30478,22.885,88.017222 ],
    [ u"in",u"Taramangalam",23790,11.7,77.983333 ],
    [ u"in",u"Taranagar",29394,28.6709,75.0351 ],
    [ u"in",u"Tarana",22775,23.333333,76.033333 ],
    [ u"in",u"Tarapur",7493,19.85,72.7 ],
    [ u"in",u"Tarn Taran",58590,31.45,74.925278 ],
    [ u"in",u"Tasgaon",34935,17.033333,74.6 ],
    [ u"in",u"Tattayyangarpettai",12605,11.133333,78.45 ],
    [ u"in",u"Tawang",4831,27.583333,91.866667 ],
    [ u"in",u"Teghra",46161,25.483333,85.95 ],
    [ u"in",u"Tehri",27614,30.383333,78.483333 ],
    [ u"in",u"Tekanpur",13683,25.983333,78.266667 ],
    [ u"in",u"Tekari",19065,24.933333,84.833333 ],
    [ u"in",u"Tekkalakota",25532,15.533333,76.883333 ],
    [ u"in",u"Tekkali",24682,18.616667,84.233333 ],
    [ u"in",u"Telhara",21148,21.026944,76.838889 ],
    [ u"in",u"Tenali",151793,16.25,80.583333 ],
    [ u"in",u"Tendukheda",12700,23.4,79.55 ],
    [ u"in",u"Tenkasi",65501,8.966667,77.3 ],
    [ u"in",u"Teonthar",16579,24.983333,81.65 ],
    [ u"in",u"Terdal",26413,16.5,75.05 ],
    [ u"in",u"Tezpur",58854,26.633333,92.8 ],
    [ u"in",u"Tezu",14928,27.916667,96.166667 ],
    [ u"in",u"Thakurdwara",39864,29.2,78.85 ],
    [ u"in",u"Thakurganj",15955,26.45,88.133333 ],
    [ u"in",u"Thalassery",97210,11.747778,75.488333 ],
    [ u"in",u"Thana Bhawan",33502,29.586389,77.416667 ],
    [ u"in",u"Thana",1486453,19.2,72.966667 ],
    [ u"in",u"Thanesar",138288,29.983333,76.816667 ],
    [ u"in",u"Thanjavur",219591,10.8,79.15 ],
    [ u"in",u"Tharad",24698,24.396111,71.626667 ],
    [ u"in",u"Thasra",18337,22.8,73.216667 ],
    [ u"in",u"Thenzawl",5964,23.316667,92.75 ],
    [ u"in",u"Theog",4191,31.116667,77.35 ],
    [ u"in",u"Thiruvananthapuram",784223,8.506944,76.956944 ],
    [ u"in",u"Thiruvarur",58782,10.766667,79.65 ],
    [ u"in",u"Thoubal",44497,24.633333,94.016667 ],
    [ u"in",u"Thrissur",325140,10.516667,76.216667 ],
    [ u"in",u"Tigri",49709,28.816667,78.15 ],
    [ u"in",u"Tijara",21835,27.933333,76.85 ],
    [ u"in",u"Tikaitnagar",8807,26.95,81.583333 ],
    [ u"in",u"Tikamgarh",74732,24.745,78.8333 ],
    [ u"in",u"Tikri",13648,29.233333,77.35 ],
    [ u"in",u"Tilhar",57048,27.983333,79.733333 ],
    [ u"in",u"Tindivanam",69845,12.25,79.65 ],
    [ u"in",u"Tindwari",10407,25.616667,80.533333 ],
    [ u"in",u"Tinnanur",22125,13.111389,80.026111 ],
    [ u"in",u"Tinsukia",89377,27.5,95.366667 ],
    [ u"in",u"Tiptur",60962,13.258611,76.478333 ],
    [ u"in",u"Tira Sujanpur",7748,31.833333,76.5 ],
    [ u"in",u"Tirodi",8871,21.683333,79.7 ],
    [ u"in",u"Tirthahalli",15423,13.7,75.233333 ],
    [ u"in",u"Tiruchchendur",29874,8.483333,78.116667 ],
    [ u"in",u"Tiruchchirappalli",775551,10.805,78.685556 ],
    [ u"in",u"Tirukkattuppalli",12466,10.85,78.966667 ],
    [ u"in",u"Tirukkoyilur",28340,11.95,79.2 ],
    [ u"in",u"Tirumakudal Narsipur",9891,12.21,76.906389 ],
    [ u"in",u"Tirumala",18015,13.683333,79.35 ],
    [ u"in",u"Tirumullaivasal",13233,11.233333,79.833333 ],
    [ u"in",u"Tirunelveli",435882,8.733333,77.7 ],
    [ u"in",u"Tirupati",250849,13.65,79.416667 ],
    [ u"in",u"Tiruppur",397554,11.1,77.35 ],
    [ u"in",u"Tiruppuvanam",22519,9.833333,78.266667 ],
    [ u"in",u"Tirur",54939,10.9,75.916667 ],
    [ u"in",u"Tiruttani",39902,13.183333,79.633333 ],
    [ u"in",u"Tiruvalla",57228,9.383333,76.566667 ],
    [ u"in",u"Tiruvallur",48099,13.15,79.916667 ],
    [ u"in",u"Tiruvannamalai",138255,12.216667,79.066667 ],
    [ u"in",u"Tiruvidaimarudur",14184,10.983333,79.466667 ],
    [ u"in",u"Tiruvottiyur",229019,13.157778,80.304167 ],
    [ u"in",u"Titagarh",127763,22.736389,88.373611 ],
    [ u"in",u"Titlagarh",28407,20.3,83.15 ],
    [ u"in",u"Titron",11570,29.668056,77.3225 ],
    [ u"in",u"Toda Bhim",22531,26.916667,76.816667 ],
    [ u"in",u"Toda Raisingh",22615,26.016667,75.483333 ],
    [ u"in",u"Tohana",59753,29.7,75.9 ],
    [ u"in",u"Tondi",16469,9.733333,79.016667 ],
    [ u"in",u"Tonk",151341,26.166667,75.783333 ],
    [ u"in",u"Topchanchi",5789,23.9,86.2 ],
    [ u"in",u"Tori Fatehpur",10211,25.45,79.133333 ],
    [ u"in",u"Tosham",12529,28.883333,75.916667 ],
    [ u"in",u"Tral",13257,33.933333,75.1 ],
    [ u"in",u"Trimbak",10591,19.933333,73.55 ],
    [ u"in",u"Tuensang",33750,26.283333,94.833333 ],
    [ u"in",u"Tufanganj",20422,26.316667,89.666667 ],
    [ u"in",u"Tuljapur",35599,18,76.083333 ],
    [ u"in",u"Tulsipur",22488,27.55,82.416667 ],
    [ u"in",u"Tumkur",307384,13.342222,77.101667 ],
    [ u"in",u"Tumsar",43222,21.383333,79.733333 ],
    [ u"in",u"Tundla",50944,27.2,78.283333 ],
    [ u"in",u"Tuni",52664,17.35,82.55 ],
    [ u"in",u"Turaiyur",32137,11.166667,78.616667 ],
    [ u"in",u"Tura",63650,25.519826,90.22007 ],
    [ u"in",u"Turuvekere",14116,13.164167,76.666667 ],
    [ u"in",u"Uchana",15831,29.466667,76.166667 ],
    [ u"in",u"Udagamandalam",98247,11.4,76.7 ],
    [ u"in",u"Udaipura",15474,23.083333,78.5 ],
    [ u"in",u"Udaipur",30266,27.716667,75.483333 ],
    [ u"in",u"Udaipur",23293,23.533333,91.483333 ],
    [ u"in",u"Udala",11812,21.574167,86.565 ],
    [ u"in",u"Udalguri",15936,26.766667,92.133333 ],
    [ u"in",u"Udankudi",19010,8.433333,78.016667 ],
    [ u"in",u"Udayagiri",10866,20.133333,84.383333 ],
    [ u"in",u"Udgir",101072,18.383333,77.116667 ],
    [ u"in",u"Udhampur",80478,32.933333,75.133333 ],
    [ u"in",u"Udpura",10015,24.716667,75.966667 ],
    [ u"in",u"Udupi",129124,13.35,74.75 ],
    [ u"in",u"Ugu",6519,26.783333,80.333333 ],
    [ u"in",u"Ujhani",56314,28.016667,79.016667 ],
    [ u"in",u"Ujjain",457395,23.183333,75.766667 ],
    [ u"in",u"Uklana Mandi",11909,29.516667,75.866667 ],
    [ u"in",u"Ukwa",7370,21.966667,80.466667 ],
    [ u"in",u"Ula",6324,22.7225,88.555556 ],
    [ u"in",u"Ulhasnagar",516625,19.216667,73.15 ],
    [ u"in",u"Ullal",59121,12.8,74.85 ],
    [ u"in",u"Ulubaria",222293,22.471667,88.113611 ],
    [ u"in",u"Ulundurpettai",19835,11.7,79.283333 ],
    [ u"in",u"Umarga",32184,17.833333,76.616667 ],
    [ u"in",u"Umaria",29743,23.533333,80.833333 ],
    [ u"in",u"Umarkhed",35268,19.6,77.7 ],
    [ u"in",u"Umarkot",27547,19.666667,82.216667 ],
    [ u"in",u"Umrala",11874,21.833333,71.816667 ],
    [ u"in",u"Umred",51798,20.85,79.333333 ],
    [ u"in",u"Umreth",32804,22.7,73.116667 ],
    [ u"in",u"Umri",9365,26.510556,78.936667 ],
    [ u"in",u"Umri",9365,26.3404,79.2561 ],
    [ u"in",u"Una",56549,20.816667,71.033333 ],
    [ u"in",u"Una",17570,31.483333,76.283333 ],
    [ u"in",u"Unhel",15838,23.333333,75.566667 ],
    [ u"in",u"Uniara",11442,26.15,75.216667 ],
    [ u"in",u"Unjha",54623,23.8,72.4 ],
    [ u"in",u"Unnao",161687,26.533333,80.5 ],
    [ u"in",u"Un",15008,29.584722,77.254167 ],
    [ u"in",u"Upleta",56357,21.733333,70.283333 ],
    [ u"in",u"Uppiliapuram",6900,11.266667,78.516667 ],
    [ u"in",u"Uran",25600,18.876944,72.939722 ],
    [ u"in",u"Uravakonda",33499,14.95,77.266667 ],
    [ u"in",u"Uri",6757,34.083333,74.033333 ],
    [ u"in",u"Usilampatti",30677,9.966667,77.8 ],
    [ u"in",u"Utran",14856,21.233333,72.866667 ],
    [ u"in",u"Utraula",28440,27.316667,82.416667 ],
    [ u"in",u"Uttamapalaiyam",22780,9.8,77.333333 ],
    [ u"in",u"Uttarkashi",17125,30.733333,78.45 ],
    [ u"in",u"Uttiramerur",24318,12.6,79.766667 ],
    [ u"in",u"Uttukkuli",7514,11.166667,77.433333 ],
    [ u"in",u"Vadakku Valliyur",24749,8.383333,77.65 ],
    [ u"in",u"Vadamadurai",15886,10.466667,78.083333 ],
    [ u"in",u"Vada",15475,19.65,73.133333 ],
    [ u"in",u"Vadgaon",12374,18.733333,73.65 ],
    [ u"in",u"Vadlapudi",17881,14.316667,79.8 ],
    [ u"in",u"Vadnagar",24833,23.783333,72.633333 ],
    [ u"in",u"Vadodara",1409565,22.3,73.2 ],
    [ u"in",u"Vaghodia",14606,22.3,73.383333 ],
    [ u"in",u"Vaijapur",40046,19.916667,74.733333 ],
    [ u"in",u"Vaikam",22810,9.766667,76.4 ],
    [ u"in",u"Valavanur",14463,11.916667,79.583333 ],
    [ u"in",u"Vallam",14935,10.716667,79.083333 ],
    [ u"in",u"Valparai",90361,10.366667,76.966667 ],
    [ u"in",u"Valpoi",8331,15.533333,74.133333 ],
    [ u"in",u"Valsad",72934,20.633333,72.933333 ],
    [ u"in",u"Vandalur",13715,12.892778,80.080833 ],
    [ u"in",u"Vandavasi",31533,12.5,79.616667 ],
    [ u"in",u"Vaniyambadi",90295,12.683333,78.616667 ],
    [ u"in",u"Vapi",92225,20.366667,72.9 ],
    [ u"in",u"Varanasi",1164520,25.333333,83 ],
    [ u"in",u"Varangaon",44066,21.016667,75.9 ],
    [ u"in",u"Varca",5079,15.216667,73.916667 ],
    [ u"in",u"Varkkallai",43280,8.733333,76.716667 ],
    [ u"in",u"Vartej",10272,21.733333,72.066667 ],
    [ u"in",u"Vasai",53255,19.35,72.8 ],
    [ u"in",u"Vasudevanallur",19021,9.233333,77.416667 ],
    [ u"in",u"Vattalkundu",22640,10.166667,77.766667 ],
    [ u"in",u"Vayalar",25094,9.7,76.333333 ],
    [ u"in",u"Vedaranniyam",32248,10.366667,79.85 ],
    [ u"in",u"Vedasandur",12494,10.533333,77.95 ],
    [ u"in",u"Vejalpur",121618,22.683333,73.566667 ],
    [ u"in",u"Velluru",177096,12.933333,79.133333 ],
    [ u"in",u"Velur",18951,11.1,78.016667 ],
    [ u"in",u"Vemalwada",22920,18.466667,78.883333 ],
    [ u"in",u"Vengurla",12499,15.866667,73.633333 ],
    [ u"in",u"Venkatagiri",32765,13.966667,79.583333 ],
    [ u"in",u"Veraval",163336,20.9,70.366667 ],
    [ u"in",u"Vetapalem",38011,15.783333,80.316667 ],
    [ u"in",u"Vettavalam",13808,12.1,79.25 ],
    [ u"in",u"Vidisha",140059,23.533333,77.816667 ],
    [ u"in",u"Vijapur",24299,23.566667,72.75 ],
    [ u"in",u"Vijayapuri",6651,11.233333,77.5 ],
    [ u"in",u"Vijayawada",874684,16.516667,80.616667 ],
    [ u"in",u"Vikarabad",43342,17.333333,77.9 ],
    [ u"in",u"Vikramasingapuram",47150,8.666667,77.333333 ],
    [ u"in",u"Vikravandi",10449,12.033333,79.55 ],
    [ u"in",u"Vinukonda",61332,16.05,79.75 ],
    [ u"in",u"Viraganur",10854,11.483333,78.733333 ],
    [ u"in",u"Viramgam",53670,23.116667,72.033333 ],
    [ u"in",u"Virapandi",27197,9.95,77.45 ],
    [ u"in",u"Virarajendrapet",15978,12.2,75.8 ],
    [ u"in",u"Virar",150419,19.466667,72.8 ],
    [ u"in",u"Viravanallur",19691,8.7,77.533333 ],
    [ u"in",u"Virbhadra",13064,30.066667,78.283333 ],
    [ u"in",u"Virpur",8866,23.183333,73.483333 ],
    [ u"in",u"Virudunagar",73280,9.6,77.966667 ],
    [ u"in",u"Visakhapatnam",1063293,17.7,83.3 ],
    [ u"in",u"Visavadar",18383,21.383333,70.683333 ],
    [ u"in",u"Visnagar",68623,23.7,72.55 ],
    [ u"in",u"Vite",45976,17.283333,74.55 ],
    [ u"in",u"Vizianagaram",179379,18.116667,83.416667 ],
    [ u"in",u"Vrindavan",60201,27.583333,77.7 ],
    [ u"in",u"Vuyyuru",36755,16.366667,80.85 ],
    [ u"in",u"Vyara",38171,21.116667,73.4 ],
    [ u"in",u"Wadhwan",66469,22.7,71.683333 ],
    [ u"in",u"Wadi",30605,17.066667,76.983333 ],
    [ u"in",u"Waghai",6462,20.766667,73.483333 ],
    [ u"in",u"Wai",32960,17.933333,73.9 ],
    [ u"in",u"Walajabad",10544,12.766667,79.783333 ],
    [ u"in",u"Walajapet",30259,12.933333,79.383333 ],
    [ u"in",u"Wangjing",7529,24.6,94.033333 ],
    [ u"in",u"Wani",57293,20.066667,78.95 ],
    [ u"in",u"Wankaner",47813,22.616667,70.933333 ],
    [ u"in",u"Wanparti",55188,16.366667,78.066667 ],
    [ u"in",u"Warangal",557864,18,79.583333 ],
    [ u"in",u"Waraseoni",23803,21.75,80.033333 ],
    [ u"in",u"Wardha",113768,20.75,78.616667 ],
    [ u"in",u"Waris Aliganj",35247,25.016667,85.633333 ],
    [ u"in",u"Warora",41526,20.233333,79 ],
    [ u"in",u"Warud",47821,21.466667,78.266667 ],
    [ u"in",u"Washim",68628,20.1,77.15 ],
    [ u"in",u"Wazirganj",19374,28.216667,79.05 ],
    [ u"in",u"Wellington",20256,11.366667,76.8 ],
    [ u"in",u"Wer",18269,27,77.166667 ],
    [ u"in",u"Wokha",54012,26.1,94.266667 ],
    [ u"in",u"Yadgir",65381,16.766667,77.133333 ],
    [ u"in",u"Yairipok",8798,24.666667,94.066667 ],
    [ u"in",u"Yamunanagar",208945,30.1,77.283333 ],
    [ u"in",u"Yanam",36900,16.733333,82.216667 ],
    [ u"in",u"Yarada",3406,17.65,83.266667 ],
    [ u"in",u"Yaval",32883,21.166667,75.7 ],
    [ u"in",u"Yavatmal",128185,20.4,78.133333 ],
    [ u"in",u"Yelahanka",116457,13.1075,77.600278 ],
    [ u"in",u"Yelandur",8902,12.066667,77.033333 ],
    [ u"in",u"Yelbarga",12023,15.633333,76.016667 ],
    [ u"in",u"Yellamanchili",26181,17.55,82.866667 ],
    [ u"in",u"Yellandu",43792,17.6,80.333333 ],
    [ u"in",u"Yellapur",19345,14.966667,74.716667 ],
    [ u"in",u"Yeola",46766,20.033333,74.483333 ],
    [ u"in",u"Yerraguntla",27874,14.633333,78.533333 ],
    [ u"in",u"Yol",11315,32.166667,76.2 ],
    [ u"in",u"Zafarabad",9107,25.7,82.733333 ],
    [ u"in",u"Zahirabad",46509,17.683333,77.616667 ],
    [ u"in",u"Zaidpur",33400,26.833333,81.333333 ],
    [ u"in",u"Zamania",32011,25.433333,83.566667 ],
    [ u"in",u"Ziro",13895,27.633333,93.833333 ],
    [ u"in",u"Zunheboto",29500,25.966667,94.516667 ],
    [ u"iq",u"Baghdad",5672516,33.3386111,44.3938889 ],
    [ u"iq",u"Balad",42227,34.0163889,44.1463889 ],
    [ u"iq",u"Bayji",36574,34.925,43.4875 ],
    [ u"iq",u"Dahuk",129127,36.8658333,42.9997222 ],
    [ u"iq",u"Hit",32008,33.6366667,42.8225 ],
    [ u"iq",u"Irbil",932854,36.19,44.0088889 ],
    [ u"iq",u"Kifri",30241,34.6913889,44.9608333 ],
    [ u"iq",u"Kirkuk",601442,35.4680556,44.3922222 ],
    [ u"iq",u"Mandali",29882,33.7436111,45.5463889 ],
    [ u"iq",u"Panjwin",27219,35.6202778,45.9472222 ],
    [ u"iq",u"Rawah",20649,34.4686111,41.9169444 ],
    [ u"iq",u"Sinjar",38437,36.3166667,41.85 ],
    [ u"iq",u"Tall Kayf",23613,36.4894444,43.1191667 ],
    [ u"iq",u"Tikrit",42616,34.5966667,43.6769444 ],
    [ u"ir",u"Abadan",370220,30.3392,48.3043 ],
    [ u"ir",u"Abdanan",19362,32.9926,47.4198 ],
    [ u"ir",u"Abhar",69894,36.1468,49.218 ],
    [ u"ir",u"Abyek",55132,36.03993,50.531015 ],
    [ u"ir",u"Agha Jari",22019,30.7006,49.8315 ],
    [ u"ir",u"Ahar",94355,38.4774,47.0699 ],
    [ u"ir",u"Ahvaz",854980,31.3203,48.6693 ],
    [ u"ir",u"Alashtar",27703,33.8633,48.2619 ],
    [ u"ir",u"Aligudarz",91048,33.400633,49.694901 ],
    [ u"ir",u"Alvand",74899,36.3187,49.1678 ],
    [ u"ir",u"Amol",199398,36.469612,52.350724 ],
    [ u"ir",u"Arak",503673,34.091741,49.689164 ],
    [ u"ir",u"Ardabil",410773,38.2498,48.2933 ],
    [ u"ir",u"Ardakan",58840,32.310011,54.017474 ],
    [ u"ir",u"Ardistan",16058,33.3761,52.3694 ],
    [ u"ir",u"Ashtian",11020,34.522,50.006 ],
    [ u"ir",u"Astaneh-ye Ashrafiyeh",42787,37.259615,49.944439 ],
    [ u"ir",u"Astara",39067,38.4291,48.872 ],
    [ u"ir",u"Azad Shahr",47594,37.087009,55.173973 ],
    [ u"ir",u"Azar Shahr",37349,37.759,45.9783 ],
    [ u"ir",u"Babol",202812,36.551321,52.678951 ],
    [ u"ir",u"Bafq",31218,31.612833,55.410666 ],
    [ u"ir",u"Baft",43081,29.2331,56.6022 ],
    [ u"ir",u"Bahar",28647,34.9072,48.4414 ],
    [ u"ir",u"Bam",99276,29.106,58.357 ],
    [ u"ir",u"Bandar-e Anzali",110834,37.4727,49.4622 ],
    [ u"ir",u"Bandar-e Lengeh",22771,26.557918,54.880669 ],
    [ u"ir",u"Bandar-e Torkaman",48658,36.90165,54.070884 ],
    [ u"ir",u"Baneh",104939,35.9975,45.8853 ],
    [ u"ir",u"Bardsir",37195,29.92266,56.574335 ],
    [ u"ir",u"Behbahan",79335,30.5959,50.2417 ],
    [ u"ir",u"Behshahr",93508,36.692347,53.552617 ],
    [ u"ir",u"Bijar",53875,35.8727,47.6029 ],
    [ u"ir",u"Birjand",197004,32.866277,59.221139 ],
    [ u"ir",u"Bojnurd",192062,37.47473,57.329031 ],
    [ u"ir",u"Borazjan",86067,29.2666,51.2159 ],
    [ u"ir",u"Borujan",52660,31.965232,51.287295 ],
    [ u"ir",u"Borujerd",251976,33.8973,48.7516 ],
    [ u"ir",u"Bukan",213349,36.521,46.2089 ],
    [ u"ir",u"Bushehr",157778,28.9684,50.8385 ],
    [ u"ir",u"Chabahar",47291,25.2919,60.643 ],
    [ u"ir",u"Chalus",69644,36.654996,51.420397 ],
    [ u"ir",u"Damavand",29147,35.717778,52.065 ],
    [ u"ir",u"Damghan",67698,36.1683,54.348 ],
    [ u"ir",u"Darab",63324,28.751944,54.544444 ],
    [ u"ir",u"Dehloran",46109,32.6941,47.2679 ],
    [ u"ir",u"Delijan",33510,33.9905,50.6838 ],
    [ u"ir",u"Dezful",212367,32.3825,48.402 ],
    [ u"ir",u"Do Gonbadan",94646,30.3586,50.7981 ],
    [ u"ir",u"Do Rud",114404,33.5,49.0571 ],
    [ u"ir",u"Eqbaliyeh",36709,35.3022,51.5358 ],
    [ u"ir",u"Esfahan",1547241,32.657218,51.677608 ],
    [ u"ir",u"Esfarayen",59685,37.076448,57.510086 ],
    [ u"ir",u"Eslamshahr",318855,35.5605,51.2346 ],
    [ u"ir",u"Falavarjan",49847,32.555301,51.509735 ],
    [ u"ir",u"Faridan",15737,32.988707,50.41267 ],
    [ u"ir",u"Fasa",98068,28.9383,53.6482 ],
    [ u"ir",u"Fereydun Kenar",34100,36.686418,52.522548 ],
    [ u"ir",u"Fereydunshahr",11562,32.940979,50.121 ],
    [ u"ir",u"Garmsar",49494,35.218242,52.340849 ],
    [ u"ir",u"Gerash",25318,27.6652,54.1371 ],
    [ u"ir",u"Golpayegan",44920,33.453702,50.288361 ],
    [ u"ir",u"Gonbad-e Qabus",131427,37.250042,55.167208 ],
    [ u"ir",u"Gorgan",244955,36.838659,54.434749 ],
    [ u"ir",u"Hadishahr",26226,38.8479,45.6623 ],
    [ u"ir",u"Hamadan",514134,34.799216,48.514556 ],
    [ u"ir",u"Harsin",57652,34.2721,47.5861 ],
    [ u"ir",u"Hashtgerd",57128,35.962,50.6799 ],
    [ u"ir",u"Hashtrud",16888,37.4779,47.0508 ],
    [ u"ir",u"Hendijan",20703,30.2363,49.7119 ],
    [ u"ir",u"Ilam",140951,33.6374,46.4227 ],
    [ u"ir",u"Iranshahr",131242,27.202446,60.684758 ],
    [ u"ir",u"Jahrom",107910,28.5024,53.5534 ],
    [ u"ir",u"Javanrud",38660,34.8067,46.4913 ],
    [ u"ir",u"Jiroft",111560,28.6535,57.7646 ],
    [ u"ir",u"Juybar",28406,36.641152,52.912443 ],
    [ u"ir",u"Kalaleh",33703,37.380712,55.491639 ],
    [ u"ir",u"Kamyaran",61647,34.7956,46.9355 ],
    [ u"ir",u"Kangavar",53418,34.5043,47.9653 ],
    [ u"ir",u"Karaj",1448996,35.8355,51.0103 ],
    [ u"ir",u"Kashan",301107,33.9888,51.4773 ],
    [ u"ir",u"Kazerun",94518,29.619491,51.654147 ],
    [ u"ir",u"Kerman",577547,30.283209,57.07879 ],
    [ u"ir",u"Kermanshah",766742,34.314167,47.065 ],
    [ u"ir",u"Khalkhal",51028,37.6189,48.5258 ],
    [ u"ir",u"Khash",69608,28.221072,61.215819 ],
    [ u"ir",u"Khomeynishahr",277355,32.700175,51.521134 ],
    [ u"ir",u"Khomeyn",77431,33.642255,50.078898 ],
    [ u"ir",u"Khonsar",21148,33.220521,50.314969 ],
    [ u"ir",u"Khormuj",29886,28.6543,51.38 ],
    [ u"ir",u"Khorramabad",329847,33.487778,48.355833 ],
    [ u"ir",u"Khorramshahr",331254,30.4397,48.1664 ],
    [ u"ir",u"Khoy",175386,38.5503,44.9521 ],
    [ u"ir",u"Kuhdasht",100216,33.535,47.6061 ],
    [ u"ir",u"Lahijan",64959,37.207318,50.003971 ],
    [ u"ir",u"Langarud",68153,37.197006,50.153508 ],
    [ u"ir",u"Lar",71744,27.6489,54.316 ],
    [ u"ir",u"Mahabad",162448,36.7499,45.7229 ],
    [ u"ir",u"Mahdasht",37076,35.7282,50.8134 ],
    [ u"ir",u"Maku",41517,39.2944,44.4809 ],
    [ u"ir",u"Malard",56790,35.6659,50.9767 ],
    [ u"ir",u"Maragheh",168290,37.3893,46.2376 ],
    [ u"ir",u"Marand",124201,38.4329,45.7749 ],
    [ u"ir",u"Marivan",111495,35.527,46.1763 ],
    [ u"ir",u"Marv Dasht",129483,29.8742,52.8025 ],
    [ u"ir",u"Mashhad",2307254,36.297,59.6062 ],
    [ u"ir",u"Masjed-e Soleyman",111522,31.9364,49.3039 ],
    [ u"ir",u"Mehran",11831,33.1222,46.1646 ],
    [ u"ir",u"Mehriz",36723,31.591682,54.431775 ],
    [ u"ir",u"Meybod",51879,32.250137,54.016585 ],
    [ u"ir",u"Miandoab",132830,36.9694,46.1027 ],
    [ u"ir",u"Minab",70796,27.1467,57.0801 ],
    [ u"ir",u"Minudasht",27988,37.228815,55.374624 ],
    [ u"ir",u"Nahavand",76258,34.1885,48.377 ],
    [ u"ir",u"Naqadeh",73535,36.9553,45.388 ],
    [ u"ir",u"Neka",48851,36.650786,53.299048 ],
    [ u"ir",u"Neyshabur",220954,36.213288,58.795755 ],
    [ u"ir",u"Nur",13529,36.573523,52.013823 ],
    [ u"ir",u"Omidiyeh",47048,30.7458,49.7087 ],
    [ u"ir",u"Orumiyeh",602443,37.5553,45.0724 ],
    [ u"ir",u"Oshnaviyeh",50692,37.0397,45.0983 ],
    [ u"ir",u"Pakdasht",57416,35.4816,51.6802 ],
    [ u"ir",u"Parsabad",101715,39.6482,47.9174 ],
    [ u"ir",u"Paveh",17779,35.0434,46.3565 ],
    [ u"ir",u"Piranshahr",61420,36.701,45.1413 ],
    [ u"ir",u"Pishva",53861,35.308,51.7267 ],
    [ u"ir",u"Qarchak",251857,35.439444,51.568889 ],
    [ u"ir",u"Qazvin",333652,36.2797,50.0049 ],
    [ u"ir",u"Qeshm",16691,26.9581,56.2719 ],
    [ u"ir",u"Qom",1011103,34.6401,50.8764 ],
    [ u"ir",u"Qorveh",87960,35.1664,47.8045 ],
    [ u"ir",u"Quchan",111765,37.105997,58.509547 ],
    [ u"ir",u"Rafsanjan",147691,30.4067,55.9939 ],
    [ u"ir",u"Ramhormoz",38825,31.279972,49.603511 ],
    [ u"ir",u"Ramsar",31976,36.902973,50.658211 ],
    [ u"ir",u"Ramshir",19456,30.8946,49.4092 ],
    [ u"ir",u"Rasht",594619,37.280769,49.58319 ],
    [ u"ir",u"Ravar",40170,31.265625,56.80545 ],
    [ u"ir",u"Rehnan",49147,32.684617,51.60129 ],
    [ u"ir",u"Robat Karim",62759,35.4846,51.0829 ],
    [ u"ir",u"Rudbar",17085,36.8049,49.408 ],
    [ u"ir",u"Rudsar",47506,37.137612,50.288001 ],
    [ u"ir",u"Sabzevar",226208,36.212598,57.681906 ],
    [ u"ir",u"Salmas",81614,38.1973,44.7653 ],
    [ u"ir",u"Sanandaj",349200,35.3144,46.9923 ],
    [ u"ir",u"Saqqez",151249,36.2463,46.2665 ],
    [ u"ir",u"Sarab",37771,37.9408,47.5367 ],
    [ u"ir",u"Sarakhs",46505,36.5449,61.1577 ],
    [ u"ir",u"Sari",255416,36.563319,53.060087 ],
    [ u"ir",u"Saveh",175545,35.0213,50.3566 ],
    [ u"ir",u"Semirom",27222,31.414183,51.569443 ],
    [ u"ir",u"Semnan",124831,35.572914,53.397139 ],
    [ u"ir",u"Shadegan",37224,30.649722,48.664722 ],
    [ u"ir",u"Shahr-e Babak",52413,30.1165,55.1186 ],
    [ u"ir",u"Shahr-e Kord",129167,32.325556,50.864444 ],
    [ u"ir",u"Shahreza",100806,32.0089,51.8668 ],
    [ u"ir",u"Shahriyar",58855,35.6596,51.0593 ],
    [ u"ir",u"Shahrud",131895,36.418189,54.976282 ],
    [ u"ir",u"Shiraz",1249972,29.6036,52.5388 ],
    [ u"ir",u"Shirvan",98688,37.396693,57.929517 ],
    [ u"ir",u"Shush",52290,32.1942,48.2436 ],
    [ u"ir",u"Shushtar",77515,32.0455,48.8567 ],
    [ u"ir",u"Sirjan",207661,29.452,55.6814 ],
    [ u"ir",u"Sonqor",43177,34.7837,47.6004 ],
    [ u"ir",u"Susangerd",41447,31.5608,48.1831 ],
    [ u"ir",u"Tabas",49999,33.595856,56.924368 ],
    [ u"ir",u"Tabriz",1424701,38.08,46.2919 ],
    [ u"ir",u"Tafresh",14399,34.692,50.013 ],
    [ u"ir",u"Taft",19394,31.747097,54.208815 ],
    [ u"ir",u"Takab",51546,36.4009,47.1133 ],
    [ u"ir",u"Takestan",71504,36.0696,49.6959 ],
    [ u"ir",u"Talesh",45309,37.8008,48.9037 ],
    [ u"ir",u"Taybad",37517,34.74,60.7756 ],
    [ u"ir",u"Tonekabon",37504,36.816259,50.873763 ],
    [ u"ir",u"Torbat-e Jam",58935,35.244,60.6225 ],
    [ u"ir",u"Tuysarkan",48165,34.5481,48.4469 ],
    [ u"ir",u"Varamin",179620,35.3242,51.6457 ],
    [ u"ir",u"Yazd",477926,31.897222,54.3675 ],
    [ u"ir",u"Zabol",121999,31.0287,61.5012 ],
    [ u"ir",u"Zanjan",357489,36.6736,48.4787 ],
    [ u"ir",u"Zarand",58987,30.812709,56.563993 ],
    [ u"is",u"Akranes",5606,64.316667,-22.1 ],
    [ u"is",u"Akureyri",16563,65.666667,-18.1 ],
    [ u"is",u"Bíldudalur",204,65.683333,-23.6 ],
    [ u"is",u"Blönduós",936,65.666667,-20.3 ],
    [ u"is",u"Bolungarvík",918,66.15,-23.25 ],
    [ u"is",u"Borgarnes",1783,64.533333,-21.916667 ],
    [ u"is",u"Dalvík",1403,65.966667,-18.533333 ],
    [ u"is",u"Djúpivogur",389,64.65,-14.283333 ],
    [ u"is",u"Drangsnes",77,65.683333,-21.45 ],
    [ u"is",u"Eyrarbakki",594,63.866667,-21.15 ],
    [ u"is",u"Flateyri",299,66.05,-23.516667 ],
    [ u"is",u"Grenivík",300,65.95,-18.183333 ],
    [ u"is",u"Grindavík",2539,63.833333,-22.433333 ],
    [ u"is",u"Hafnir",118,63.933333,-22.683333 ],
    [ u"is",u"Hella",694,63.833333,-20.4 ],
    [ u"is",u"Hellissandur",408,64.916667,-23.9 ],
    [ u"is",u"Hjalteyri",41,65.85,-18.2 ],
    [ u"is",u"Hnífsdalur",409,66.116667,-23.133333 ],
    [ u"is",u"Höfn",1695,64.25,-15.216667 ],
    [ u"is",u"Hofsós",172,65.9,-19.433333 ],
    [ u"is",u"Hólar",108,65.733333,-19.133333 ],
    [ u"is",u"Hólmavík",424,65.716667,-21.683333 ],
    [ u"is",u"Húsavík",2338,66.05,-17.35 ],
    [ u"is",u"Hvammstangi",573,65.4,-20.95 ],
    [ u"is",u"Hvanneyri",231,64.566667,-21.766667 ],
    [ u"is",u"Hvolsvöllur",753,63.75,-20.233333 ],
    [ u"is",u"Keflavík",7930,64.016667,-22.566667 ],
    [ u"is",u"Kirkjubæjarklaustur",139,63.783333,-18.066667 ],
    [ u"is",u"Kópasker",144,66.3,-16.45 ],
    [ u"is",u"Kópavogur",26157,64.1,-21.916667 ],
    [ u"is",u"Laugarvatn",212,64.216667,-20.733333 ],
    [ u"is",u"Litli-Árskógssandur",130,65.95,-18.366667 ],
    [ u"is",u"Ólafsvík",992,64.883333,-23.716667 ],
    [ u"is",u"Raufarhöfn",226,66.45,-15.95 ],
    [ u"is",u"Reykhólar",117,65.45,-22.2 ],
    [ u"is",u"Reykholt",31,64.666667,-21.3 ],
    [ u"is",u"Reykjavík",113907,64.15,-21.95 ],
    [ u"is",u"Selfoss",5396,63.933333,-21 ],
    [ u"is",u"Skagaströnd",550,65.833333,-20.316667 ],
    [ u"is",u"Stokkseyri",459,63.833333,-21.066667 ],
    [ u"is",u"Stykkishólmur",1059,65.066667,-22.733333 ],
    [ u"is",u"Vestmannaeyjar",4203,63.365,-20.2075 ],
    [ u"is",u"Vogar",982,63.966667,-22.366667 ],
    [ u"it",u"Abano Terme",19112,45.35,11.783333 ],
    [ u"it",u"Abbiategrasso",30308,45.4,8.9 ],
    [ u"it",u"Acerra",46729,40.95,14.366667 ],
    [ u"it",u"Aci Castello",18554,37.55,15.133333 ],
    [ u"it",u"Aci Catena",31216,37.6,15.133333 ],
    [ u"it",u"Acireale",51967,37.616667,15.166667 ],
    [ u"it",u"Acquaviva delle Fonti",22030,40.9,16.833333 ],
    [ u"it",u"Acqui Terme",19410,44.683333,8.466667 ],
    [ u"it",u"Acri",21495,39.483333,16.383333 ],
    [ u"it",u"Adelfia",17132,41,16.866667 ],
    [ u"it",u"Adrano",36184,37.666667,14.833333 ],
    [ u"it",u"Adria",21182,45.056389,12.057778 ],
    [ u"it",u"Afragola",59416,40.916667,14.3 ],
    [ u"it",u"Agira",8585,37.65,14.516667 ],
    [ u"it",u"Agliana",15721,43.9,11 ],
    [ u"it",u"Agrate Brianza",14002,45.566667,9.35 ],
    [ u"it",u"Agrigento",55402,37.316667,13.566667 ],
    [ u"it",u"Agropoli",21243,40.35,14.983333 ],
    [ u"it",u"Alassio",10384,44,8.166667 ],
    [ u"it",u"Alatri",30322,41.716667,13.35 ],
    [ u"it",u"Alba",30860,44.7,8.033333 ],
    [ u"it",u"Albano Laziale",37869,41.733333,12.65 ],
    [ u"it",u"Albenga",22761,44.05,8.216667 ],
    [ u"it",u"Alberobello",11112,40.783333,17.266667 ],
    [ u"it",u"Albignasego",19835,45.35,11.866667 ],
    [ u"it",u"Albino",17387,45.766667,9.783333 ],
    [ u"it",u"Alcamo",44278,37.983333,12.966667 ],
    [ u"it",u"Alfonsine",11963,44.506111,12.056389 ],
    [ u"it",u"Alghero",42034,40.558889,8.318056 ],
    [ u"it",u"Alpignano",17390,45.1,7.516667 ],
    [ u"it",u"Altamura",66119,40.816667,16.55 ],
    [ u"it",u"Altavilla Vicentina",10643,45.516667,11.466667 ],
    [ u"it",u"Altopascio",12150,43.816667,10.666667 ],
    [ u"it",u"Alzano Lombardo",12767,45.733333,9.716667 ],
    [ u"it",u"Amantea",13733,39.133333,16.066667 ],
    [ u"it",u"Amelia",11282,42.55,12.416667 ],
    [ u"it",u"Anagni",21519,41.733333,13.15 ],
    [ u"it",u"Ancona",100982,43.633333,13.5 ],
    [ u"it",u"Andria",93819,41.216667,16.283333 ],
    [ u"it",u"Angri",29745,40.733333,14.566667 ],
    [ u"it",u"Anguillara Sabazia",17734,42.083333,12.266667 ],
    [ u"it",u"Anzio",41629,41.45,12.616667 ],
    [ u"it",u"Aosta",33503,45.733333,7.333333 ],
    [ u"it",u"Appiano",13521,46.466667,11.25 ],
    [ u"it",u"Apricena",13753,41.783333,15.45 ],
    [ u"it",u"Aprilia",67935,41.6,12.65 ],
    [ u"it",u"Aradeo",9108,40.133333,18.133333 ],
    [ u"it",u"Aragona",10490,37.4,13.616667 ],
    [ u"it",u"Arco",15373,45.916667,10.883333 ],
    [ u"it",u"Arcola",10170,44.116667,9.9 ],
    [ u"it",u"Arcore",17361,45.616667,9.316667 ],
    [ u"it",u"Ardea",32934,41.6,12.55 ],
    [ u"it",u"Arenzano",11572,44.4,8.683333 ],
    [ u"it",u"Arese",19649,45.533333,9.083333 ],
    [ u"it",u"Arezzo",95233,43.416667,11.883333 ],
    [ u"it",u"Argenta",22005,44.616667,11.833333 ],
    [ u"it",u"Ariano Irpino",23034,41.15,15.083333 ],
    [ u"it",u"Ariccia",19033,41.716667,12.666667 ],
    [ u"it",u"Arluno",10662,45.5,8.933333 ],
    [ u"it",u"Arona",14423,45.766667,8.566667 ],
    [ u"it",u"Artena",11564,41.733333,12.916667 ],
    [ u"it",u"Arzachena",11716,41.083333,9.383333 ],
    [ u"it",u"Arzano",38397,40.916667,14.266667 ],
    [ u"it",u"Arzignano",24565,45.516667,11.333333 ],
    [ u"it",u"Ascoli Piceno",50092,42.85,13.566667 ],
    [ u"it",u"Asola",10112,45.216667,10.4 ],
    [ u"it",u"Assèmini",26309,39.290556,8.996944 ],
    [ u"it",u"Assisi",25749,43.066667,12.616667 ],
    [ u"it",u"Asti",72194,44.9,8.2 ],
    [ u"it",u"Atessa",11081,42.066667,14.45 ],
    [ u"it",u"Atri",11904,42.583333,13.966667 ],
    [ u"it",u"Atripalda",11361,40.916667,14.833333 ],
    [ u"it",u"Augusta",33635,37.216667,15.216667 ],
    [ u"it",u"Aulla",10492,44.2,9.966667 ],
    [ u"it",u"Avellino",52466,40.9,14.783333 ],
    [ u"it",u"Aversa",56626,40.966667,14.2 ],
    [ u"it",u"Avezzano",38957,42.033333,13.416667 ],
    [ u"it",u"Avigliana",12080,45.083333,7.383333 ],
    [ u"it",u"Avigliano",11881,40.733333,15.716667 ],
    [ u"it",u"Avola",32767,36.9,15.133333 ],
    [ u"it",u"Azzano Decimo",13421,45.883056,12.713056 ],
    [ u"it",u"Bacoli",26579,40.8,14.083333 ],
    [ u"it",u"Badia Polesine",10947,45.083333,11.483333 ],
    [ u"it",u"Bagheria",55388,38.083333,13.5 ],
    [ u"it",u"Bagnacavallo",16423,44.416667,12 ],
    [ u"it",u"Bagnara Calabra",11165,38.283333,15.8 ],
    [ u"it",u"Bagno a Ripoli",25431,43.75,11.316667 ],
    [ u"it",u"Bagnolo Mella",12165,45.433333,10.166667 ],
    [ u"it",u"Barberino di Mugello",10271,44,11.25 ],
    [ u"it",u"Bareggio",17271,45.466667,8.983333 ],
    [ u"it",u"Barga",10292,44.066667,10.483333 ],
    [ u"it",u"Bari",303049,41.133333,16.85 ],
    [ u"it",u"Barletta",92650,41.316667,16.283333 ],
    [ u"it",u"Baronissi",16375,40.733333,14.75 ],
    [ u"it",u"Barrafranca",12737,37.366667,14.2 ],
    [ u"it",u"Bassano del Grappa",42457,45.766667,11.733333 ],
    [ u"it",u"Battipaglia",52818,40.616667,14.966667 ],
    [ u"it",u"Beinasco",17416,45.016667,7.583333 ],
    [ u"it",u"Belluno",35895,46.145,12.221389 ],
    [ u"it",u"Belmonte Mezzagno",11279,38.033333,13.383333 ],
    [ u"it",u"Belpasso",22316,37.583333,14.966667 ],
    [ u"it",u"Belvedere Marittimo",8880,39.616667,15.866667 ],
    [ u"it",u"Benevento",61728,41.133333,14.75 ],
    [ u"it",u"Bergamo",113603,45.683333,9.716667 ],
    [ u"it",u"Bernalda",11532,40.4,16.683333 ],
    [ u"it",u"Bertinoro",9941,44.146944,12.138889 ],
    [ u"it",u"Besana in Brianza",15703,45.7,9.283333 ],
    [ u"it",u"Biancavilla",22829,37.633333,14.866667 ],
    [ u"it",u"Biassono",12090,45.616667,9.266667 ],
    [ u"it",u"Bibbiena",12123,43.7,11.816667 ],
    [ u"it",u"Biella",45636,45.566667,8.05 ],
    [ u"it",u"Bisceglie",52878,41.233333,16.5 ],
    [ u"it",u"Bisignano",11136,39.516667,16.283333 ],
    [ u"it",u"Bitetto",10662,41.033333,16.75 ],
    [ u"it",u"Bitonto",58242,41.1,16.683333 ],
    [ u"it",u"Bitritto",10384,41.05,16.833333 ],
    [ u"it",u"Bollate",49620,45.55,9.116667 ],
    [ u"it",u"Bologna",367168,44.483333,11.333333 ],
    [ u"it",u"Bolzano",91209,46.516667,11.366667 ],
    [ u"it",u"Bondeno",15698,44.883333,11.416667 ],
    [ u"it",u"Bordighera",9965,43.766667,7.65 ],
    [ u"it",u"Borgaro Torinese",14353,45.15,7.666667 ],
    [ u"it",u"Borgomanero",20133,45.7,8.466667 ],
    [ u"it",u"Borgo San Dalmazzo",11857,44.333333,7.5 ],
    [ u"it",u"Borgo San Lorenzo",16628,43.95,11.383333 ],
    [ u"it",u"Borgosesia",14144,45.716667,8.266667 ],
    [ u"it",u"Boscoreale",26944,40.783333,14.466667 ],
    [ u"it",u"Boscotrecase",10393,40.766667,14.466667 ],
    [ u"it",u"Boves",9782,44.316667,7.55 ],
    [ u"it",u"Bovolone",14128,45.25,11.116667 ],
    [ u"it",u"Bra",29454,44.7,7.85 ],
    [ u"it",u"Bracciano",15003,42.1,12.166667 ],
    [ u"it",u"Brescia",193713,45.55,10.25 ],
    [ u"it",u"Bressanone",18599,46.716667,11.65 ],
    [ u"it",u"Bresso",26815,45.533333,9.183333 ],
    [ u"it",u"Brindisi",92457,40.633333,17.933333 ],
    [ u"it",u"Broni",9514,45.066667,9.266667 ],
    [ u"it",u"Bronte",19134,37.783333,14.833333 ],
    [ u"it",u"Brugherio",32439,45.55,9.3 ],
    [ u"it",u"Brunico",13982,46.8,11.933333 ],
    [ u"it",u"Brusciano",16051,40.916667,14.416667 ],
    [ u"it",u"Bucine",9940,43.483333,11.616667 ],
    [ u"it",u"Budrio",16322,44.383333,11.9 ],
    [ u"it",u"Busca",10168,44.516667,7.483333 ],
    [ u"it",u"Bussolengo",18755,45.466667,10.85 ],
    [ u"it",u"Busto Arsizio",79229,45.616667,8.85 ],
    [ u"it",u"Busto Garolfo",13520,45.55,8.883333 ],
    [ u"it",u"Càbras",9249,39.93,8.531389 ],
    [ u"it",u"Cadoneghe",15600,45.433333,11.916667 ],
    [ u"it",u"Cagliari",157343,39.216667,9.116667 ],
    [ u"it",u"Cagli",9068,43.55,12.65 ],
    [ u"it",u"Cairo Montenotte",13547,44.4,8.266667 ],
    [ u"it",u"Caivano",36860,40.95,14.3 ],
    [ u"it",u"Calcinato",11817,45.45,10.4 ],
    [ u"it",u"Calderara di Reno",12521,44.566667,11.266667 ],
    [ u"it",u"Caldogno",10854,45.6,11.5 ],
    [ u"it",u"Calenzano",15349,43.85,11.15 ],
    [ u"it",u"Calolziocorte",14168,45.8,9.433333 ],
    [ u"it",u"Caltagirone",38753,37.233333,14.516667 ],
    [ u"it",u"Caltanissetta",64189,37.483333,14.066667 ],
    [ u"it",u"Calvizzano",13333,40.9,14.183333 ],
    [ u"it",u"Camaiore",30860,43.933333,10.3 ],
    [ u"it",u"Cameri",10236,45.5,8.65 ],
    [ u"it",u"Campagna",16760,40.666667,15.116667 ],
    [ u"it",u"Campi Bisenzio",39555,43.816667,11.133333 ],
    [ u"it",u"Campiglia Marittima",13014,43.05,10.616667 ],
    [ u"it",u"Campi Salentina",11120,40.399444,18.018611 ],
    [ u"it",u"Campobasso",47569,41.566667,14.65 ],
    [ u"it",u"Campobello di Licata",11557,37.25,13.916667 ],
    [ u"it",u"Campobello di Mazara",11225,37.633333,12.75 ],
    [ u"it",u"Campodarsego",12327,45.5,11.9 ],
    [ u"it",u"Campolongo Maggiore",9607,45.321111,12.046667 ],
    [ u"it",u"Camponogara",11841,45.385,12.072222 ],
    [ u"it",u"Camposampiero",11651,45.566667,11.933333 ],
    [ u"it",u"Canegrate",12649,45.566667,8.933333 ],
    [ u"it",u"Canelli",10595,44.716667,8.283333 ],
    [ u"it",u"Canicattì",32514,37.35,13.85 ],
    [ u"it",u"Canosa di Puglia",30426,41.216667,16.066667 ],
    [ u"it",u"Cantù",36513,45.733333,9.133333 ],
    [ u"it",u"Caorle",11647,45.599722,12.883889 ],
    [ u"it",u"Capaccio",21122,40.416667,15.083333 ],
    [ u"it",u"Capaci",10559,38.166667,13.233333 ],
    [ u"it",u"Capannori",41274,43.833333,10.566667 ],
    [ u"it",u"Capoterra",25572,39.174444,8.971111 ],
    [ u"it",u"Capua",19209,41.1,14.2 ],
    [ u"it",u"Capurso",14808,41.05,16.916667 ],
    [ u"it",u"Carate Brianza",17114,45.683333,9.233333 ],
    [ u"it",u"Caravaggio",14976,45.5,9.633333 ],
    [ u"it",u"Carbonera",10501,45.680556,12.288333 ],
    [ u"it",u"Carbonia",31508,39.167222,8.522222 ],
    [ u"it",u"Cardito",20232,40.95,14.3 ],
    [ u"it",u"Cariati",8058,39.5,16.95 ],
    [ u"it",u"Carini",29785,38.133333,13.183333 ],
    [ u"it",u"Carlentini",17572,37.266667,15.016667 ],
    [ u"it",u"Carmagnola",25658,44.85,7.716667 ],
    [ u"it",u"Carmiano",12291,40.35,18.05 ],
    [ u"it",u"Carmignano",13366,45.15,11.65 ],
    [ u"it",u"Carovigno",15611,40.7,17.65 ],
    [ u"it",u"Carpenedolo",11306,45.366667,10.433333 ],
    [ u"it",u"Carpi",63336,44.783333,10.883333 ],
    [ u"it",u"Carrara",67228,44.083333,10.1 ],
    [ u"it",u"Carugate",14033,45.55,9.333333 ],
    [ u"it",u"Casal di Principe",19983,41,14.133333 ],
    [ u"it",u"Casalecchio di Reno",33288,44.466667,11.266667 ],
    [ u"it",u"Casale Monferrato",35337,45.133333,8.45 ],
    [ u"it",u"Casalgrande",15082,44.583333,10.733333 ],
    [ u"it",u"Casalmaggiore",14802,44.983333,10.433333 ],
    [ u"it",u"Casalnuovo di Napoli",52709,40.916667,14.333333 ],
    [ u"it",u"Casalpusterlengo",14586,45.183333,9.65 ],
    [ u"it",u"Casaluce",10243,41,14.2 ],
    [ u"it",u"Casamassima",17519,40.95,16.916667 ],
    [ u"it",u"Casandrino",13963,40.933333,14.25 ],
    [ u"it",u"Casarano",20722,40,18.166667 ],
    [ u"it",u"Casatenovo",13014,45.7,9.316667 ],
    [ u"it",u"Cascina",40663,43.683333,10.55 ],
    [ u"it",u"Caselle Torinese",16826,45.166667,7.65 ],
    [ u"it",u"Caserta",78598,41.066667,14.333333 ],
    [ u"it",u"Casoria",78629,40.9,14.283333 ],
    [ u"it",u"Cassano delle Murge",12545,40.883333,16.766667 ],
    [ u"it",u"Cassino",35683,41.5,13.816667 ],
    [ u"it",u"Castano Primo",10792,45.55,8.783333 ],
    [ u"it",u"Castelbuono",10129,37.933333,14.083333 ],
    [ u"it",u"Casteldaccia",9671,38.05,13.533333 ],
    [ u"it",u"Castelfidardo",17870,43.466667,13.55 ],
    [ u"it",u"Castelfiorentino",17602,43.6,10.966667 ],
    [ u"it",u"Castelfranco di Sotto",12130,43.7,10.75 ],
    [ u"it",u"Castelfranco Emilia",27398,44.616667,11.05 ],
    [ u"it",u"Castelfranco Veneto",33449,45.666667,11.916667 ],
    [ u"it",u"Castel Goffredo",10916,45.3,10.466667 ],
    [ u"it",u"Castellammare del Golfo",15504,38.016667,12.883333 ],
    [ u"it",u"Castellammare di Stabia",66944,40.7,14.483333 ],
    [ u"it",u"Castellamonte",9437,45.383333,7.7 ],
    [ u"it",u"Castellana Grotte",18437,40.883333,17.166667 ],
    [ u"it",u"Castellaneta",18022,40.633333,16.933333 ],
    [ u"it",u"Castellanza",14926,45.616667,8.9 ],
    [ u"it",u"Castellarano",13323,44.516667,10.733333 ],
    [ u"it",u"Castelletto sopra Ticino",9416,45.716667,8.633333 ],
    [ u"it",u"Castel Maggiore",17023,44.566667,11.366667 ],
    [ u"it",u"Castelnuovo Rangone",13498,44.55,10.933333 ],
    [ u"it",u"Castel San Giorgio",13460,40.783333,14.7 ],
    [ u"it",u"Castel San Giovanni",12316,45.066667,9.433333 ],
    [ u"it",u"Castel San Pietro Terme",20368,44.4,11.583333 ],
    [ u"it",u"Casteltermini",8384,37.533333,13.65 ],
    [ u"it",u"Castelvetrano",27286,37.683333,12.783333 ],
    [ u"it",u"Castelvetro di Modena",10604,44.5,10.95 ],
    [ u"it",u"Castel Volturno",19652,41.033333,13.933333 ],
    [ u"it",u"Castenaso",14193,44.5,11.466667 ],
    [ u"it",u"Castiglione del Lago",15309,43.116667,12.05 ],
    [ u"it",u"Castiglione delle Stiviere",20166,45.383333,10.483333 ],
    [ u"it",u"Castiglion Fiorentino",12795,43.333333,11.916667 ],
    [ u"it",u"Castrolibero",10495,39.3,16.183333 ],
    [ u"it",u"Castrovillari",21094,39.816667,16.2 ],
    [ u"it",u"Catania",307331,37.5,15.1 ],
    [ u"it",u"Catanzaro",91584,38.9,16.583333 ],
    [ u"it",u"Cattolica",16157,43.966667,12.733333 ],
    [ u"it",u"Cavallino",11878,40.3,18.2 ],
    [ u"it",u"Cavarzere",15543,45.135556,12.081667 ],
    [ u"it",u"Cave",11014,41.816667,12.933333 ],
    [ u"it",u"Cazzago San Martino",10732,45.583333,10.016667 ],
    [ u"it",u"Ceccano",24918,41.566667,13.333333 ],
    [ u"it",u"Cecina",27969,43.316667,10.516667 ],
    [ u"it",u"Cefalù",14334,38.033333,14.016667 ],
    [ u"it",u"Céglie Messápica",20695,40.65,17.516667 ],
    [ u"it",u"Celano",11701,42.083333,13.55 ],
    [ u"it",u"Cento",30001,44.716667,11.283333 ],
    [ u"it",u"Cercola",19764,40.85,14.35 ],
    [ u"it",u"Cerea",16046,45.2,11.216667 ],
    [ u"it",u"Cerignola",58888,41.266667,15.9 ],
    [ u"it",u"Cernusco sul Naviglio",27540,45.516667,9.316667 ],
    [ u"it",u"Cerreto Guidi",10208,43.75,10.883333 ],
    [ u"it",u"Cerro Maggiore",14181,45.6,8.95 ],
    [ u"it",u"Certaldo",16096,43.55,11.033333 ],
    [ u"it",u"Cerveteri",33069,42,12.1 ],
    [ u"it",u"Cervia",26914,44.261667,12.358889 ],
    [ u"it",u"Cervignano del Friuli",12674,45.821111,13.338056 ],
    [ u"it",u"Cesano Maderno",34758,45.633333,9.133333 ],
    [ u"it",u"Cesena",92280,44.143333,12.249722 ],
    [ u"it",u"Cesenatico",22479,44.198333,12.411667 ],
    [ u"it",u"Cetraro",10296,39.516667,15.933333 ],
    [ u"it",u"Chiampo",12865,45.55,11.283333 ],
    [ u"it",u"Chiaravalle",14334,43.6,13.316667 ],
    [ u"it",u"Chiari",18414,45.533333,9.933333 ],
    [ u"it",u"Chiavari",27277,44.316667,9.316667 ],
    [ u"it",u"Chieri",33804,45.016667,7.816667 ],
    [ u"it",u"Chieti",51194,42.35,14.166667 ],
    [ u"it",u"Chioggia",53074,45.225556,12.288889 ],
    [ u"it",u"Chiusi",8100,43.016667,11.95 ],
    [ u"it",u"Chivasso",23591,45.183333,7.883333 ],
    [ u"it",u"Ciampino",40686,41.8,12.6 ],
    [ u"it",u"Cicciano",12266,40.966667,14.533333 ],
    [ u"it",u"Cingoli",10261,43.366667,13.216667 ],
    [ u"it",u"Cinisello Balsamo",74123,45.55,9.216667 ],
    [ u"it",u"Cinisi",11305,38.15,13.1 ],
    [ u"it",u"Ciriè",18882,45.233333,7.6 ],
    [ u"it",u"Cirò Marina",13929,39.366667,17.133333 ],
    [ u"it",u"Cisterna",35945,41.583333,12.816667 ],
    [ u"it",u"Cisternino",12265,40.733333,17.416667 ],
    [ u"it",u"Cittadella",19681,45.65,11.783333 ],
    [ u"it",u"Città di Castello",39959,43.45,12.233333 ],
    [ u"it",u"Cittanova",10282,38.35,16.083333 ],
    [ u"it",u"Cividale del Friuli",11590,46.093056,13.4275 ],
    [ u"it",u"Civita Castellana",16785,42.283333,12.416667 ],
    [ u"it",u"Civitanova Marche",39288,43.3,13.733333 ],
    [ u"it",u"Civitavecchia",51480,42.1,11.8 ],
    [ u"it",u"Codigoro",13147,44.831111,12.114167 ],
    [ u"it",u"Codogno",14558,45.15,9.7 ],
    [ u"it",u"Codroipo",14660,45.96,12.979167 ],
    [ u"it",u"Cogoleto",9148,44.383333,8.65 ],
    [ u"it",u"Collecchio",12647,44.75,10.216667 ],
    [ u"it",u"Colleferro",22123,41.733333,12.983333 ],
    [ u"it",u"Collegno",17767,45.083333,7.566667 ],
    [ u"it",u"Cologno al Serio",10175,45.583333,9.7 ],
    [ u"it",u"Cologno Monzese",47871,45.533333,9.283333 ],
    [ u"it",u"Comacchio",20054,44.6975,12.185833 ],
    [ u"it",u"Comiso",29575,36.933333,14.6 ],
    [ u"it",u"Como",78582,45.783333,9.083333 ],
    [ u"it",u"Concordia Sagittaria",10859,45.759444,12.840556 ],
    [ u"it",u"Concorezzo",14646,45.583333,9.333333 ],
    [ u"it",u"Conegliano",36037,45.890556,12.2925 ],
    [ u"it",u"Conselice",9011,44.516667,11.816667 ],
    [ u"it",u"Conversano",24802,40.966667,17.116667 ],
    [ u"it",u"Copertino",22105,40.266667,18.05 ],
    [ u"it",u"Copparo",18110,44.9,11.816667 ],
    [ u"it",u"Corato",45276,41.15,16.416667 ],
    [ u"it",u"Corciano",16983,43.133333,12.283333 ],
    [ u"it",u"Cordenons",17824,45.989722,12.701944 ],
    [ u"it",u"Cori",11826,41.65,12.916667 ],
    [ u"it",u"Corigliano Calabro",36531,39.6,16.516667 ],
    [ u"it",u"Corleone",11982,37.816667,13.3 ],
    [ u"it",u"Cormano",18545,45.533333,9.166667 ],
    [ u"it",u"Cornaredo",21091,45.5,9.016667 ],
    [ u"it",u"Cornedo Vicentino",11378,45.616667,11.333333 ],
    [ u"it",u"Correggio",21540,44.766667,10.783333 ],
    [ u"it",u"Corridonia",14425,43.25,13.5 ],
    [ u"it",u"Corsico",32168,45.433333,9.116667 ],
    [ u"it",u"Cortona",22705,43.266667,11.983333 ],
    [ u"it",u"Cosenza",67380,39.3,16.25 ],
    [ u"it",u"Cossato",15921,45.566667,8.166667 ],
    [ u"it",u"Creazzo",10529,45.366667,11.45 ],
    [ u"it",u"Crema",34359,45.366667,9.683333 ],
    [ u"it",u"Cremona",70748,45.116667,10.033333 ],
    [ u"it",u"Crevalcore",12413,44.716667,11.15 ],
    [ u"it",u"Crispiano",12663,40.605833,17.230278 ],
    [ u"it",u"Crotone",48825,39.083333,17.133333 ],
    [ u"it",u"Cuneo",52500,44.383333,7.533333 ],
    [ u"it",u"Cuorgnè",10371,45.383333,7.65 ],
    [ u"it",u"Cusano Milanino",19368,45.55,9.183333 ],
    [ u"it",u"Cutro",10102,39.033333,16.983333 ],
    [ u"it",u"Cutrofiano",9105,40.116667,18.2 ],
    [ u"it",u"Dalmine",23928,45.65,9.6 ],
    [ u"it",u"Darfo",14391,45.883333,10.183333 ],
    [ u"it",u"Desenzano del Garda",25974,45.466667,10.533333 ],
    [ u"it",u"Desio",36708,45.616667,9.216667 ],
    [ u"it",u"Dolo",15173,45.428333,12.0725 ],
    [ u"it",u"Domodossola",18887,46.116667,8.283333 ],
    [ u"it",u"Dueville",13841,45.633333,11.533333 ],
    [ u"it",u"Eboli",37120,40.6,15.066667 ],
    [ u"it",u"Empoli",45971,43.716667,10.95 ],
    [ u"it",u"Enna",30785,37.566667,14.266667 ],
    [ u"it",u"Eraclea",13132,45.580556,12.675556 ],
    [ u"it",u"Erba",17258,45.8,9.25 ],
    [ u"it",u"Erchie",8828,40.433333,17.733333 ],
    [ u"it",u"Ercolano",53341,40.8,14.35 ],
    [ u"it",u"Erice",25160,38.033333,12.583333 ],
    [ u"it",u"Este",16790,45.233333,11.65 ],
    [ u"it",u"Fabriano",31087,43.333333,12.9 ],
    [ u"it",u"Faenza",54919,44.283333,11.883333 ],
    [ u"it",u"Fagnano Olona",10957,45.666667,8.866667 ],
    [ u"it",u"Falconara Marittima",27917,43.616667,13.4 ],
    [ u"it",u"Fano",59864,43.833333,13.016667 ],
    [ u"it",u"Fara in Sabina",12825,42.2,12.716667 ],
    [ u"it",u"Fasano",38871,40.833333,17.366667 ],
    [ u"it",u"Favara",31846,37.316667,13.65 ],
    [ u"it",u"Feltre",19580,46.016667,11.9 ],
    [ u"it",u"Ferentino",22555,41.7,13.25 ],
    [ u"it",u"Fermo",36060,43.15,13.716667 ],
    [ u"it",u"Ferrandina",9092,40.483333,16.45 ],
    [ u"it",u"Ferrara",131252,44.833333,11.583333 ],
    [ u"it",u"Ficarazzi",10829,38.083333,13.466667 ],
    [ u"it",u"Fidenza",24218,44.866667,10.05 ],
    [ u"it",u"Fiesole",14295,43.8,11.283333 ],
    [ u"it",u"Figline Valdarno",17130,43.616667,11.466667 ],
    [ u"it",u"Filottrano",9550,43.433333,13.35 ],
    [ u"it",u"Finale Emilia",15665,44.833333,11.283333 ],
    [ u"it",u"Finale Ligure",11543,44.166667,8.333333 ],
    [ u"it",u"Fiorano Modenese",16817,44.533333,10.816667 ],
    [ u"it",u"Fisciano",12790,40.766667,14.8 ],
    [ u"it",u"Fiume Veneto",10556,45.932778,12.730833 ],
    [ u"it",u"Fiumicino",56970,41.766667,12.233333 ],
    [ u"it",u"Fivizzano",8971,44.233333,10.133333 ],
    [ u"it",u"Florence",347194,43.766667,11.25 ],
    [ u"it",u"Floridia",22616,37.083333,15.15 ],
    [ u"it",u"Foggia",143826,41.45,15.566667 ],
    [ u"it",u"Foligno",50616,42.95,12.7 ],
    [ u"it",u"Follonica",21460,42.916667,10.75 ],
    [ u"it",u"Fondi",35157,41.35,13.416667 ],
    [ u"it",u"Fontanafredda",9796,45.975556,12.568333 ],
    [ u"it",u"Forio",15939,40.733333,13.85 ],
    [ u"it",u"Forlì",111574,44.223611,12.052778 ],
    [ u"it",u"Forlimpopoli",11622,44.194167,12.141111 ],
    [ u"it",u"Formello",11097,42.083333,12.4 ],
    [ u"it",u"Formia",40726,41.25,13.616667 ],
    [ u"it",u"Formigine",32419,44.566667,10.85 ],
    [ u"it",u"Forte dei Marmi",8177,43.95,10.166667 ],
    [ u"it",u"Fossano",25133,44.55,7.716667 ],
    [ u"it",u"Fossombrone",9621,43.683333,12.8 ],
    [ u"it",u"Francavilla al Mare",26335,42.416667,14.283333 ],
    [ u"it",u"Francavilla Fontana",37411,40.533333,17.583333 ],
    [ u"it",u"Francofonte",13398,37.233333,14.883333 ],
    [ u"it",u"Frascati",21305,41.8,12.683333 ],
    [ u"it",u"Frattamaggiore",31251,40.95,14.266667 ],
    [ u"it",u"Frattaminore",15664,40.95,14.266667 ],
    [ u"it",u"Frosinone",49775,41.633333,13.316667 ],
    [ u"it",u"Fucecchio",22187,43.733333,10.8 ],
    [ u"it",u"Gaeta",22566,41.2,13.583333 ],
    [ u"it",u"Galatina",27985,40.166667,18.166667 ],
    [ u"it",u"Galatone",15802,40.15,18.066667 ],
    [ u"it",u"Gallarate",48529,45.666667,8.783333 ],
    [ u"it",u"Galliate",14035,45.483333,8.7 ],
    [ u"it",u"Gallipoli",20588,40.055556,17.976389 ],
    [ u"it",u"Gambettola",9889,44.122778,12.343056 ],
    [ u"it",u"Garbagnate Milanese",29295,45.566667,9.066667 ],
    [ u"it",u"Gardone Val Trompia",11478,45.683333,10.183333 ],
    [ u"it",u"Garlasco",9429,45.2,8.916667 ],
    [ u"it",u"Gavardo",10948,45.583333,10.433333 ],
    [ u"it",u"Gavirate",9910,45.833333,8.716667 ],
    [ u"it",u"Gela",74959,37.066667,14.25 ],
    [ u"it",u"Gemona",11061,46.279444,13.143056 ],
    [ u"it",u"Genoa",585815,44.416667,8.95 ],
    [ u"it",u"Genzano di Roma",24626,41.7,12.683333 ],
    [ u"it",u"Ghedi",16690,45.4,10.266667 ],
    [ u"it",u"Giarre",27688,37.716667,15.183333 ],
    [ u"it",u"Giaveno",15884,45.033333,7.35 ],
    [ u"it",u"Giffoni Valle Piana",11523,40.733333,14.933333 ],
    [ u"it",u"Ginosa",22451,40.583333,16.75 ],
    [ u"it",u"Gioia del Colle",26205,40.8,16.916667 ],
    [ u"it",u"Gioia Tauro",18772,38.416667,15.9 ],
    [ u"it",u"Giovinazzo",19962,41.183333,16.666667 ],
    [ u"it",u"Giugliano in Campania",107680,40.933333,14.2 ],
    [ u"it",u"Giulianova",22299,42.75,13.95 ],
    [ u"it",u"Giussano",23745,45.7,9.233333 ],
    [ u"it",u"Goito",10185,45.25,10.666667 ],
    [ u"it",u"Gorgonzola",19167,45.533333,9.4 ],
    [ u"it",u"Gorizia",34602,45.945,13.597778 ],
    [ u"it",u"Grado",8658,45.678611,13.386944 ],
    [ u"it",u"Gragnano",29227,40.683333,14.516667 ],
    [ u"it",u"Grammichele",12797,37.216667,14.633333 ],
    [ u"it",u"Gravina in Puglia",43640,40.816667,16.416667 ],
    [ u"it",u"Grezzana",10706,45.516667,11.016667 ],
    [ u"it",u"Grosseto",72328,42.766667,11.133333 ],
    [ u"it",u"Grottaferrata",19485,41.783333,12.666667 ],
    [ u"it",u"Grottaglie",31543,40.533333,17.433333 ],
    [ u"it",u"Grottammare",15057,42.983333,13.866667 ],
    [ u"it",u"Grugliasco",37599,45.066667,7.583333 ],
    [ u"it",u"Grumo Appula",12677,41.016667,16.7 ],
    [ u"it",u"Grumo Nevano",18623,40.933333,14.266667 ],
    [ u"it",u"Gualdo Tadino",16216,43.233333,12.783333 ],
    [ u"it",u"Guardiagrele",10451,42.183333,14.216667 ],
    [ u"it",u"Guastalla",14572,44.916667,10.65 ],
    [ u"it",u"Gubbio",31742,43.35,12.583333 ],
    [ u"it",u"Guidonia",81837,42.016667,12.75 ],
    [ u"it",u"Guspini",13229,39.540556,8.629444 ],
    [ u"it",u"Gussago",15585,45.583333,10.15 ],
    [ u"it",u"Iesolo",22976,45.539444,12.649444 ],
    [ u"it",u"Iglesias",30851,39.311389,8.535 ],
    [ u"it",u"Imola",66903,44.35,11.7 ],
    [ u"it",u"Imperia",39987,43.883333,8.05 ],
    [ u"it",u"Impruneta",14949,43.683333,11.25 ],
    [ u"it",u"Induno Olona",10325,45.85,8.833333 ],
    [ u"it",u"Ischia",18621,40.733333,13.95 ],
    [ u"it",u"Isernia",21409,41.6,14.233333 ],
    [ u"it",u"Isola della Scala",10879,45.266667,11 ],
    [ u"it",u"Isola del Liri",12893,41.683333,13.566667 ],
    [ u"it",u"Ispica",15238,36.783333,14.916667 ],
    [ u"it",u"Ittiri",9593,40.6,8.566667 ],
    [ u"it",u"Ivrea",23680,45.466667,7.866667 ],
    [ u"it",u"Jesi",39463,43.516667,13.233333 ],
    [ u"it",u"Ladispoli",34995,41.933333,12.083333 ],
    [ u"it",u"Lainate",25446,45.566667,9.033333 ],
    [ u"it",u"Laives",15989,46.433333,11.333333 ],
    [ u"it",u"La Maddalena",11885,41.216667,9.4 ],
    [ u"it",u"Lana",10341,46.616667,11.15 ],
    [ u"it",u"Lanciano",38351,42.233333,14.383333 ],
    [ u"it",u"Lanuvio",11458,41.666667,12.7 ],
    [ u"it",u"Lariano",12092,41.716667,12.833333 ],
    [ u"it",u"La Spezia",89012,44.116667,9.833333 ],
    [ u"it",u"Lastra a Signa",18870,43.766667,11.1 ],
    [ u"it",u"Laterza",15268,40.616667,16.8 ],
    [ u"it",u"Latiano",15321,40.55,17.716667 ],
    [ u"it",u"Latina",124330,41.466667,12.866667 ],
    [ u"it",u"Latisana",12432,45.779167,13 ],
    [ u"it",u"Lauria",13507,40.033333,15.833333 ],
    [ u"it",u"Lavagna",13002,44.3,9.333333 ],
    [ u"it",u"Lavello",12774,41.05,15.8 ],
    [ u"it",u"Lecce",79259,40.383333,18.183333 ],
    [ u"it",u"Lecco",47113,45.85,9.383333 ],
    [ u"it",u"Leghorn",146762,43.55,10.316667 ],
    [ u"it",u"Legnago",24319,45.183333,11.3 ],
    [ u"it",u"Legnano",57996,45.6,8.9 ],
    [ u"it",u"Leinì",12343,45.183333,7.716667 ],
    [ u"it",u"Lendinara",12477,45.083333,11.6 ],
    [ u"it",u"Leno",13604,45.366667,10.216667 ],
    [ u"it",u"Lentate sul Seveso",15205,45.683333,9.116667 ],
    [ u"it",u"Lentini",23235,37.283333,15 ],
    [ u"it",u"Leonforte",14576,37.633333,14.383333 ],
    [ u"it",u"Lerici",10684,44.066667,9.916667 ],
    [ u"it",u"Leverano",13795,40.283333,18 ],
    [ u"it",u"Licata",35018,37.1,13.933333 ],
    [ u"it",u"Limbiate",31736,45.6,9.116667 ],
    [ u"it",u"Lipari",10649,38.466667,14.95 ],
    [ u"it",u"Lissone",37137,45.616667,9.233333 ],
    [ u"it",u"Lizzanello",10737,40.3,18.216667 ],
    [ u"it",u"Lizzano",10376,40.383333,17.45 ],
    [ u"it",u"Loano",10375,44.133333,8.25 ],
    [ u"it",u"Locorotondo",14294,40.75,17.333333 ],
    [ u"it",u"Locri",12994,38.233333,16.266667 ],
    [ u"it",u"Lodi",41043,45.316667,9.5 ],
    [ u"it",u"Lonate Pozzolo",12316,45.6,8.75 ],
    [ u"it",u"Lonato",13196,45.45,10.483333 ],
    [ u"it",u"Lonigo",15001,45.383333,11.383333 ],
    [ u"it",u"Loreto",11701,43.433333,13.6 ],
    [ u"it",u"Lucca",80617,43.833333,10.483333 ],
    [ u"it",u"Lucera",35396,41.5,15.333333 ],
    [ u"it",u"Lugo",32235,44.416667,11.9 ],
    [ u"it",u"Luino",14450,46,8.733333 ],
    [ u"it",u"Lurate Caccivio",10369,45.766667,9.016667 ],
    [ u"it",u"Luzzi",10338,39.45,16.283333 ],
    [ u"it",u"Macerata",40893,43.3,13.45 ],
    [ u"it",u"Macomer",11796,40.266667,8.783333 ],
    [ u"it",u"Maddaloni",38099,41.033333,14.383333 ],
    [ u"it",u"Magenta",23621,45.466667,8.883333 ],
    [ u"it",u"Magione",13326,43.133333,12.2 ],
    [ u"it",u"Maglie",15295,40.116667,18.3 ],
    [ u"it",u"Malnate",16282,45.8,8.883333 ],
    [ u"it",u"Malo",13107,45.65,11.4 ],
    [ u"it",u"Mandello del Lario",10196,45.9,9.316667 ],
    [ u"it",u"Manduria",30534,40.4,17.633333 ],
    [ u"it",u"Manerbio",13349,45.35,10.133333 ],
    [ u"it",u"Manfredonia",57015,41.633333,15.916667 ],
    [ u"it",u"Maniago",12299,46.170556,12.707778 ],
    [ u"it",u"Mantova",45959,45.15,10.8 ],
    [ u"it",u"Maranello",16988,44.533333,10.866667 ],
    [ u"it",u"Marano di Napoli",50885,40.9,14.183333 ],
    [ u"it",u"Marcianise",41726,41.033333,14.283333 ],
    [ u"it",u"Marcon",13368,45.564444,12.298889 ],
    [ u"it",u"Margherita di Savoia",12589,41.366667,16.15 ],
    [ u"it",u"Mariano Comense",21877,45.7,9.183333 ],
    [ u"it",u"Marigliano",31772,40.933333,14.45 ],
    [ u"it",u"Marino",32905,41.766667,12.65 ],
    [ u"it",u"Marostica",13401,45.75,11.65 ],
    [ u"it",u"Marsala",80755,37.8,12.433333 ],
    [ u"it",u"Marsciano",17262,42.9,12.333333 ],
    [ u"it",u"Martano",9644,40.2,18.3 ],
    [ u"it",u"Martellago",20335,45.5475,12.15 ],
    [ u"it",u"Martina Franca",48233,40.7,17.333333 ],
    [ u"it",u"Martinsicuro",15030,42.883333,13.916667 ],
    [ u"it",u"Mascali",12525,37.75,15.2 ],
    [ u"it",u"Mascalucia",27703,37.566667,15.05 ],
    [ u"it",u"Massafra",31436,40.591944,17.115278 ],
    [ u"it",u"Massa Marittima",8924,43.05,10.883333 ],
    [ u"it",u"Massa",68318,44.016667,10.15 ],
    [ u"it",u"Massarosa",21262,43.866667,10.333333 ],
    [ u"it",u"Matelica",10294,43.25,13 ],
    [ u"it",u"Matera",57250,40.666667,16.6 ],
    [ u"it",u"Matino",11410,40.033333,18.133333 ],
    [ u"it",u"Mazara del Vallo",50979,37.65,12.583333 ],
    [ u"it",u"Mazzarino",12483,37.3,14.216667 ],
    [ u"it",u"Meda",22048,45.666667,9.15 ],
    [ u"it",u"Medicina",14065,44.466667,11.633333 ],
    [ u"it",u"Melegnano",16155,45.35,9.316667 ],
    [ u"it",u"Melendugno",9554,40.266667,18.333333 ],
    [ u"it",u"Melfi",15897,41,15.65 ],
    [ u"it",u"Melilli",13211,37.183333,15.116667 ],
    [ u"it",u"Melito di Napoli",41291,40.916667,14.233333 ],
    [ u"it",u"Melito di Porto Salvo",10602,37.916667,15.783333 ],
    [ u"it",u"Melzo",19453,45.5,9.416667 ],
    [ u"it",u"Menfi",13231,37.6,12.966667 ],
    [ u"it",u"Mentana",14925,42.033333,12.633333 ],
    [ u"it",u"Merano",33514,46.666667,11.15 ],
    [ u"it",u"Merate",14801,45.7,9.416667 ],
    [ u"it",u"Mercato San Severino",20954,40.783333,14.766667 ],
    [ u"it",u"Mercogliano",13046,40.916667,14.733333 ],
    [ u"it",u"Mesagne",26981,40.566667,17.8 ],
    [ u"it",u"Messina",237956,38.183333,15.566667 ],
    [ u"it",u"Milan",1156903,45.466667,9.2 ],
    [ u"it",u"Milazzo",30778,38.216667,15.233333 ],
    [ u"it",u"Militello in Val di Catania",8035,37.266667,14.8 ],
    [ u"it",u"Minervino Murge",9955,41.083333,16.083333 ],
    [ u"it",u"Minturno",19520,41.25,13.75 ],
    [ u"it",u"Mira",36219,45.43,12.119722 ],
    [ u"it",u"Mirandola",22173,44.883333,11.066667 ],
    [ u"it",u"Mirano",27152,45.494444,12.104722 ],
    [ u"it",u"Misilmeri",25692,38.033333,13.45 ],
    [ u"it",u"Misterbianco",46600,37.516667,15 ],
    [ u"it",u"Modena",180641,44.666667,10.916667 ],
    [ u"it",u"Modica",56282,36.866667,14.766667 ],
    [ u"it",u"Modugno",36208,41.083333,16.783333 ],
    [ u"it",u"Mogliano Veneto",27612,45.565,12.235 ],
    [ u"it",u"Mola di Bari",23918,41.066667,17.083333 ],
    [ u"it",u"Molfetta",61308,41.2,16.6 ],
    [ u"it",u"Molinella",14943,44.616667,11.666667 ],
    [ u"it",u"Moncalieri",52820,45,7.683333 ],
    [ u"it",u"Mondolfo",11477,43.75,13.1 ],
    [ u"it",u"Mondovì",22457,44.383333,7.816667 ],
    [ u"it",u"Mondragone",24810,41.116667,13.883333 ],
    [ u"it",u"Monfalcone",26331,45.807222,13.534167 ],
    [ u"it",u"Monopoli",50064,40.95,17.3 ],
    [ u"it",u"Monreale",34544,38.083333,13.283333 ],
    [ u"it",u"Monselice",16815,45.233333,11.75 ],
    [ u"it",u"Monserrato",23415,39.256111,9.139722 ],
    [ u"it",u"Monsummano Terme",21415,43.866667,10.816667 ],
    [ u"it",u"Montagnana",9607,45.233333,11.466667 ],
    [ u"it",u"Montale",10704,43.933333,11.016667 ],
    [ u"it",u"Montalto Uffugo",19140,39.4,16.15 ],
    [ u"it",u"Montebelluna",28562,45.775278,12.038889 ],
    [ u"it",u"Montecchio Maggiore",21875,45.5,11.4 ],
    [ u"it",u"Montecorvino Rovella",12208,40.7,14.983333 ],
    [ u"it",u"Monte di Procida",12757,40.8,14.05 ],
    [ u"it",u"Montefiascone",13326,42.533333,12.033333 ],
    [ u"it",u"Montegranaro",13039,43.233333,13.633333 ],
    [ u"it",u"Montegrotto Terme",10865,45.316667,11.766667 ],
    [ u"it",u"Montelupo Fiorentino",12146,43.733333,11.016667 ],
    [ u"it",u"Montemarciano",10012,43.633333,13.316667 ],
    [ u"it",u"Montemurlo",18352,43.916667,11.05 ],
    [ u"it",u"Monteprandone",11113,42.916667,13.833333 ],
    [ u"it",u"Montepulciano",14389,43.083333,11.783333 ],
    [ u"it",u"Monteroni di Lecce",13908,40.316667,18.1 ],
    [ u"it",u"Monterotondo",40249,42.05,12.616667 ],
    [ u"it",u"Monte San Giovanni Campano",13538,41.633333,13.516667 ],
    [ u"it",u"Monte San Pietro",12106,44.433333,11.133333 ],
    [ u"it",u"Montesarchio",13110,41.066667,14.633333 ],
    [ u"it",u"Montescaglioso",10005,40.55,16.666667 ],
    [ u"it",u"Montesilvano",43237,42.483333,14.133333 ],
    [ u"it",u"Montespertoli",12723,43.633333,11.066667 ],
    [ u"it",u"Montevarchi",22987,43.516667,11.566667 ],
    [ u"it",u"Montichiari",21041,45.416667,10.383333 ],
    [ u"it",u"Montignoso",10804,44.016667,10.166667 ],
    [ u"it",u"Montorio al Vomano",8223,42.583333,13.633333 ],
    [ u"it",u"Monza",120857,45.583333,9.266667 ],
    [ u"it",u"Morbegno",11775,46.133333,9.566667 ],
    [ u"it",u"Morrovalle",9723,43.316667,13.566667 ],
    [ u"it",u"Mortara",14300,45.25,8.733333 ],
    [ u"it",u"Motta di Livenza",10501,45.778056,12.602778 ],
    [ u"it",u"Mottola",16686,40.635278,17.035278 ],
    [ u"it",u"Múggia",13470,45.603056,13.767222 ],
    [ u"it",u"Muggiò",21561,45.583333,9.216667 ],
    [ u"it",u"Mugnano di Napoli",32847,40.916667,14.2 ],
    [ u"it",u"Musile di Piave",10779,45.616667,12.55 ],
    [ u"it",u"Mussomeli",11846,37.583333,13.75 ],
    [ u"it",u"Naples",981284,40.833333,14.25 ],
    [ u"it",u"Nardò",31294,40.183333,18.033333 ],
    [ u"it",u"Narni",20567,42.516667,12.516667 ],
    [ u"it",u"Naro",8747,37.3,13.783333 ],
    [ u"it",u"Nave",11001,45.583333,10.283333 ],
    [ u"it",u"Negrar",18134,45.533333,10.916667 ],
    [ u"it",u"Nembro",11635,45.75,9.75 ],
    [ u"it",u"Nerviano",18000,45.55,8.966667 ],
    [ u"it",u"Nettuno",40642,41.45,12.65 ],
    [ u"it",u"Nichelino",49474,44.983333,7.633333 ],
    [ u"it",u"Nicosia",15416,37.75,14.4 ],
    [ u"it",u"Niscemi",29459,37.15,14.383333 ],
    [ u"it",u"Nizza Monferrato",10391,44.766667,8.35 ],
    [ u"it",u"Noale",15512,45.553333,12.071944 ],
    [ u"it",u"Nocera Inferiore",48798,40.733333,14.633333 ],
    [ u"it",u"Nocera Superiore",22898,40.733333,14.666667 ],
    [ u"it",u"Noceto",11258,44.8,10.183333 ],
    [ u"it",u"Noci",19993,40.8,17.116667 ],
    [ u"it",u"Noicattaro",25022,41.033333,16.983333 ],
    [ u"it",u"Nola",32872,40.916667,14.55 ],
    [ u"it",u"Nonantola",13544,44.683333,11.033333 ],
    [ u"it",u"Noto",24049,36.883333,15.066667 ],
    [ u"it",u"Nova Milanese",23655,45.583333,9.2 ],
    [ u"it",u"Novara",105903,45.466667,8.633333 ],
    [ u"it",u"Novate Milanese",20576,45.533333,9.133333 ],
    [ u"it",u"Novellara",12598,44.85,10.733333 ],
    [ u"it",u"Novi di Modena",10896,44.9,10.9 ],
    [ u"it",u"Novi Ligure",27115,44.766667,8.783333 ],
    [ u"it",u"Nuoro",38543,40.316667,9.35 ],
    [ u"it",u"Occhiobello",10500,44.916667,11.583333 ],
    [ u"it",u"Oderzo",18158,45.78,12.488056 ],
    [ u"it",u"Olbia",44903,40.916667,9.516667 ],
    [ u"it",u"Oleggio",13097,45.6,8.633333 ],
    [ u"it",u"Olgiate Comasco",11261,45.8,8.966667 ],
    [ u"it",u"Olgiate Olona",11628,45.633333,8.883333 ],
    [ u"it",u"Omegna",15940,45.883333,8.4 ],
    [ u"it",u"Opera",13986,45.366667,9.2 ],
    [ u"it",u"Orbassano",22805,45.016667,7.533333 ],
    [ u"it",u"Orbetello",14805,42.45,11.216667 ],
    [ u"it",u"Oria",15505,40.5,17.633333 ],
    [ u"it",u"Oristano",30069,39.903056,8.591944 ],
    [ u"it",u"Orta Nova",17873,41.316667,15.7 ],
    [ u"it",u"Ortona",22874,42.35,14.4 ],
    [ u"it",u"Orvieto",21573,42.716667,12.116667 ],
    [ u"it",u"Orzinuovi",12022,45.4,9.916667 ],
    [ u"it",u"Osimo",30463,43.483333,13.483333 ],
    [ u"it",u"Ospitaletto",12368,45.133333,10.6 ],
    [ u"it",u"Ostuni",32604,40.733333,17.583333 ],
    [ u"it",u"Ottaviano",23161,40.85,14.466667 ],
    [ u"it",u"Ovada",11898,44.633333,8.633333 ],
    [ u"it",u"Ozieri",11924,40.583333,9 ],
    [ u"it",u"Paceco",11418,37.983333,12.55 ],
    [ u"it",u"Pachino",22301,36.716667,15.083333 ],
    [ u"it",u"Paderno Dugnano",47733,45.55,9.166667 ],
    [ u"it",u"Padova",205247,45.416667,11.883333 ],
    [ u"it",u"Paese",20224,45.674167,12.163889 ],
    [ u"it",u"Pagani",32580,40.75,14.616667 ],
    [ u"it",u"Palagiano",16426,40.578889,17.038611 ],
    [ u"it",u"Palagonia",17745,37.316667,14.75 ],
    [ u"it",u"Palazzolo Acreide",9548,37.066667,14.9 ],
    [ u"it",u"Palermo",669582,38.116667,13.366667 ],
    [ u"it",u"Palestrina",18697,41.833333,12.883333 ],
    [ u"it",u"Palma Campania",14741,40.866667,14.55 ],
    [ u"it",u"Palma di Montechiaro",21567,37.183333,13.766667 ],
    [ u"it",u"Palmi",19317,38.35,15.85 ],
    [ u"it",u"Palo del Colle",22505,41.05,16.7 ],
    [ u"it",u"Palombara Sabina",12787,42.066667,12.766667 ],
    [ u"it",u"Paola",16896,39.35,16.033333 ],
    [ u"it",u"Parabiago",25186,45.55,8.95 ],
    [ u"it",u"Parabita",9804,40.05,18.133333 ],
    [ u"it",u"Parma",155693,44.8,10.333333 ],
    [ u"it",u"Partanna",11852,37.716667,12.883333 ],
    [ u"it",u"Partinico",32870,38.05,13.116667 ],
    [ u"it",u"Paterno",47042,37.566667,14.9 ],
    [ u"it",u"Patti",13703,38.133333,14.966667 ],
    [ u"it",u"Paullo",10758,45.416667,9.4 ],
    [ u"it",u"Pavia",71520,45.166667,9.166667 ],
    [ u"it",u"Pavullo nel Frignano",16114,44.333333,10.833333 ],
    [ u"it",u"Pedara",11579,37.633333,15.066667 ],
    [ u"it",u"Pellezzano",10969,40.716667,14.75 ],
    [ u"it",u"Penne",13394,42.45,13.916667 ],
    [ u"it",u"Pergine Valsugana",17883,46.066667,11.233333 ],
    [ u"it",u"Perugia",157077,43.133333,12.366667 ],
    [ u"it",u"Pesaro",91817,43.9,12.916667 ],
    [ u"it",u"Pescantina",14175,45.483333,10.85 ],
    [ u"it",u"Pescara",118136,42.466667,14.216667 ],
    [ u"it",u"Pescia",17868,43.9,10.683333 ],
    [ u"it",u"Petilia Policastro",9159,39.116667,16.783333 ],
    [ u"it",u"Piacenza",95453,45.016667,9.666667 ],
    [ u"it",u"Pianezza",11672,45.1,7.55 ],
    [ u"it",u"Piano di Sorrento",13111,40.633333,14.383333 ],
    [ u"it",u"Pianoro",17497,44.366667,11.333333 ],
    [ u"it",u"Piazza Armerina",21864,37.383333,14.366667 ],
    [ u"it",u"Piazzola sul Brenta",11204,45.533333,11.783333 ],
    [ u"it",u"Pietra Ligure",8301,44.15,8.283333 ],
    [ u"it",u"Pietrasanta",24625,43.95,10.233333 ],
    [ u"it",u"Pieve di Soligo",11642,45.9025,12.177222 ],
    [ u"it",u"Pinerolo",33807,44.883333,7.35 ],
    [ u"it",u"Pineto",14469,42.6,14.066667 ],
    [ u"it",u"Pioltello",32312,45.5,9.333333 ],
    [ u"it",u"Piombino",34114,42.916667,10.533333 ],
    [ u"it",u"Piossasco",17036,44.983333,7.466667 ],
    [ u"it",u"Piove di Sacco",18196,45.2975,12.042778 ],
    [ u"it",u"Pisa",83803,43.716667,10.383333 ],
    [ u"it",u"Pisticci",17393,40.383333,16.55 ],
    [ u"it",u"Pistoia",85267,43.916667,10.9 ],
    [ u"it",u"Poggibonsi",28619,43.466667,11.15 ],
    [ u"it",u"Poggiomarino",21214,40.8,14.533333 ],
    [ u"it",u"Poirino",9404,44.916667,7.85 ],
    [ u"it",u"Policoro",15083,40.216667,16.683333 ],
    [ u"it",u"Polignano a Mare",16462,41,17.216667 ],
    [ u"it",u"Polistena",11637,38.4,16.066667 ],
    [ u"it",u"Pomezia",48859,41.666667,12.5 ],
    [ u"it",u"Pompei",26251,40.75,14.5 ],
    [ u"it",u"Ponsacco",13257,43.616667,10.633333 ],
    [ u"it",u"Pontassieve",21423,43.766667,11.433333 ],
    [ u"it",u"Pontecagnano",22997,40.633333,14.883333 ],
    [ u"it",u"Pontecorvo",14863,41.45,13.666667 ],
    [ u"it",u"Pontedera",26713,43.666667,10.633333 ],
    [ u"it",u"Ponte San Nicolò",13148,45.366667,11.616667 ],
    [ u"it",u"Ponte San Pietro",9873,45.7,9.583333 ],
    [ u"it",u"Pontinia",14621,41.4,13.033333 ],
    [ u"it",u"Porcia",13981,45.96,12.607222 ],
    [ u"it",u"Pordenone",48581,45.963889,12.6575 ],
    [ u"it",u"Portici",55775,40.816667,14.333333 ],
    [ u"it",u"Porto Empedocle",16110,37.283333,13.533333 ],
    [ u"it",u"Portoferraio",10102,42.816667,10.316667 ],
    [ u"it",u"Portogruaro",23843,45.775278,12.838611 ],
    [ u"it",u"Portomaggiore",11910,44.7,11.8 ],
    [ u"it",u"Porto Recanati",10233,43.433333,13.666667 ],
    [ u"it",u"Porto San Giorgio",16010,43.183333,13.8 ],
    [ u"it",u"Porto Tolle",10894,44.933333,12.366667 ],
    [ u"it",u"Porto Torres",22302,40.835,8.397222 ],
    [ u"it",u"Potenza Picena",15044,43.366667,13.616667 ],
    [ u"it",u"Potenza",68823,40.633333,15.8 ],
    [ u"it",u"Pozzallo",19030,36.716667,14.85 ],
    [ u"it",u"Pozzuoli",81237,40.816667,14.116667 ],
    [ u"it",u"Prato",178915,43.883333,11.1 ],
    [ u"it",u"Preganziol",15877,45.601389,12.237222 ],
    [ u"it",u"Priolo Gargallo",12498,37.15,15.183333 ],
    [ u"it",u"Priverno",14494,41.466667,13.183333 ],
    [ u"it",u"Procida",10835,40.766667,14.033333 ],
    [ u"it",u"Pulsano",10191,40.383333,17.35 ],
    [ u"it",u"Putignano",27994,40.85,17.116667 ],
    [ u"it",u"Qualiano",27149,40.916667,14.15 ],
    [ u"it",u"Quartucciu",12145,39.251944,9.179444 ],
    [ u"it",u"Quattro Castella",12369,44.633333,10.466667 ],
    [ u"it",u"Quinto di Treviso",9726,45.648056,12.166667 ],
    [ u"it",u"Racale",10502,39.95,18.1 ],
    [ u"it",u"Racalmuto",10076,37.4,13.733333 ],
    [ u"it",u"Racconigi",10128,44.766667,7.766667 ],
    [ u"it",u"Raffadali",14023,37.4,13.533333 ],
    [ u"it",u"Ragusa",72631,36.916667,14.733333 ],
    [ u"it",u"Ramacca",11219,37.383333,14.7 ],
    [ u"it",u"Randazzo",11731,37.883333,14.95 ],
    [ u"it",u"Rapallo",29379,44.35,9.233333 ],
    [ u"it",u"Ravanusa",13492,37.266667,13.966667 ],
    [ u"it",u"Ravenna",143396,44.4175,12.201111 ],
    [ u"it",u"Recanati",20540,43.4,13.533333 ],
    [ u"it",u"Recco",10341,44.366667,9.15 ],
    [ u"it",u"Reggello",15388,43.683333,11.533333 ],
    [ u"it",u"Reggio di Calabria",181990,38.1,15.65 ],
    [ u"it",u"Rende",36400,39.333333,16.183333 ],
    [ u"it",u"Rescaldina",14194,45.616667,8.95 ],
    [ u"it",u"Rezzato",13190,45.516667,10.316667 ],
    [ u"it",u"Rho",53558,45.533333,9.033333 ],
    [ u"it",u"Ribera",21086,37.5,13.266667 ],
    [ u"it",u"Riccione",34228,43.983333,12.65 ],
    [ u"it",u"Riese",10568,45.733333,11.916667 ],
    [ u"it",u"Riesi",11322,37.283333,14.083333 ],
    [ u"it",u"Rieti",45355,42.4,12.85 ],
    [ u"it",u"Rimini",132031,44.063333,12.580833 ],
    [ u"it",u"Rionero in Vulture",13399,40.916667,15.666667 ],
    [ u"it",u"Riposto",14054,37.733333,15.2 ],
    [ u"it",u"Rivalta di Torino",19069,45.033333,7.516667 ],
    [ u"it",u"Riva",15389,45.783333,11.1 ],
    [ u"it",u"Rivarolo Canavese",12497,45.316667,7.716667 ],
    [ u"it",u"Rivoli",49959,45.066667,7.516667 ],
    [ u"it",u"Rocca di Papa",15026,41.766667,12.7 ],
    [ u"it",u"Roccapiemonte",9368,40.766667,14.683333 ],
    [ u"it",u"Rocca Priora",11117,41.8,12.75 ],
    [ u"it",u"Roccastrada",9470,43,11.166667 ],
    [ u"it",u"Romano di Lombardia",16358,45.516667,9.75 ],
    [ u"it",u"Rome",2643736,41.9,12.483333 ],
    [ u"it",u"Roncade",12540,45.63,12.374167 ],
    [ u"it",u"Ronchi dei Legionari",11746,45.823611,13.509722 ],
    [ u"it",u"Rosarno",15558,38.483333,15.966667 ],
    [ u"it",u"Rosa",13186,45.930556,12.870833 ],
    [ u"it",u"Roseto degli Abruzzi",22868,42.683333,14.016667 ],
    [ u"it",u"Rosignano Marittimo",31871,43.4,10.466667 ],
    [ u"it",u"Rosolini",20671,36.816667,14.95 ],
    [ u"it",u"Rossano",35073,39.566667,16.633333 ],
    [ u"it",u"Rovato",15569,45.566667,10 ],
    [ u"it",u"Rovereto",33510,45.883333,11.033333 ],
    [ u"it",u"Rovigo",48634,45.066667,11.783333 ],
    [ u"it",u"Rozzano",36179,45.366667,9.15 ],
    [ u"it",u"Rubano",14458,45.433333,11.783333 ],
    [ u"it",u"Rubiera",12617,44.65,10.783333 ],
    [ u"it",u"Ruffano",9186,39.983333,18.25 ],
    [ u"it",u"Russi",10712,44.3725,12.032222 ],
    [ u"it",u"Rutigliano",18115,41.016667,17 ],
    [ u"it",u"Ruvo di Puglia",26385,41.116667,16.483333 ],
    [ u"it",u"Sabaudia",18951,41.3,13.016667 ],
    [ u"it",u"Sacile",18935,45.955278,12.501944 ],
    [ u"it",u"Sala Consilina",12903,40.383333,15.6 ],
    [ u"it",u"Salemi",11937,37.816667,12.8 ],
    [ u"it",u"Salerno",144147,40.683333,14.783333 ],
    [ u"it",u"Salice Salentino",8932,40.383333,17.966667 ],
    [ u"it",u"Salò",10525,45.6,10.516667 ],
    [ u"it",u"Salsomaggiore Terme",18565,44.816667,9.983333 ],
    [ u"it",u"Saluzzo",16080,44.65,7.483333 ],
    [ u"it",u"Salzano",12306,45.521944,12.108333 ],
    [ u"it",u"Samarate",16128,45.633333,8.783333 ],
    [ u"it",u"San Benedetto del Tronto",43767,42.95,13.883333 ],
    [ u"it",u"San Bonifacio",18684,45.4,11.266667 ],
    [ u"it",u"San Cataldo",24487,37.483333,13.983333 ],
    [ u"it",u"San Cesareo",11312,41.816667,12.8 ],
    [ u"it",u"San Donà di Piave",37452,45.631667,12.569444 ],
    [ u"it",u"San Donato Milanese",33116,45.416667,9.266667 ],
    [ u"it",u"San Felice sul Panaro",10589,44.833333,11.133333 ],
    [ u"it",u"San Ferdinando di Puglia",14792,41.3,16.066667 ],
    [ u"it",u"San Gavino Monreale",9814,39.551389,8.791667 ],
    [ u"it",u"San Gennaro Vesuviano",10955,40.883333,14.533333 ],
    [ u"it",u"San Giorgio a Cremano",50887,40.833333,14.333333 ],
    [ u"it",u"San Giorgio del Sannio",9929,41.066667,14.85 ],
    [ u"it",u"San Giorgio Ionico",15682,40.45,17.383333 ],
    [ u"it",u"San Giovanni in Fiore",17202,39.25,16.7 ],
    [ u"it",u"San Giovanni in Persiceto",25344,44.633333,11.183333 ],
    [ u"it",u"San Giovanni la Punta",22970,37.583333,15.116667 ],
    [ u"it",u"San Giovanni Lupatoto",22034,45.383333,11.05 ],
    [ u"it",u"San Giovanni Rotondo",27228,41.7,15.733333 ],
    [ u"it",u"San Giovanni Valdarno",17245,43.566667,11.533333 ],
    [ u"it",u"San Giuliano Milanese",32437,45.4,9.283333 ],
    [ u"it",u"San Giuliano Terme",32516,43.766667,10.433333 ],
    [ u"it",u"San Giuseppe Jato",8380,37.966667,13.183333 ],
    [ u"it",u"San Giuseppe Vesuviano",22551,40.833333,14.5 ],
    [ u"it",u"San Giustino",11138,43.55,12.166667 ],
    [ u"it",u"San Gregorio di Catania",11616,37.566667,15.1 ],
    [ u"it",u"San Lazzaro di Savena",29962,44.466667,11.416667 ],
    [ u"it",u"San Marco in Lamis",16109,41.716667,15.633333 ],
    [ u"it",u"San Martino Buon Albergo",13471,45.416667,11.083333 ],
    [ u"it",u"San Martino di Lupari",12023,45.65,11.85 ],
    [ u"it",u"San Marzano sul Sarno",9501,40.766667,14.583333 ],
    [ u"it",u"San Mauro Torinese",18799,45.1,7.766667 ],
    [ u"it",u"San Michele al Tagliamento",11602,45.7625,12.999444 ],
    [ u"it",u"San Miniato",27806,43.683333,10.85 ],
    [ u"it",u"Sannicandro di Bari",9761,41,16.8 ],
    [ u"it",u"San Nicola",19627,38.266667,15.8 ],
    [ u"it",u"San Pancrazio Salentino",10546,40.416667,17.833333 ],
    [ u"it",u"San Pietro in Casale",10667,44.7,11.4 ],
    [ u"it",u"San Pietro Vernotico",14779,40.485278,17.999722 ],
    [ u"it",u"San Prisco",10730,41.083333,14.266667 ],
    [ u"it",u"San Remo",49053,43.816667,7.766667 ],
    [ u"it",u"San Salvo",19249,42.05,14.733333 ],
    [ u"it",u"San Sebastiano al Vesuvio",9931,40.833333,14.366667 ],
    [ u"it",u"Sansepolcro",16302,43.566667,12.133333 ],
    [ u"it",u"San Severino Marche",12896,43.216667,13.166667 ],
    [ u"it",u"San Severo",56708,41.683333,15.383333 ],
    [ u"it",u"Santa Flavia",10630,38.083333,13.516667 ],
    [ u"it",u"Santa Margherita Ligure",10310,44.333333,9.2 ],
    [ u"it",u"Santa Maria a Monte",11384,43.7,10.7 ],
    [ u"it",u"Santa Maria a Vico",14211,41.033333,14.483333 ],
    [ u"it",u"Santa Maria Capua Vetere",29780,41.083333,14.25 ],
    [ u"it",u"Santa Maria di Sala",15322,45.506944,12.029722 ],
    [ u"it",u"Santa Marinella",17577,42.033333,11.85 ],
    [ u"it",u"Santeramo in Colle",27024,40.8,16.75 ],
    [ u"it",u"Santhià",9614,45.366667,8.166667 ],
    [ u"it",u"Santo Stino di Livenza",12294,45.735,12.680833 ],
    [ u"it",u"San Vito al Tagliamento",13834,45.914444,12.85 ],
    [ u"it",u"San Vito dei Normanni",20057,40.65,17.7 ],
    [ u"it",u"Sarezzo",12423,45.65,10.2 ],
    [ u"it",u"Sarno",31278,40.816667,14.616667 ],
    [ u"it",u"Saronno",38080,45.633333,9.033333 ],
    [ u"it",u"Sarzana",20596,44.116667,9.966667 ],
    [ u"it",u"Sassari",119187,40.727222,8.560278 ],
    [ u"it",u"Sasso Marconi",14487,44.4,11.25 ],
    [ u"it",u"Sassuolo",37446,44.55,10.783333 ],
    [ u"it",u"Sava",15819,40.4,17.55 ],
    [ u"it",u"Saviano",15792,40.9,14.5 ],
    [ u"it",u"Savigliano",21161,44.633333,7.666667 ],
    [ u"it",u"Savignano sul Rubicone",16276,44.095278,12.408611 ],
    [ u"it",u"Savona",58302,44.283333,8.5 ],
    [ u"it",u"Scafati",48113,40.75,14.516667 ],
    [ u"it",u"Scalea",10765,39.816667,15.783333 ],
    [ u"it",u"Scandiano",23918,44.6,10.716667 ],
    [ u"it",u"Scandicci",50491,43.75,11.183333 ],
    [ u"it",u"Schio",39001,45.716667,11.35 ],
    [ u"it",u"Sciacca",42902,37.516667,13.05 ],
    [ u"it",u"Scicli",27198,36.783333,14.7 ],
    [ u"it",u"Scordia",17742,37.3,14.85 ],
    [ u"it",u"Scorzè",18546,45.573611,12.106111 ],
    [ u"it",u"Sedriano",11231,45.483333,8.966667 ],
    [ u"it",u"Segrate",33249,45.483333,9.283333 ],
    [ u"it",u"Selargius",30232,39.256667,9.1675 ],
    [ u"it",u"Selvazzano Dentro",20047,45.383333,11.783333 ],
    [ u"it",u"Senago",20198,45.583333,9.116667 ],
    [ u"it",u"Senigallia",42180,43.716667,13.216667 ],
    [ u"it",u"Seravezza",12985,43.983333,10.216667 ],
    [ u"it",u"Seregno",40237,45.65,9.2 ],
    [ u"it",u"Seriate",21795,45.683333,9.716667 ],
    [ u"it",u"Serramanna",9766,39.424444,8.924444 ],
    [ u"it",u"Serravalle Pistoiese",11171,43.9,10.816667 ],
    [ u"it",u"Sessa Aurunca",22821,41.233333,13.933333 ],
    [ u"it",u"Sesto Calende",10402,45.733333,8.633333 ],
    [ u"it",u"Sesto Fiorentino",47074,43.833333,11.2 ],
    [ u"it",u"Sesto San Giovanni",74668,45.533333,9.233333 ],
    [ u"it",u"Sestri Levante",18906,44.266667,9.4 ],
    [ u"it",u"Sestu",17618,39.300556,9.090833 ],
    [ u"it",u"Settimo Torinese",47463,45.15,7.766667 ],
    [ u"it",u"Seveso",20142,45.65,9.15 ],
    [ u"it",u"Sezze",24214,41.5,13.05 ],
    [ u"it",u"Siano",10613,40.8,14.683333 ],
    [ u"it",u"Siderno",17194,38.266667,16.3 ],
    [ u"it",u"Siena",47922,43.316667,11.35 ],
    [ u"it",u"Signa",16237,43.783333,11.083333 ],
    [ u"it",u"Silea",9447,45.656111,12.300278 ],
    [ u"it",u"Silvi",16070,42.566667,14.083333 ],
    [ u"it",u"Sinalunga",12348,43.2,11.733333 ],
    [ u"it",u"Siniscola",10187,40.566667,9.683333 ],
    [ u"it",u"Sìnnai",17218,39.302222,9.203056 ],
    [ u"it",u"Solaro",13435,44.883333,9.166667 ],
    [ u"it",u"Soliera",14530,44.733333,10.916667 ],
    [ u"it",u"Solofra",12419,40.833333,14.85 ],
    [ u"it",u"Sommacampagna",14414,45.4,10.833333 ],
    [ u"it",u"Somma Lombardo",16935,45.683333,8.7 ],
    [ u"it",u"Somma Vesuviana",35196,40.866667,14.433333 ],
    [ u"it",u"Sona",15528,45.433333,10.833333 ],
    [ u"it",u"Sondrio",22064,46.166667,9.866667 ],
    [ u"it",u"Sora",25977,41.716667,13.616667 ],
    [ u"it",u"Soresina",8947,45.283333,9.85 ],
    [ u"it",u"Sorrento",15308,40.616667,14.366667 ],
    [ u"it",u"Sorso",13555,40.8,8.577222 ],
    [ u"it",u"Sortino",9617,37.15,15.033333 ],
    [ u"it",u"Soverato",9884,38.683333,16.55 ],
    [ u"it",u"Spilamberto",11472,44.533333,11.016667 ],
    [ u"it",u"Spilimbergo",11193,46.1125,12.896944 ],
    [ u"it",u"Spinea",25198,45.493056,12.160556 ],
    [ u"it",u"Spoleto",36489,42.733333,12.733333 ],
    [ u"it",u"Spoltore",17633,42.45,14.133333 ],
    [ u"it",u"Spresiano",9868,45.777778,12.266111 ],
    [ u"it",u"Squinzano",15156,40.436111,18.041667 ],
    [ u"it",u"Stezzano",11844,45.633333,9.65 ],
    [ u"it",u"Stradella",11050,45.083333,9.3 ],
    [ u"it",u"Subiaco",9932,41.916667,13.1 ],
    [ u"it",u"Sulmona",26796,42.05,13.916667 ],
    [ u"it",u"Surbo",13711,40.399444,18.133056 ],
    [ u"it",u"Susegana",11594,45.851389,12.248333 ],
    [ u"it",u"Suzzara",18304,45,10.75 ],
    [ u"it",u"Syracuse",127666,37.066667,15.3 ],
    [ u"it",u"Taggia",12367,43.866667,7.85 ],
    [ u"it",u"Taormina",10160,37.85,15.283333 ],
    [ u"it",u"Taranto",191364,40.476111,17.229722 ],
    [ u"it",u"Tarquinia",16898,42.25,11.75 ],
    [ u"it",u"Taurianova",15488,38.35,16.016667 ],
    [ u"it",u"Taurisano",12340,39.95,18.216667 ],
    [ u"it",u"Tavagnacco",12877,46.133889,13.176389 ],
    [ u"it",u"Taviano",12797,39.983333,18.083333 ],
    [ u"it",u"Teano",12806,41.25,14.066667 ],
    [ u"it",u"Tempio Pausania",13947,40.9,9.1 ],
    [ u"it",u"Teramo",49605,42.65,13.7 ],
    [ u"it",u"Terlizzi",27076,41.133333,16.533333 ],
    [ u"it",u"Termini Imerese",27632,37.983333,13.7 ],
    [ u"it",u"Termoli",32917,42,15 ],
    [ u"it",u"Terni",108006,42.566667,12.616667 ],
    [ u"it",u"Terracina",37984,41.283333,13.25 ],
    [ u"it",u"Terralba",9530,39.719167,8.639167 ],
    [ u"it",u"Terranuova Bracciolini",12026,43.55,11.583333 ],
    [ u"it",u"Terrasini",11269,38.15,13.083333 ],
    [ u"it",u"Terzigno",17155,40.8,14.483333 ],
    [ u"it",u"Tezze sul Brenta",11215,45.683333,11.683333 ],
    [ u"it",u"Thiene",20474,45.7,11.483333 ],
    [ u"it",u"Tirano",9546,46.216667,10.166667 ],
    [ u"it",u"Tivoli",49303,41.966667,12.8 ],
    [ u"it",u"Todi",17321,42.783333,12.4 ],
    [ u"it",u"Tolentino",19055,43.2,13.283333 ],
    [ u"it",u"Tolmezzo",10777,46.4075,13.0175 ],
    [ u"it",u"Torre Annunziata",47211,40.75,14.45 ],
    [ u"it",u"Torre del Greco",88006,40.783333,14.366667 ],
    [ u"it",u"Torre Santa Susanna",10575,40.466667,17.733333 ],
    [ u"it",u"Torri di Quartesolo",11900,45.516667,11.616667 ],
    [ u"it",u"Tortolì",11127,39.925556,9.657222 ],
    [ u"it",u"Tortona",25129,44.9,8.866667 ],
    [ u"it",u"Tradate",16621,45.716667,8.9 ],
    [ u"it",u"Trani",53902,41.283333,16.416667 ],
    [ u"it",u"Trapani",70031,38.016667,12.483333 ],
    [ u"it",u"Travagliato",12234,45.516667,10.083333 ],
    [ u"it",u"Trebaseleghe",12137,45.592778,12.050556 ],
    [ u"it",u"Trebisacce",9028,39.866667,16.533333 ],
    [ u"it",u"Trecate",18578,45.433333,8.733333 ],
    [ u"it",u"Treia",9673,43.316667,13.316667 ],
    [ u"it",u"Tréntola-Ducenta",15215,40.983333,14.166667 ],
    [ u"it",u"Trento",106703,46.066667,11.133333 ],
    [ u"it",u"Trepuzzi",14198,40.405556,18.075556 ],
    [ u"it",u"Treviglio",27200,45.516667,9.583333 ],
    [ u"it",u"Treviso",81323,45.666667,12.245 ],
    [ u"it",u"Trezzano sul Naviglio",18220,45.416667,9.066667 ],
    [ u"it",u"Trezzo",12360,45.6,9.516667 ],
    [ u"it",u"Tricase",17836,39.933333,18.366667 ],
    [ u"it",u"Trieste",204379,45.648611,13.78 ],
    [ u"it",u"Triggiano",26708,41.066667,16.916667 ],
    [ u"it",u"Trinitapoli",14629,41.35,16.083333 ],
    [ u"it",u"Trofarello",11377,44.983333,7.733333 ],
    [ u"it",u"Troina",10450,37.783333,14.6 ],
    [ u"it",u"Turin",846489,45.05,7.666667 ],
    [ u"it",u"Turi",11680,40.916667,17.016667 ],
    [ u"it",u"Udine",94597,46.061944,13.242222 ],
    [ u"it",u"Ugento",9893,39.933333,18.166667 ],
    [ u"it",u"Umbertide",16451,43.3,12.333333 ],
    [ u"it",u"Urbino",15284,43.716667,12.633333 ],
    [ u"it",u"Vaiano",9514,43.966667,11.116667 ],
    [ u"it",u"Valdagno",26435,45.65,11.3 ],
    [ u"it",u"Valdobbiadene",10854,45.9,12 ],
    [ u"it",u"Valeggio sul Mincio",12015,45.35,10.733333 ],
    [ u"it",u"Valenzano",17960,41.033333,16.883333 ],
    [ u"it",u"Valenza",20625,45.016667,8.633333 ],
    [ u"it",u"Valguarnera Caropepe",8991,37.5,14.383333 ],
    [ u"it",u"Valmadrera",11574,45.85,9.35 ],
    [ u"it",u"Valmontone",14448,41.766667,12.95 ],
    [ u"it",u"Varazze",13464,44.366667,8.566667 ],
    [ u"it",u"Varedo",13151,45.6,9.15 ],
    [ u"it",u"Varese",84371,45.8,8.833333 ],
    [ u"it",u"Vasto",37841,42.116667,14.7 ],
    [ u"it",u"Vecchiano",12339,43.783333,10.383333 ],
    [ u"it",u"Vedelago",14702,45.687222,12.016389 ],
    [ u"it",u"Veglie",14227,40.333333,17.966667 ],
    [ u"it",u"Velletri",56758,41.683333,12.783333 ],
    [ u"it",u"Venafro",12050,41.483333,14.033333 ],
    [ u"it",u"Venaria Reale",37806,45.133333,7.633333 ],
    [ u"it",u"Venice",259126,45.438611,12.326667 ],
    [ u"it",u"Venosa",11982,40.966667,15.816667 ],
    [ u"it",u"Ventimiglia",24734,43.783333,7.6 ],
    [ u"it",u"Vercelli",45114,45.316667,8.416667 ],
    [ u"it",u"Veroli",22352,41.683333,13.416667 ],
    [ u"it",u"Verona",247082,45.45,11 ],
    [ u"it",u"Vetralla",13250,42.316667,12.05 ],
    [ u"it",u"Viadana",18158,44.933333,10.516667 ],
    [ u"it",u"Viareggio",59866,43.866667,10.233333 ],
    [ u"it",u"Vibo Valentia",36055,38.666667,16.1 ],
    [ u"it",u"Vicenza",108636,45.55,11.55 ],
    [ u"it",u"Vico Equense",20756,40.666667,14.416667 ],
    [ u"it",u"Vieste",13440,41.883333,16.166667 ],
    [ u"it",u"Vietri sul Mare",8105,40.666667,14.733333 ],
    [ u"it",u"Vigevano",55078,45.316667,8.85 ],
    [ u"it",u"Vignola",22092,44.483333,11 ],
    [ u"it",u"Vigodarzere",13309,45.45,11.883333 ],
    [ u"it",u"Vigonza",21541,45.45,11.983333 ],
    [ u"it",u"Villabate",20927,38.066667,13.433333 ],
    [ u"it",u"Villacidro",15513,39.457778,8.740556 ],
    [ u"it",u"Villafranca di Verona",30271,45.35,10.833333 ],
    [ u"it",u"Villa Literno",10562,41,14.066667 ],
    [ u"it",u"Villaricca",28190,40.916667,14.2 ],
    [ u"it",u"Villa San Giovanni",13187,38.216667,15.633333 ],
    [ u"it",u"Villasanta",14218,45.616667,9.3 ],
    [ u"it",u"Villorba",18144,45.738333,12.233611 ],
    [ u"it",u"Vimercate",26053,45.616667,9.366667 ],
    [ u"it",u"Vimodrone",14040,45.5,9.266667 ],
    [ u"it",u"Vinci",14284,43.783333,10.916667 ],
    [ u"it",u"Virgilio",10891,45.116667,10.783333 ],
    [ u"it",u"Viterbo",63299,42.416667,12.1 ],
    [ u"it",u"Vittoria",56765,36.95,14.533333 ],
    [ u"it",u"Vittorio Veneto",30193,45.976667,12.303333 ],
    [ u"it",u"Voghera",38848,44.983333,9.016667 ],
    [ u"it",u"Volpago del Montello",9593,45.783333,12.116667 ],
    [ u"it",u"Volpiano",13842,45.2,7.766667 ],
    [ u"it",u"Volterra",11130,43.4,10.85 ],
    [ u"it",u"Zagarolo",14410,41.833333,12.833333 ],
    [ u"it",u"Zevio",13318,45.366667,11.133333 ],
    [ u"it",u"Zogno",9607,45.8,9.666667 ],
    [ u"it",u"Zola Predosa",15362,44.483333,11.2 ],
    [ u"jm",u"Albert Town",3449,18.2833333,-77.55 ],
    [ u"jm",u"Anchovy",4161,18.4,-77.9333333 ],
    [ u"jm",u"Bamboo",4264,18.3833333,-77.2666667 ],
    [ u"jm",u"Black River",4229,18.0166667,-77.85 ],
    [ u"jm",u"Bull Savanna",6962,17.8833333,-77.6 ],
    [ u"jm",u"Cambridge",3930,18.3166667,-77.9 ],
    [ u"jm",u"Discovery Bay",2536,18.4666667,-77.4 ],
    [ u"jm",u"Falmouth",7780,18.5,-77.65 ],
    [ u"jm",u"Half Way Tree",18552,18.0,-76.8 ],
    [ u"jm",u"Kingston",583999,18.0,-76.8 ],
    [ u"jm",u"Lucea",6290,18.45,-78.1666667 ],
    [ u"jm",u"Mandeville",47116,18.0333333,-77.5 ],
    [ u"jm",u"Maroon Town",3643,18.35,-77.8 ],
    [ u"jm",u"May Pen",44757,17.9666667,-77.2333333 ],
    [ u"jm",u"Montego Bay",82868,18.4666667,-77.9166667 ],
    [ u"jm",u"Morant Bay",9369,17.8833333,-76.4166667 ],
    [ u"jm",u"Ocho Rios",9451,18.4166667,-77.1166667 ],
    [ u"jm",u"Port Antonio",14235,18.1833333,-76.4666667 ],
    [ u"jm",u"Port Maria",7906,18.3666667,-76.9 ],
    [ u"jm",u"Portmore",102865,17.9666667,-76.8666667 ],
    [ u"jm",u"Spanish Town",145024,17.9833333,-76.95 ],
    [ u"jo",u"Aydun",20041,32.507222,35.8575 ],
    [ u"jo",u"Balila",5639,32.388064,35.935046 ],
    [ u"jo",u"Bayir",5314,30.763606,36.678913 ],
    [ u"jo",u"Bayt Idis",5151,32.437604,35.698359 ],
    [ u"jo",u"Bayt Yafa",8494,32.517366,35.788295 ],
    [ u"jo",u"Burma",5128,32.219904,35.783935 ],
    [ u"jo",u"Busayra",8238,30.737604,35.607747 ],
    [ u"jo",u"Dayr Yusuf",6787,32.491157,35.798732 ],
    [ u"jo",u"Diban",6854,31.5,35.783333 ],
    [ u"jo",u"Hawwarah",13337,32.532848,35.908174 ],
    [ u"jo",u"Irbid",296050,32.555556,35.85 ],
    [ u"jo",u"Jawa",11859,31.852474,35.939277 ],
    [ u"jo",u"Judayta",13163,32.40792,35.708022 ],
    [ u"jo",u"Kafr Abil",6907,32.417554,35.669375 ],
    [ u"jo",u"Kafr Asad",8947,32.598276,35.712398 ],
    [ u"jo",u"Kafr Rakib",4832,32.454665,35.689535 ],
    [ u"jo",u"Kafr Sawm",7800,32.683333,35.8 ],
    [ u"jo",u"Kafr Yuba",11730,32.541922,35.801895 ],
    [ u"jo",u"Kitim",5771,32.438321,35.89563 ],
    [ u"jo",u"Kuraymah",19453,32.276391,35.599384 ],
    [ u"jo",u"Madaba",82471,31.715993,35.793919 ],
    [ u"jo",u"Malka",7477,32.673806,35.750129 ],
    [ u"jo",u"Qafqafa",4767,32.348311,35.939496 ],
    [ u"jo",u"Qumaym",5574,32.571339,35.732687 ],
    [ u"jo",u"Raymun",6587,32.283394,35.825318 ],
    [ u"jo",u"Sabha",5854,32.329646,36.500978 ],
    [ u"jo",u"Safut",6645,32.037383,35.834912 ],
    [ u"jo",u"Sakib",11339,32.283298,35.809457 ],
    [ u"jo",u"Sal",7521,32.569444,35.911944 ],
    [ u"jo",u"Samma",9736,32.571027,35.690251 ],
    [ u"jo",u"Sirfa",4454,31.329643,35.654394 ],
    [ u"jo",u"Suf",14017,32.313722,35.837129 ],
    [ u"jo",u"Tibnah",5703,32.475548,35.728436 ],
    [ u"jo",u"Umm Nuwarah",11677,31.931965,35.796827 ],
    [ u"jo",u"Umm Qays",4683,32.65348,35.685397 ],
    [ u"jo",u"Wadi Musa",15618,30.322211,35.479329 ],
    [ u"jo",u"Waqqas",6192,32.542696,35.605332 ],
    [ u"jo",u"Yarqa",5146,31.97845,35.694729 ],
    [ u"jp",u"Abashiri",42498,44.019722,144.258611 ],
    [ u"jp",u"Abiko",131774,35.866667,140.016667 ],
    [ u"jp",u"Ageo",219405,35.969722,139.588611 ],
    [ u"jp",u"Aioi",32394,34.803611,134.468056 ],
    [ u"jp",u"Akabira",14214,43.551389,142.053056 ],
    [ u"jp",u"Akashi",297281,34.633333,134.983333 ],
    [ u"jp",u"Aki",20118,33.5,133.9 ],
    [ u"jp",u"Akiruno",82022,35.749435,139.248346 ],
    [ u"jp",u"Akishima",107926,35.720848,139.379991 ],
    [ u"jp",u"Akita",320071,39.716667,140.116667 ],
    [ u"jp",u"Ako",52016,34.75,134.4 ],
    [ u"jp",u"Amagasaki",442176,34.716667,135.416667 ],
    [ u"jp",u"Amagi",42312,33.416667,130.65 ],
    [ u"jp",u"Ami",48257,36.033333,140.2 ],
    [ u"jp",u"Anan",55422,33.916667,134.65 ],
    [ u"jp",u"Anjo",168664,34.95,137.083333 ],
    [ u"jp",u"Annaka",48236,36.316667,138.9 ],
    [ u"jp",u"Arai",27481,37.016667,138.25 ],
    [ u"jp",u"Asahi",41721,35.716667,140.65 ],
    [ u"jp",u"Asahikawa",356615,43.767778,142.370278 ],
    [ u"jp",u"Asaka",128061,35.804722,139.601944 ],
    [ u"jp",u"Ashibetsu",19108,43.509722,142.185556 ],
    [ u"jp",u"Ashikaga",159673,36.333333,139.45 ],
    [ u"jp",u"Ashiya",88574,34.733333,135.316667 ],
    [ u"jp",u"Atami",40688,35.089444,139.068611 ],
    [ u"jp",u"Atsugi",229203,35.438889,139.359722 ],
    [ u"jp",u"Ayabe",37613,35.3,135.25 ],
    [ u"jp",u"Ayase",82613,35.386462,139.417373 ],
    [ u"jp",u"Beppu",125067,33.273611,131.491944 ],
    [ u"jp",u"Bibai",29029,43.324722,141.858611 ],
    [ u"jp",u"Bihoro",22972,43.822778,144.104444 ],
    [ u"jp",u"Chatan",27844,26.309444,127.770278 ],
    [ u"jp",u"Chichibu",58508,35.990278,139.076389 ],
    [ u"jp",u"Chigasaki",231660,35.326111,139.403889 ],
    [ u"jp",u"Chino",56567,35.983333,138.15 ],
    [ u"jp",u"Chiryu",67062,35,137.033333 ],
    [ u"jp",u"Chita",83276,35.002668,136.864205 ],
    [ u"jp",u"Chitose",92943,42.819444,141.652222 ],
    [ u"jp",u"Chofu",212978,35.655556,139.552222 ],
    [ u"jp",u"Choshi",75651,35.733333,140.833333 ],
    [ u"jp",u"Daigo",22311,36.766667,140.35 ],
    [ u"jp",u"Daito",129523,34.7,135.616667 ],
    [ u"jp",u"Date",35301,42.468056,140.868056 ],
    [ u"jp",u"Ebetsu",133955,43.108056,141.550556 ],
    [ u"jp",u"Ebina",123667,35.381212,139.396515 ],
    [ u"jp",u"Edosaki",20801,35.95,140.316667 ],
    [ u"jp",u"Ena",35689,35.447216,137.38332 ],
    [ u"jp",u"Eniwa",68771,42.883333,141.566667 ],
    [ u"jp",u"Enzan",25143,35.7,138.733333 ],
    [ u"jp",u"Fuchu",50747,34.566667,133.233333 ],
    [ u"jp",u"Fuchu",240082,35.666667,139.483333 ],
    [ u"jp",u"Fujieda",132860,34.866667,138.266667 ],
    [ u"jp",u"Fuji",240017,35.15,138.65 ],
    [ u"jp",u"Fujiidera",66856,34.563769,135.578629 ],
    [ u"jp",u"Fujimi",108462,35.873739,139.555375 ],
    [ u"jp",u"Fujinomiya",121517,35.216667,138.616667 ],
    [ u"jp",u"Fujioka",63359,36.25,139.083333 ],
    [ u"jp",u"Fujisawa",394630,35.341944,139.47 ],
    [ u"jp",u"Fujishiro",33149,35.916667,140.116667 ],
    [ u"jp",u"Fukagawa",26152,43.708056,142.039167 ],
    [ u"jp",u"Fukaya",106597,36.2,139.283333 ],
    [ u"jp",u"Fukiage",28334,36.1,139.45 ],
    [ u"jp",u"Fukuchiyama",68736,35.3,135.116667 ],
    [ u"jp",u"Fukue",26637,32.688056,128.841944 ],
    [ u"jp",u"Fukuma",43154,33.766667,130.466667 ],
    [ u"jp",u"Fukumitsu",19535,36.55,136.866667 ],
    [ u"jp",u"Fukuroi",63046,34.75,137.916667 ],
    [ u"jp",u"Fukuyama",383302,34.483333,133.366667 ],
    [ u"jp",u"Funabashi",560754,35.693056,139.983333 ],
    [ u"jp",u"Funehiki",23524,37.433333,140.583333 ],
    [ u"jp",u"Furano",25873,43.35,142.383333 ],
    [ u"jp",u"Furukawa",76313,38.571667,140.955556 ],
    [ u"jp",u"Fussa",62297,35.736667,139.323611 ],
    [ u"jp",u"Futtsu",51651,35.305278,139.818611 ],
    [ u"jp",u"Gamagori",80786,34.833333,137.233333 ],
    [ u"jp",u"Ginowan",91801,26.26265,127.761472 ],
    [ u"jp",u"Gobo",27169,33.883333,135.15 ],
    [ u"jp",u"Godo",20758,35.416667,136.6 ],
    [ u"jp",u"Gojo",34343,34.35,135.7 ],
    [ u"jp",u"Gose",32871,34.45,135.733333 ],
    [ u"jp",u"Gosen",37361,37.733333,139.166667 ],
    [ u"jp",u"Goshogawara",49111,40.804444,140.441389 ],
    [ u"jp",u"Gotemba",83795,35.3,138.933333 ],
    [ u"jp",u"Gotsu",24597,35,132.216667 ],
    [ u"jp",u"Gushikawa",65252,26.354444,127.868611 ],
    [ u"jp",u"Gyoda",86344,36.133333,139.45 ],
    [ u"jp",u"Habikino",121052,34.534062,135.583343 ],
    [ u"jp",u"Hachinohe",239047,40.505,141.491944 ],
    [ u"jp",u"Hachioji",579402,35.655833,139.323889 ],
    [ u"jp",u"Hadano",174284,35.371111,139.223611 ],
    [ u"jp",u"Haebaru",34240,26.184722,127.7225 ],
    [ u"jp",u"Hagi",43826,34.4,131.416667 ],
    [ u"jp",u"Haibara",18472,34.533333,135.95 ],
    [ u"jp",u"Hakodate",275733,41.775833,140.736667 ],
    [ u"jp",u"Hakone",13939,35.183333,139.033333 ],
    [ u"jp",u"Hakui",24529,36.883333,136.783333 ],
    [ u"jp",u"Hamada",45751,34.883333,132.083333 ],
    [ u"jp",u"Hamakita",86503,34.8,137.783333 ],
    [ u"jp",u"Hamamatsu",605105,34.7,137.733333 ],
    [ u"jp",u"Hamura",58201,35.790722,139.338888 ],
    [ u"jp",u"Hanamaki",73116,39.383333,141.116667 ],
    [ u"jp",u"Handa",116120,34.883333,136.933333 ],
    [ u"jp",u"Hannan",60796,34.333333,135.25 ],
    [ u"jp",u"Hanno",86264,35.851944,139.318056 ],
    [ u"jp",u"Hanyu",58687,36.166667,139.533333 ],
    [ u"jp",u"Hasaki",39209,35.733333,140.833333 ],
    [ u"jp",u"Hasama",22740,38.490529,141.114724 ],
    [ u"jp",u"Hashima",65613,35.328999,136.680514 ],
    [ u"jp",u"Hashimoto",57115,34.316667,135.616667 ],
    [ u"jp",u"Hasuda",65162,35.975556,139.650833 ],
    [ u"jp",u"Hatogaya",53063,35.834167,139.736389 ],
    [ u"jp",u"Hatsukaichi",77342,34.35,132.333333 ],
    [ u"jp",u"Hayama",31136,35.266667,139.583333 ],
    [ u"jp",u"Hayato",39475,31.716667,130.733333 ],
    [ u"jp",u"Hekinan",68873,34.883333,136.983333 ],
    [ u"jp",u"Hidaka",52912,35.916637,139.362331 ],
    [ u"jp",u"Higashine",45779,38.438889,140.400556 ],
    [ u"jp",u"Higashiyamato",79333,35.762978,139.445755 ],
    [ u"jp",u"Hiji",27864,33.366667,131.533333 ],
    [ u"jp",u"Hikari",45886,33.955,131.95 ],
    [ u"jp",u"Hikone",110927,35.25,136.25 ],
    [ u"jp",u"Himeji",481496,34.816667,134.7 ],
    [ u"jp",u"Himi",54511,36.85,136.983333 ],
    [ u"jp",u"Hino",22768,35,136.25 ],
    [ u"jp",u"Hino",171778,35.673056,139.400278 ],
    [ u"jp",u"Hirado",22516,33.359722,129.553056 ],
    [ u"jp",u"Hirakata",406335,34.8,135.633333 ],
    [ u"jp",u"Hirara",34354,24.803788,125.302222 ],
    [ u"jp",u"Hirata",28154,35.216667,132.933333 ],
    [ u"jp",u"Hiratsuka",259056,35.323056,139.342222 ],
    [ u"jp",u"Hirosaki",174973,40.593056,140.4725 ],
    [ u"jp",u"Hiroshima",1143850,34.434844,132.740622 ],
    [ u"jp",u"Hisai",41643,34.666667,136.466667 ],
    [ u"jp",u"Hitachi",186311,36.6,140.65 ],
    [ u"jp",u"Hita",61482,33.316667,130.933333 ],
    [ u"jp",u"Hitoyoshi",38007,32.216667,130.75 ],
    [ u"jp",u"Hobara",24516,37.816667,140.55 ],
    [ u"jp",u"Hofu",116926,34.05,131.566667 ],
    [ u"jp",u"Hojo",27992,33.966667,132.766667 ],
    [ u"jp",u"Hokota",27691,36.15,140.516667 ],
    [ u"jp",u"Hondo",40787,32.45,130.2 ],
    [ u"jp",u"Honjo",46730,39.388333,140.083333 ],
    [ u"jp",u"Honjo",61869,36.233333,139.183333 ],
    [ u"jp",u"Hotaka",33195,36.333333,137.883333 ],
    [ u"jp",u"Ibara",34425,34.6,133.466667 ],
    [ u"jp",u"Ibaraki",263408,34.816667,135.566667 ],
    [ u"jp",u"Ichihara",283537,35.516667,140.083333 ],
    [ u"jp",u"Ichikawa",458249,35.719722,139.924722 ],
    [ u"jp",u"Ichinohe",15825,40.206944,141.301667 ],
    [ u"jp",u"Ichinomiya",280333,35.3,136.8 ],
    [ u"jp",u"Ichinoseki",62971,38.916667,141.133333 ],
    [ u"jp",u"Iida",107112,35.516667,137.833333 ],
    [ u"jp",u"Iiyama",25281,36.85,138.366667 ],
    [ u"jp",u"Iizuka",78206,33.633333,130.683333 ],
    [ u"jp",u"Ijuin",25217,31.616667,130.4 ],
    [ u"jp",u"Ikeda",99477,34.816667,135.416667 ],
    [ u"jp",u"Ikeda",15895,34.016667,133.8 ],
    [ u"jp",u"Ikoma",117604,34.683333,135.7 ],
    [ u"jp",u"Imabari",115356,34.066667,132.966667 ],
    [ u"jp",u"Imaichi",64324,36.716667,139.683333 ],
    [ u"jp",u"Imari",57940,33.266667,129.883333 ],
    [ u"jp",u"Inagi",77024,35.634533,139.558786 ],
    [ u"jp",u"Ina",62105,35.833333,137.95 ],
    [ u"jp",u"Inawashiro",17413,37.566667,140.116667 ],
    [ u"jp",u"Inazawa",102131,35.25,136.783333 ],
    [ u"jp",u"Innoshima",26141,34.283333,133.183333 ],
    [ u"jp",u"Ino",24123,33.55,133.433333 ],
    [ u"jp",u"Inuyama",73996,35.383333,136.933333 ],
    [ u"jp",u"Inzai",67406,35.834791,140.163612 ],
    [ u"jp",u"Iruma",151548,35.845516,139.412003 ],
    [ u"jp",u"Isahaya",97372,32.841111,130.043056 ],
    [ u"jp",u"Isawa",29616,35.65,138.633333 ],
    [ u"jp",u"Isehara",103402,35.390556,139.307778 ],
    [ u"jp",u"Ise",97315,34.483333,136.7 ],
    [ u"jp",u"Isesaki",130694,36.316667,139.2 ],
    [ u"jp",u"Ishigaki",44803,24.344782,124.157167 ],
    [ u"jp",u"Ishige",24948,36.116667,139.966667 ],
    [ u"jp",u"Ishii",26394,34.066667,134.433333 ],
    [ u"jp",u"Ishikari",57302,43.239722,141.353889 ],
    [ u"jp",u"Ishikawa",18817,37.15,140.45 ],
    [ u"jp",u"Ishikawa",22412,26.423333,127.821389 ],
    [ u"jp",u"Ishinomaki",117235,38.416667,141.3 ],
    [ u"jp",u"Ishioka",52305,36.183333,140.266667 ],
    [ u"jp",u"Isshiki",23966,34.8,137.016667 ],
    [ u"jp",u"Itako",25791,35.933333,140.55 ],
    [ u"jp",u"Itami",193526,34.766667,135.416667 ],
    [ u"jp",u"Itoigawa",30866,37.033333,137.85 ],
    [ u"jp",u"Ito",71579,34.966667,139.083333 ],
    [ u"jp",u"Itoman",57185,26.124722,127.669444 ],
    [ u"jp",u"Itsukaichi",24956,35.725278,139.217778 ],
    [ u"jp",u"Iwade",55634,34.25,135.316667 ],
    [ u"jp",u"Iwai",42498,36.05,139.9 ],
    [ u"jp",u"Iwaki",357313,37.05,140.883333 ],
    [ u"jp",u"Iwakuni",104006,34.15,132.183333 ],
    [ u"jp",u"Iwakura",48007,35.283333,136.866667 ],
    [ u"jp",u"Iwamizawa",85108,43.200278,141.759722 ],
    [ u"jp",u"Iwanai",15584,42.974444,140.508889 ],
    [ u"jp",u"Iwanuma",42411,38.104722,140.859444 ],
    [ u"jp",u"Iwase",21981,36.35,140.1 ],
    [ u"jp",u"Iwata",88510,34.7,137.85 ],
    [ u"jp",u"Iwatsuki",108835,35.942778,139.691944 ],
    [ u"jp",u"Iyo",30760,33.751389,132.701389 ],
    [ u"jp",u"Izumi",189087,34.483333,135.433333 ],
    [ u"jp",u"Izumiotsu",80773,34.5,135.4 ],
    [ u"jp",u"Izumo",89287,35.366667,132.766667 ],
    [ u"jp",u"Joetsu",136235,37.111749,138.268442 ],
    [ u"jp",u"Kadoma",131729,34.733333,135.583333 ],
    [ u"jp",u"Kaga",67370,36.3,136.333333 ],
    [ u"jp",u"Kainan",43369,34.15,135.2 ],
    [ u"jp",u"Kaita",29902,34.366667,132.55 ],
    [ u"jp",u"Kaizuka",92633,34.45,135.35 ],
    [ u"jp",u"Kakamigahara",132243,35.416667,136.866667 ],
    [ u"jp",u"Kakegawa",84005,34.766667,138.016667 ],
    [ u"jp",u"Kakogawa",271636,34.766667,134.85 ],
    [ u"jp",u"Kakuda",33221,37.966667,140.783333 ],
    [ u"jp",u"Kamagaya",106288,35.803041,140.021792 ],
    [ u"jp",u"Kamaishi",43108,39.266667,141.883333 ],
    [ u"jp",u"Kamakura",166019,35.308889,139.550278 ],
    [ u"jp",u"Kameda",32765,37.866667,139.116667 ],
    [ u"jp",u"Kameoka",97182,35,135.583333 ],
    [ u"jp",u"Kameyama",39900,34.85,136.45 ],
    [ u"jp",u"Kamifukuoka",52324,35.8725,139.509722 ],
    [ u"jp",u"Kamiichi",23004,36.7,137.366667 ],
    [ u"jp",u"Kamiiso",38098,41.816667,140.65 ],
    [ u"jp",u"Kaminokawa",30828,36.433333,139.916667 ],
    [ u"jp",u"Kaminoyama",35594,38.153889,140.273611 ],
    [ u"jp",u"Kamisu",52554,35.896846,140.66666 ],
    [ u"jp",u"Kamogata",18413,34.533333,133.583333 ],
    [ u"jp",u"Kamogawa",29120,35.083333,140.1 ],
    [ u"jp",u"Kamojima",24374,34.066667,134.35 ],
    [ u"jp",u"Kamo",32129,37.65,139.05 ],
    [ u"jp",u"Kanaya",20286,34.816667,138.133333 ],
    [ u"jp",u"Kanda",36122,33.783333,130.983333 ],
    [ u"jp",u"Kanie",36592,35.133333,136.8 ],
    [ u"jp",u"Kani",97471,35.404346,137.05595 ],
    [ u"jp",u"Kannabe",40767,34.533333,133.383333 ],
    [ u"jp",u"Kanonji",44364,34.116667,133.65 ],
    [ u"jp",u"Kanuma",94904,36.55,139.733333 ],
    [ u"jp",u"Kanzaki",20173,33.3,130.366667 ],
    [ u"jp",u"Karasuyama",18488,36.65,140.15 ],
    [ u"jp",u"Karatsu",78331,33.4425,129.969722 ],
    [ u"jp",u"Kariya",139160,34.983333,136.983333 ],
    [ u"jp",u"Kasama",29478,36.383333,140.266667 ],
    [ u"jp",u"Kasamatsu",22671,35.366667,136.766667 ],
    [ u"jp",u"Kasaoka",58461,34.5,133.5 ],
    [ u"jp",u"Kaseda",23711,31.416667,130.316667 ],
    [ u"jp",u"Kashiba",69391,34.534717,135.70925 ],
    [ u"jp",u"Kashihara",126224,34.45,135.766667 ],
    [ u"jp",u"Kashima",65936,35.966667,140.633333 ],
    [ u"jp",u"Kashima",32410,33.106111,130.090556 ],
    [ u"jp",u"Kashiwa",340228,35.854444,139.968889 ],
    [ u"jp",u"Kashiwara",79059,34.583333,135.616667 ],
    [ u"jp",u"Kashiwazaki",86184,37.366667,138.55 ],
    [ u"jp",u"Kasugai",298591,35.233333,136.983333 ],
    [ u"jp",u"Kasuga",112300,33.526111,130.487032 ],
    [ u"jp",u"Kasukabe",206919,35.976389,139.753611 ],
    [ u"jp",u"Kasumigaura",18018,36.153259,140.246353 ],
    [ u"jp",u"Katano",82027,34.783333,135.683333 ],
    [ u"jp",u"Katsuura",22308,35.133333,140.3 ],
    [ u"jp",u"Katsuyama",27088,36.05,136.5 ],
    [ u"jp",u"Kawagoe",337937,35.908611,139.485278 ],
    [ u"jp",u"Kawaguchi",468574,35.805,139.720556 ],
    [ u"jp",u"Kawai",20106,34.233333,135.85 ],
    [ u"jp",u"Kawanishi",160522,34.816667,135.416667 ],
    [ u"jp",u"Kawanoe",37641,34.016667,133.566667 ],
    [ u"jp",u"Kawasaki",19141,33.583333,130.833333 ],
    [ u"jp",u"Kawasaki",1306804,35.520556,139.717222 ],
    [ u"jp",u"Kazo",71292,36.116667,139.6 ],
    [ u"jp",u"Kazuno",36925,40.183611,140.787222 ],
    [ u"jp",u"Kesennuma",59117,38.9,141.583333 ],
    [ u"jp",u"Kikuchi",26678,32.983333,130.816667 ],
    [ u"jp",u"Kikugawa",32500,34.702912,138.119779 ],
    [ u"jp",u"Kimitsu",92128,35.325278,139.891111 ],
    [ u"jp",u"Kiryu",110221,36.4,139.333333 ],
    [ u"jp",u"Kisai",20851,36.1,139.583333 ],
    [ u"jp",u"Kisarazu",122527,35.374722,139.9225 ],
    [ u"jp",u"Kishiwada",205563,34.466667,135.366667 ],
    [ u"jp",u"Kisogawa",32586,35.35,136.783333 ],
    [ u"jp",u"Kitahiroshima",62371,42.975833,141.567222 ],
    [ u"jp",u"Kitaibaraki",50844,36.783333,140.75 ],
    [ u"jp",u"Kitakami",93855,39.283333,141.116667 ],
    [ u"jp",u"Kitakata",37140,37.65,139.866667 ],
    [ u"jp",u"Kitakyushu",997545,33.833333,130.833333 ],
    [ u"jp",u"Kitami",113138,43.803056,143.890833 ],
    [ u"jp",u"Kitamoto",69840,36.027694,139.556645 ],
    [ u"jp",u"Kitsuki",23353,33.416667,131.616667 ],
    [ u"jp",u"Kizu",41761,34.733333,135.816667 ],
    [ u"jp",u"Kizukuri",18907,40.806111,140.386111 ],
    [ u"jp",u"Kobayashi",39748,31.983333,130.983333 ],
    [ u"jp",u"Kobe",1528487,34.691304,135.182995 ],
    [ u"jp",u"Kodaira",187369,35.726389,139.483889 ],
    [ u"jp",u"Kodama",21545,36.183333,139.133333 ],
    [ u"jp",u"Koga",60046,33.733333,130.466667 ],
    [ u"jp",u"Koga",58005,36.183333,139.716667 ],
    [ u"jp",u"Koganei",115968,35.691389,139.501111 ],
    [ u"jp",u"Kogota",19761,38.55,141.05 ],
    [ u"jp",u"Kokubu",57897,31.733333,130.766667 ],
    [ u"jp",u"Kokubunji",118682,35.702222,139.475556 ],
    [ u"jp",u"Komae",77643,35.636389,139.574444 ],
    [ u"jp",u"Komagane",34757,35.716573,137.937451 ],
    [ u"jp",u"Komaki",151026,35.283333,136.916667 ],
    [ u"jp",u"Komatsu",109047,36.4,136.45 ],
    [ u"jp",u"Komatsushima",42599,34,134.583333 ],
    [ u"jp",u"Komono",40740,35,136.516667 ],
    [ u"jp",u"Komoro",46272,36.316667,138.433333 ],
    [ u"jp",u"Konan",100390,35.333333,136.866667 ],
    [ u"jp",u"Konosu",88494,36.05,139.516667 ],
    [ u"jp",u"Koriyama",340563,37.4,140.383333 ],
    [ u"jp",u"Kosai",43914,34.700529,137.522525 ],
    [ u"jp",u"Koshigaya",317443,35.883333,139.783333 ],
    [ u"jp",u"Kosugi",33200,36.716667,137.1 ],
    [ u"jp",u"Kozakai",22064,34.8,137.358889 ],
    [ u"jp",u"Kudamatsu",52773,34,131.866667 ],
    [ u"jp",u"Kuji",35568,36.483333,140.616667 ],
    [ u"jp",u"Kuki",73375,36.066667,139.666667 ],
    [ u"jp",u"Kumagaya",155816,36.133333,139.383333 ],
    [ u"jp",u"Kumano",19517,33.903886,136.122138 ],
    [ u"jp",u"Kunitachi",78062,35.674444,139.435 ],
    [ u"jp",u"Kurashiki",437585,34.583333,133.766667 ],
    [ u"jp",u"Kurayoshi",48347,35.433333,133.816667 ],
    [ u"jp",u"Kure",196626,34.233333,132.566667 ],
    [ u"jp",u"Kurihashi",27813,36.133333,139.7 ],
    [ u"jp",u"Kurobe",36479,36.865783,137.43636 ],
    [ u"jp",u"Kuroishi",38615,40.638889,140.592222 ],
    [ u"jp",u"Kuroiso",61231,36.966667,140.05 ],
    [ u"jp",u"Kurume",238199,33.316667,130.516667 ],
    [ u"jp",u"Kusatsu",127681,35.016667,135.966667 ],
    [ u"jp",u"Kushikino",25744,31.716667,130.266667 ],
    [ u"jp",u"Kushima",22102,31.458333,131.233333 ],
    [ u"jp",u"Kushiro",22864,42.975,144.374722 ],
    [ u"jp",u"Kusu",18371,33.266667,131.15 ],
    [ u"jp",u"Kuwana",113108,35.066667,136.7 ],
    [ u"jp",u"Machida",399971,35.540278,139.450833 ],
    [ u"jp",u"Maebaru",70339,33.55,130.2 ],
    [ u"jp",u"Maizuru",92466,35.45,135.333333 ],
    [ u"jp",u"Makabe",19294,36.266667,140.1 ],
    [ u"jp",u"Maki",29042,37.75,138.883333 ],
    [ u"jp",u"Makubetsu",25935,45.371389,141.821111 ],
    [ u"jp",u"Marugame",82091,34.283333,133.783333 ],
    [ u"jp",u"Maruko",25403,36.316667,138.266667 ],
    [ u"jp",u"Marumori",16752,37.916667,140.766667 ],
    [ u"jp",u"Maruoka",33564,36.15,136.266667 ],
    [ u"jp",u"Masaki",30471,33.783333,132.701111 ],
    [ u"jp",u"Mashiko",26045,36.466667,140.1 ],
    [ u"jp",u"Masuda",48577,34.666667,131.85 ],
    [ u"jp",u"Matsubara",130857,34.566667,135.55 ],
    [ u"jp",u"Matsubase",26163,32.65,130.666667 ],
    [ u"jp",u"Matsudo",470287,35.783333,139.9 ],
    [ u"jp",u"Matsumoto",210669,36.233333,137.966667 ],
    [ u"jp",u"Matsusaka",124614,34.566667,136.533333 ],
    [ u"jp",u"Matsuura",20785,33.340585,129.69504 ],
    [ u"jp",u"Matto",68160,36.516667,136.566667 ],
    [ u"jp",u"Menuma",27685,36.216667,139.383333 ],
    [ u"jp",u"Mibu",39729,36.416667,139.8 ],
    [ u"jp",u"Mihara",80388,34.4,133.083333 ],
    [ u"jp",u"Miharu",19709,37.433333,140.483333 ],
    [ u"jp",u"Mikasa",12102,43.255814,141.888176 ],
    [ u"jp",u"Miki",74702,34.8,134.983333 ],
    [ u"jp",u"Mikuni",23480,36.216667,136.15 ],
    [ u"jp",u"Minakuchi",38986,34.966667,136.166667 ],
    [ u"jp",u"Minamata",29429,32.216667,130.4 ],
    [ u"jp",u"Minamiashigara",45129,35.319467,139.109597 ],
    [ u"jp",u"Minokamo",53968,35.430328,137.00009 ],
    [ u"jp",u"Mino",23567,35.533333,136.916667 ],
    [ u"jp",u"Misato",129695,35.860597,139.864486 ],
    [ u"jp",u"Misawa",42805,40.683611,141.359722 ],
    [ u"jp",u"Mishima",113480,35.116667,138.916667 ],
    [ u"jp",u"Mitaka",178739,35.683333,139.55 ],
    [ u"jp",u"Mitake",19340,35.416667,137.133333 ],
    [ u"jp",u"Mitsukaido",41147,36.016667,139.983333 ],
    [ u"jp",u"Mitsuke",43180,37.533333,138.933333 ],
    [ u"jp",u"Miura",51484,35.14,139.619167 ],
    [ u"jp",u"Miyako",51721,39.636667,141.9525 ],
    [ u"jp",u"Miyakonojo",130995,31.733333,131.066667 ],
    [ u"jp",u"Miyata",20421,33.716667,130.666667 ],
    [ u"jp",u"Miyazu",21632,35.533333,135.183333 ],
    [ u"jp",u"Miyoshi",39257,34.8,132.85 ],
    [ u"jp",u"Mizunami",42618,35.366667,137.25 ],
    [ u"jp",u"Mizusawa",61281,39.133333,141.133333 ],
    [ u"jp",u"Mobara",97317,35.416667,140.3 ],
    [ u"jp",u"Moka",65718,36.433333,140.016667 ],
    [ u"jp",u"Mombetsu",26895,44.3525,143.3525 ],
    [ u"jp",u"Moriguchi",148352,34.733333,135.566667 ],
    [ u"jp",u"Mori",20280,34.833333,137.933333 ],
    [ u"jp",u"Moriyama",68585,35.066667,135.983333 ],
    [ u"jp",u"Moriya",56567,35.933333,140 ],
    [ u"jp",u"Moroyama",39693,35.935556,139.304444 ],
    [ u"jp",u"Motegi",19575,36.516667,140.183333 ],
    [ u"jp",u"Motomiya",22705,37.516667,140.4 ],
    [ u"jp",u"Muika",29123,37.066667,138.883333 ],
    [ u"jp",u"Muko",53222,34.933333,135.7 ],
    [ u"jp",u"Murakami",31334,38.233333,139.483333 ],
    [ u"jp",u"Muramatsu",19712,37.683333,139.183333 ],
    [ u"jp",u"Murayama",28427,38.469722,140.414407 ],
    [ u"jp",u"Muroran",96198,42.317222,140.988056 ],
    [ u"jp",u"Muroto",17601,33.283333,134.15 ],
    [ u"jp",u"Musashimurayama",66554,35.74242,139.426348 ],
    [ u"jp",u"Musashino",137480,35.706111,139.559444 ],
    [ u"jp",u"Mutsu",49221,41.289444,141.216944 ],
    [ u"jp",u"Nabari",88129,34.616667,136.083333 ],
    [ u"jp",u"Nagahama",62090,35.383333,136.266667 ],
    [ u"jp",u"Nagai",31026,38.103611,140.035 ],
    [ u"jp",u"Nagaoka",195320,37.45,138.85 ],
    [ u"jp",u"Nagareyama",156003,35.883333,139.933333 ],
    [ u"jp",u"Nagareyama",156003,35.850556,139.891389 ],
    [ u"jp",u"Nagato",23101,34.383333,131.2 ],
    [ u"jp",u"Nagayo",45293,32.816667,129.883333 ],
    [ u"jp",u"Nago",59588,26.588056,127.976111 ],
    [ u"jp",u"Nagoya",2191291,35.180198,136.906739 ],
    [ u"jp",u"Nakajo",26671,38.05,139.416667 ],
    [ u"jp",u"Nakama",46746,33.816667,130.7 ],
    [ u"jp",u"Nakamura",34559,32.983333,132.933333 ],
    [ u"jp",u"Naka",46761,36.05,140.166667 ],
    [ u"jp",u"Nakanojo",17742,36.583333,138.85 ],
    [ u"jp",u"Nakano",42708,36.75,138.366667 ],
    [ u"jp",u"Nakatsugawa",55012,35.483333,137.5 ],
    [ u"jp",u"Nakatsu",67373,33.601389,131.184167 ],
    [ u"jp",u"Namerikawa",34638,36.766667,137.333333 ],
    [ u"jp",u"Namie",21866,37.483333,141 ],
    [ u"jp",u"Namioka",20681,40.707222,140.589444 ],
    [ u"jp",u"Nanae",30008,41.883333,140.683333 ],
    [ u"jp",u"Nanao",45309,37.05,136.966667 ],
    [ u"jp",u"Narashino",156085,35.683333,140.033333 ],
    [ u"jp",u"Narita",100644,35.783333,140.316667 ],
    [ u"jp",u"Naruto",25697,35.6,140.416667 ],
    [ u"jp",u"Naruto",64083,34.183333,134.616667 ],
    [ u"jp",u"Natori",75563,38.166667,140.883333 ],
    [ u"jp",u"Nayoro",26457,44.350556,142.457778 ],
    [ u"jp",u"Naze",41366,28.366667,129.483333 ],
    [ u"jp",u"Nemuro",31224,43.323611,145.575 ],
    [ u"jp",u"Neyagawa",245112,34.75,135.633333 ],
    [ u"jp",u"Nichinan",44243,31.6,131.366667 ],
    [ u"jp",u"Nihommatsu",36287,37.583333,140.433333 ],
    [ u"jp",u"Niigata",505276,37.902222,139.023611 ],
    [ u"jp",u"Niihama",123061,33.959326,133.316722 ],
    [ u"jp",u"Niimi",23787,34.983333,133.466667 ],
    [ u"jp",u"Niitsu",65911,37.8,139.116667 ],
    [ u"jp",u"Niiza",153591,35.797915,139.525391 ],
    [ u"jp",u"Nikko",16042,36.75,139.616667 ],
    [ u"jp",u"Ninohe",26873,40.290813,141.31334 ],
    [ u"jp",u"Ninomiya",31412,35.303333,139.253333 ],
    [ u"jp",u"Nirasaki",33264,35.7,138.45 ],
    [ u"jp",u"Nishihara",37583,26.184167,127.755833 ],
    [ u"jp",u"Nishinomiya",468929,34.716667,135.333333 ],
    [ u"jp",u"Nishio",103338,34.866667,137.05 ],
    [ u"jp",u"Nishiwaki",36953,34.983333,134.966667 ],
    [ u"jp",u"Nisshin",81866,35.165834,136.963975 ],
    [ u"jp",u"Nobeoka",121951,32.583333,131.666667 ],
    [ u"jp",u"Noboribetsu",52881,42.451389,141.173056 ],
    [ u"jp",u"Noda",121414,35.941111,139.858056 ],
    [ u"jp",u"Nogata",56822,33.733333,130.733333 ],
    [ u"jp",u"Nonoichi",48355,36.533333,136.616667 ],
    [ u"jp",u"Noshiro",51079,40.203889,140.024167 ],
    [ u"jp",u"Numata",45526,36.633333,139.05 ],
    [ u"jp",u"Numazu",204320,35.1,138.866667 ],
    [ u"jp",u"Nyuzen",27585,36.933333,137.5 ],
    [ u"jp",u"Oarai",19326,36.316667,140.6 ],
    [ u"jp",u"Obama",32896,35.5,135.75 ],
    [ u"jp",u"Obanazawa",20822,38.603333,140.401944 ],
    [ u"jp",u"Obihiro",173892,42.917222,143.204444 ],
    [ u"jp",u"Obu",77865,35,136.966667 ],
    [ u"jp",u"Oda",31868,35.183333,132.5 ],
    [ u"jp",u"Odate",64543,40.268611,140.568333 ],
    [ u"jp",u"Odawara",203038,35.255556,139.159722 ],
    [ u"jp",u"Ofunato",35418,39.071667,141.716667 ],
    [ u"jp",u"Ogaki",150572,35.35,136.616667 ],
    [ u"jp",u"Oga",28304,39.870999,139.849258 ],
    [ u"jp",u"Ogawa",37444,36.05,139.266667 ],
    [ u"jp",u"Ogawara",23340,38.05,140.733611 ],
    [ u"jp",u"Ogori",23516,34.1,131.4 ],
    [ u"jp",u"Ohara",20226,35.25,140.383333 ],
    [ u"jp",u"Oi",50594,35.851111,139.516667 ],
    [ u"jp",u"Oiso",32595,35.303056,139.302778 ],
    [ u"jp",u"Ojiya",40549,37.3,138.8 ],
    [ u"jp",u"Okawa",39224,33.2,130.35 ],
    [ u"jp",u"Okaya",54286,36.05,138.05 ],
    [ u"jp",u"Okazaki",352364,34.916667,137.15 ],
    [ u"jp",u"Okegawa",75063,36,139.557222 ],
    [ u"jp",u"Okinawa",125485,26.335833,127.801389 ],
    [ u"jp",u"Okuchi",22426,32.066667,130.616667 ],
    [ u"jp",u"Omachi",30599,36.5,137.866667 ],
    [ u"jp",u"Omagari",38805,39.45,140.483333 ],
    [ u"jp",u"Omama",21286,36.433333,139.283333 ],
    [ u"jp",u"Ome",149324,35.783889,139.243056 ],
    [ u"jp",u"Omigawa",25763,35.85,140.616667 ],
    [ u"jp",u"Omihachiman",68697,35.140842,136.082859 ],
    [ u"jp",u"Omura",89919,32.921389,129.953889 ],
    [ u"jp",u"Omuta",131975,33.033333,130.45 ],
    [ u"jp",u"Onoda",44296,34.001389,131.183611 ],
    [ u"jp",u"Onojo",96167,33.506994,130.50979 ],
    [ u"jp",u"Onomichi",90937,34.416667,133.2 ],
    [ u"jp",u"Ono",37470,35.983333,136.483333 ],
    [ u"jp",u"Ono",26191,34.283333,132.266667 ],
    [ u"jp",u"Ono",50231,34.85,134.933333 ],
    [ u"jp",u"Osakasayama",57170,34.516855,135.562978 ],
    [ u"jp",u"Otake",30151,34.2,132.216667 ],
    [ u"jp",u"Ota",152106,36.3,139.366667 ],
    [ u"jp",u"Otaru",143794,43.189444,141.002222 ],
    [ u"jp",u"Otawara",58889,36.866667,140.033333 ],
    [ u"jp",u"Otofuke",40945,42.991667,143.200278 ],
    [ u"jp",u"Otsuchi",16497,39.366667,141.9 ],
    [ u"jp",u"Otsuki",31226,35.6,138.933333 ],
    [ u"jp",u"Owase",22038,34.066667,136.2 ],
    [ u"jp",u"Oyabe",33495,36.666667,136.85 ],
    [ u"jp",u"Oyama",21745,34.6,138.216667 ],
    [ u"jp",u"Oyama",159938,36.3,139.8 ],
    [ u"jp",u"Ozu",38834,33.5,132.55 ],
    [ u"jp",u"Ozu",29820,32.866667,130.866667 ],
    [ u"jp",u"Rifu",35038,38.323611,140.974444 ],
    [ u"jp",u"Ritto",60363,35.027452,135.999712 ],
    [ u"jp",u"Rumoi",26454,43.934444,141.642778 ],
    [ u"jp",u"Ryotsu",16359,38.083333,138.433333 ],
    [ u"jp",u"Ryugasaki",85763,35.9,140.183333 ],
    [ u"jp",u"Ryuo",43181,35.65,138.5 ],
    [ u"jp",u"Sabae",66292,35.95,136.183333 ],
    [ u"jp",u"Sadowara",33112,32.033333,131.433333 ],
    [ u"jp",u"Sagae",43544,38.3725,140.2725 ],
    [ u"jp",u"Sagamihara",648811,35.553056,139.354444 ],
    [ u"jp",u"Sagara",25922,34.683333,138.2 ],
    [ u"jp",u"Saga",165237,33.249322,130.298799 ],
    [ u"jp",u"Saijo",58824,33.916667,133.183333 ],
    [ u"jp",u"Saiki",49066,32.95,131.9 ],
    [ u"jp",u"Saitama",1077730,35.895534,139.67747 ],
    [ u"jp",u"Sakado",96658,35.956944,139.388889 ],
    [ u"jp",u"Sakaide",57090,34.316667,133.85 ],
    [ u"jp",u"Sakaiminato",36324,35.55,133.233333 ],
    [ u"jp",u"Sakai",31268,36.266667,139.25 ],
    [ u"jp",u"Sakai",26919,36.1,139.8 ],
    [ u"jp",u"Sakai",782347,34.583333,135.466667 ],
    [ u"jp",u"Sakata",100446,38.916667,139.855 ],
    [ u"jp",u"Sakurai",62966,34.5,135.85 ],
    [ u"jp",u"Sakura",182553,35.716667,140.233333 ],
    [ u"jp",u"Saku",68886,36.216667,138.483333 ],
    [ u"jp",u"Sanda",132864,34.883333,135.233333 ],
    [ u"jp",u"Sanjo",82894,37.616667,138.95 ],
    [ u"jp",u"Sano",82536,36.316667,139.583333 ],
    [ u"jp",u"Sasaguri",32588,33.616667,130.533333 ],
    [ u"jp",u"Sasayama",47205,35.066667,135.216667 ],
    [ u"jp",u"Sasebo",237446,33.159167,129.722778 ],
    [ u"jp",u"Satte",55287,36.066667,139.716667 ],
    [ u"jp",u"Sawara",47200,35.883333,140.5 ],
    [ u"jp",u"Sayama",160846,35.824167,139.376389 ],
    [ u"jp",u"Seki",77085,34.85,136.4 ],
    [ u"jp",u"Sekiyado",30923,36.1,139.783333 ],
    [ u"jp",u"Sendai",73133,31.816667,130.3 ],
    [ u"jp",u"Sennan",66460,34.348349,135.26842 ],
    [ u"jp",u"Setaka",23985,33.15,130.466667 ],
    [ u"jp",u"Seto",134247,35.233333,137.1 ],
    [ u"jp",u"Settsu",83337,34.778191,135.595121 ],
    [ u"jp",u"Shibata",80794,37.95,139.333333 ],
    [ u"jp",u"Shibetsu",21744,43.653611,145.125 ],
    [ u"jp",u"Shibukawa",48323,36.483333,139 ],
    [ u"jp",u"Shido",22859,34.323333,134.173333 ],
    [ u"jp",u"Shijonawate",56851,34.733333,135.683333 ],
    [ u"jp",u"Shiki",65413,35.833333,139.583333 ],
    [ u"jp",u"Shimabara",38114,32.783333,130.366667 ],
    [ u"jp",u"Shimada",75782,34.816667,138.183333 ],
    [ u"jp",u"Shimizu",32380,35.016667,138.483333 ],
    [ u"jp",u"Shimminato",35994,36.783333,137.066667 ],
    [ u"jp",u"Shimoda",26705,34.666667,138.95 ],
    [ u"jp",u"Shimodate",63667,36.3,139.983333 ],
    [ u"jp",u"Shimonoseki",245789,33.95,130.95 ],
    [ u"jp",u"Shingu",25992,33.716667,130.433333 ],
    [ u"jp",u"Shingu",31619,33.733333,135.983333 ],
    [ u"jp",u"Shinichi",21030,34.55,133.266667 ],
    [ u"jp",u"Shinjo",41141,38.758611,140.300833 ],
    [ u"jp",u"Shinshiro",36070,34.9,137.5 ],
    [ u"jp",u"Shintomi",20051,32.063174,131.486927 ],
    [ u"jp",u"Shiogama",59526,38.316667,141.033333 ],
    [ u"jp",u"Shiojiri",67160,36.1,137.966667 ],
    [ u"jp",u"Shiozawa",20178,37.033333,138.85 ],
    [ u"jp",u"Shirakawa",48340,37.133333,140.216667 ],
    [ u"jp",u"Shiraoi",20805,42.55,141.35 ],
    [ u"jp",u"Shiraoka",50975,36.016667,139.666667 ],
    [ u"jp",u"Shiroi",55316,35.8,140.066667 ],
    [ u"jp",u"Shiroishi",39482,38.003333,140.618333 ],
    [ u"jp",u"Shirone",41406,37.766667,139.016667 ],
    [ u"jp",u"Shisui",19904,35.716667,140.266667 ],
    [ u"jp",u"Shizukuishi",19866,39.683333,140.983333 ],
    [ u"jp",u"Shizunai",22436,42.333889,142.366944 ],
    [ u"jp",u"Shobara",20527,34.85,133.016667 ],
    [ u"jp",u"Shobu",22156,36.066667,139.6 ],
    [ u"jp",u"Sobue",23372,35.25,136.716667 ],
    [ u"jp",u"Sodegaura",60594,35.673447,140.022924 ],
    [ u"jp",u"Soja",57469,34.666667,133.75 ],
    [ u"jp",u"Soka",231449,35.820278,139.804444 ],
    [ u"jp",u"Soma",38042,37.792833,140.929406 ],
    [ u"jp",u"Sueyoshi",19986,31.65,131.016667 ],
    [ u"jp",u"Sugito",49818,36.033333,139.733333 ],
    [ u"jp",u"Suibara",20392,37.833333,139.233333 ],
    [ u"jp",u"Suita",351634,34.75,135.533333 ],
    [ u"jp",u"Sukagawa",68791,37.283333,140.383333 ],
    [ u"jp",u"Sukumo",25784,32.933333,132.733333 ],
    [ u"jp",u"Sumoto",39546,34.35,134.9 ],
    [ u"jp",u"Sunagawa",20102,43.486389,141.905556 ],
    [ u"jp",u"Susaki",26195,33.366667,133.283333 ],
    [ u"jp",u"Susono",55545,35.17388,138.906913 ],
    [ u"jp",u"Suwa",54736,36.033333,138.133333 ],
    [ u"jp",u"Suzaka",54023,36.65,138.316667 ],
    [ u"jp",u"Suzuka",191479,34.883333,136.583333 ],
    [ u"jp",u"Suzu",18205,37.416667,137.25 ],
    [ u"jp",u"Tachikawa",173696,35.692778,139.418056 ],
    [ u"jp",u"Tadotsu",23515,34.275,133.75 ],
    [ u"jp",u"Tagajo",61937,38.3,141 ],
    [ u"jp",u"Tagawa",51608,33.633333,130.8 ],
    [ u"jp",u"Tahara",38177,34.666667,137.266667 ],
    [ u"jp",u"Tajimi",107819,35.316667,137.133333 ],
    [ u"jp",u"Takahagi",33576,36.716667,140.716667 ],
    [ u"jp",u"Takahama",40502,34.916667,136.983333 ],
    [ u"jp",u"Takahashi",24819,34.783333,133.616667 ],
    [ u"jp",u"Takahata",26347,38.0025,140.191111 ],
    [ u"jp",u"Takaishi",60512,34.516667,135.433333 ],
    [ u"jp",u"Takanabe",22513,32.133333,131.5 ],
    [ u"jp",u"Takanosu",20542,40.221944,140.369444 ],
    [ u"jp",u"Takaoka",170079,36.75,137.016667 ],
    [ u"jp",u"Takarazuka",219790,34.8,135.35 ],
    [ u"jp",u"Takasaki",240860,36.333333,139.016667 ],
    [ u"jp",u"Takatsuki",354472,34.85,135.616667 ],
    [ u"jp",u"Takayama",66637,36.133333,137.25 ],
    [ u"jp",u"Takefu",75753,35.9,136.166667 ],
    [ u"jp",u"Takehara",30506,34.338333,132.916667 ],
    [ u"jp",u"Takeo",34230,33.2,130.016667 ],
    [ u"jp",u"Taketa",16361,32.966667,131.4 ],
    [ u"jp",u"Taketoyo",41679,34.85,136.916667 ],
    [ u"jp",u"Takikawa",45132,43.552778,141.906389 ],
    [ u"jp",u"Tamamura",42567,36.3,139.116667 ],
    [ u"jp",u"Tamana",45661,32.916667,130.566667 ],
    [ u"jp",u"Tamano",67786,34.483333,133.95 ],
    [ u"jp",u"Tama",147477,35.643599,139.468436 ],
    [ u"jp",u"Tanabe",69564,33.733333,135.366667 ],
    [ u"jp",u"Tanashi",82112,35.723889,139.522222 ],
    [ u"jp",u"Tanuma",28724,36.366667,139.583333 ],
    [ u"jp",u"Tanushimaru",21156,33.35,130.683333 ],
    [ u"jp",u"Tarui",29070,35.366667,136.533333 ],
    [ u"jp",u"Tatebayashi",81275,36.25,139.533333 ],
    [ u"jp",u"Tateyama",50065,34.983333,139.866667 ],
    [ u"jp",u"Tatsuno",40011,34.866667,134.55 ],
    [ u"jp",u"Tatsuno",21499,35.983333,138 ],
    [ u"jp",u"Tawaramoto",32660,34.55,135.8 ],
    [ u"jp",u"Tendo",65394,38.353611,140.369722 ],
    [ u"jp",u"Tenno",22740,39.9,139.966667 ],
    [ u"jp",u"Tenri",71054,34.583333,135.833333 ],
    [ u"jp",u"Toba",23303,34.483333,136.85 ],
    [ u"jp",u"Tobe",21382,33.733333,132.783333 ],
    [ u"jp",u"Tobetsu",21818,43.216944,141.516944 ],
    [ u"jp",u"Tochigi",82134,36.383333,139.733333 ],
    [ u"jp",u"Tochio",23045,37.466667,139 ],
    [ u"jp",u"Toda",118733,35.809444,139.6925 ],
    [ u"jp",u"Togane",66334,35.55,140.366667 ],
    [ u"jp",u"Togitsu",29365,32.833333,129.85 ],
    [ u"jp",u"Tokamachi",41136,37.133333,138.766667 ],
    [ u"jp",u"Toki",61395,35.35,137.183333 ],
    [ u"jp",u"Tokoname",49554,34.883333,136.85 ],
    [ u"jp",u"Tokorozawa",339441,35.786389,139.467778 ],
    [ u"jp",u"Tokuyama",101134,34.05,131.816667 ],
    [ u"jp",u"Tokyo",31480498,35.685,139.751389 ],
    [ u"jp",u"Tomakomai",174808,42.636944,141.603333 ],
    [ u"jp",u"Tomigusuku",55715,26.185,127.675 ],
    [ u"jp",u"Tomioka",49282,36.25,138.9 ],
    [ u"jp",u"Tomisato",53017,35.744831,140.403859 ],
    [ u"jp",u"Tomiya",42501,38.393056,140.886111 ],
    [ u"jp",u"Tomobe",37147,36.35,140.3 ],
    [ u"jp",u"Tonami",42692,36.620467,136.943211 ],
    [ u"jp",u"Tondabayashi",132875,34.5,135.6 ],
    [ u"jp",u"Tonosho",16514,34.483333,134.183333 ],
    [ u"jp",u"Tono",26781,39.316667,141.533333 ],
    [ u"jp",u"Toride",80717,35.9,140.083333 ],
    [ u"jp",u"Tosu",63596,33.366667,130.516667 ],
    [ u"jp",u"Tottori",154099,35.5,134.233333 ],
    [ u"jp",u"Towada",63672,40.620495,141.210674 ],
    [ u"jp",u"Toyoake",68558,35.038004,136.99931 ],
    [ u"jp",u"Toyohashi",378377,34.766667,137.383333 ],
    [ u"jp",u"Toyokawa",120538,34.816667,137.4 ],
    [ u"jp",u"Toyonaka",384463,34.783333,135.466667 ],
    [ u"jp",u"Toyooka",46500,35.533333,134.833333 ],
    [ u"jp",u"Toyoshina",27835,36.3,137.9 ],
    [ u"jp",u"Toyota",362386,35.083333,137.15 ],
    [ u"jp",u"Toyo",32475,33.921667,133.088333 ],
    [ u"jp",u"Tsubame",44284,37.65,138.933333 ],
    [ u"jp",u"Tsubata",38645,36.666667,136.733333 ],
    [ u"jp",u"Tsuchiura",136386,36.090469,140.210473 ],
    [ u"jp",u"Tsukuba",175593,36.083333,140.116667 ],
    [ u"jp",u"Tsukumi",21659,33.070556,131.857222 ],
    [ u"jp",u"Tsurugashima",69431,35.959959,139.402831 ],
    [ u"jp",u"Tsuruga",68483,35.65,136.066667 ],
    [ u"jp",u"Tsurugi",22042,36.45,136.633333 ],
    [ u"jp",u"Tsuruoka",99821,38.721667,139.821667 ],
    [ u"jp",u"Tsushima",67658,35.166667,136.716667 ],
    [ u"jp",u"Tsuyama",89718,35.05,134 ],
    [ u"jp",u"Ube",173735,33.943056,131.251111 ],
    [ u"jp",u"Ueda",126607,36.4,138.266667 ],
    [ u"jp",u"Ueki",31688,32.9,130.683333 ],
    [ u"jp",u"Uenohara",27840,35.616667,139.116667 ],
    [ u"jp",u"Ueno",61599,34.75,136.133333 ],
    [ u"jp",u"Ujiie",30366,36.683333,139.966667 ],
    [ u"jp",u"Uji",192926,34.883333,135.8 ],
    [ u"jp",u"Umi",39773,33.566667,130.5 ],
    [ u"jp",u"Uozu",45849,36.8,137.4 ],
    [ u"jp",u"Urasoe",110284,26.259023,127.730124 ],
    [ u"jp",u"Urayasu",143761,35.663338,139.908548 ],
    [ u"jp",u"Urayasu",143761,35.670556,139.888611 ],
    [ u"jp",u"Ureshino",18953,33.1,129.983333 ],
    [ u"jp",u"Ushibuka",16668,32.190556,130.022778 ],
    [ u"jp",u"Ushiku",80021,35.966667,140.133333 ],
    [ u"jp",u"Usuki",35001,33.108056,131.787778 ],
    [ u"jp",u"Utashinai",5163,43.516667,142.05 ],
    [ u"jp",u"Uto",39234,32.683333,130.666667 ],
    [ u"jp",u"Uwajima",58972,33.216667,132.566667 ],
    [ u"jp",u"Wajima",24605,37.4,136.9 ],
    [ u"jp",u"Waki",17659,34.066667,134.15 ],
    [ u"jp",u"Wakkanai",41556,45.409444,141.673889 ],
    [ u"jp",u"Wako",77437,35.789444,139.623333 ],
    [ u"jp",u"Wakuya",18334,38.533333,141.133333 ],
    [ u"jp",u"Warabi",69648,35.826389,139.704444 ],
    [ u"jp",u"Watari",36322,38.035,140.851111 ],
    [ u"jp",u"Yachimata",83324,35.65,140.316667 ],
    [ u"jp",u"Yachiyo",182894,35.735306,140.124453 ],
    [ u"jp",u"Yaita",36275,36.8,139.933333 ],
    [ u"jp",u"Yaizu",121059,34.866667,138.333333 ],
    [ u"jp",u"Yamada",20144,39.466667,141.95 ],
    [ u"jp",u"Yamaga",32298,33.016667,130.683333 ],
    [ u"jp",u"Yamasaki",25115,35,134.55 ],
    [ u"jp",u"Yamoto",32029,38.427378,141.21487 ],
    [ u"jp",u"Yanagawa",40386,33.166667,130.4 ],
    [ u"jp",u"Yanagawa",20808,37.85,140.6 ],
    [ u"jp",u"Yanai",32229,33.966667,132.116667 ],
    [ u"jp",u"Yao",273216,34.616667,135.6 ],
    [ u"jp",u"Yashiro",21554,34.916667,134.966667 ],
    [ u"jp",u"Yasugi",29368,35.433333,133.25 ],
    [ u"jp",u"Yasu",37587,35.05,136.016667 ],
    [ u"jp",u"Yatsuo",22205,36.566667,137.133333 ],
    [ u"jp",u"Yatsushiro",104343,32.5,130.6 ],
    [ u"jp",u"Yawata",71657,34.866667,135.7 ],
    [ u"jp",u"Yoichi",22788,43.203889,140.770278 ],
    [ u"jp",u"Yokaichiba",32651,35.7,140.55 ],
    [ u"jp",u"Yokaichi",45339,35.1,136.2 ],
    [ u"jp",u"Yokkaichi",295843,34.966667,136.616667 ],
    [ u"jp",u"Yokosuka",428999,35.283611,139.667222 ],
    [ u"jp",u"Yokote",39178,39.3,140.566667 ],
    [ u"jp",u"Yomitan",39538,26.4,127.746389 ],
    [ u"jp",u"Yonago",141369,35.433333,133.333333 ],
    [ u"jp",u"Yonezawa",94487,37.916667,140.116667 ],
    [ u"jp",u"Yorii",38718,36.116667,139.2 ],
    [ u"jp",u"Yoshida",25500,37.683333,138.883333 ],
    [ u"jp",u"Yoshii",25656,36.25,138.983333 ],
    [ u"jp",u"Yoshikawa",60511,35.885278,139.839444 ],
    [ u"jp",u"Yotsukaido",86703,35.65,140.166667 ],
    [ u"jp",u"Yubari",12872,43.037778,141.957778 ],
    [ u"jp",u"Yugawara",27567,35.15,139.066667 ],
    [ u"jp",u"Yuki",51575,36.3,139.883333 ],
    [ u"jp",u"Yukuhashi",71278,33.733333,130.983333 ],
    [ u"jp",u"Yuzawa",33537,39.166667,140.5 ],
    [ u"jp",u"Yuza",17083,39,139.916667 ],
    [ u"jp",u"Zama",134674,35.488889,139.388611 ],
    [ u"jp",u"Zushi",60056,35.291667,139.585556 ],
    [ u"ke",u"Ahero",8788,-0.1833333,34.9166667 ],
    [ u"ke",u"Baringo",7656,0.4666667,35.9666667 ],
    [ u"ke",u"Bomet",5270,-0.7833333,35.35 ],
    [ u"ke",u"Bondo",8683,0.2386111,34.2694444 ],
    [ u"ke",u"Bungoma",55968,0.5666667,34.5666667 ],
    [ u"ke",u"Busia",40920,0.3936111,34.3052778 ],
    [ u"ke",u"Butere",11206,0.2094444,34.4927778 ],
    [ u"ke",u"Chepareria",1073,1.3166667,35.2 ],
    [ u"ke",u"Chuka",9348,-0.3333333,37.65 ],
    [ u"ke",u"Eldama Ravine",12523,0.05,35.7166667 ],
    [ u"ke",u"Eldoret",218472,0.5166667,35.2833333 ],
    [ u"ke",u"Embu",34927,-0.5333333,37.45 ],
    [ u"ke",u"Garissa",67843,-0.4569444,39.6583333 ],
    [ u"ke",u"Gazi",5222,-4.4166667,39.5 ],
    [ u"ke",u"Gilgil",25264,-0.2166667,36.2666667 ],
    [ u"ke",u"Gilgil",25264,-0.5,36.3166667 ],
    [ u"ke",u"Homa Bay",40324,-0.5166667,34.45 ],
    [ u"ke",u"Isiolo",33212,0.35,37.5833333 ],
    [ u"ke",u"Kabarnet",10134,0.5,35.75 ],
    [ u"ke",u"Kajiado",11199,-1.85,36.7833333 ],
    [ u"ke",u"Kakamega",63433,0.2833333,34.75 ],
    [ u"ke",u"Kandara",914,-0.9,37.0 ],
    [ u"ke",u"Kangema",4319,-0.6833333,36.9666667 ],
    [ u"ke",u"Kangundo",10094,-1.3,37.35 ],
    [ u"ke",u"Kapenguria",15436,1.2333333,35.1166667 ],
    [ u"ke",u"Kapsabet",23990,0.2,35.1 ],
    [ u"ke",u"Karuri",21476,-0.7166667,37.0333333 ],
    [ u"ke",u"Kendu Bay",434,-0.3666667,34.65 ],
    [ u"ke",u"Kericho",35747,-0.3666667,35.2833333 ],
    [ u"ke",u"Keroka",4143,-0.7833333,34.95 ],
    [ u"ke",u"Kerugoya",15287,-0.5,37.2833333 ],
    [ u"ke",u"Kiambu",21267,-1.1666667,36.8333333 ],
    [ u"ke",u"Kijabe",4679,-0.9333333,36.5666667 ],
    [ u"ke",u"Kikuyu",3960,-1.25,36.6666667 ],
    [ u"ke",u"Kilifi",46124,-3.6333333,39.85 ],
    [ u"ke",u"Kinango",8070,-4.1333333,39.3166667 ],
    [ u"ke",u"Kipini",4114,-2.5227778,40.5388889 ],
    [ u"ke",u"Kisii",28547,-0.6833333,34.7666667 ],
    [ u"ke",u"Kisumu",216479,-0.1,34.75 ],
    [ u"ke",u"Kitale",75136,1.0166667,35.0 ],
    [ u"ke",u"Kitui",15957,-1.3666667,38.0166667 ],
    [ u"ke",u"Konza",2004,-1.75,37.1166667 ],
    [ u"ke",u"Kwale",4883,-4.1833333,39.45 ],
    [ u"ke",u"Lamu",24529,-2.2783333,40.9033333 ],
    [ u"ke",u"Limuru",6323,-1.1,36.65 ],
    [ u"ke",u"Litein",3129,-0.5833333,35.1833333 ],
    [ u"ke",u"Lodwar",20219,3.1166667,35.6 ],
    [ u"ke",u"Londiani",4758,-0.1666667,35.6 ],
    [ u"ke",u"Luanda",10053,0.3077778,34.0586111 ],
    [ u"ke",u"Machakos",31971,-1.5166667,37.2666667 ],
    [ u"ke",u"Magadi",14529,-1.9,36.2833333 ],
    [ u"ke",u"Makueni",20681,-1.8,37.6166667 ],
    [ u"ke",u"Makuyu",191,-0.9,37.1833333 ],
    [ u"ke",u"Malaba",8383,0.6327778,34.2694444 ],
    [ u"ke",u"Malakisi",4319,0.6769444,34.4216667 ],
    [ u"ke",u"Malindi",68311,-3.2166667,40.1166667 ],
    [ u"ke",u"Mandera",36066,3.9261111,41.8461111 ],
    [ u"ke",u"Maragua",4662,-0.7833333,37.1333333 ],
    [ u"ke",u"Maralal",20843,1.1,36.7 ],
    [ u"ke",u"Mariakani",12786,-3.8666667,39.4666667 ],
    [ u"ke",u"Marsabit",15364,2.3333333,37.9833333 ],
    [ u"ke",u"Maua",10804,0.2333333,37.9333333 ],
    [ u"ke",u"Meru",47226,0.05,37.65 ],
    [ u"ke",u"Migori",35240,-1.0666667,34.4666667 ],
    [ u"ke",u"Molo",27901,-0.25,35.7333333 ],
    [ u"ke",u"Mombasa",799727,-4.05,39.6666667 ],
    [ u"ke",u"Moyale",16246,3.5163889,39.0691667 ],
    [ u"ke",u"Muhoroni",15217,-0.15,35.2 ],
    [ u"ke",u"Mumias",45492,0.3363889,34.4891667 ],
    [ u"ke",u"Mwingi",11219,-0.9333333,38.0666667 ],
    [ u"ke",u"Nairobi",2750561,-1.2833333,36.8166667 ],
    [ u"ke",u"Naivasha",38366,-0.7166667,36.4333333 ],
    [ u"ke",u"Nakuru",259934,-0.2833333,36.0666667 ],
    [ u"ke",u"Namanga",13193,-2.55,36.7833333 ],
    [ u"ke",u"Nambale",1154,0.4472222,34.2519444 ],
    [ u"ke",u"Nandi Hills",4257,0.1166667,35.1833333 ],
    [ u"ke",u"Nandi",3758,0.2,35.1 ],
    [ u"ke",u"Nanyuki",36147,0.0166667,37.0666667 ],
    [ u"ke",u"Narok",36067,-1.0833333,35.8666667 ],
    [ u"ke",u"Naro Moru",9018,-0.1666667,37.0166667 ],
    [ u"ke",u"Ngong",9519,-1.3666667,36.65 ],
    [ u"ke",u"Nyahururu",31982,0.0333333,36.3666667 ],
    [ u"ke",u"Nyeri",51084,-0.4166667,36.95 ],
    [ u"ke",u"Ogembo",1842,-0.8,34.7166667 ],
    [ u"ke",u"Othaya",4468,-0.5666667,36.95 ],
    [ u"ke",u"Oyugis",10116,-0.5,34.7166667 ],
    [ u"ke",u"Port Victoria",6793,0.1,33.9666667 ],
    [ u"ke",u"Rongai",30471,-0.1666667,35.85 ],
    [ u"ke",u"Ruiru",114636,-1.15,36.9666667 ],
    [ u"ke",u"Rumuruti",4502,0.2666667,36.5333333 ],
    [ u"ke",u"Sagana",3297,-0.6666667,37.2 ],
    [ u"ke",u"Sawasawa",12975,-4.4666667,39.4833333 ],
    [ u"ke",u"Shimoni",2374,-4.65,39.3833333 ],
    [ u"ke",u"Siaya",15354,0.06,34.2861111 ],
    [ u"ke",u"Sirisia",944,0.1166667,34.0 ],
    [ u"ke",u"Sotik",2600,-0.6833333,35.1166667 ],
    [ u"ke",u"Takaungu",10760,-3.6833333,39.85 ],
    [ u"ke",u"Taveta",13377,-3.4,37.6833333 ],
    [ u"ke",u"Thika",99335,-1.05,37.0833333 ],
    [ u"ke",u"Voi",19624,-3.3833333,38.5666667 ],
    [ u"ke",u"Wajir",45679,1.7472222,40.0688889 ],
    [ u"ke",u"Webuye",22508,0.6166667,34.7666667 ],
    [ u"ke",u"Witu",5380,-2.3905556,40.4530556 ],
    [ u"ke",u"Wote",6133,-1.7833333,37.6333333 ],
    [ u"ke",u"Wundanyi",12501,-3.4,38.3666667 ],
    [ u"ke",u"Yala",2715,0.1,34.5333333 ],
    [ u"kg",u"At-Bashi",15227,41.1697222,75.8102778 ],
    [ u"kg",u"Batken",10155,40.05,70.8333333 ],
    [ u"kg",u"Isfana",16952,39.8333333,69.5166667 ],
    [ u"kg",u"Kant",20182,42.8875,74.8472222 ],
    [ u"kg",u"Karakol",70172,42.4833333,78.4 ],
    [ u"kg",u"Kemin",10295,42.7852778,75.6911111 ],
    [ u"kg",u"Kyzyl-Suu",16927,42.3408333,77.9980556 ],
    [ u"kg",u"Özgön",40364,40.7666667,73.3 ],
    [ u"kg",u"Sülüktü",15019,39.9302778,69.5697222 ],
    [ u"kg",u"Talas",35172,42.5222222,72.2419444 ],
    [ u"kg",u"Tokmak",63047,42.8413889,75.2883333 ],
    [ u"kg",u"Toktogul",19336,41.9033333,72.9455556 ],
    [ u"kg",u"Tyup",13438,42.75,78.3333333 ],
    [ u"kh",u"Kâmpóng Cham",61761,12.0,105.45 ],
    [ u"kh",u"Kampong Chhnang",75304,12.25,104.6666667 ],
    [ u"kh",u"Kâmpóng Thum",19955,12.7,104.9 ],
    [ u"kh",u"Kâmpôt",22696,10.6166667,104.1833333 ],
    [ u"kh",u"Krâchéh",19979,12.4833333,106.0166667 ],
    [ u"kh",u"Lumphat",19205,13.5,106.9833333 ],
    [ u"kh",u"Phnum Pénh",1573523,11.55,104.9166667 ],
    [ u"kh",u"Phumi Samraong",27858,12.45,105.5833333 ],
    [ u"kh",u"Pousat",52486,12.5333333,103.9166667 ],
    [ u"kh",u"Senmonorom",7944,12.45,107.2 ],
    [ u"kh",u"Sisophon",23215,13.5833333,102.9833333 ],
    [ u"kh",u"Svay Rieng",23956,11.0833333,105.8 ],
    [ u"kh",u"Ta Khmau",52066,11.4833333,104.95 ],
    [ u"ki",u"Bairiki",44428,1.3166667,172.9666667 ],
    [ u"ki",u"Binoinano",369,0.4166667,173.9166667 ],
    [ u"ki",u"Buariki",2715,1.5833333,172.9666667 ],
    [ u"ki",u"Butaritari",2582,3.0833333,172.8166667 ],
    [ u"ki",u"Ijaki",825,-1.9166667,175.5833333 ],
    [ u"ki",u"Ooma",112,-0.9,169.55 ],
    [ u"ki",u"Rawannawi",1916,2.05,173.2666667 ],
    [ u"ki",u"Rungata",1414,-1.35,176.4333333 ],
    [ u"ki",u"Tabiauea",1476,0.9,173.0333333 ],
    [ u"ki",u"Tabukiniberu",1993,-1.35,175.9833333 ],
    [ u"ki",u"Taburao",3823,1.8166667,173.0166667 ],
    [ u"ki",u"Temaraia",2631,-0.6666667,174.45 ],
    [ u"ki",u"Utiroa",2230,-1.2166667,174.75 ],
    [ u"km",u"Domoni",14508,-12.2569444,44.5319444 ],
    [ u"km",u"Fomboni",14965,-12.28,43.7425 ],
    [ u"km",u"Mitsamiouli",6104,-11.3847222,43.2844444 ],
    [ u"km",u"Moroni",42882,-11.7041667,43.2402778 ],
    [ u"km",u"Mutsamudu",23593,-12.1627778,44.3963889 ],
    [ u"kn",u"Basseterre",12920,17.3,-62.7166667 ],
    [ u"kn",u"Cayon",788,17.35,-62.7333333 ],
    [ u"kn",u"Charlestown",1538,17.1333333,-62.6166667 ],
    [ u"kn",u"Cotton Ground",381,17.1666667,-62.6166667 ],
    [ u"kn",u"Dieppe Bay",592,17.4166667,-62.8 ],
    [ u"kn",u"Fig Tree",395,17.3666667,-62.85 ],
    [ u"kn",u"Fig Tree",395,17.1166667,-62.6 ],
    [ u"kn",u"Gingerland",493,17.1333333,-62.55 ],
    [ u"kn",u"Mansion",690,17.3666667,-62.75 ],
    [ u"kn",u"Middle Island",887,17.3166667,-62.8166667 ],
    [ u"kn",u"Monkey Hill",592,17.3166667,-62.7166667 ],
    [ u"kn",u"Newcastle",493,17.2,-62.5833333 ],
    [ u"kn",u"Sadlers",986,17.4,-62.7833333 ],
    [ u"kn",u"Sandy Point",780,17.35,-62.8333333 ],
    [ u"kr",u"Seoul",10323448,37.5985,126.9783 ],
    [ u"kw",u"Bayan",30656,29.318056,48.039167 ],
    [ u"kw",u"Doha",37804,29.367778,47.81 ],
    [ u"kw",u"Hawalli",93312,29.332778,48.028611 ],
    [ u"kw",u"Kayfan",27202,29.341389,47.963333 ],
    [ u"ky",u"Bodden Town",6514,19.2833333,-81.25 ],
    [ u"ky",u"George Town",27340,19.3,-81.3833333 ],
    [ u"ky",u"West Bay",10768,19.3666667,-81.4166667 ],
    [ u"kz",u"Abay",35454,49.631111,72.853889 ],
    [ u"kz",u"Achisay",5635,43.554167,68.888889 ],
    [ u"kz",u"Aksay",34802,51.167778,52.995 ],
    [ u"kz",u"Aksu",8543,52.458611,71.985833 ],
    [ u"kz",u"Aksu",26114,42.416667,69.833333 ],
    [ u"kz",u"Aksu",44812,52.033333,76.916667 ],
    [ u"kz",u"Aktas",9888,49.778889,72.960833 ],
    [ u"kz",u"Aktau",187700,43.65,51.2 ],
    [ u"kz",u"Aktau",9977,50.236667,73.062778 ],
    [ u"kz",u"Alekseyevka",2605,51.997778,70.934167 ],
    [ u"kz",u"Almaty",1204820,43.25,76.95 ],
    [ u"kz",u"Aqtöbe",262471,50.298056,57.181389 ],
    [ u"kz",u"Arys",36289,42.433333,68.8 ],
    [ u"kz",u"Astana",345621,51.181111,71.427778 ],
    [ u"kz",u"Atasu",13184,48.681389,71.643333 ],
    [ u"kz",u"Atbasar",34796,51.8,68.333333 ],
    [ u"kz",u"Atyrau",146440,47.116667,51.883333 ],
    [ u"kz",u"Ayagoz",33479,47.971389,80.439167 ],
    [ u"kz",u"Balkhash",81369,46.848056,74.995 ],
    [ u"kz",u"Balykshi",19260,47.066667,51.866667 ],
    [ u"kz",u"Batamshinskiy",5668,50.559444,58.274722 ],
    [ u"kz",u"Belousovka",9948,50.133889,82.523889 ],
    [ u"kz",u"Bestöbe",7188,52.499444,73.0975 ],
    [ u"kz",u"Beyneu",14245,45.316667,55.2 ],
    [ u"kz",u"Boralday",20996,43.360278,76.857778 ],
    [ u"kz",u"Borovskoy",9659,53.8,64.15 ],
    [ u"kz",u"Bulaevo",9886,54.905556,70.443889 ],
    [ u"kz",u"Chardara",25356,41.254722,67.969167 ],
    [ u"kz",u"Chingirlau",6218,51.095,54.081389 ],
    [ u"kz",u"Derzhavinsk",13856,51.1,66.316667 ],
    [ u"kz",u"Dossor",9526,47.527222,52.981111 ],
    [ u"kz",u"Dzhusaly",20065,45.487778,64.078056 ],
    [ u"kz",u"Ekibastuz",144133,51.666667,75.366667 ],
    [ u"kz",u"Emba",18762,48.826389,58.144167 ],
    [ u"kz",u"Energeticheskiy",17463,43.333333,77.05 ],
    [ u"kz",u"Ereymentau",14169,51.621389,73.106944 ],
    [ u"kz",u"Esik",26447,43.355,77.463333 ],
    [ u"kz",u"Esil",13504,51.955556,66.404167 ],
    [ u"kz",u"Fort-Shevchenko",5213,44.516667,50.266667 ],
    [ u"kz",u"Georgiyevka",9821,43.036944,74.711389 ],
    [ u"kz",u"Glubokoe",11192,50.145556,82.311389 ],
    [ u"kz",u"Gülshat",891,46.633333,74.361111 ],
    [ u"kz",u"Ilyich",12895,40.846389,68.506667 ],
    [ u"kz",u"Inderborskiy",13254,48.55,51.783333 ],
    [ u"kz",u"Kachiry",8931,53.0675,76.103611 ],
    [ u"kz",u"Karabulak",16252,44.908889,78.492222 ],
    [ u"kz",u"Karatau",37881,43.166667,70.466667 ],
    [ u"kz",u"Karaton",8905,46.435278,53.486389 ],
    [ u"kz",u"Karkaralinsk",8195,49.405833,75.474167 ],
    [ u"kz",u"Kazalinsk",6582,45.762778,62.1075 ],
    [ u"kz",u"Kentau",57412,43.521944,68.510833 ],
    [ u"kz",u"Khromtau",23717,50.250278,58.434722 ],
    [ u"kz",u"Kirovskiy",11810,44.894722,78.208333 ],
    [ u"kz",u"Komsomolets",9838,53.745278,62.070833 ],
    [ u"kz",u"Krasnoarmeysk",13148,53.847778,69.763889 ],
    [ u"kz",u"Kurchum",8800,48.572222,83.654167 ],
    [ u"kz",u"Kuryk",11836,43.2,51.65 ],
    [ u"kz",u"Kushmurun",8049,52.450278,64.631111 ],
    [ u"kz",u"Lenger",21238,42.2,69.9 ],
    [ u"kz",u"Lisakovsk",33460,52.536944,62.493611 ],
    [ u"kz",u"Makat",14082,47.65,53.316667 ],
    [ u"kz",u"Makinsk",17711,52.629167,70.416944 ],
    [ u"kz",u"Mamlyutka",9328,54.9375,68.539444 ],
    [ u"kz",u"Maykain",7695,51.4625,75.798611 ],
    [ u"kz",u"Merke",15934,42.872778,73.178611 ],
    [ u"kz",u"Mikhaylovka",15132,43,71.5 ],
    [ u"kz",u"Novodolinskiy",5167,49.705,72.704722 ],
    [ u"kz",u"Osakarovka",7305,50.565,72.569167 ],
    [ u"kz",u"Öskemen",319082,49.978889,82.610278 ],
    [ u"kz",u"Oytal",9821,42.907222,73.273611 ],
    [ u"kz",u"Pavlodar",329014,52.3,76.95 ],
    [ u"kz",u"Petropavl",200891,54.875278,69.162778 ],
    [ u"kz",u"Qostanay",230282,53.166667,63.583333 ],
    [ u"kz",u"Sarkand",76919,45.41,79.918611 ],
    [ u"kz",u"Saryagash",25139,41.45,69.166667 ],
    [ u"kz",u"Saryözek",13930,44.358333,77.975278 ],
    [ u"kz",u"Saryshagan",4365,46.119167,73.619167 ],
    [ u"kz",u"Semey",292795,50.411111,80.2275 ],
    [ u"kz",u"Serebryansk",11478,49.6925,83.289167 ],
    [ u"kz",u"Sergeyevka",8845,53.88,67.415833 ],
    [ u"kz",u"Shakhtinsk",52638,49.71,72.587222 ],
    [ u"kz",u"Shar",9087,49.588611,81.045278 ],
    [ u"kz",u"Shemonaikha",20087,50.632778,81.905556 ],
    [ u"kz",u"Shetpe",11836,44.166667,52.116667 ],
    [ u"kz",u"Shieli",29832,44.166667,66.75 ],
    [ u"kz",u"Shubarkuduk",11733,49.144722,56.487222 ],
    [ u"kz",u"Shubarshi",8651,48.587222,57.186944 ],
    [ u"kz",u"Shu",39785,43.598333,73.761389 ],
    [ u"kz",u"Shymkent",414059,42.3,69.6 ],
    [ u"kz",u"Stepnogorsk",46741,52.354444,71.886944 ],
    [ u"kz",u"Stepnyak",4929,52.833889,70.780278 ],
    [ u"kz",u"Talgar",42194,43.304444,77.232778 ],
    [ u"kz",u"Taraz",358167,42.9,71.366667 ],
    [ u"kz",u"Tasbuget",16455,44.772778,65.5525 ],
    [ u"kz",u"Tekeli",22470,44.83,78.823889 ],
    [ u"kz",u"Temirtau",172809,50.054444,72.948333 ],
    [ u"kz",u"Temir",2560,49.141389,57.13 ],
    [ u"kz",u"Tobol",7155,52.684444,62.579444 ],
    [ u"kz",u"Türkistan",97368,43.333333,68.25 ],
    [ u"kz",u"Urdzhar",14826,47.088333,81.630833 ],
    [ u"kz",u"Üshtöbe",20491,45.242222,77.982222 ],
    [ u"kz",u"Zachagansk",13345,51.184167,51.335278 ],
    [ u"kz",u"Zaysan",17600,47.466667,84.866667 ],
    [ u"kz",u"Zhanakorgan",21339,43.915,67.248056 ],
    [ u"kz",u"Zhanaozen",54889,43.3,52.8 ],
    [ u"kz",u"Zhanatas",33495,43.566667,69.75 ],
    [ u"kz",u"Zharkent",34422,44.162778,80 ],
    [ u"kz",u"Zhetybay",11731,43.594167,52.078889 ],
    [ u"kz",u"Zhetysay",29257,40.733333,68.3 ],
    [ u"kz",u"Zhezkazgan",104365,47.783333,67.766667 ],
    [ u"kz",u"Zhitikara",43107,52.190833,61.200556 ],
    [ u"kz",u"Zholymbet",6876,51.743333,71.712222 ],
    [ u"kz",u"Zyryanovsk",44939,49.738611,84.271944 ],
    [ u"la",u"Ban Nahin",3465,18.233333,104.216667 ],
    [ u"la",u"Champasak",12994,14.883333,105.866667 ],
    [ u"la",u"Luang Prabang",47510,19.885556,102.134722 ],
    [ u"la",u"Nam Tha",3227,20.949722,101.401111 ],
    [ u"la",u"Pakxan",21958,18.366667,103.65 ],
    [ u"la",u"Pakxé",88463,15.116667,105.783333 ],
    [ u"la",u"Phonhong",10122,18.492778,102.417222 ],
    [ u"la",u"Saravan",5519,15.716667,106.416667 ],
    [ u"la",u"Savannakhét",66552,16.55,104.75 ],
    [ u"la",u"Vientiane",196644,17.966667,102.6 ],
    [ u"la",u"Xam Nua",38976,20.419722,104.043889 ],
    [ u"lb",u"Bayrut",1252010,33.8719444,35.5097222 ],
    [ u"lb",u"Beirut",1252010,33.8719444,35.5097222 ],
    [ u"lb",u"Jazzin",13477,33.5416667,35.5888889 ],
    [ u"lb",u"Jubayl",20786,34.1166667,35.65 ],
    [ u"lb",u"Jubb Jannin",7088,33.6269444,35.7833333 ],
    [ u"lb",u"Juniyah",96322,33.9808333,35.6177778 ],
    [ u"lb",u"Riyaq",18878,33.85,36.0 ],
    [ u"lb",u"Sur",135211,33.2711111,35.1963889 ],
    [ u"lc",u"Canaries",710,13.9,-61.0666667 ],
    [ u"lc",u"Cap Estate",699,14.0833333,-60.95 ],
    [ u"lc",u"Castries",12981,14.0,-61.0 ],
    [ u"lc",u"Choc",52,14.0333333,-60.9666667 ],
    [ u"lc",u"Choiseul",363,13.7666667,-61.05 ],
    [ u"lc",u"Dennery",2893,13.9,-60.8833333 ],
    [ u"lc",u"Gros Islet",2448,14.0666667,-60.95 ],
    [ u"lc",u"Laborie",1133,13.75,-60.9833333 ],
    [ u"lc",u"Micoud",3458,13.8166667,-60.9 ],
    [ u"lc",u"Soufrière",2878,13.85,-61.05 ],
    [ u"lc",u"Vieux Fort",4629,13.7166667,-60.95 ],
    [ u"li",u"Balzers",4447,47.0666667,9.5 ],
    [ u"li",u"Eschen",4008,47.2166667,9.5166667 ],
    [ u"li",u"Gamprin",1268,47.2166667,9.5 ],
    [ u"li",u"Mauren",3626,47.2166667,9.5333333 ],
    [ u"li",u"Planken",377,47.1833333,9.5333333 ],
    [ u"li",u"Ruggell",1862,47.2333333,9.5166667 ],
    [ u"li",u"Schaan",5748,47.1666667,9.5 ],
    [ u"li",u"Schellenberg",1004,47.2333333,9.5333333 ],
    [ u"li",u"Triesenberg",2689,47.1166667,9.5333333 ],
    [ u"li",u"Triesen",4701,47.1,9.5333333 ],
    [ u"li",u"Vaduz",5197,47.1333333,9.5166667 ],
    [ u"lk",u"Amparai",18351,7.2833333,81.6666667 ],
    [ u"lk",u"Anuradhapura",60954,8.35,80.3833333 ],
    [ u"lk",u"Badulla",42237,6.9833333,81.05 ],
    [ u"lk",u"Bandarawela",7103,6.8369444,80.9855556 ],
    [ u"lk",u"Battaramulla",75632,6.9,79.9166667 ],
    [ u"lk",u"Batticaloa",86743,7.7166667,81.7 ],
    [ u"lk",u"Beruwala",34256,6.4738889,79.9841667 ],
    [ u"lk",u"Chavakachcheri",121897,9.65,80.15 ],
    [ u"lk",u"Colombo",648119,6.9319444,79.8477778 ],
    [ u"lk",u"Dambulla",66727,7.86,80.6516667 ],
    [ u"lk",u"Eravur",22979,7.7666667,81.6 ],
    [ u"lk",u"Galle",93134,6.0536111,80.2116667 ],
    [ u"lk",u"Gampaha",9352,7.0916667,79.9941667 ],
    [ u"lk",u"Gampola",24734,7.1647222,80.5766667 ],
    [ u"lk",u"Hambantota",11598,6.1166667,81.1166667 ],
    [ u"lk",u"Haputale",4722,6.7666667,80.9666667 ],
    [ u"lk",u"Hatton",15076,6.8972222,80.5958333 ],
    [ u"lk",u"Hendala",56977,6.9838889,79.8763889 ],
    [ u"lk",u"Homagama",34664,6.8408333,80.0138889 ],
    [ u"lk",u"Horana",8984,6.7166667,80.06 ],
    [ u"lk",u"Jaffna",169126,9.6666667,80.0 ],
    [ u"lk",u"Kadugannawa",1216,7.2536111,80.5275 ],
    [ u"lk",u"Kalmunai",100172,7.4166667,81.8166667 ],
    [ u"lk",u"Kalutara",38007,6.5761111,79.9658333 ],
    [ u"lk",u"Kandana",33424,7.0477778,79.8938889 ],
    [ u"lk",u"Kandy",111720,7.2963889,80.635 ],
    [ u"lk",u"Katunayaka",84658,7.1647222,79.8730556 ],
    [ u"lk",u"Kegalla",17772,7.2530556,80.3505556 ],
    [ u"lk",u"Kelaniya",28852,6.96,79.8977778 ],
    [ u"lk",u"Kilinochchi",13006,9.4,80.4 ],
    [ u"lk",u"Kolonnawa",58086,6.9316667,79.8944444 ],
    [ u"lk",u"Kotikawatta",64565,6.9333333,79.9166667 ],
    [ u"lk",u"Kotte",118199,6.9027778,79.9083333 ],
    [ u"lk",u"Kuliyapitiya",6878,7.4708333,80.0455556 ],
    [ u"lk",u"Kurunegala",28576,7.4866667,80.3647222 ],
    [ u"lk",u"Maharagama",66575,6.8461111,79.9280556 ],
    [ u"lk",u"Matale",37464,7.4716667,80.6244444 ],
    [ u"lk",u"Matara",43233,5.9486111,80.5427778 ],
    [ u"lk",u"Minuwangoda",7774,7.1733333,79.9619444 ],
    [ u"lk",u"Monaragala",10236,6.8666667,81.35 ],
    [ u"lk",u"Moratuwa",185062,6.7733333,79.8825 ],
    [ u"lk",u"Mullaitivu",7787,9.2666667,80.8166667 ],
    [ u"lk",u"Mulleriyawa",33540,6.9333333,79.9333333 ],
    [ u"lk",u"Nawalapitiya",13751,7.055,80.5358333 ],
    [ u"lk",u"Negombo",137246,7.2086111,79.8358333 ],
    [ u"lk",u"Nuwara Eliya",25780,6.9697222,80.77 ],
    [ u"lk",u"Peliyagoda",30722,6.95,79.9 ],
    [ u"lk",u"Point Pedro",89944,9.8166667,80.2333333 ],
    [ u"lk",u"Polonnaruwa",15286,7.9333333,81.0 ],
    [ u"lk",u"Ragama",34313,7.0308333,79.9166667 ],
    [ u"lk",u"Ratnapura",47841,6.6827778,80.3991667 ],
    [ u"lk",u"Sigiriya",1001,7.95,80.75 ],
    [ u"lk",u"Talawakele",3546,6.9366667,80.6611111 ],
    [ u"lk",u"Trincomalee",108434,8.5666667,81.2333333 ],
    [ u"lk",u"Valvedditturai",78324,9.8166667,80.1666667 ],
    [ u"lk",u"Vavuniya",60174,8.75,80.5 ],
    [ u"lk",u"Wattala",30730,6.9897222,79.8933333 ],
    [ u"lk",u"Wattegama",8001,6.8,81.5 ],
    [ u"lk",u"Weligama",22183,5.9666667,80.4166667 ],
    [ u"lr",u"Bensonville",32970,6.4461111,-10.6125 ],
    [ u"lr",u"Buchanan",25864,5.8808333,-10.0466667 ],
    [ u"lr",u"Ganta",13828,7.3022222,-8.5308333 ],
    [ u"lr",u"Gbarnga",45947,6.9955556,-9.4722222 ],
    [ u"lr",u"Harper",32931,4.375,-7.7169444 ],
    [ u"lr",u"Monrovia",935427,6.3105556,-10.8047222 ],
    [ u"lr",u"Robertsport",12015,6.7533333,-11.3686111 ],
    [ u"lr",u"Tubmanburg",3168,6.8708333,-10.8172222 ],
    [ u"lr",u"Yekepa",24746,7.5794444,-8.5377778 ],
    [ u"lr",u"Zwedru",25772,6.0666667,-8.1280556 ],
    [ u"ls",u"Hlotse",46416,-28.8833333,28.05 ],
    [ u"ls",u"Mafeteng",40591,-29.8166667,27.25 ],
    [ u"ls",u"Maseru",194387,-29.3166667,27.4833333 ],
    [ u"ls",u"Mokhotlong",5484,-29.2833333,29.0833333 ],
    [ u"ls",u"Quthing",17073,-30.4,27.7166667 ],
    [ u"ls",u"Teyateyaneng",25149,-29.15,27.7333333 ],
    [ u"ls",u"Thaba-Tseka",4843,-29.5333333,28.6 ],
    [ u"lt",u"Akmene",3026,56.25,22.75 ],
    [ u"lt",u"Alytus",70750,54.4,24.05 ],
    [ u"lt",u"Anyksciai",11570,55.5333333,25.1 ],
    [ u"lt",u"Ariogala",3653,55.2666667,23.4666667 ],
    [ u"lt",u"Baltoji Voke",1071,54.6,25.2 ],
    [ u"lt",u"Birstonas",3181,54.6166667,24.0333333 ],
    [ u"lt",u"Birzai",14912,56.2,24.75 ],
    [ u"lt",u"Daugai",1279,54.3666667,24.3333333 ],
    [ u"lt",u"Dotnuva",783,55.35,23.9 ],
    [ u"lt",u"Druskininkai",17793,54.0166667,23.9666667 ],
    [ u"lt",u"Dukstas",1021,55.5333333,26.3333333 ],
    [ u"lt",u"Dusetos",833,55.75,25.85 ],
    [ u"lt",u"Eisiskes",3810,54.1666667,25.0 ],
    [ u"lt",u"Elektrenai",13722,54.7666667,24.6333333 ],
    [ u"lt",u"Ezerelis",2051,54.8833333,23.6166667 ],
    [ u"lt",u"Gargzdai",15951,55.7127778,21.4033333 ],
    [ u"lt",u"Garliava",13811,54.8166667,23.8666667 ],
    [ u"lt",u"Gelgaudiskis",1839,55.0791667,22.9758333 ],
    [ u"lt",u"Grigiskes",11556,54.6833333,25.0833333 ],
    [ u"lt",u"Ignalina",6422,55.35,26.1666667 ],
    [ u"lt",u"Jieznas",1390,54.6,24.1666667 ],
    [ u"lt",u"Jonava",34996,55.0833333,24.2833333 ],
    [ u"lt",u"Joniskelis",1430,56.0252778,24.1688889 ],
    [ u"lt",u"Joniskis",11114,56.2402778,23.6152778 ],
    [ u"lt",u"Juodupe",1989,56.0833333,25.6166667 ],
    [ u"lt",u"Jurbarkas",13103,55.0777778,22.7663889 ],
    [ u"lt",u"Kacergine",897,54.9333333,23.65 ],
    [ u"lt",u"Kaisiadorys",9868,54.8666667,24.45 ],
    [ u"lt",u"Kalvarija",4876,54.4,23.2333333 ],
    [ u"lt",u"Kaunas",374655,54.9,23.9 ],
    [ u"lt",u"Kavarskas",755,55.4333333,24.9166667 ],
    [ u"lt",u"Kazlu Ruda",7248,54.7666667,23.5 ],
    [ u"lt",u"Kedainiai",31983,55.2883333,23.9747222 ],
    [ u"lt",u"Kelme",10627,55.6338889,22.9341667 ],
    [ u"lt",u"Klaipeda",192314,55.7172222,21.1175 ],
    [ u"lt",u"Kretinga",22238,55.8166667,21.2 ],
    [ u"lt",u"Kudirkos Naumiestis",1962,54.7730556,22.8630556 ],
    [ u"lt",u"Kulautuva",1401,54.9333333,23.6 ],
    [ u"lt",u"Kupiskis",8264,55.8333333,24.9666667 ],
    [ u"lt",u"Kursenai",13915,55.985,22.9188889 ],
    [ u"lt",u"Kybartai",6355,54.6355556,22.7383333 ],
    [ u"lt",u"Lazdijai",4975,54.2333333,23.5166667 ],
    [ u"lt",u"Lentvaris",11589,54.65,25.05 ],
    [ u"lt",u"Linkuva",1720,56.0855556,23.9725 ],
    [ u"lt",u"Marijampole",47617,54.5666667,23.35 ],
    [ u"lt",u"Mazeikiai",41314,56.3166667,22.3333333 ],
    [ u"lt",u"Moletai",7243,55.2333333,25.4166667 ],
    [ u"lt",u"Naujamiestis",770,55.6833333,24.15 ],
    [ u"lt",u"Naujoji Akmene",11923,56.3166667,22.9 ],
    [ u"lt",u"Nemencine",6063,54.85,25.4833333 ],
    [ u"lt",u"Neringa",2380,55.3080556,21.0066667 ],
    [ u"lt",u"Obeliai",1247,55.9666667,25.15 ],
    [ u"lt",u"Pabirze",490,56.1858333,24.6366667 ],
    [ u"lt",u"Pabrade",6376,55.0,25.7833333 ],
    [ u"lt",u"Pagegiai",2363,55.1380556,21.9088889 ],
    [ u"lt",u"Pakruojis",5964,55.9666667,23.8666667 ],
    [ u"lt",u"Palanga",17798,55.9175,21.0686111 ],
    [ u"lt",u"Pandelys",974,56.0166667,25.2166667 ],
    [ u"lt",u"Panemune",313,55.0933333,21.8919444 ],
    [ u"lt",u"Panevezys",117400,55.7333333,24.35 ],
    [ u"lt",u"Pasvalys",8511,56.0594444,24.4036111 ],
    [ u"lt",u"Plunge",23383,55.9113889,21.8441667 ],
    [ u"lt",u"Priekule",1711,55.5536111,21.3266667 ],
    [ u"lt",u"Prienai",11353,54.6333333,23.95 ],
    [ u"lt",u"Radviliskis",19916,55.8166667,23.5333333 ],
    [ u"lt",u"Ramygala",1637,55.5166667,24.3 ],
    [ u"lt",u"Raseiniai",12525,55.3736111,23.1216667 ],
    [ u"lt",u"Rietavas",3737,55.7194444,21.9311111 ],
    [ u"lt",u"Rokiskis",16257,55.9666667,25.5833333 ],
    [ u"lt",u"Rudiskes",2616,54.5166667,24.8333333 ],
    [ u"lt",u"Rusne",2484,55.2961111,21.3133333 ],
    [ u"lt",u"Sakiai",6614,54.95,23.05 ],
    [ u"lt",u"Salantai",1829,56.0666667,21.5666667 ],
    [ u"lt",u"Salcininkai",6892,54.3,25.3833333 ],
    [ u"lt",u"Seda",1224,56.1666667,22.1 ],
    [ u"lt",u"Seduva",3321,55.7666667,23.7666667 ],
    [ u"lt",u"Siauliai",130594,55.9333333,23.3166667 ],
    [ u"lt",u"Silale",6026,55.4905556,22.1813889 ],
    [ u"lt",u"Silute",21762,55.3488889,21.4830556 ],
    [ u"lt",u"Simnas",1864,54.4,23.65 ],
    [ u"lt",u"Sirvintos",7322,55.05,24.95 ],
    [ u"lt",u"Skaudvile",1976,55.4066667,22.5841667 ],
    [ u"lt",u"Skuodas",7726,56.2666667,21.5333333 ],
    [ u"lt",u"Smalininkai",599,55.0755556,22.5797222 ],
    [ u"lt",u"Subacius",1116,55.7333333,24.7833333 ],
    [ u"lt",u"Svencioneliai",6791,55.1666667,26.0 ],
    [ u"lt",u"Svencionys",5539,55.15,26.1666667 ],
    [ u"lt",u"Taurage",27665,55.2522222,22.2897222 ],
    [ u"lt",u"Telsiai",30101,55.9813889,22.2472222 ],
    [ u"lt",u"Trakai",5531,54.6333333,24.9333333 ],
    [ u"lt",u"Troskunai",480,55.6,24.85 ],
    [ u"lt",u"Turmantas",282,55.7,26.45 ],
    [ u"lt",u"Tyruliai",373,55.75,23.25 ],
    [ u"lt",u"Tytuvenai",2770,55.6,23.2 ],
    [ u"lt",u"Ukmerge",28662,55.25,24.75 ],
    [ u"lt",u"Utena",33243,55.5,25.6 ],
    [ u"lt",u"Uzventis",827,55.7802778,22.6547222 ],
    [ u"lt",u"Vabalninkas",1177,55.9666667,24.75 ],
    [ u"lt",u"Varena",10305,54.2166667,24.5666667 ],
    [ u"lt",u"Varniai",1227,55.7405556,22.3644444 ],
    [ u"lt",u"Veisiejai",1654,54.1,23.7 ],
    [ u"lt",u"Venta",3270,56.2,22.7 ],
    [ u"lt",u"Vieksniai",2212,56.2333333,22.5166667 ],
    [ u"lt",u"Vievis",5269,54.7666667,24.8 ],
    [ u"lt",u"Vilkaviskis",13012,54.6516667,23.0322222 ],
    [ u"lt",u"Vilkija",2289,55.05,23.5833333 ],
    [ u"lt",u"Vilnius",542381,54.6833333,25.3166667 ],
    [ u"lt",u"Virbalis",1281,54.6266667,22.8169444 ],
    [ u"lt",u"Visaginas",28350,55.6,26.4166667 ],
    [ u"lt",u"Zagare",2201,56.3591667,23.25 ],
    [ u"lt",u"Zarasai",8096,55.7333333,26.25 ],
    [ u"lt",u"Zemaiciu Naumiestis",1285,55.3591667,21.7022222 ],
    [ u"lt",u"Ziezmariai",4061,54.8,24.45 ],
    [ u"lu",u"Abweiler",75,49.5336111,6.0808333 ],
    [ u"lu",u"Allerborn",59,50.0366667,5.8708333 ],
    [ u"lu",u"Alscheid",50,49.9711111,6.0097222 ],
    [ u"lu",u"Altlinster",115,49.7155556,6.2166667 ],
    [ u"lu",u"Altrier",190,49.7441667,6.3283333 ],
    [ u"lu",u"Altwies",617,49.5105556,6.2572222 ],
    [ u"lu",u"Alzingen",1376,49.565,6.1636111 ],
    [ u"lu",u"Angelsberg",292,49.7563889,6.1608333 ],
    [ u"lu",u"Ansembourg",42,49.7025,6.0433333 ],
    [ u"lu",u"Arsdorf",241,49.8613889,5.8438889 ],
    [ u"lu",u"Aspelt",1013,49.5227778,6.2247222 ],
    [ u"lu",u"Assel",174,49.5527778,6.3158333 ],
    [ u"lu",u"Asselborn",413,50.0972222,5.9730556 ],
    [ u"lu",u"Basbellain",164,50.1458333,5.9838889 ],
    [ u"lu",u"Bascharage",4645,49.5675,5.9102778 ],
    [ u"lu",u"Baschleiden",185,49.8983333,5.8202778 ],
    [ u"lu",u"Bastendorf",377,49.8919444,6.1652778 ],
    [ u"lu",u"Bavigne",132,49.9219444,5.8494444 ],
    [ u"lu",u"Beaufort",1418,49.8358333,6.2916667 ],
    [ u"lu",u"Bech",380,49.7461111,6.3636111 ],
    [ u"lu",u"Bech-Kleinmacher",593,49.5308333,6.355 ],
    [ u"lu",u"Beckerich",672,49.7305556,5.8872222 ],
    [ u"lu",u"Beidweiler",227,49.7233333,6.3025 ],
    [ u"lu",u"Beiler",87,50.1655556,6.0888889 ],
    [ u"lu",u"Belvaux",5313,49.5127778,5.9294444 ],
    [ u"lu",u"Berbourg",664,49.7272222,6.3938889 ],
    [ u"lu",u"Berchem",863,49.5402778,6.1291667 ],
    [ u"lu",u"Berdorf",900,49.8136111,6.3502778 ],
    [ u"lu",u"Béreldange",3627,49.6569444,6.1275 ],
    [ u"lu",u"Berg",93,49.6777778,6.3594444 ],
    [ u"lu",u"Bergem",1535,49.525,6.0422222 ],
    [ u"lu",u"Beringen",956,49.7583333,6.1169444 ],
    [ u"lu",u"Berlé",110,49.9522222,5.8561111 ],
    [ u"lu",u"Bertrange",5615,49.6111111,6.05 ],
    [ u"lu",u"Bettange-sur-Mess",992,49.5758333,5.9838889 ],
    [ u"lu",u"Bettborn",231,49.7952778,5.9411111 ],
    [ u"lu",u"Bettel",223,49.9172222,6.2277778 ],
    [ u"lu",u"Bettembourg",7437,49.5186111,6.1027778 ],
    [ u"lu",u"Bettendorf",1072,49.8766667,6.2180556 ],
    [ u"lu",u"Betzdorf",248,49.6833333,6.35 ],
    [ u"lu",u"Beyren",312,49.6263889,6.3369444 ],
    [ u"lu",u"Bigelbach",79,49.8602778,6.2880556 ],
    [ u"lu",u"Bigonville",475,49.8516667,5.7933333 ],
    [ u"lu",u"Bilsdorf",121,49.8575,5.825 ],
    [ u"lu",u"Binsfeld",235,50.1188889,6.0386111 ],
    [ u"lu",u"Bissen",2547,49.7875,6.0694444 ],
    [ u"lu",u"Bivange",617,49.5444444,6.1377778 ],
    [ u"lu",u"Bivels",80,49.9602778,6.1922222 ],
    [ u"lu",u"Biwer",653,49.7027778,6.3747222 ],
    [ u"lu",u"Biwisch",103,50.1180556,5.9791667 ],
    [ u"lu",u"Blaschette",465,49.6972222,6.1705556 ],
    [ u"lu",u"Bockholtz",47,50.0122222,6.0527778 ],
    [ u"lu",u"Boevange",125,50.0463889,5.9341667 ],
    [ u"lu",u"Bofferdange",802,49.6830556,6.1416667 ],
    [ u"lu",u"Born",336,49.7541667,6.5138889 ],
    [ u"lu",u"Boudler",69,49.7177778,6.355 ],
    [ u"lu",u"Boulaide",396,49.8877778,5.8163889 ],
    [ u"lu",u"Bour",67,49.7013889,6.0188889 ],
    [ u"lu",u"Bourglinster",680,49.6977778,6.2197222 ],
    [ u"lu",u"Bourscheid",275,49.91,6.0672222 ],
    [ u"lu",u"Boursdorf",22,49.7580556,6.4786111 ],
    [ u"lu",u"Bous",560,49.5538889,6.3291667 ],
    [ u"lu",u"Boxhorn",259,50.0838889,5.9925 ],
    [ u"lu",u"Brachtenbach",159,50.0213889,5.9113889 ],
    [ u"lu",u"Brandenbourg",193,49.9125,6.14 ],
    [ u"lu",u"Breidfeld",49,50.1241667,6.0636111 ],
    [ u"lu",u"Breidweiler",99,49.7708333,6.3041667 ],
    [ u"lu",u"Breinert",50,49.7066667,6.3405556 ],
    [ u"lu",u"Bridel",2404,49.6583333,6.0822222 ],
    [ u"lu",u"Brouch",52,49.7236111,6.3425 ],
    [ u"lu",u"Brouch",676,49.7361111,6.0230556 ],
    [ u"lu",u"Buderscheid",126,49.9338889,5.9419444 ],
    [ u"lu",u"Burden",450,49.8830556,6.0988889 ],
    [ u"lu",u"Burmerange",191,49.4852778,6.3230556 ],
    [ u"lu",u"Buschdorf",387,49.7508333,6.0083333 ],
    [ u"lu",u"Buschrodt",118,49.8272222,5.9358333 ],
    [ u"lu",u"Calmus",76,49.7255556,5.9644444 ],
    [ u"lu",u"Canach",955,49.6069444,6.3258333 ],
    [ u"lu",u"Capellen",1330,49.645,5.9908333 ],
    [ u"lu",u"Christnach",394,49.7811111,6.2736111 ],
    [ u"lu",u"Cinqfontaines",13,50.1072222,6.0077778 ],
    [ u"lu",u"Clemency",1821,49.5966667,5.8758333 ],
    [ u"lu",u"Clervaux",1103,50.0547222,6.0313889 ],
    [ u"lu",u"Colpach-Bas",110,49.7583333,5.8269444 ],
    [ u"lu",u"Colpach-Haut",152,49.7686111,5.82 ],
    [ u"lu",u"Consdorf",1241,49.7730556,6.3383333 ],
    [ u"lu",u"Consthum",207,49.9747222,6.0541667 ],
    [ u"lu",u"Contern",1083,49.5819444,6.2266667 ],
    [ u"lu",u"Crauthem",1278,49.5355556,6.1469444 ],
    [ u"lu",u"Crendal",10,50.0577778,5.8980556 ],
    [ u"lu",u"Cruchten",404,49.7919444,6.1327778 ],
    [ u"lu",u"Dahl",246,49.9352778,5.9758333 ],
    [ u"lu",u"Dahlem",389,49.6022222,5.9483333 ],
    [ u"lu",u"Dalheim",1364,49.5408333,6.2597222 ],
    [ u"lu",u"Derenbach",287,50.015,5.8897222 ],
    [ u"lu",u"Dickweiler",111,49.7775,6.4722222 ],
    [ u"lu",u"Diekirch",6243,49.8677778,6.1558333 ],
    [ u"lu",u"Differdange",5295,49.5241667,5.8913889 ],
    [ u"lu",u"Dillingen",159,49.8536111,6.3191667 ],
    [ u"lu",u"Dippach",808,49.5883333,5.9833333 ],
    [ u"lu",u"Doennange",146,50.0622222,5.9558333 ],
    [ u"lu",u"Doncols",232,49.97,5.8372222 ],
    [ u"lu",u"Dorscheid",90,50.0361111,6.0713889 ],
    [ u"lu",u"Drauffelt",143,50.0177778,6.0061111 ],
    [ u"lu",u"Drinklange",124,50.1336111,6.0191667 ],
    [ u"lu",u"Dudelange",18013,49.4805556,6.0875 ],
    [ u"lu",u"Echternach",4787,49.8055556,6.4222222 ],
    [ u"lu",u"Ehlange",429,49.5488889,6.0169444 ],
    [ u"lu",u"Ehlerange",756,49.5241667,5.9661111 ],
    [ u"lu",u"Ehnen",531,49.5997222,6.3877778 ],
    [ u"lu",u"Ehner",13,49.7175,5.95 ],
    [ u"lu",u"Eischen",1559,49.6855556,5.8786111 ],
    [ u"lu",u"Eisenborn",170,49.6866667,6.1852778 ],
    [ u"lu",u"Ellange",299,49.52,6.2983333 ],
    [ u"lu",u"Ell",359,49.7638889,5.8572222 ],
    [ u"lu",u"Eltz",34,49.7783333,5.895 ],
    [ u"lu",u"Elvange",96,49.7247222,5.9177778 ],
    [ u"lu",u"Elvange",713,49.5052778,6.3163889 ],
    [ u"lu",u"Emerange",99,49.4869444,6.2916667 ],
    [ u"lu",u"Enscherange",174,49.9994444,5.9927778 ],
    [ u"lu",u"Eppeldorf",181,49.8444444,6.2497222 ],
    [ u"lu",u"Ermsdorf",228,49.8294444,6.2227778 ],
    [ u"lu",u"Ernster",350,49.6755556,6.2472222 ],
    [ u"lu",u"Ernzen",398,49.7658333,6.2219444 ],
    [ u"lu",u"Erpeldange",845,49.8647222,6.1147222 ],
    [ u"lu",u"Erpeldange",359,49.5444444,6.3275 ],
    [ u"lu",u"Eschdorf",433,49.8861111,5.9366667 ],
    [ u"lu",u"Eschette",34,49.8230556,5.8883333 ],
    [ u"lu",u"Esch-sur-Sûre",333,49.9113889,5.9363889 ],
    [ u"lu",u"Eschweiler",205,49.9977778,5.9488889 ],
    [ u"lu",u"Eschweiler",118,49.7113889,6.3105556 ],
    [ u"lu",u"Eselborn",337,50.0627778,6.0036111 ],
    [ u"lu",u"Essingen",18,49.7788889,6.1166667 ],
    [ u"lu",u"Ettelbruck",6364,49.8475,6.1041667 ],
    [ u"lu",u"Everlange",370,49.7741667,5.9555556 ],
    [ u"lu",u"Fennange",293,49.5197222,6.0783333 ],
    [ u"lu",u"Fentange",1302,49.5627778,6.1538889 ],
    [ u"lu",u"Filsdorf",371,49.5325,6.2483333 ],
    [ u"lu",u"Findel",105,49.6238889,6.2027778 ],
    [ u"lu",u"Fingig",329,49.6036111,5.9008333 ],
    [ u"lu",u"Fischbach",114,50.0752778,6.0688889 ],
    [ u"lu",u"Fischbach",184,49.7397222,6.1872222 ],
    [ u"lu",u"Flaxweiler",358,49.6616667,6.3436111 ],
    [ u"lu",u"Foetz",483,49.5294444,6.0108333 ],
    [ u"lu",u"Folkendange",21,49.8430556,6.2041667 ],
    [ u"lu",u"Folschette",289,49.8141667,5.8747222 ],
    [ u"lu",u"Fouhren",380,49.9155556,6.1961111 ],
    [ u"lu",u"Frisange",1355,49.515,6.1916667 ],
    [ u"lu",u"Garnich",824,49.6166667,5.9525 ],
    [ u"lu",u"Gilsdorf",887,49.8669444,6.1825 ],
    [ u"lu",u"Girsterklaus",12,49.7777778,6.4994444 ],
    [ u"lu",u"Girst",113,49.7672222,6.4988889 ],
    [ u"lu",u"Givenich",84,49.7422222,6.48 ],
    [ u"lu",u"Godbrange",463,49.7288889,6.2319444 ],
    [ u"lu",u"Goeblange",434,49.6697222,5.9652778 ],
    [ u"lu",u"Goedange",45,50.1491667,6.0133333 ],
    [ u"lu",u"Goetzingen",341,49.6602778,5.9816667 ],
    [ u"lu",u"Gonderange",1469,49.6888889,6.2483333 ],
    [ u"lu",u"Gosseldange",458,49.7263889,6.1169444 ],
    [ u"lu",u"Gostingen",342,49.6191667,6.3544444 ],
    [ u"lu",u"Gralingen",142,49.9369444,6.1016667 ],
    [ u"lu",u"Grass",71,49.6308333,5.8913889 ],
    [ u"lu",u"Greisch",210,49.7097222,5.9883333 ],
    [ u"lu",u"Greiveldange",630,49.5838889,6.3591667 ],
    [ u"lu",u"Grevels",207,49.8530556,5.9158333 ],
    [ u"lu",u"Grevenmacher",3958,49.6747222,6.4419444 ],
    [ u"lu",u"Grindhausen",25,50.0833333,6.06 ],
    [ u"lu",u"Grosbous",656,49.8277778,5.9672222 ],
    [ u"lu",u"Grumelscheid",64,49.9844444,5.8725 ],
    [ u"lu",u"Grundhof",27,49.835,6.3313889 ],
    [ u"lu",u"Hachiville",194,50.1080556,5.9233333 ],
    [ u"lu",u"Hagelsdorf",19,49.6877778,6.3655556 ],
    [ u"lu",u"Hagen",978,49.6494444,5.9316667 ],
    [ u"lu",u"Haller",223,49.8125,6.2825 ],
    [ u"lu",u"Hamiville",171,50.0461111,5.9041667 ],
    [ u"lu",u"Harlange",378,49.9313889,5.79 ],
    [ u"lu",u"Hassel",436,49.5486111,6.2091667 ],
    [ u"lu",u"Hautbellain",151,50.1566667,5.9786111 ],
    [ u"lu",u"Hautcharage",1495,49.5775,5.9108333 ],
    [ u"lu",u"Haut-Martelange",32,49.825,5.7511111 ],
    [ u"lu",u"Heffingen",623,49.7625,6.2413889 ],
    [ u"lu",u"Heiderscheid",424,49.8888889,5.9788889 ],
    [ u"lu",u"Heinerscheid",429,50.0961111,6.0880556 ],
    [ u"lu",u"Heisdorf",1586,49.6686111,6.1422222 ],
    [ u"lu",u"Heispelt",81,49.8572222,5.8805556 ],
    [ u"lu",u"Hellange",629,49.5066667,6.1505556 ],
    [ u"lu",u"Helmdange",638,49.6872222,6.1436111 ],
    [ u"lu",u"Helmsange",2193,49.6527778,6.1413889 ],
    [ u"lu",u"Hemstal",79,49.7344444,6.3361111 ],
    [ u"lu",u"Herborn",150,49.7416667,6.4277778 ],
    [ u"lu",u"Hesperange",1937,49.5680556,6.1513889 ],
    [ u"lu",u"Hierheck",36,49.8730556,5.9311111 ],
    [ u"lu",u"Hinkel",82,49.7763889,6.5152778 ],
    [ u"lu",u"Hivange",119,49.6072222,5.9322222 ],
    [ u"lu",u"Hobscheid",1051,49.6886111,5.9147222 ],
    [ u"lu",u"Hoesdorf",105,49.8838889,6.2580556 ],
    [ u"lu",u"Hoffelt",270,50.0997222,5.9233333 ],
    [ u"lu",u"Hollenfels",247,49.7130556,6.0508333 ],
    [ u"lu",u"Holler",87,50.1236111,6.0494444 ],
    [ u"lu",u"Holtz",196,49.8072222,5.7916667 ],
    [ u"lu",u"Holzem",541,49.6163889,5.9902778 ],
    [ u"lu",u"Holzthum",143,49.985,6.0733333 ],
    [ u"lu",u"Hoscheid",319,49.9472222,6.0816667 ],
    [ u"lu",u"Hosingen",811,50.0177778,6.0933333 ],
    [ u"lu",u"Hostert",360,49.81,5.8666667 ],
    [ u"lu",u"Hostert",364,49.6508333,6.235 ],
    [ u"lu",u"Hovelange",285,49.7225,5.9072222 ],
    [ u"lu",u"Huldange",376,50.1647222,6.015 ],
    [ u"lu",u"Huncherange",615,49.5169444,6.065 ],
    [ u"lu",u"Hunsdorf",413,49.6966667,6.1316667 ],
    [ u"lu",u"Hupperdange",210,50.0961111,6.0591667 ],
    [ u"lu",u"Huttange",37,49.7361111,5.8986111 ],
    [ u"lu",u"Imbringen",292,49.6975,6.1975 ],
    [ u"lu",u"Ingeldorf",833,49.8519444,6.1347222 ],
    [ u"lu",u"Insenborn",165,49.9016667,5.8847222 ],
    [ u"lu",u"Itzig",1836,49.5841667,6.1736111 ],
    [ u"lu",u"Junglinster",2358,49.7072222,6.2530556 ],
    [ u"lu",u"Kahler",192,49.6313889,5.9177778 ],
    [ u"lu",u"Kalborn",58,50.1027778,6.1130556 ],
    [ u"lu",u"Kapweiler",30,49.7394444,5.9705556 ],
    [ u"lu",u"Kaundorf",192,49.9213889,5.9030556 ],
    [ u"lu",u"Kautenbach",126,49.9527778,6.02 ],
    [ u"lu",u"Kayl",4396,49.4891667,6.0397222 ],
    [ u"lu",u"Kehlen",1658,49.6683333,6.0358333 ],
    [ u"lu",u"Keispelt",567,49.6944444,6.0694444 ],
    [ u"lu",u"Kleinbettingen",872,49.6463889,5.9163889 ],
    [ u"lu",u"Knaphoscheid",180,50.0133333,5.9647222 ],
    [ u"lu",u"Kockelscheuer",270,49.5611111,6.1122222 ],
    [ u"lu",u"Koerich",1066,49.67,5.95 ],
    [ u"lu",u"Koetschette",125,49.8380556,5.8402778 ],
    [ u"lu",u"Kopstal",657,49.6644444,6.0730556 ],
    [ u"lu",u"Kuborn",75,49.8705556,5.9030556 ],
    [ u"lu",u"Lamadelaine",2428,49.5463889,5.8563889 ],
    [ u"lu",u"Landscheid",76,49.9244444,6.1302778 ],
    [ u"lu",u"Lannen",113,49.7894444,5.8397222 ],
    [ u"lu",u"Larochette",1410,49.7769444,6.2211111 ],
    [ u"lu",u"Lasauvage",402,49.525,5.8375 ],
    [ u"lu",u"Leithum",78,50.1608333,6.1088889 ],
    [ u"lu",u"Lellig",142,49.7161111,6.4363889 ],
    [ u"lu",u"Lellingen",93,49.9836111,6.0144444 ],
    [ u"lu",u"Lenningen",338,49.5986111,6.3680556 ],
    [ u"lu",u"Leudelange",1924,49.5683333,6.0652778 ],
    [ u"lu",u"Levelange",43,49.7397222,5.8566667 ],
    [ u"lu",u"Liefrange",85,49.91,5.8775 ],
    [ u"lu",u"Lieler",179,50.1244444,6.11 ],
    [ u"lu",u"Limpach",254,49.5588889,5.9805556 ],
    [ u"lu",u"Linger",591,49.5658333,5.8866667 ],
    [ u"lu",u"Lintgen",1752,49.7158333,6.1336111 ],
    [ u"lu",u"Lipperscheid",186,49.9186111,6.0866667 ],
    [ u"lu",u"Livange",306,49.5302778,6.1202778 ],
    [ u"lu",u"Longsdorf",80,49.8988889,6.2052778 ],
    [ u"lu",u"Lorentzweiler",772,49.6947222,6.1425 ],
    [ u"lu",u"Lullange",132,50.06,5.9419444 ],
    [ u"lu",u"Lultzhausen",32,49.9094444,5.8908333 ],
    [ u"lu",u"Luxemburg",76684,49.6116667,6.13 ],
    [ u"lu",u"Machtum",304,49.6555556,6.4344444 ],
    [ u"lu",u"Mamer",5017,49.6275,6.0233333 ],
    [ u"lu",u"Manternach",443,49.7027778,6.4263889 ],
    [ u"lu",u"Marienthal",108,49.71,6.0616667 ],
    [ u"lu",u"Marnach",454,50.0533333,6.0619444 ],
    [ u"lu",u"Masseler",36,49.9308333,6.0372222 ],
    [ u"lu",u"Mecher",63,49.9233333,5.8722222 ],
    [ u"lu",u"Medernach",907,49.8019444,6.2183333 ],
    [ u"lu",u"Medingen",102,49.5727778,6.2486111 ],
    [ u"lu",u"Meispelt",290,49.6911111,6.0591667 ],
    [ u"lu",u"Mensdorf",813,49.6508333,6.3036111 ],
    [ u"lu",u"Merscheid",103,49.9547222,6.1069444 ],
    [ u"lu",u"Mersch",3464,49.7488889,6.1061111 ],
    [ u"lu",u"Mertert",1163,49.6961111,6.4813889 ],
    [ u"lu",u"Mertzig",1482,49.8338889,6.0075 ],
    [ u"lu",u"Michelau",281,49.9,6.0919444 ],
    [ u"lu",u"Michelbouch",116,49.8186111,6.0202778 ],
    [ u"lu",u"Moersdorf",301,49.7383333,6.5 ],
    [ u"lu",u"Moesdorf",353,49.7680556,6.1166667 ],
    [ u"lu",u"Moestroff",418,49.8677778,6.2394444 ],
    [ u"lu",u"Mompach",100,49.7461111,6.465 ],
    [ u"lu",u"Mondercange",3306,49.5330556,5.9883333 ],
    [ u"lu",u"Mondorf-les-Bains",3113,49.505,6.2811111 ],
    [ u"lu",u"Moutfort",1171,49.5852778,6.2555556 ],
    [ u"lu",u"Müllendorf",1024,49.6802778,6.13 ],
    [ u"lu",u"Müllerthal",152,49.7847222,6.3108333 ],
    [ u"lu",u"Münsbach",585,49.6291667,6.2675 ],
    [ u"lu",u"Münschecker",152,49.6938889,6.4422222 ],
    [ u"lu",u"Munshausen",147,50.0336111,6.0386111 ],
    [ u"lu",u"Nachtmanderscheid",70,49.9483333,6.1294444 ],
    [ u"lu",u"Nagem",216,49.7891667,5.8577778 ],
    [ u"lu",u"Neidhausen",53,50.0288889,6.0666667 ],
    [ u"lu",u"Neuhaeusgen",239,49.6194444,6.24 ],
    [ u"lu",u"Neunhausen",65,49.8775,5.8872222 ],
    [ u"lu",u"Niederanven",1508,49.6475,6.26 ],
    [ u"lu",u"Niedercorn",3164,49.5361111,5.8930556 ],
    [ u"lu",u"Niederdonven",324,49.6313889,6.4036111 ],
    [ u"lu",u"Niederfeulen",1125,49.8555556,6.0472222 ],
    [ u"lu",u"Niederpallen",374,49.7552778,5.9122222 ],
    [ u"lu",u"Nocher",233,49.9475,5.9791667 ],
    [ u"lu",u"Noerdange",466,49.7422222,5.9261111 ],
    [ u"lu",u"Noertrange",274,49.9797222,5.9108333 ],
    [ u"lu",u"Noertzange",999,49.5091667,6.0561111 ],
    [ u"lu",u"Nommern",272,49.7869444,6.1747222 ],
    [ u"lu",u"Nospelt",766,49.6752778,6.0088889 ],
    [ u"lu",u"Nothum",161,49.9413889,5.8827778 ],
    [ u"lu",u"Oberanven",682,49.6536111,6.2411111 ],
    [ u"lu",u"Obercorn",4666,49.5136111,5.8961111 ],
    [ u"lu",u"Oberdonven",164,49.6466667,6.4005556 ],
    [ u"lu",u"Oberfeulen",283,49.8480556,6.0355556 ],
    [ u"lu",u"Oberpallen",397,49.7302778,5.8438889 ],
    [ u"lu",u"Oberwampach",183,50.0166667,5.8608333 ],
    [ u"lu",u"Oetrange",781,49.5963889,6.26 ],
    [ u"lu",u"Olingen",403,49.6761111,6.3155556 ],
    [ u"lu",u"Olm",1459,49.6572222,6.0002778 ],
    [ u"lu",u"Ospern",276,49.7838889,5.9044444 ],
    [ u"lu",u"Osweiler",381,49.7788889,6.4413889 ],
    [ u"lu",u"Peppange",593,49.5244444,6.1297222 ],
    [ u"lu",u"Perlé",649,49.8116667,5.7658333 ],
    [ u"lu",u"Pétange",7187,49.5583333,5.8805556 ],
    [ u"lu",u"Petit-Nobressart",89,49.7797222,5.8094444 ],
    [ u"lu",u"Pettingen",206,49.7702778,6.1091667 ],
    [ u"lu",u"Pintsch",126,49.9944444,6.0130556 ],
    [ u"lu",u"Pissange",66,49.5494444,6.0002778 ],
    [ u"lu",u"Platen",541,49.7911111,5.9347222 ],
    [ u"lu",u"Pommerloch",51,49.9602778,5.8608333 ],
    [ u"lu",u"Pontpierre",1009,49.5363889,6.0294444 ],
    [ u"lu",u"Pratz",367,49.8016667,5.9391667 ],
    [ u"lu",u"Prettange",101,49.7175,6.1202778 ],
    [ u"lu",u"Putscheid",38,49.9608333,6.1430556 ],
    [ u"lu",u"Rambrouch",401,49.8308333,5.845 ],
    [ u"lu",u"Rameldange",682,49.6569444,6.2336111 ],
    [ u"lu",u"Reckange",611,49.7497222,6.0830556 ],
    [ u"lu",u"Reckange-sur-Mess",571,49.5625,6.0088889 ],
    [ u"lu",u"Redange",1164,49.7655556,5.8908333 ],
    [ u"lu",u"Reichlange",132,49.7736111,5.9280556 ],
    [ u"lu",u"Reimberg",182,49.7972222,5.9538889 ],
    [ u"lu",u"Reisdorf",493,49.8686111,6.2677778 ],
    [ u"lu",u"Remerschen",704,49.4886111,6.3516667 ],
    [ u"lu",u"Remich",3187,49.545,6.3669444 ],
    [ u"lu",u"Reuland",196,49.7466667,6.2602778 ],
    [ u"lu",u"Reuler",193,50.0577778,6.0375 ],
    [ u"lu",u"Rippig",113,49.7341667,6.3194444 ],
    [ u"lu",u"Rippweiler",153,49.7516667,5.9575 ],
    [ u"lu",u"Rodange",4683,49.5463889,5.8408333 ],
    [ u"lu",u"Rodenbourg",109,49.6825,6.2891667 ],
    [ u"lu",u"Roder",66,50.0558333,6.0836111 ],
    [ u"lu",u"Rodershausen",96,50.0366667,6.1311111 ],
    [ u"lu",u"Roedgen",337,49.5747222,6.0347222 ],
    [ u"lu",u"Roeser",708,49.5422222,6.15 ],
    [ u"lu",u"Rollingen",1448,49.7416667,6.1144444 ],
    [ u"lu",u"Rolling",117,49.5488889,6.3172222 ],
    [ u"lu",u"Rombach",244,49.8347222,5.7427778 ],
    [ u"lu",u"Roodt",159,49.7944444,5.8216667 ],
    [ u"lu",u"Rosport",681,49.7977778,6.5041667 ],
    [ u"lu",u"Saeul",316,49.7272222,5.9863889 ],
    [ u"lu",u"Sandweiler",2522,49.6133333,6.2188889 ],
    [ u"lu",u"Sanem",2489,49.5480556,5.9288889 ],
    [ u"lu",u"Sassel",45,50.0994444,5.9975 ],
    [ u"lu",u"Schandel",194,49.7922222,5.9758333 ],
    [ u"lu",u"Scheidgen",461,49.775,6.3605556 ],
    [ u"lu",u"Schengen",470,49.4716667,6.3658333 ],
    [ u"lu",u"Schieren",1397,49.8305556,6.0986111 ],
    [ u"lu",u"Schifflange",8155,49.5063889,6.0127778 ],
    [ u"lu",u"Schleif",8,49.9905556,5.8575 ],
    [ u"lu",u"Schlindermanderscheid",170,49.9330556,6.0636111 ],
    [ u"lu",u"Schoenfels",216,49.7188889,6.0922222 ],
    [ u"lu",u"Schoos",164,49.7441667,6.1708333 ],
    [ u"lu",u"Schouweiler",1090,49.5825,5.9563889 ],
    [ u"lu",u"Schrassig",1051,49.6058333,6.2588889 ],
    [ u"lu",u"Schrondweiler",285,49.7977778,6.1591667 ],
    [ u"lu",u"Schuttrange",841,49.6205556,6.2686111 ],
    [ u"lu",u"Schwebach",55,49.7461111,5.9719444 ],
    [ u"lu",u"Schwebsingen",307,49.5116667,6.3569444 ],
    [ u"lu",u"Schweich",194,49.7227778,5.9275 ],
    [ u"lu",u"Selscheid",59,50.0180556,5.9488889 ],
    [ u"lu",u"Senningen",378,49.6419444,6.2394444 ],
    [ u"lu",u"Septfontaines",363,49.7011111,5.9672222 ],
    [ u"lu",u"Siebenaler",58,50.0105556,6.0266667 ],
    [ u"lu",u"Soleuvre",4988,49.5255556,5.9405556 ],
    [ u"lu",u"Sonlez",41,49.965,5.8266667 ],
    [ u"lu",u"Stadtbredimus",749,49.5627778,6.3644444 ],
    [ u"lu",u"Stegen",406,49.83,6.1719444 ],
    [ u"lu",u"Steinfort",2225,49.6613889,5.9191667 ],
    [ u"lu",u"Steinheim",550,49.8113889,6.4783333 ],
    [ u"lu",u"Steinsel",1879,49.6769444,6.1238889 ],
    [ u"lu",u"Stockem",119,50.0788889,5.9580556 ],
    [ u"lu",u"Stolzembourg",183,49.9672222,6.1677778 ],
    [ u"lu",u"Strassen",6006,49.6205556,6.0733333 ],
    [ u"lu",u"Surré",190,49.9030556,5.78 ],
    [ u"lu",u"Syren",423,49.5619444,6.2216667 ],
    [ u"lu",u"Tandel",89,49.8975,6.1833333 ],
    [ u"lu",u"Tarchamps",294,49.9505556,5.7961111 ],
    [ u"lu",u"Tétange",2929,49.4758333,6.0422222 ],
    [ u"lu",u"Trintange",289,49.5708333,6.2805556 ],
    [ u"lu",u"Troisvierges",1457,50.1211111,6.0002778 ],
    [ u"lu",u"Tuntange",605,49.7177778,6.0102778 ],
    [ u"lu",u"Uebersyren",616,49.6286111,6.2780556 ],
    [ u"lu",u"Urspelt",54,50.0755556,6.0466667 ],
    [ u"lu",u"Useldange",657,49.7697222,5.9822222 ],
    [ u"lu",u"Vianden",1626,49.935,6.2088889 ],
    [ u"lu",u"Vichten",764,49.8030556,6.0 ],
    [ u"lu",u"Wahlhausen",246,49.9852778,6.1266667 ],
    [ u"lu",u"Wahl",235,49.8366667,5.9063889 ],
    [ u"lu",u"Waldbillig",408,49.7888889,6.2866667 ],
    [ u"lu",u"Waldbredimus",416,49.555,6.2875 ],
    [ u"lu",u"Walferdange",740,49.6583333,6.1372222 ],
    [ u"lu",u"Walsdorf",68,49.9266667,6.1736111 ],
    [ u"lu",u"Warken",1188,49.8544444,6.095 ],
    [ u"lu",u"Wasserbillig",2327,49.71,6.5002778 ],
    [ u"lu",u"Watrange",92,49.9441667,5.7858333 ],
    [ u"lu",u"Wecker",667,49.6913889,6.3883333 ],
    [ u"lu",u"Weicherdange",220,50.0383333,5.9894444 ],
    [ u"lu",u"Weilerbach",274,49.8333333,6.3827778 ],
    [ u"lu",u"Weiler-la-Tour",484,49.5408333,6.2008333 ],
    [ u"lu",u"Weiler",153,49.9636111,6.1241667 ],
    [ u"lu",u"Weiswampach",691,50.1372222,6.075 ],
    [ u"lu",u"Welfrange",154,49.5380556,6.2841667 ],
    [ u"lu",u"Wellenstein",499,49.5238889,6.3422222 ],
    [ u"lu",u"Welscheid",149,49.8880556,6.0677778 ],
    [ u"lu",u"Wickrange",111,49.5413889,6.0216667 ],
    [ u"lu",u"Wiltz",4816,49.9688889,5.9319444 ],
    [ u"lu",u"Wilwerdange",268,50.1405556,6.0238889 ],
    [ u"lu",u"Wilwerwiltz",249,49.9888889,5.9991667 ],
    [ u"lu",u"Wincrange",210,50.0533333,5.9191667 ],
    [ u"lu",u"Winseler",126,49.9677778,5.8902778 ],
    [ u"lu",u"Wintrange",384,49.5013889,6.3527778 ],
    [ u"lu",u"Wolwelange",358,49.8286111,5.7647222 ],
    [ u"lu",u"Wormeldange",786,49.6083333,6.4058333 ],
    [ u"lu",u"Zittig",38,49.7388889,6.345 ],
    [ u"lv",u"Ainazi",1278,57.8636111,24.3577778 ],
    [ u"lv",u"Aizkraukle",8840,56.6,25.1833333 ],
    [ u"lv",u"Aizpute",5634,56.7166667,21.6 ],
    [ u"lv",u"Akniste",1314,56.1666667,25.75 ],
    [ u"lv",u"Aloja",1509,57.7669444,24.8825 ],
    [ u"lv",u"Aluksne",2264,57.4166667,27.05 ],
    [ u"lv",u"Ape",1521,57.5333333,26.6666667 ],
    [ u"lv",u"Auce",3125,56.4666667,22.8833333 ],
    [ u"lv",u"Baldone",2025,56.7069444,24.3519444 ],
    [ u"lv",u"Balozi",3854,56.8477778,24.0438889 ],
    [ u"lv",u"Balvi",8409,57.1333333,27.25 ],
    [ u"lv",u"Bauska",10532,56.4075,24.1905556 ],
    [ u"lv",u"Broceni",3486,56.7,22.5333333 ],
    [ u"lv",u"Cesis",18198,57.3,25.25 ],
    [ u"lv",u"Cesvaine",1811,56.9666667,26.3166667 ],
    [ u"lv",u"Dagda",2740,56.1,27.5333333 ],
    [ u"lv",u"Daugavpils",111564,55.8833333,26.5333333 ],
    [ u"lv",u"Dobele",11225,56.625,23.2786111 ],
    [ u"lv",u"Durbe",454,56.5833333,21.35 ],
    [ u"lv",u"Grobina",4203,56.55,21.1666667 ],
    [ u"lv",u"Gulbene",9355,57.1833333,26.75 ],
    [ u"lv",u"Ikskile",3368,56.8333333,24.5 ],
    [ u"lv",u"Ilukste",2898,55.9666667,26.3 ],
    [ u"lv",u"Jaunjelgava",1938,56.6166667,25.0833333 ],
    [ u"lv",u"Jelgava",61793,56.65,23.7127778 ],
    [ u"lv",u"Jurmala",54088,56.9608333,23.75 ],
    [ u"lv",u"Kalnciems",2103,56.8011111,23.6097222 ],
    [ u"lv",u"Kandava",3592,57.0333333,22.7666667 ],
    [ u"lv",u"Karsava",2645,56.7833333,27.6666667 ],
    [ u"lv",u"Kegums",2372,56.7441667,24.7158333 ],
    [ u"lv",u"Kraslava",11088,55.9,27.1666667 ],
    [ u"lv",u"Kuldiga",13289,56.9666667,21.9833333 ],
    [ u"lv",u"Lielvarde",5114,56.7225,24.805 ],
    [ u"lv",u"Liepaja",85263,56.5166667,21.0166667 ],
    [ u"lv",u"Ligatne",1433,57.2333333,25.05 ],
    [ u"lv",u"Limbazi",8974,57.5102778,24.7141667 ],
    [ u"lv",u"Livani",10073,56.3666667,26.1833333 ],
    [ u"lv",u"Lubana",1918,56.9,26.7166667 ],
    [ u"lv",u"Ludza",10514,56.55,27.7166667 ],
    [ u"lv",u"Madona",9280,56.85,26.2166667 ],
    [ u"lv",u"Mazsalaca",1701,57.8666667,25.05 ],
    [ u"lv",u"Ogre",25818,56.8166667,24.6 ],
    [ u"lv",u"Olaine",12584,56.7852778,23.9380556 ],
    [ u"lv",u"Pavilosta",1171,56.8833333,21.1833333 ],
    [ u"lv",u"Piltene",1103,57.2166667,21.6666667 ],
    [ u"lv",u"Plavinas",3848,56.6166667,25.7166667 ],
    [ u"lv",u"Preili",8656,56.3,26.7166667 ],
    [ u"lv",u"Priekule",2550,56.4333333,21.5833333 ],
    [ u"lv",u"Rezekne",38340,56.5,27.3166667 ],
    [ u"lv",u"Riga",742570,56.95,24.1 ],
    [ u"lv",u"Rujiena",3638,57.9,25.3166667 ],
    [ u"lv",u"Sabile",1580,57.05,22.5833333 ],
    [ u"lv",u"Salacgriva",3427,57.7536111,24.3580556 ],
    [ u"lv",u"Salaspils",17606,56.8611111,24.3494444 ],
    [ u"lv",u"Saldus",12223,56.6666667,22.5 ],
    [ u"lv",u"Saulkrasti",3184,57.2636111,24.4180556 ],
    [ u"lv",u"Seda",1778,57.65,25.75 ],
    [ u"lv",u"Sigulda",10422,57.1519444,24.8647222 ],
    [ u"lv",u"Skrunda",2659,56.6833333,22.0166667 ],
    [ u"lv",u"Smiltene",6108,57.4333333,25.9 ],
    [ u"lv",u"Staicele",1175,57.8363889,24.75 ],
    [ u"lv",u"Stende",1955,57.15,22.5333333 ],
    [ u"lv",u"Strenci",1593,57.6166667,25.6833333 ],
    [ u"lv",u"Subate",908,56.0166667,25.9 ],
    [ u"lv",u"Talsi",12022,57.25,22.6 ],
    [ u"lv",u"Tukums",18348,56.9669444,23.1552778 ],
    [ u"lv",u"Valdemarpils",1447,57.3666667,22.5833333 ],
    [ u"lv",u"Valka",6589,57.7666667,26.0 ],
    [ u"lv",u"Valmiera",26963,57.55,25.4 ],
    [ u"lv",u"Vangazi",4020,57.0936111,24.5486111 ],
    [ u"lv",u"Varaklani",2344,56.6166667,26.7333333 ],
    [ u"lv",u"Ventspils",42643,57.3894444,21.5605556 ],
    [ u"lv",u"Viesite",2162,56.35,25.55 ],
    [ u"lv",u"Vilaka",1797,57.1833333,27.6833333 ],
    [ u"lv",u"Vilani",3934,56.55,26.95 ],
    [ u"lv",u"Zilupe",1897,56.3833333,28.1166667 ],
    [ u"ly",u"Ajdabiya",134357,30.7591667,20.2230556 ],
    [ u"ly",u"Awbari",42975,26.5833333,12.7666667 ],
    [ u"ly",u"Awjilah",6610,29.1080556,21.2869444 ],
    [ u"ly",u"Bani Walid",46350,31.7666667,13.9833333 ],
    [ u"ly",u"Bardiyah",9149,31.7666667,25.1 ],
    [ u"ly",u"Benghazi",650629,32.1166667,20.0666667 ],
    [ u"ly",u"Darnah",78782,32.765,22.6391667 ],
    [ u"ly",u"Gat",24347,24.9647222,10.1727778 ],
    [ u"ly",u"Hun",18878,29.1166667,15.9333333 ],
    [ u"ly",u"Jadu",6013,31.95,12.0166667 ],
    [ u"ly",u"Jalu",3334,29.0333333,21.55 ],
    [ u"ly",u"Marzuq",43732,25.9044444,13.8972222 ],
    [ u"ly",u"Masallatah",23702,32.6166667,14.0 ],
    [ u"ly",u"Misratah",386120,32.3783333,15.0905556 ],
    [ u"ly",u"Mizdah",26107,31.4333333,12.9833333 ],
    [ u"ly",u"Nalut",66228,31.8683333,10.9827778 ],
    [ u"ly",u"Sabha",126387,27.0333333,14.4333333 ],
    [ u"ly",u"Sabratah",102037,32.7919444,12.4847222 ],
    [ u"ly",u"Suluq",15543,31.6686111,20.25 ],
    [ u"ly",u"Surman",25235,32.7563889,12.575 ],
    [ u"ly",u"Surt",128123,31.2061111,16.5947222 ],
    [ u"ly",u"Tarhunah",210698,32.4333333,13.6333333 ],
    [ u"ly",u"Tripoli",1150990,32.8925,13.18 ],
    [ u"ly",u"Tubruq",121052,32.0836111,23.9763889 ],
    [ u"ly",u"Tukrah",23164,32.5333333,20.5666667 ],
    [ u"ly",u"Waddan",27590,29.1666667,16.1333333 ],
    [ u"ly",u"Yafran",67638,32.0630556,12.5269444 ],
    [ u"ly",u"Zaltan",16291,32.95,11.8666667 ],
    [ u"ly",u"Zlitan",99289,32.4666667,14.5666667 ],
    [ u"ly",u"Zuwarah",180310,32.9344444,12.0791667 ],
    [ u"ma",u"Agadir",656110,30.420664,-9.593161 ],
    [ u"ma",u"Asfi",328883,32.299392,-9.237181 ],
    [ u"ma",u"Asilah",31666,35.465017,-6.0348 ],
    [ u"ma",u"Azimur",37969,33.289518,-8.342498 ],
    [ u"ma",u"Casablanca",3609698,33.592779,-7.619157 ],
    [ u"ma",u"Fez",1160239,34.037151,-4.999797 ],
    [ u"ma",u"Kenitra",420534,34.261008,-6.580203 ],
    [ u"ma",u"Marrakesh",942631,31.631485,-8.008281 ],
    [ u"ma",u"Martil",29805,35.616617,-5.275219 ],
    [ u"ma",u"Mrirt",36496,33.169833,-5.567073 ],
    [ u"ma",u"Nador",157665,35.174041,-2.92866 ],
    [ u"ma",u"Rabat",1894386,34.013784,-6.844268 ],
    [ u"ma",u"Sidi Qasim",78723,34.221493,-5.707749 ],
    [ u"ma",u"Tangier",825316,35.780576,-5.813646 ],
    [ u"ma",u"Tarudant",84609,30.471106,-8.880651 ],
    [ u"ma",u"Tawnat",27249,34.538222,-4.641434 ],
    [ u"ma",u"Tétouan",365355,35.571091,-5.372424 ],
    [ u"ma",u"Tiznit",73334,29.697425,-9.731618 ],
    [ u"ma",u"Wazzan",64118,34.797107,-5.582242 ],
    [ u"mc",u"Fontvieille",4307,43.7333333,7.4166667 ],
    [ u"mc",u"La Condamine",11985,43.7333333,7.4166667 ],
    [ u"mc",u"Monaco-Ville",967,43.7333333,7.4166667 ],
    [ u"md",u"Balti",150472,47.761667,27.928889 ],
    [ u"md",u"Basarabeasca",13569,46.331111,28.972778 ],
    [ u"md",u"Briceni",10762,48.357222,27.703611 ],
    [ u"md",u"Cahul",43778,45.9075,28.194444 ],
    [ u"md",u"Calarasi",17125,47.254444,28.308056 ],
    [ u"md",u"Camenca",12820,48.031944,28.697778 ],
    [ u"md",u"Chisinau",713805,47.005556,28.8575 ],
    [ u"md",u"Cimislia",15441,46.52,28.784167 ],
    [ u"md",u"Comrat",28284,46.300278,28.657222 ],
    [ u"md",u"Dnestrovsc",12072,46.622222,29.913333 ],
    [ u"md",u"Donduseni",9077,48.224444,27.585278 ],
    [ u"md",u"Drochia",19933,48.035,27.816111 ],
    [ u"md",u"Dubasari",16180,47.263056,29.160833 ],
    [ u"md",u"Edinet",18342,48.168056,27.305 ],
    [ u"md",u"Falesti",17967,47.573611,27.709167 ],
    [ u"md",u"Floresti",17032,47.893333,28.301389 ],
    [ u"md",u"Glodeni",12353,47.770833,27.514444 ],
    [ u"md",u"Leova",11417,46.478611,28.255278 ],
    [ u"md",u"Nisporeni",14692,47.081389,28.178333 ],
    [ u"md",u"Ocnita",10762,48.385278,27.439167 ],
    [ u"md",u"Orhei",49629,47.383056,28.823056 ],
    [ u"md",u"Rabnita",60951,47.766389,29.001111 ],
    [ u"md",u"Rascani",25055,47.957222,27.553889 ],
    [ u"md",u"Rezina",14835,47.749167,28.962222 ],
    [ u"md",u"Slobozia",17780,46.728056,29.707778 ],
    [ u"md",u"Soroca",38232,48.155833,28.2975 ],
    [ u"md",u"Straseni",19652,47.141389,28.610278 ],
    [ u"md",u"Taraclia",14094,45.9,28.668889 ],
    [ u"md",u"Telenesti",8954,47.499722,28.365556 ],
    [ u"md",u"Tighina",128403,46.830556,29.471111 ],
    [ u"md",u"Ungheni",39709,47.204167,27.795833 ],
    [ u"md",u"Vulcanesti",17032,45.684167,28.402778 ],
    [ u"me",u"Niksic",65896,42.775,18.958333 ],
    [ u"me",u"Pljevlja",26266,43.352222,19.354167 ],
    [ u"me",u"Podgorica",156988,42.441111,19.263611 ],
    [ u"me",u"Ulcinj",10641,41.928333,19.206389 ],
    [ u"mg",u"Ambalavao",28027,-21.6,47.0 ],
    [ u"mg",u"Ambanja",30621,-13.6833333,48.45 ],
    [ u"mg",u"Ambatofinandrahana",25997,-20.55,46.8 ],
    [ u"mg",u"Ambatolampy",28461,-19.3833333,47.4166667 ],
    [ u"mg",u"Ambatondrazaka",43134,-17.8333333,48.4166667 ],
    [ u"mg",u"Ambilobe",14635,-13.2,49.05 ],
    [ u"mg",u"Amboasary",36082,-25.0333333,46.3833333 ],
    [ u"mg",u"Ambodifototra",11830,-16.9833333,49.85 ],
    [ u"mg",u"Ambositra",30353,-20.5166667,47.25 ],
    [ u"mg",u"Ambovombe",66818,-25.1666667,46.0833333 ],
    [ u"mg",u"Ampanihy",25686,-24.7,44.75 ],
    [ u"mg",u"Amparafaravola",51520,-17.5833333,48.2166667 ],
    [ u"mg",u"Andapa",20798,-14.65,49.65 ],
    [ u"mg",u"Andevoranto",10429,-18.95,49.1 ],
    [ u"mg",u"Andilamena",19750,-17.0166667,48.5833333 ],
    [ u"mg",u"Anjozorobe",19027,-18.4,47.8666667 ],
    [ u"mg",u"Ankazoabo",25961,-22.2833333,44.5166667 ],
    [ u"mg",u"Ankazobe",15722,-18.3166667,47.1166667 ],
    [ u"mg",u"Antalaha",34112,-14.8833333,50.2833333 ],
    [ u"mg",u"Antananarivo",1391506,-18.9166667,47.5166667 ],
    [ u"mg",u"Antanifotsy",70625,-19.5833333,47.5666667 ],
    [ u"mg",u"Antsirabe",182804,-19.85,47.0333333 ],
    [ u"mg",u"Antsohihy",21290,-14.8666667,47.9833333 ],
    [ u"mg",u"Arivonimamo",21982,-19.0166667,47.1833333 ],
    [ u"mg",u"Bealanana",16948,-14.55,48.7333333 ],
    [ u"mg",u"Beloha",23021,-25.1666667,45.05 ],
    [ u"mg",u"Beroroha",18632,-21.6666667,45.1666667 ],
    [ u"mg",u"Betafo",29785,-19.8333333,46.85 ],
    [ u"mg",u"Betioky",31102,-23.7166667,44.3833333 ],
    [ u"mg",u"Fandriana",31437,-20.2333333,47.3833333 ],
    [ u"mg",u"Farafangana",24764,-22.8166667,47.8333333 ],
    [ u"mg",u"Faratsiho",37563,-19.4,46.95 ],
    [ u"mg",u"Fenoarivo Atsinanana",21036,-17.3666667,49.4166667 ],
    [ u"mg",u"Fenoarivo",19605,-18.4333333,46.5666667 ],
    [ u"mg",u"Fianarantsoa",167240,-21.4333333,47.0833333 ],
    [ u"mg",u"Ifanadiana",17543,-21.3,47.6333333 ],
    [ u"mg",u"Ihosy",16990,-22.4,46.1166667 ],
    [ u"mg",u"Ikalamavony",15601,-21.15,46.5833333 ],
    [ u"mg",u"Ikongo",32374,-21.8833333,47.4333333 ],
    [ u"mg",u"Mahajanga",154670,-15.7166667,46.3166667 ],
    [ u"mg",u"Mahanoro",39879,-19.9,48.8 ],
    [ u"mg",u"Manakara",35499,-22.1333333,48.0166667 ],
    [ u"mg",u"Mananara",41209,-16.1666667,49.7666667 ],
    [ u"mg",u"Mananjary",27686,-21.2166667,48.3333333 ],
    [ u"mg",u"Manjakandriana",31840,-18.9166667,47.8 ],
    [ u"mg",u"Maroantsetra",23859,-15.4333333,49.7333333 ],
    [ u"mg",u"Marolambo",26160,-20.05,48.1166667 ],
    [ u"mg",u"Marovoay",31253,-16.1,46.6333333 ],
    [ u"mg",u"Miandrivazo",20631,-19.5166667,45.4666667 ],
    [ u"mg",u"Moramanga",29212,-18.9333333,48.2 ],
    [ u"mg",u"Morondava",36803,-20.2833333,44.2833333 ],
    [ u"mg",u"Nosy Varika",37152,-20.5833333,48.5333333 ],
    [ u"mg",u"Sakaraha",21826,-22.9,44.5333333 ],
    [ u"mg",u"Sambava",31522,-14.2666667,50.1666667 ],
    [ u"mg",u"Soanierana Ivongo",39271,-16.9166667,49.5833333 ],
    [ u"mg",u"Soavinandriana",40453,-19.1666667,46.7333333 ],
    [ u"mg",u"Taolanaro",45141,-25.0333333,47.0 ],
    [ u"mg",u"Toamasina",206390,-18.1666667,49.3833333 ],
    [ u"mg",u"Toliary",115328,-23.35,43.6666667 ],
    [ u"mg",u"Tsaratanana",16761,-16.7833333,47.65 ],
    [ u"mg",u"Tsihombe",29825,-25.3,45.4833333 ],
    [ u"mg",u"Tsiroanomandidy",27060,-18.7666667,46.0333333 ],
    [ u"mg",u"Vangaindrano",23523,-23.35,47.6 ],
    [ u"mg",u"Vavatenina",36916,-17.4666667,49.2 ],
    [ u"mg",u"Vohibinany",25311,-17.35,49.0333333 ],
    [ u"mg",u"Vondrozo",19949,-22.8166667,47.2833333 ],
    [ u"mk",u"Aracinovo",12800,42.0263889,21.5619444 ],
    [ u"mk",u"Bac",692,40.9333333,21.5666667 ],
    [ u"mk",u"Belcista",2804,41.3027778,20.8302778 ],
    [ u"mk",u"Berovo",13847,41.7030556,22.8577778 ],
    [ u"mk",u"Bistrica",4798,40.9833333,21.3666667 ],
    [ u"mk",u"Bitola",86528,41.0311111,21.3402778 ],
    [ u"mk",u"Blatec",2031,41.8377778,22.5780556 ],
    [ u"mk",u"Bogdanci",8635,41.2030556,22.5755556 ],
    [ u"mk",u"Bogomila",1223,41.5930556,21.4716667 ],
    [ u"mk",u"Bogovinje",15166,41.9236111,20.9136111 ],
    [ u"mk",u"Bosilovo",12447,41.4405556,22.7277778 ],
    [ u"mk",u"Brod",5607,41.5136111,21.2152778 ],
    [ u"mk",u"Brvenica",16267,41.9672222,20.9808333 ],
    [ u"mk",u"Capari",1311,41.0561111,21.1783333 ],
    [ u"mk",u"Caska",2878,41.6505556,21.6622222 ],
    [ u"mk",u"Cegrane",12523,41.8388889,20.9758333 ],
    [ u"mk",u"Cesinovo",2377,41.8713889,22.2891667 ],
    [ u"mk",u"Cucer",8646,42.1036111,21.3822222 ],
    [ u"mk",u"Debar",18075,41.525,20.5275 ],
    [ u"mk",u"Delcevo",17415,41.9672222,22.7694444 ],
    [ u"mk",u"Delogozdi",8413,41.2572222,20.7236111 ],
    [ u"mk",u"Demir Hisar",7011,41.2216667,21.2030556 ],
    [ u"mk",u"Demir Kapija",4451,41.405,22.2488889 ],
    [ u"mk",u"Dobrusevo",2103,41.1686111,21.4825 ],
    [ u"mk",u"Dolna Banjica",10147,41.7861111,20.9061111 ],
    [ u"mk",u"Dolneni",11534,41.4252778,21.4547222 ],
    [ u"mk",u"Drugovo",3149,41.4841667,20.9233333 ],
    [ u"mk",u"Dzepciste",8166,42.0327778,21.0 ],
    [ u"mk",u"Gevgelija",20664,41.1391667,22.5025 ],
    [ u"mk",u"Gostivar",50974,41.7972222,20.9083333 ],
    [ u"mk",u"Gradsko",3737,41.5722222,21.9627778 ],
    [ u"mk",u"Ilinden",16406,41.9961111,21.5822222 ],
    [ u"mk",u"Izvor",1014,42.2038889,21.5783333 ],
    [ u"mk",u"Jegunovce",7313,42.0736111,21.1236111 ],
    [ u"mk",u"Kamenica",8114,42.02,22.5919444 ],
    [ u"mk",u"Kamenjane",15376,41.9444444,20.9266667 ],
    [ u"mk",u"Karbinci",3900,41.8166667,22.2375 ],
    [ u"mk",u"Kavadarci",38800,41.4330556,22.0119444 ],
    [ u"mk",u"Kicevo",31124,41.5144444,20.9633333 ],
    [ u"mk",u"Klecevce",1505,42.1161111,21.8572222 ],
    [ u"mk",u"Kocani",34259,41.9163889,22.4127778 ],
    [ u"mk",u"Konce",3475,41.4958333,22.385 ],
    [ u"mk",u"Konopiste",327,41.2472222,22.0772222 ],
    [ u"mk",u"Kosel",1281,41.1744444,20.8355556 ],
    [ u"mk",u"Kratovo",10288,42.0791667,22.1813889 ],
    [ u"mk",u"Kriva Palanka",20820,42.2019444,22.3319444 ],
    [ u"mk",u"Krivogastani",5899,41.3361111,21.3330556 ],
    [ u"mk",u"Kuklis",4368,41.4052778,22.6652778 ],
    [ u"mk",u"Kukurecani",2395,41.0955556,21.3255556 ],
    [ u"mk",u"Kumanovo",108471,42.1322222,21.7144444 ],
    [ u"mk",u"Labunista",8805,41.2686111,20.5961111 ],
    [ u"mk",u"Lipkovo",28103,42.1563889,21.5852778 ],
    [ u"mk",u"Lozovo",2836,41.7838889,21.9055556 ],
    [ u"mk",u"Lukovo",1424,41.3494444,20.6047222 ],
    [ u"mk",u"Mavrovi Anovi",914,41.7005556,20.7555556 ],
    [ u"mk",u"Meseista",2452,41.2386111,20.7766667 ],
    [ u"mk",u"Miravci",2573,41.3077778,22.435 ],
    [ u"mk",u"Mogila",4392,41.1083333,21.3786111 ],
    [ u"mk",u"Murtino",6658,41.4152778,22.7266667 ],
    [ u"mk",u"Negotino",19516,41.4838889,22.0891667 ],
    [ u"mk",u"Negotino-Polosko",17518,41.8786111,20.8838889 ],
    [ u"mk",u"Novaci",2357,41.0419444,21.4561111 ],
    [ u"mk",u"Novo Selo",11818,41.4138889,22.8811111 ],
    [ u"mk",u"Oblesevo",4972,41.8833333,22.3338889 ],
    [ u"mk",u"Ohrid",54908,41.1172222,20.8019444 ],
    [ u"mk",u"Orasac",1180,42.0625,21.7997222 ],
    [ u"mk",u"Orizari",4292,41.9227778,22.4469444 ],
    [ u"mk",u"Oslomej",10919,41.5772222,21.0 ],
    [ u"mk",u"Petrovec",8298,41.9388889,21.615 ],
    [ u"mk",u"Plasnica",4574,41.4672222,21.1230556 ],
    [ u"mk",u"Podares",3774,41.6138889,22.5422222 ],
    [ u"mk",u"Prilep",73815,41.3463889,21.5544444 ],
    [ u"mk",u"Probistip",12702,42.0030556,22.1786111 ],
    [ u"mk",u"Radovis",24983,41.6383333,22.4647222 ],
    [ u"mk",u"Rankovce",4071,42.1819444,22.1227778 ],
    [ u"mk",u"Resen",16539,41.0888889,21.0122222 ],
    [ u"mk",u"Rosoman",4106,41.5161111,21.9497222 ],
    [ u"mk",u"Rostusa",9147,41.61,20.6 ],
    [ u"mk",u"Samokov",1429,41.6836111,21.1441667 ],
    [ u"mk",u"Saraj",25379,42.0,21.3277778 ],
    [ u"mk",u"Sipkovica",8228,42.035,20.9155556 ],
    [ u"mk",u"Skopje",474887,42.0,21.4333333 ],
    [ u"mk",u"Sopiste",9460,41.9547222,21.4275 ],
    [ u"mk",u"Sopotnica",2110,41.2947222,21.155 ],
    [ u"mk",u"Srbinovo",3629,41.7058333,20.9602778 ],
    [ u"mk",u"Staravina",285,41.0897222,21.7338889 ],
    [ u"mk",u"Star Dojran",3348,41.1875,22.7208333 ],
    [ u"mk",u"Staro Nagoricane",4112,42.1980556,21.8286111 ],
    [ u"mk",u"Stip",48279,41.7458333,22.1958333 ],
    [ u"mk",u"Struga",37388,41.1780556,20.6761111 ],
    [ u"mk",u"Strumica",45509,41.4375,22.6433333 ],
    [ u"mk",u"Studenicani",18219,41.9158333,21.5305556 ],
    [ u"mk",u"Sveti Nikole",18475,41.865,21.9427778 ],
    [ u"mk",u"Tearce",23096,42.0744444,21.0525 ],
    [ u"mk",u"Tetovo",72945,42.0105556,20.9713889 ],
    [ u"mk",u"Topolcani",2773,41.2286111,21.4313889 ],
    [ u"mk",u"Valandovo",11825,41.3169444,22.5611111 ],
    [ u"mk",u"Vasilevo",12382,41.4761111,22.6416667 ],
    [ u"mk",u"Velesta",8646,41.2408333,20.6438889 ],
    [ u"mk",u"Veles",57873,41.7155556,21.7755556 ],
    [ u"mk",u"Vevcani",2429,41.2405556,20.5933333 ],
    [ u"mk",u"Vinica",18218,41.8827778,22.5091667 ],
    [ u"mk",u"Vitoliste",456,41.1808333,21.8266667 ],
    [ u"mk",u"Vranestica",1265,41.4452778,21.0266667 ],
    [ u"mk",u"Vrapciste",8652,41.8338889,20.8852778 ],
    [ u"mk",u"Vratnica",3678,42.1433333,21.1169444 ],
    [ u"mk",u"Zajas",12219,41.6072222,20.9383333 ],
    [ u"mk",u"Zelenikovo",4020,41.8866667,21.5869444 ],
    [ u"mk",u"Zelino",25422,41.9802778,21.0641667 ],
    [ u"mk",u"Zitose",2131,41.4208333,21.2905556 ],
    [ u"mk",u"Zletovo",3340,41.9886111,22.2361111 ],
    [ u"mk",u"Zrnovci",3236,41.8541667,22.4444444 ],
    [ u"ml",u"Araouane",4026,18.9,-3.55 ],
    [ u"ml",u"Bafoulabé",26866,13.8,-10.8333333 ],
    [ u"ml",u"Bamako",1297390,12.65,-8.0 ],
    [ u"ml",u"Banamba",30603,13.55,-7.45 ],
    [ u"ml",u"Bandiagara",6856,14.35,-3.6166667 ],
    [ u"ml",u"Bougouni",35567,11.4166667,-7.4833333 ],
    [ u"ml",u"Diré",10947,12.2833333,-10.9666667 ],
    [ u"ml",u"Djénné",22391,13.9,-4.55 ],
    [ u"ml",u"Douentza",8057,15.0,-2.95 ],
    [ u"ml",u"Gao",38186,16.2666667,-0.05 ],
    [ u"ml",u"Goundam",8459,16.4166667,-3.6666667 ],
    [ u"ml",u"Kangaba",17232,11.9333333,-8.4166667 ],
    [ u"ml",u"Kati",42927,12.7466667,-8.0713889 ],
    [ u"ml",u"Kayes",97475,14.45,-11.4333333 ],
    [ u"ml",u"Kidal",11642,18.4411111,1.4077778 ],
    [ u"ml",u"Kimparana",6014,12.8333333,-4.9333333 ],
    [ u"ml",u"Kita",5769,13.05,-9.4833333 ],
    [ u"ml",u"Kolokani",48792,13.5833333,-8.0333333 ],
    [ u"ml",u"Kolondiéba",10041,11.0833333,-6.9 ],
    [ u"ml",u"Koulikoro",23922,12.8661111,-7.5605556 ],
    [ u"ml",u"Koutiala",99662,12.3833333,-5.4666667 ],
    [ u"ml",u"Markala",53746,13.6833333,-6.0833333 ],
    [ u"ml",u"Mopti",108790,14.5,-4.2 ],
    [ u"ml",u"Nara",27797,15.1666667,-7.2833333 ],
    [ u"ml",u"Niono",32621,14.25,-6.0 ],
    [ u"ml",u"Nioro",72080,15.2333333,-9.5833333 ],
    [ u"ml",u"San",24813,13.3,-4.9 ],
    [ u"ml",u"Ségou",92562,13.45,-6.2666667 ],
    [ u"ml",u"Sikasso",144801,11.3166667,-5.6666667 ],
    [ u"ml",u"Sokolo",4374,14.7333333,-6.1333333 ],
    [ u"ml",u"Taoudenni",3019,22.6666667,-3.9833333 ],
    [ u"ml",u"Ténenkou",7471,14.4666667,-4.9166667 ],
    [ u"ml",u"Tessalit",2787,20.2013889,1.0088889 ],
    [ u"ml",u"Tombouctou",32463,16.7666667,-3.0166667 ],
    [ u"ml",u"Yorosso",17447,12.3666667,-4.7833333 ],
    [ u"mm",u"Akyab",177765,20.15,92.9 ],
    [ u"mm",u"Allanmyo",57904,19.3666667,95.2166667 ],
    [ u"mm",u"Bago",244407,17.3333333,96.4833333 ],
    [ u"mm",u"Banmo",47920,24.2666667,97.2333333 ],
    [ u"mm",u"Bogale",68947,16.2833333,95.4 ],
    [ u"mm",u"Chauk",90882,20.8833333,94.8166667 ],
    [ u"mm",u"Dawei",136798,14.0833333,98.2 ],
    [ u"mm",u"Falam",5404,22.9166667,93.6833333 ],
    [ u"mm",u"Henzada",134964,17.6333333,95.4666667 ],
    [ u"mm",u"Kanbè",58146,16.7166667,96.0 ],
    [ u"mm",u"Kanbe",58146,16.7,96.0166667 ],
    [ u"mm",u"Katha",38634,24.1833333,96.35 ],
    [ u"mm",u"Kayan",40322,16.9055556,96.5630556 ],
    [ u"mm",u"Kyaikkami",48100,16.08,97.5675 ],
    [ u"mm",u"Kyaiklat",52432,16.4333333,95.7333333 ],
    [ u"mm",u"Kyaikto",48658,17.3,97.0166667 ],
    [ u"mm",u"Kyaukse",50486,21.6,96.1333333 ],
    [ u"mm",u"Labutta",41769,16.15,94.7666667 ],
    [ u"mm",u"Lashio",131033,22.9333333,97.75 ],
    [ u"mm",u"Letpadan",38936,17.7833333,95.75 ],
    [ u"mm",u"Loikaw",17293,19.6833333,97.2166667 ],
    [ u"mm",u"Magway",96966,20.15,94.9166667 ],
    [ u"mm",u"Mandalay",1208227,22.0,96.0833333 ],
    [ u"mm",u"Martaban",48629,16.5313889,97.6111111 ],
    [ u"mm",u"Maubin",51542,16.7333333,95.65 ],
    [ u"mm",u"Mawlaik",44540,23.6333333,94.4166667 ],
    [ u"mm",u"Mawlamyine",438907,16.4913889,97.6255556 ],
    [ u"mm",u"Maymyo",117318,22.0333333,96.4666667 ],
    [ u"mm",u"Meiktila",177464,20.8666667,95.8666667 ],
    [ u"mm",u"Mergui",173317,12.4333333,98.6 ],
    [ u"mm",u"Minbu",57350,20.1833333,94.8833333 ],
    [ u"mm",u"Mogok",90854,22.9166667,96.5 ],
    [ u"mm",u"Monywa",182034,22.1166667,95.1333333 ],
    [ u"mm",u"Moulmeingyun",39115,16.3833333,95.2666667 ],
    [ u"mm",u"Mudon",89134,16.2577778,97.7163889 ],
    [ u"mm",u"Myanaung",42252,18.2833333,95.3166667 ],
    [ u"mm",u"Myingyan",141731,21.4666667,95.3833333 ],
    [ u"mm",u"Myitkyina",90905,25.3833333,97.4 ],
    [ u"mm",u"Nyaunglebin",89638,17.95,96.7333333 ],
    [ u"mm",u"Pakokku",126954,21.3333333,95.1 ],
    [ u"mm",u"Pathein",237119,16.7833333,94.7333333 ],
    [ u"mm",u"Paungde",36971,18.4833333,95.5 ],
    [ u"mm",u"Pyapon",65610,16.2833333,95.6833333 ],
    [ u"mm",u"Pyay",135325,18.8166667,95.2166667 ],
    [ u"mm",u"Pyinmana",97421,19.7333333,96.2166667 ],
    [ u"mm",u"Pyu",40386,18.4833333,96.4333333 ],
    [ u"mm",u"Rangoon",4477782,16.7833333,96.1666667 ],
    [ u"mm",u"Sagaing",78749,21.8666667,95.9833333 ],
    [ u"mm",u"Shwebo",88926,22.5666667,95.7 ],
    [ u"mm",u"Syriam",69448,16.7658333,96.2477778 ],
    [ u"mm",u"Taungdwingyi",70103,20.0166667,95.55 ],
    [ u"mm",u"Taunggyi",160136,20.7833333,97.0333333 ],
    [ u"mm",u"Thanatpin",38059,17.3,96.5833333 ],
    [ u"mm",u"Tharrawaddy",54393,17.65,95.8 ],
    [ u"mm",u"Thaton",123742,16.9205556,97.3713889 ],
    [ u"mm",u"Thayetmyo",98197,19.3166667,95.1833333 ],
    [ u"mm",u"Thongwa",52496,16.7619444,96.5277778 ],
    [ u"mm",u"Toungoo",106959,18.9333333,96.4333333 ],
    [ u"mm",u"Twante",46516,16.7166667,95.9333333 ],
    [ u"mm",u"Wakema",42705,16.6,95.1833333 ],
    [ u"mm",u"Yamethin",59874,20.4333333,96.15 ],
    [ u"mm",u"Yandoon",40092,17.0333333,95.65 ],
    [ u"mm",u"Yenangyaung",110567,20.4666667,94.8833333 ],
    [ u"mm",u"Ye",55682,15.25,97.85 ],
    [ u"mn",u"Baruun-Urt",15808,46.7,113.2833333 ],
    [ u"mn",u"Bulgan",17351,48.8105556,103.5316667 ],
    [ u"mn",u"Darhan",72386,46.6166667,109.4166667 ],
    [ u"mn",u"Erdenet",79649,49.0333333,104.0833333 ],
    [ u"mn",u"Hovd",27929,44.6666667,102.1666667 ],
    [ u"mn",u"Mandalgovi",15433,45.75,106.2666667 ],
    [ u"mn",u"Mörön",27694,49.6452778,100.1544444 ],
    [ u"mn",u"Öndörhaan",14724,47.3166667,110.65 ],
    [ u"mn",u"Sühbaatar",24238,50.2313889,106.2077778 ],
    [ u"mn",u"Ulaanbaatar",844786,47.9166667,106.9166667 ],
    [ u"mn",u"Ulaangom",28091,49.9666667,92.0333333 ],
    [ u"mq",u"Basse-Pointe",4037,14.8666667,-61.1166667 ],
    [ u"mq",u"Ducos",17395,14.5666667,-60.9833333 ],
    [ u"mq",u"Fort-de-France",89997,14.6,-61.0833333 ],
    [ u"mq",u"Gros-Morne",11026,14.7,-61.0 ],
    [ u"mq",u"La Trinité",15041,14.7333333,-60.9666667 ],
    [ u"mq",u"Le François",19683,14.6,-60.9 ],
    [ u"mq",u"Le Lamentin",39230,14.6,-61.0 ],
    [ u"mq",u"Le Lorrain",8342,14.8333333,-61.0666667 ],
    [ u"mq",u"Le Marin",7944,14.4666667,-60.8666667 ],
    [ u"mq",u"Le Robert",23815,14.6666667,-60.9333333 ],
    [ u"mq",u"Les Trois-Îlets",5658,14.5333333,-61.0333333 ],
    [ u"mq",u"Le Vauclin",7813,14.5333333,-60.8333333 ],
    [ u"mq",u"Rivière-Pilote",13360,14.4833333,-60.9 ],
    [ u"mq",u"Sainte-Luce",9197,14.4666667,-60.9166667 ],
    [ u"mq",u"Sainte-Marie",20381,14.7833333,-60.9833333 ],
    [ u"mq",u"Saint-Joseph",16974,14.6666667,-61.0333333 ],
    [ u"mq",u"Saint-Pierre",4125,14.7333333,-61.1666667 ],
    [ u"mr",u"Atâr",30501,20.5166667,-13.05 ],
    [ u"mr",u"Bababé",11507,16.3333333,-13.95 ],
    [ u"mr",u"Maghama",5100,15.5166667,-12.85 ],
    [ u"mr",u"Nouâdhibou",80181,20.9,-17.0666667 ],
    [ u"mr",u"Nouakchott",709835,18.0863889,-15.9752778 ],
    [ u"mt",u"Attard",9510,35.889722,14.4425 ],
    [ u"mt",u"Birgu",2936,35.892222,14.518333 ],
    [ u"mt",u"Birkirkara",21676,35.897222,14.461111 ],
    [ u"mt",u"Bormla",6096,35.885556,14.5275 ],
    [ u"mt",u"Dingli",3009,35.861389,14.382222 ],
    [ u"mt",u"Fgura",11819,35.870278,14.513333 ],
    [ u"mt",u"Floriana",2516,35.895833,14.508333 ],
    [ u"mt",u"Gharb",971,36.06,14.208889 ],
    [ u"mt",u"Gharghur",2025,35.924167,14.451944 ],
    [ u"mt",u"Ghasri",364,36.057778,14.226389 ],
    [ u"mt",u"Ghaxaq",4375,35.848889,14.516667 ],
    [ u"mt",u"Gudja",3023,35.849167,14.503056 ],
    [ u"mt",u"Gzira",7513,35.905833,14.488056 ],
    [ u"mt",u"Hamrun",10680,35.884722,14.484444 ],
    [ u"mt",u"Isla",3543,35.8875,14.516944 ],
    [ u"mt",u"Kalkara",2982,35.889167,14.532778 ],
    [ u"mt",u"Kercem",1627,36.041944,14.226667 ],
    [ u"mt",u"Kirkop",2137,35.842222,14.485278 ],
    [ u"mt",u"Lija",2471,35.900556,14.446389 ],
    [ u"mt",u"Luqa",5053,35.858889,14.488611 ],
    [ u"mt",u"Marsa",5116,35.879167,14.495278 ],
    [ u"mt",u"Marsaxlokk",3026,35.841944,14.543056 ],
    [ u"mt",u"Mdina",360,35.886944,14.4025 ],
    [ u"mt",u"Mellieha",5976,35.956389,14.362222 ],
    [ u"mt",u"Mgarr",2868,36.025278,14.295 ],
    [ u"mt",u"Mosta",17789,35.909167,14.425556 ],
    [ u"mt",u"Mqabba",2891,35.846111,14.467222 ],
    [ u"mt",u"Msida",6920,35.8925,14.482778 ],
    [ u"mt",u"Munxar",840,36.03,14.233333 ],
    [ u"mt",u"Nadur",3933,36.037778,14.294167 ],
    [ u"mt",u"Naxxar",10378,35.913611,14.443611 ],
    [ u"mt",u"Paola",9257,35.873056,14.498889 ],
    [ u"mt",u"Qala",1534,36.036111,14.309444 ],
    [ u"mt",u"Qormi",18230,35.878333,14.471944 ],
    [ u"mt",u"Qrendi",2493,35.834722,14.458333 ],
    [ u"mt",u"Rabat",12914,35.882222,14.398056 ],
    [ u"mt",u"Safi",1863,35.833056,14.484722 ],
    [ u"mt",u"San Giljan",6799,35.919722,14.484444 ],
    [ u"mt",u"San Gwann",12346,35.905556,14.476111 ],
    [ u"mt",u"San Lawrenz",530,36.055556,14.203611 ],
    [ u"mt",u"Sannat",1681,36.024444,14.242778 ],
    [ u"mt",u"San Pawl il-Bahar",7396,35.948333,14.400556 ],
    [ u"mt",u"Santa Lucia",3760,35.862778,14.5075 ],
    [ u"mt",u"Santa Venera",6264,35.890833,14.474167 ],
    [ u"mt",u"Siggiewi",7676,35.855556,14.436389 ],
    [ u"mt",u"Sliema",11318,35.9125,14.501944 ],
    [ u"mt",u"Tarxien",7761,35.865833,14.515 ],
    [ u"mt",u"Valletta",6794,35.899722,14.514722 ],
    [ u"mt",u"Xaghra",3680,36.05,14.264444 ],
    [ u"mt",u"Xewkija",3303,36.032778,14.258056 ],
    [ u"mt",u"Xghajra",837,35.885556,14.5475 ],
    [ u"mt",u"Zabbar",15030,35.876111,14.535 ],
    [ u"mt",u"Zebbug",11063,35.871944,14.441111 ],
    [ u"mt",u"Zejtun",11549,35.855833,14.533056 ],
    [ u"mt",u"Zurrieq",9149,35.831111,14.474167 ],
    [ u"mu",u"Albion",3254,-20.2116667,57.4008333 ],
    [ u"mu",u"Amaury",2912,-20.1308333,57.6591667 ],
    [ u"mu",u"Arsenal",2599,-20.1055556,57.5352778 ],
    [ u"mu",u"Baie du Tombeau",13153,-20.1194444,57.4913889 ],
    [ u"mu",u"Bambous",13047,-20.2566667,57.4061111 ],
    [ u"mu",u"Bambous Virieux",1541,-20.3427778,57.7575 ],
    [ u"mu",u"Bananes",652,-20.3466667,57.5886111 ],
    [ u"mu",u"Beau Vallon",7016,-20.35,57.6833333 ],
    [ u"mu",u"Bel Air",17671,-20.2541667,57.7452778 ],
    [ u"mu",u"Belle Vue Maurel",5088,-20.1202778,57.6636111 ],
    [ u"mu",u"Bois des Amourettes",1986,-20.3630556,57.7311111 ],
    [ u"mu",u"Bon Accueil",6553,-20.1708333,57.6563889 ],
    [ u"mu",u"Brisée Verdière",7374,-20.1638889,57.6466667 ],
    [ u"mu",u"Calebasses",4648,-20.1116667,57.5538889 ],
    [ u"mu",u"Camp de Masque",2721,-20.2369444,57.6633333 ],
    [ u"mu",u"Camp de Masque Pave",4520,-20.2361111,57.675 ],
    [ u"mu",u"Camp Diable",5082,-20.4627778,57.5788889 ],
    [ u"mu",u"Camp Ithier",4401,-20.2158333,57.7455556 ],
    [ u"mu",u"Camp Thorel",2299,-20.2147222,57.6161111 ],
    [ u"mu",u"Cap Malheureux",4803,-19.9841667,57.6141667 ],
    [ u"mu",u"Cascavelle",2613,-20.2869444,57.4072222 ],
    [ u"mu",u"Chamarel",723,-20.4225,57.3838889 ],
    [ u"mu",u"Chamouny",4913,-20.4822222,57.4661111 ],
    [ u"mu",u"Chemin Grenier",12457,-20.4872222,57.4655556 ],
    [ u"mu",u"Clémencia",1835,-20.2638889,57.7061111 ],
    [ u"mu",u"Cluny",1629,-20.3669444,57.6038889 ],
    [ u"mu",u"Congomah",1956,-20.1488889,57.5908333 ],
    [ u"mu",u"Cottage",3646,-20.0597222,57.6291667 ],
    [ u"mu",u"Crève Coeur",3097,-20.1911111,57.5572222 ],
    [ u"mu",u"Curepipe",84200,-20.3147222,57.5202778 ],
    [ u"mu",u"Dagotière",6915,-20.2444444,57.5541667 ],
    [ u"mu",u"Dubreuil",2726,-20.2975,57.595 ],
    [ u"mu",u"Ecroignard",5952,-20.2261111,57.7361111 ],
    [ u"mu",u"Espérance",1878,-20.225,57.5872222 ],
    [ u"mu",u"Espérance",1878,-20.0697222,57.6419444 ],
    [ u"mu",u"Espérance Trébuchet",2323,-20.0697222,57.6419444 ],
    [ u"mu",u"Flic en Flac",2010,-20.2741667,57.3630556 ],
    [ u"mu",u"Fond du Sac",5796,-20.0430556,57.5786111 ],
    [ u"mu",u"Goodlands",20910,-20.035,57.6430556 ],
    [ u"mu",u"Grand Baie",11512,-20.0136111,57.5738889 ],
    [ u"mu",u"Grand Bel Air",1452,-20.4063889,57.6736111 ],
    [ u"mu",u"Grand Bois",7804,-20.4188889,57.5441667 ],
    [ u"mu",u"Grande Rivière Noire",2361,-20.3602778,57.3661111 ],
    [ u"mu",u"Grand Gaube",7156,-20.0063889,57.6608333 ],
    [ u"mu",u"Grand River South East",2472,-20.2861111,57.7758333 ],
    [ u"mu",u"Grand Sable",2208,-20.3141667,57.7644444 ],
    [ u"mu",u"Gros Cailloux",3361,-20.2072222,57.43 ],
    [ u"mu",u"La Gaulette",2216,-20.4247222,57.3527778 ],
    [ u"mu",u"Lalmatie",10404,-20.1897222,57.6611111 ],
    [ u"mu",u"Laventure",6171,-20.1458333,57.6766667 ],
    [ u"mu",u"Le Hochet",15197,-20.135,57.5211111 ],
    [ u"mu",u"Long Mountain",7775,-20.1430556,57.5622222 ],
    [ u"mu",u"Mahébourg",17042,-20.4080556,57.7 ],
    [ u"mu",u"Mapou",1288,-20.0758333,57.6013889 ],
    [ u"mu",u"Mare La Chaux",2058,-20.1980556,57.7494444 ],
    [ u"mu",u"Melrose",2002,-20.2697222,57.6319444 ],
    [ u"mu",u"Midlands",4546,-20.3325,57.5583333 ],
    [ u"mu",u"Moka",8842,-20.2188889,57.4958333 ],
    [ u"mu",u"Montagne Blanche",8661,-20.2827778,57.6544444 ],
    [ u"mu",u"New Grove",9935,-20.4086111,57.6136111 ],
    [ u"mu",u"Notre Dame",3959,-20.1405556,57.5530556 ],
    [ u"mu",u"Nouvelle France",7238,-20.3705556,57.5611111 ],
    [ u"mu",u"Olivia",3980,-20.2975,57.7255556 ],
    [ u"mu",u"Pailles",10622,-20.1855556,57.4772222 ],
    [ u"mu",u"Petite Rivière",5331,-20.1894444,57.4452778 ],
    [ u"mu",u"Petit Raffray",9117,-20.0133333,57.6119444 ],
    [ u"mu",u"Piton",5909,-20.0902778,57.6302778 ],
    [ u"mu",u"Plaine Magnien",10778,-20.4286111,57.6530556 ],
    [ u"mu",u"Plaines des Papayes",7617,-20.065,57.5725 ],
    [ u"mu",u"Port Louis",155226,-20.1619444,57.4988889 ],
    [ u"mu",u"Poste de Flacq",7133,-20.1630556,57.7305556 ],
    [ u"mu",u"Providence",3126,-20.2447222,57.6122222 ],
    [ u"mu",u"Quartier Militaire",6424,-20.2438889,57.5891667 ],
    [ u"mu",u"Quatre Bornes",80961,-20.2644444,57.4719444 ],
    [ u"mu",u"Quatre Cocos",5724,-20.2077778,57.7625 ],
    [ u"mu",u"Quatre Soeurs",3515,-20.2991667,57.7705556 ],
    [ u"mu",u"Queen Victoria",3025,-20.22,57.7075 ],
    [ u"mu",u"Ripailles",3050,-20.1936111,57.5722222 ],
    [ u"mu",u"Rivière des Anguilles",9927,-20.4852778,57.5508333 ],
    [ u"mu",u"Rivière du Rempart",11675,-20.1030556,57.6847222 ],
    [ u"mu",u"Roches Noires",5733,-20.1111111,57.7122222 ],
    [ u"mu",u"Roche Terre",3199,-20.0186111,57.6447222 ],
    [ u"mu",u"Rose Belle",12619,-20.4002778,57.5966667 ],
    [ u"mu",u"Saint Aubin",1659,-20.4916667,57.5413889 ],
    [ u"mu",u"Saint Hubert",4170,-20.3641667,57.6383333 ],
    [ u"mu",u"Saint Julien",3188,-20.2263889,57.6363889 ],
    [ u"mu",u"Saint Pierre",16414,-20.2175,57.5208333 ],
    [ u"mu",u"Sebastopol",5745,-20.2888889,57.6875 ],
    [ u"mu",u"Souillac",4392,-20.5166667,57.5166667 ],
    [ u"mu",u"Surinam",10621,-20.5097222,57.5052778 ],
    [ u"mu",u"Tamarin",3764,-20.3255556,57.3705556 ],
    [ u"mu",u"Terre Rouge",9566,-20.0433333,57.5683333 ],
    [ u"mu",u"The Vale",3707,-20.0283333,57.5877778 ],
    [ u"mu",u"Triolet",23270,-20.0547222,57.5452778 ],
    [ u"mu",u"Verdun",2208,-20.2283333,57.5438889 ],
    [ u"mv",u"Dhidhdhoo",3039,6.8833333,73.1 ],
    [ u"mv",u"Eydhafushi",2808,5.1166667,73.0333333 ],
    [ u"mv",u"Felidhoo",541,3.4833333,73.5333333 ],
    [ u"mv",u"Funadhoo",1221,6.15,73.2666667 ],
    [ u"mv",u"Hithadhoo",9927,-0.6,73.0833333 ],
    [ u"mv",u"Hithadhoo",683,1.7833333,73.3833333 ],
    [ u"mv",u"Kudahuvadhoo",1320,2.6666667,72.9 ],
    [ u"mv",u"Kulhudhuffushi",7775,6.6166667,73.05 ],
    [ u"mv",u"Magoodhoo",453,3.1,72.9666667 ],
    [ u"mv",u"Mahibadhoo",2155,3.7833333,72.9666667 ],
    [ u"mv",u"Male",84971,4.1666667,73.5 ],
    [ u"mv",u"Manadhoo",1418,5.7666667,73.3833333 ],
    [ u"mv",u"Muli",1008,2.9166667,73.5666667 ],
    [ u"mv",u"Naifaru",3836,5.4333333,73.3333333 ],
    [ u"mv",u"Nolhivaranfaru",448,6.7166667,73.1 ],
    [ u"mv",u"Thinadhoo",5361,0.5333333,72.9333333 ],
    [ u"mv",u"Ugoofaaru",1264,5.6666667,73.0 ],
    [ u"mv",u"Viligili",2305,0.75,73.3833333 ],
    [ u"mw",u"Balaka",18907,-14.9833333,34.95 ],
    [ u"mw",u"Blantyre",584870,-15.7833333,35.0 ],
    [ u"mw",u"Chikwawa",8966,-16.05,34.8 ],
    [ u"mw",u"Chipoka",4346,-13.9833333,34.5166667 ],
    [ u"mw",u"Chiradzulu",1580,-15.7,35.1833333 ],
    [ u"mw",u"Chitipa",8825,-9.7166667,33.2666667 ],
    [ u"mw",u"Dedza",15611,-14.3666667,34.3333333 ],
    [ u"mw",u"Dowa",5568,-13.65,33.9333333 ],
    [ u"mw",u"Karonga",34211,-9.9333333,33.9333333 ],
    [ u"mw",u"Kasungu",42565,-13.0333333,33.4833333 ],
    [ u"mw",u"Lilongwe",646738,-13.9833333,33.7833333 ],
    [ u"mw",u"Livingstonia",5552,-10.6,34.1166667 ],
    [ u"mw",u"Liwonde",22476,-15.0666667,35.2166667 ],
    [ u"mw",u"Luchenza",11958,-16.0166667,35.3 ],
    [ u"mw",u"Machinga",1418,-14.9666667,35.5166667 ],
    [ u"mw",u"Mangochi",40295,-14.4666667,35.2666667 ],
    [ u"mw",u"Mchinji",18328,-13.7166667,32.9 ],
    [ u"mw",u"Monkey Bay",11623,-14.0833333,34.9166667 ],
    [ u"mw",u"Mponela",11222,-13.5166667,33.7166667 ],
    [ u"mw",u"Mulanje",16512,-16.0333333,35.5 ],
    [ u"mw",u"Mwanza",11384,-15.6166667,34.5166667 ],
    [ u"mw",u"Mzimba",19310,-11.9,33.6 ],
    [ u"mw",u"Nkhata Bay",11722,-11.6,34.3 ],
    [ u"mw",u"Nkhotakota",24869,-12.9166667,34.3 ],
    [ u"mw",u"Nsanje",21782,-16.9166667,35.2666667 ],
    [ u"mw",u"Ntcheu",10464,-14.8166667,34.6333333 ],
    [ u"mw",u"Ntchisi",7326,-13.3666667,34.0 ],
    [ u"mw",u"Phalombe",2663,-15.8,35.65 ],
    [ u"mw",u"Rumphi",20731,-11.0166667,33.8666667 ],
    [ u"mw",u"Salima",30056,-13.7833333,34.4333333 ],
    [ u"mw",u"Thyolo",5776,-16.0666667,35.1333333 ],
    [ u"mw",u"Zomba",80932,-15.3833333,35.3333333 ],
    [ u"mx",u"Abasolo",25821,20.45,-101.516667 ],
    [ u"mx",u"Abasolo",6740,24.066667,-98.366667 ],
    [ u"mx",u"Acacoyagua",6202,15.35,-92.65 ],
    [ u"mx",u"Acahualco",13968,19.276944,-99.775556 ],
    [ u"mx",u"Acajete",18068,19.1,-97.95 ],
    [ u"mx",u"Acala",12954,16.566667,-92.8 ],
    [ u"mx",u"Acámbaro",56265,20.033333,-100.733333 ],
    [ u"mx",u"Acambay",5807,19.955833,-99.841667 ],
    [ u"mx",u"Acamixtla",4866,18.566667,-99.583333 ],
    [ u"mx",u"Acancéh",9892,20.816667,-89.45 ],
    [ u"mx",u"Acapetahua",6115,15.283333,-92.7 ],
    [ u"mx",u"Acaponeta",18564,22.496389,-105.359444 ],
    [ u"mx",u"Acapulco",652160,16.85,-99.916667 ],
    [ u"mx",u"Acateno",3295,19.883333,-97.35 ],
    [ u"mx",u"Acatic",11582,20.783333,-102.883333 ],
    [ u"mx",u"Acatlan",5933,18.533333,-96.616667 ],
    [ u"mx",u"Acatlán",16292,18.2,-98.05 ],
    [ u"mx",u"Acatzingo",22386,18.983333,-97.783333 ],
    [ u"mx",u"Acaxochitlán",3746,20.166667,-98.2 ],
    [ u"mx",u"Acayuca",7276,20.033333,-98.833333 ],
    [ u"mx",u"Acayucan",46992,17.95,-94.916667 ],
    [ u"mx",u"Acazulco",5131,19.266667,-99.433333 ],
    [ u"mx",u"Acolman",4998,19.625,-98.916667 ],
    [ u"mx",u"Actipan",6037,18.958333,-97.802778 ],
    [ u"mx",u"Actopan",26706,20.266667,-98.933333 ],
    [ u"mx",u"Actopan",3990,19.5,-96.616667 ],
    [ u"mx",u"Acuautla",21905,19.333333,-98.85 ],
    [ u"mx",u"Acuexcomac",4236,18.841667,-98.063889 ],
    [ u"mx",u"Acuitzio",5918,19.483333,-101.333333 ],
    [ u"mx",u"Acultzingo",5801,18.716667,-97.316667 ],
    [ u"mx",u"Acuña",144703,29.3,-100.916667 ],
    [ u"mx",u"Acutzilapan",5232,19.783333,-99.683333 ],
    [ u"mx",u"Adolfo López Mateos",8770,28.466667,-107.3 ],
    [ u"mx",u"Adolfo Ruíz Cortínes",12947,25.75,-108.75 ],
    [ u"mx",u"Agua Dulce",36121,18.133333,-94.133333 ],
    [ u"mx",u"Agua Prieta",68449,31.3,-109.566667 ],
    [ u"mx",u"Aguascalientes",658193,21.883333,-102.3 ],
    [ u"mx",u"Agua Verde",4192,22.9,-106.05 ],
    [ u"mx",u"Aguililla",9422,18.733333,-102.733333 ],
    [ u"mx",u"Ahome",10806,25.916667,-109.183333 ],
    [ u"mx",u"Ahuacatlán",6450,21.05,-104.483333 ],
    [ u"mx",u"Ahualulco",14778,20.7,-103.983333 ],
    [ u"mx",u"Ahualulco",3844,22.4,-101.166667 ],
    [ u"mx",u"Ahuatempan",4246,18.416667,-98.016667 ],
    [ u"mx",u"Ahumada",9326,30.616667,-106.516667 ],
    [ u"mx",u"Ajacuba",6590,20.0875,-99.1125 ],
    [ u"mx",u"Ajalpan",24218,18.366667,-97.25 ],
    [ u"mx",u"Ajijic",13714,20.3,-103.283333 ],
    [ u"mx",u"Ajoloapan",15905,19.978611,-99.047222 ],
    [ u"mx",u"Ajuchitlan",6329,18.15,-100.483333 ],
    [ u"mx",u"Ajuchitlán",4876,20.716667,-100.016667 ],
    [ u"mx",u"Akil",9858,20.25,-89.35 ],
    [ u"mx",u"Álamo",22741,20.883333,-97.666667 ],
    [ u"mx",u"Álamos",8521,27.016667,-108.933333 ],
    [ u"mx",u"Aldama",4044,20.816667,-101.316667 ],
    [ u"mx",u"Aldama",12292,22.916667,-98.066667 ],
    [ u"mx",u"Algodones",4874,32.7,-114.766667 ],
    [ u"mx",u"Aljojuca",4358,19.1,-97.516667 ],
    [ u"mx",u"Allende",19636,28.333333,-100.85 ],
    [ u"mx",u"Allende",22609,25.283333,-100.016667 ],
    [ u"mx",u"Allende",21398,18.15,-94.4 ],
    [ u"mx",u"Almaya",4810,19.233333,-99.416667 ],
    [ u"mx",u"Almecatla",7366,19.133333,-98.233333 ],
    [ u"mx",u"Almoloya",4217,19.7,-98.4 ],
    [ u"mx",u"Almoloya",3843,18.95,-100.116667 ],
    [ u"mx",u"Almoloya del Río",8995,19.158056,-99.489722 ],
    [ u"mx",u"Alpoyeca",3284,17.666667,-98.516667 ],
    [ u"mx",u"Alpuyeca",7811,18.733333,-99.266667 ],
    [ u"mx",u"Alseseca",6490,18.833333,-97.683333 ],
    [ u"mx",u"Altamira",54956,22.4,-97.916667 ],
    [ u"mx",u"Altamirano",6672,16.736111,-92.038889 ],
    [ u"mx",u"Altamirano",4714,19.1,-96.333333 ],
    [ u"mx",u"Altar",6193,30.7,-111.816667 ],
    [ u"mx",u"Altepexi",16587,18.35,-97.316667 ],
    [ u"mx",u"Alto Lucero",4564,19.616667,-96.716667 ],
    [ u"mx",u"Altotonga",15800,19.766667,-97.233333 ],
    [ u"mx",u"Altzayanca",3353,19.433333,-97.783333 ],
    [ u"mx",u"Alvarado",21519,18.766667,-95.766667 ],
    [ u"mx",u"Álvaro Obregón",4979,14.933333,-92.416667 ],
    [ u"mx",u"Álvaro Obregón",8120,19.833333,-101.083333 ],
    [ u"mx",u"Amacuzac",5510,18.583333,-99.35 ],
    [ u"mx",u"Amatán",3742,17.35,-92.75 ],
    [ u"mx",u"Amatenango del Valle",3632,16.516667,-92.45 ],
    [ u"mx",u"Amatitán",9791,20.833333,-103.716667 ],
    [ u"mx",u"Amatlan",3539,16.316667,-96.45 ],
    [ u"mx",u"Amatlán",7634,18.833333,-96.916667 ],
    [ u"mx",u"Amaxac",7710,19.366667,-98.183333 ],
    [ u"mx",u"Amayuca",4984,18.7,-98.766667 ],
    [ u"mx",u"Amealco",7827,20.183333,-100.15 ],
    [ u"mx",u"Ameca",35869,20.55,-104.033333 ],
    [ u"mx",u"Amecac",4242,18.816667,-98.65 ],
    [ u"mx",u"Amecameca",31719,19.116667,-98.766667 ],
    [ u"mx",u"Ameyalco",5022,19.316667,-99.466667 ],
    [ u"mx",u"Amilpas",8796,16.366667,-94.616667 ],
    [ u"mx",u"Amozoc",57364,19.033333,-98.05 ],
    [ u"mx",u"Anáhuac",10696,28.5,-106.75 ],
    [ u"mx",u"Anáhuac",17181,27.233333,-100.15 ],
    [ u"mx",u"Anáhuac",13074,22.2,-97.866667 ],
    [ u"mx",u"Anenecuilco",10295,18.766667,-98.983333 ],
    [ u"mx",u"Angahuán",4864,19.55,-102.183333 ],
    [ u"mx",u"Angamacutiro",5021,20.166667,-101.683333 ],
    [ u"mx",u"Angangueo",4943,19.616667,-100.3 ],
    [ u"mx",u"Angostura",4587,25.366667,-108.183333 ],
    [ u"mx",u"Antiguo Morelos",3219,22.55,-99.083333 ],
    [ u"mx",u"Antonio Escobedo",5269,20.766667,-103.95 ],
    [ u"mx",u"Antón Lizardo",6535,19.05,-95.983333 ],
    [ u"mx",u"Antúnez",8591,19.016667,-102.2 ],
    [ u"mx",u"Apan",26386,19.716667,-98.416667 ],
    [ u"mx",u"Apango",3863,17.733333,-99.333333 ],
    [ u"mx",u"Apaseo el Alto",25577,20.45,-100.616667 ],
    [ u"mx",u"Apaseo el Grande",22636,20.566667,-100.7 ],
    [ u"mx",u"Apatlaco",12530,18.783333,-98.95 ],
    [ u"mx",u"Apatzingan",98426,19.083333,-102.35 ],
    [ u"mx",u"Apaxco",14138,19.973889,-99.173889 ],
    [ u"mx",u"Apaxtla",7413,18.15,-99.866667 ],
    [ u"mx",u"Apetatitlán",7026,19.333333,-98.183333 ],
    [ u"mx",u"Apizaco",46461,19.416667,-98.15 ],
    [ u"mx",u"Apodaca",352246,25.766667,-100.2 ],
    [ u"mx",u"Apozol",2933,21.483333,-103.1 ],
    [ u"mx",u"Aquiles Serdán",4277,17.783333,-92.283333 ],
    [ u"mx",u"Arandas",43344,20.7,-102.35 ],
    [ u"mx",u"Arcelia",16940,18.283333,-100.266667 ],
    [ u"mx",u"Ario",14585,19.2,-101.716667 ],
    [ u"mx",u"Armería",16953,18.915278,-103.969444 ],
    [ u"mx",u"Arriaga",22820,16.233333,-93.9 ],
    [ u"mx",u"Arteaga",6352,25.466667,-100.85 ],
    [ u"mx",u"Arteaga",9550,18.466667,-102.416667 ],
    [ u"mx",u"Ascensión",11781,31.1,-107.983333 ],
    [ u"mx",u"Asientos",4039,22.233333,-102.1 ],
    [ u"mx",u"Asunción Ixtaltepec",7556,16.5,-95.05 ],
    [ u"mx",u"Asunción Nochixtlán",10012,17.466667,-97.233333 ],
    [ u"mx",u"Asunción Ocotlán",3848,16.766667,-96.716667 ],
    [ u"mx",u"Atarasquillo",5660,19.325833,-99.471944 ],
    [ u"mx",u"Atempan",5284,19.85,-97.433333 ],
    [ u"mx",u"Atencingo",12910,18.516667,-98.6 ],
    [ u"mx",u"Atenco",16159,19.516667,-98.916667 ],
    [ u"mx",u"Atengo",7806,20.166667,-99.333333 ],
    [ u"mx",u"Atequiza",5579,20.4,-103.133333 ],
    [ u"mx",u"Atexcatzingo",4504,19.466667,-98.133333 ],
    [ u"mx",u"Atitalaquia",5806,20.066667,-99.216667 ],
    [ u"mx",u"Atizapán",7243,19.25,-99.55 ],
    [ u"mx",u"Atlacomulco",22247,19.798889,-99.874444 ],
    [ u"mx",u"Atlatlahuca",5380,19.066944,-99.613056 ],
    [ u"mx",u"Atlatlahucan",7554,18.933333,-98.9 ],
    [ u"mx",u"Atlatongo",4983,19.666667,-98.9 ],
    [ u"mx",u"Atlautla",10635,19.016667,-98.783333 ],
    [ u"mx",u"Atlazalpan",10062,19.216667,-98.9 ],
    [ u"mx",u"Atliaca",6766,17.65,-99.366667 ],
    [ u"mx",u"Atlixco",85894,18.966667,-98.466667 ],
    [ u"mx",u"Atotonilco el Alto",27012,20.55,-102.516667 ],
    [ u"mx",u"Atotonilco el Grande",6871,20.283333,-98.666667 ],
    [ u"mx",u"Atotonilquillo",7130,20.4,-103.133333 ],
    [ u"mx",u"Atoyac",20515,17.2,-100.433333 ],
    [ u"mx",u"Atoyac",5359,20.016667,-103.533333 ],
    [ u"mx",u"Atoyatempan",6109,18.816667,-97.916667 ],
    [ u"mx",u"Atzacán",7888,18.9,-97.083333 ],
    [ u"mx",u"Atzitzintla",3424,18.9,-97.316667 ],
    [ u"mx",u"Atzompa",4176,19.033333,-98.333333 ],
    [ u"mx",u"Autlán",42157,19.766667,-104.366667 ],
    [ u"mx",u"Autopan",30417,19.356111,-99.6625 ],
    [ u"mx",u"Axapusco",3343,19.733333,-98.75 ],
    [ u"mx",u"Axochiapan",17568,18.5,-98.766667 ],
    [ u"mx",u"Axtla",6522,21.466667,-98.85 ],
    [ u"mx",u"Ayala",6869,18.75,-98.983333 ],
    [ u"mx",u"Ayapa",4761,18.183333,-93.166667 ],
    [ u"mx",u"Ayautla",2896,18.033333,-96.666667 ],
    [ u"mx",u"Ayometla",7591,19.2,-98.2 ],
    [ u"mx",u"Ayoquezco",5302,16.683333,-96.833333 ],
    [ u"mx",u"Ayotzingo",9174,19.2,-98.933333 ],
    [ u"mx",u"Ayotzintepec",3680,17.666667,-96.133333 ],
    [ u"mx",u"Ayutla",9897,16.9,-99.216667 ],
    [ u"mx",u"Ayutla",7835,20.116667,-104.333333 ],
    [ u"mx",u"Ayutla",6749,18.55,-98.5 ],
    [ u"mx",u"Azoyú",4462,16.716667,-98.733333 ],
    [ u"mx",u"Baca",4356,21.1,-89.416667 ],
    [ u"mx",u"Bacalar",11513,18.666667,-88.383333 ],
    [ u"mx",u"Bácum",3830,27.55,-110.083333 ],
    [ u"mx",u"Badiraguato",3634,25.366667,-107.516667 ],
    [ u"mx",u"Bagojo",4395,25.866667,-109.116667 ],
    [ u"mx",u"Balancan",11895,17.8,-91.533333 ],
    [ u"mx",u"Balderas",4621,19.106944,-99.654722 ],
    [ u"mx",u"Banderilla",15757,19.583333,-96.933333 ],
    [ u"mx",u"Bañón",4137,23.183333,-102.483333 ],
    [ u"mx",u"Becal",6894,20.45,-90.033333 ],
    [ u"mx",u"Belén",5680,17.8,-92.616667 ],
    [ u"mx",u"Bellavista",6884,20.433333,-103.65 ],
    [ u"mx",u"Benemérito de las Américas",6676,16.402778,-90.633333 ],
    [ u"mx",u"Benito Juárez",6138,29.75,-107.933333 ],
    [ u"mx",u"Benito Juárez",3074,19.233333,-100.466667 ],
    [ u"mx",u"Benito Juárez",4822,19.833333,-97.75 ],
    [ u"mx",u"Benito Juárez",5123,19.366667,-97.916667 ],
    [ u"mx",u"Benito Juárez",13001,20.9,-98.2 ],
    [ u"mx",u"Benjamín Hill",5735,30.166667,-111.1 ],
    [ u"mx",u"Bermejillo",7692,25.883333,-103.616667 ],
    [ u"mx",u"Berriozábal",20952,16.8,-93.266667 ],
    [ u"mx",u"Boca del Monte",4434,19.15,-96.816667 ],
    [ u"mx",u"Boca del Río",11099,19.1,-96.1 ],
    [ u"mx",u"Bocanegra",5681,19.85,-99.1 ],
    [ u"mx",u"Bochil",10383,16.983333,-92.916667 ],
    [ u"mx",u"Bolonchen",3913,19.45,-90.166667 ],
    [ u"mx",u"Briseñas",4030,20.266667,-102.566667 ],
    [ u"mx",u"Bucerías",9037,20.75,-105.333333 ],
    [ u"mx",u"Buctzotz",7162,21.2,-88.783333 ],
    [ u"mx",u"Buenavista",7170,18.45,-99.416667 ],
    [ u"mx",u"Buenavista",9121,19.2,-102.6 ],
    [ u"mx",u"Buenavista",4468,17.6625,-92.708333 ],
    [ u"mx",u"Buenos Aires",10707,19.066667,-102.166667 ],
    [ u"mx",u"Bustamante",3543,26.533333,-100.5 ],
    [ u"mx",u"Caborca",52899,30.716667,-112.15 ],
    [ u"mx",u"Cabo San Lucas",42601,22.883333,-109.9 ],
    [ u"mx",u"Cacahoatán",14404,14.983333,-92.166667 ],
    [ u"mx",u"Cacahuatepec",3636,16.616667,-98.15 ],
    [ u"mx",u"Cacalchén",6671,20.983333,-89.233333 ],
    [ u"mx",u"Cacalomacán",10723,19.254167,-99.707222 ],
    [ u"mx",u"Cacaotepec",5774,17.133333,-96.8 ],
    [ u"mx",u"Cadereyta",67997,25.583333,-99.983333 ],
    [ u"mx",u"Cadereyta",11524,20.7,-99.816667 ],
    [ u"mx",u"Cahuacán",4729,19.639167,-99.416111 ],
    [ u"mx",u"Cajititlán",4855,20.433333,-103.316667 ],
    [ u"mx",u"Calderitas",5599,18.55,-88.25 ],
    [ u"mx",u"Calimaya",10407,19.16,-99.620833 ],
    [ u"mx",u"Calipan",4454,18.295833,-97.166667 ],
    [ u"mx",u"Calixtlahuaca",8865,19.334167,-99.691111 ],
    [ u"mx",u"Calkiní",14195,20.366667,-90.05 ],
    [ u"mx",u"Calmeca",4918,18.633333,-98.633333 ],
    [ u"mx",u"Calnalí",3600,20.916667,-98.583333 ],
    [ u"mx",u"Calpan",10402,19.1,-98.45 ],
    [ u"mx",u"Calpulalpan",29321,19.583333,-98.583333 ],
    [ u"mx",u"Caltenco",4761,18.9,-97.8 ],
    [ u"mx",u"Caltzontzín",4109,19.416667,-102 ],
    [ u"mx",u"Calvillo",19663,21.85,-102.716667 ],
    [ u"mx",u"Camalú",7425,30.85,-116.066667 ],
    [ u"mx",u"Camargo",37745,27.666667,-105.166667 ],
    [ u"mx",u"Camargo",10085,26.25,-98.833333 ],
    [ u"mx",u"Campeche",205221,19.85,-90.533333 ],
    [ u"mx",u"Campo Gobierno",20985,24.653611,-107.541111 ],
    [ u"mx",u"Campo Sesenta",6012,27.45,-110.1 ],
    [ u"mx",u"Cañada",4255,18.5,-97.283333 ],
    [ u"mx",u"Cananea",33435,30.95,-110.3 ],
    [ u"mx",u"Canatlán",10342,24.516667,-104.783333 ],
    [ u"mx",u"Cancuc",4970,16.916667,-92.483333 ],
    [ u"mx",u"Cancún",542156,21.166667,-86.833333 ],
    [ u"mx",u"Candelaria",8652,18.3,-91.35 ],
    [ u"mx",u"Cañitas",5965,23.6,-102.716667 ],
    [ u"mx",u"Canoa",14030,19.15,-98.083333 ],
    [ u"mx",u"Cansahcab",4582,21.166667,-89.1 ],
    [ u"mx",u"Capácuaro",7283,19.55,-102.05 ],
    [ u"mx",u"Capilla de Guadalupe",12445,20.833333,-102.583333 ],
    [ u"mx",u"Capula",4678,19.7,-101.8 ],
    [ u"mx",u"Capulhuac",20517,19.191389,-99.466944 ],
    [ u"mx",u"Carácuaro",3218,19.010556,-101.126389 ],
    [ u"mx",u"Cárdenas",15331,22,-99.666667 ],
    [ u"mx",u"Cárdenas",85354,17.983333,-93.366667 ],
    [ u"mx",u"Cardonal",6398,20.616667,-99.116667 ],
    [ u"mx",u"Carmen",141315,18.633333,-91.833333 ],
    [ u"mx",u"Casas Grandes",4124,30.366667,-107.95 ],
    [ u"mx",u"Casimiro Castillo",11215,19.6,-104.433333 ],
    [ u"mx",u"Castaños",20809,26.783333,-101.416667 ],
    [ u"mx",u"Castillo de Teayo",4267,20.75,-97.616667 ],
    [ u"mx",u"Catazajá",3223,17.725,-92.016667 ],
    [ u"mx",u"Catemaco",24258,18.416667,-95.116667 ],
    [ u"mx",u"Caucel",6396,21.016667,-89.716667 ],
    [ u"mx",u"Caxhuacán",3816,20.066667,-97.6 ],
    [ u"mx",u"Cazones",4001,20.716667,-97.316667 ],
    [ u"mx",u"Cedral",9475,23.8,-100.733333 ],
    [ u"mx",u"Celaya",305913,20.516667,-100.816667 ],
    [ u"mx",u"Celestún",6401,20.866667,-90.4 ],
    [ u"mx",u"Cenotillo",3176,20.966667,-88.616667 ],
    [ u"mx",u"Cerano",7860,20.116667,-101.383333 ],
    [ u"mx",u"Cerritos",13453,22.433333,-100.283333 ],
    [ u"mx",u"Cerro Azul",19633,21.2,-97.733333 ],
    [ u"mx",u"Cerro Gordo",4714,20.583333,-101.133333 ],
    [ u"mx",u"Chacaltianguis",4084,18.333333,-95.833333 ],
    [ u"mx",u"Chahuites",9837,16.283333,-94.183333 ],
    [ u"mx",u"Chalchihuites",4028,23.483333,-103.883333 ],
    [ u"mx",u"Chalco",164003,19.266667,-98.9 ],
    [ u"mx",u"Champotón",24809,19.35,-90.716667 ],
    [ u"mx",u"Chanal",5592,16.716667,-92.4 ],
    [ u"mx",u"Chapala",20323,20.3,-103.2 ],
    [ u"mx",u"Chapulco",4394,18.608333,-97.416667 ],
    [ u"mx",u"Chapulhuacán",3501,21.166667,-98.9 ],
    [ u"mx",u"Chapultepec",5828,19.199444,-99.565 ],
    [ u"mx",u"Charapán",3615,19.65,-102.25 ],
    [ u"mx",u"Charcas",11365,23.133333,-101.116667 ],
    [ u"mx",u"Charo",4689,19.75,-101.05 ],
    [ u"mx",u"Chautla",5174,18.95,-98.15 ],
    [ u"mx",u"Chavinda",6841,20.016667,-102.45 ],
    [ u"mx",u"Chemax",10596,20.65,-87.933333 ],
    [ u"mx",u"Cherán",12949,19.683333,-101.95 ],
    [ u"mx",u"Chetumal",134464,18.5,-88.3 ],
    [ u"mx",u"Chiapa",32183,16.7,-93 ],
    [ u"mx",u"Chiapa",4405,19.25,-97.766667 ],
    [ u"mx",u"Chiapilla",4141,16.516667,-92.733333 ],
    [ u"mx",u"Chiautempan",48324,19.316667,-98.183333 ],
    [ u"mx",u"Chiautla",7775,19.533333,-98.883333 ],
    [ u"mx",u"Chiautla",11511,18.283333,-98.6 ],
    [ u"mx",u"Chiautzingo",7176,19.2,-98.466667 ],
    [ u"mx",u"Chichicapam",3029,16.75,-96.483333 ],
    [ u"mx",u"Chichihualco",10391,17.683333,-99.65 ],
    [ u"mx",u"Chichimilá",4693,20.616667,-88.216667 ],
    [ u"mx",u"Chicoloapan",84444,19.416667,-98.9 ],
    [ u"mx",u"Chicomuselo",4956,15.766667,-92.266667 ],
    [ u"mx",u"Chiconautla",7844,19.620833,-99.006944 ],
    [ u"mx",u"Chiconcuac",19047,19.55,-98.9 ],
    [ u"mx",u"Chicontepec",4480,20.966667,-98.166667 ],
    [ u"mx",u"Chicxulub",3613,21.133333,-89.516667 ],
    [ u"mx",u"Chietla",6902,18.516667,-98.583333 ],
    [ u"mx",u"Chignahuapan",16138,19.833333,-98.033333 ],
    [ u"mx",u"Chignautla",9259,19.833333,-97.383333 ],
    [ u"mx",u"Chihuahua",708292,28.633333,-106.083333 ],
    [ u"mx",u"Chilac",12099,18.316667,-97.35 ],
    [ u"mx",u"Chilapa",23665,17.6,-99.166667 ],
    [ u"mx",u"Chilchota",7103,19.85,-102.133333 ],
    [ u"mx",u"Chilchotla",4348,19.25,-97.166667 ],
    [ u"mx",u"Chilón",5228,17.233333,-92.416667 ],
    [ u"mx",u"Chilpancingo",165257,17.55,-99.5 ],
    [ u"mx",u"Chiltepec",3294,17.95,-96.183333 ],
    [ u"mx",u"Chimalhuacán",590165,19.416667,-98.9 ],
    [ u"mx",u"Chimalpa",7182,19.433333,-99.35 ],
    [ u"mx",u"Chiná",4583,19.766667,-90.5 ],
    [ u"mx",u"China",9591,25.7,-99.233333 ],
    [ u"mx",u"Chinameca",7094,18.016667,-94.666667 ],
    [ u"mx",u"Chinampa",4871,21.366667,-97.733333 ],
    [ u"mx",u"Chiquilistlán",3683,20.083333,-103.85 ],
    [ u"mx",u"Chocamán",9277,19.016667,-97.016667 ],
    [ u"mx",u"Chocholá",4244,20.75,-89.833333 ],
    [ u"mx",u"Choix",7623,26.709167,-108.321944 ],
    [ u"mx",u"Cholula",8798,19.266667,-99.483333 ],
    [ u"mx",u"Cholula",79793,19.066667,-98.3 ],
    [ u"mx",u"Cholul",4716,21.016667,-89.283333 ],
    [ u"mx",u"Chontalpa",6145,17.7,-93.516667 ],
    [ u"mx",u"Chumayel",2982,20.433333,-89.316667 ],
    [ u"mx",u"Chunhuhub",5231,19.55,-88.683333 ],
    [ u"mx",u"Churintzio",3026,20.15,-102.066667 ],
    [ u"mx",u"Churumuco",4265,18.616667,-101.633333 ],
    [ u"mx",u"Ciénaga de Flores",11035,25.95,-100.183333 ],
    [ u"mx",u"Cihuatlán",16520,19.25,-104.566667 ],
    [ u"mx",u"Cintalapa",33465,16.733333,-93.716667 ],
    [ u"mx",u"Ciudad del Maíz",8456,22.4,-99.6 ],
    [ u"mx",u"Ciudad Valles",109508,21.983333,-99.016667 ],
    [ u"mx",u"Coacalco",313419,19.631667,-99.110278 ],
    [ u"mx",u"Coacoatzintla",4978,19.633333,-96.933333 ],
    [ u"mx",u"Coacotla",6428,17.933333,-94.675 ],
    [ u"mx",u"Coacoyul",5658,17.616667,-101.433333 ],
    [ u"mx",u"Coahuayana",6848,18.7,-103.658333 ],
    [ u"mx",u"Coalcomán",10715,18.783333,-103.15 ],
    [ u"mx",u"Coatepec",7604,19.135833,-99.432222 ],
    [ u"mx",u"Coatepec",5631,19.1,-97.583333 ],
    [ u"mx",u"Coatepec",48455,19.45,-96.966667 ],
    [ u"mx",u"Coatepec Harinas",7243,18.9,-99.716667 ],
    [ u"mx",u"Coatetelco",9503,18.716667,-99.333333 ],
    [ u"mx",u"Coatlan",4052,16.166667,-96.666667 ],
    [ u"mx",u"Coatlinchán",21498,19.45,-98.866667 ],
    [ u"mx",u"Coatzacoalcos",230727,18.15,-94.416667 ],
    [ u"mx",u"Coatzintla",30608,20.483333,-97.45 ],
    [ u"mx",u"Cócorit",8695,27.583333,-109.966667 ],
    [ u"mx",u"Cocotitlán",9599,19.233333,-98.866667 ],
    [ u"mx",u"Cocoyoc",9752,18.866667,-98.983333 ],
    [ u"mx",u"Cocula",4546,18.233333,-99.666667 ],
    [ u"mx",u"Cocula",14434,20.383333,-103.833333 ],
    [ u"mx",u"Coeneo",4185,19.816667,-101.583333 ],
    [ u"mx",u"Cofradía",6495,19.433333,-103.55 ],
    [ u"mx",u"Cojumatlán",6653,20.116667,-102.833333 ],
    [ u"mx",u"Colima",127239,19.233333,-103.716667 ],
    [ u"mx",u"Colón",7088,20.8,-100.05 ],
    [ u"mx",u"Colorines",7246,19.183333,-100.216667 ],
    [ u"mx",u"Colotlán",12927,22.1,-103.266667 ],
    [ u"mx",u"Comachuén",4412,19.616667,-101.9 ],
    [ u"mx",u"Comala",9117,19.316667,-103.75 ],
    [ u"mx",u"Comalcalco",40992,18.266667,-93.216667 ],
    [ u"mx",u"Comitancillo",3824,16.485278,-95.156111 ],
    [ u"mx",u"Comitan",79947,16.25,-92.133333 ],
    [ u"mx",u"Comoapan",4846,18.416667,-95.166667 ],
    [ u"mx",u"Comonfort",22300,20.716667,-100.766667 ],
    [ u"mx",u"Compostela",16162,21.233333,-104.916667 ],
    [ u"mx",u"Compuertas",4163,25.45,-108.35 ],
    [ u"mx",u"Concepción de Buenos Aires",4767,19.966667,-103.266667 ],
    [ u"mx",u"Concepción del Oro",6523,24.633333,-101.416667 ],
    [ u"mx",u"Concordia",6964,25.783333,-103.116667 ],
    [ u"mx",u"Concordia",7560,23.283333,-106.066667 ],
    [ u"mx",u"Conkal",6395,21.066667,-89.533333 ],
    [ u"mx",u"Constancia",5836,24.223056,-107.186944 ],
    [ u"mx",u"Constitución",39915,25.036944,-111.664444 ],
    [ u"mx",u"Contepec",3623,20.016667,-100.116667 ],
    [ u"mx",u"Contla",24569,19.197222,-98.2 ],
    [ u"mx",u"Copainalá",6365,17.083333,-93.2 ],
    [ u"mx",u"Copala",6875,16.65,-98.983333 ],
    [ u"mx",u"Copalillo",5993,18.033333,-99.116667 ],
    [ u"mx",u"Copándaro",3498,19.883333,-101.216667 ],
    [ u"mx",u"Copoya",5287,16.716667,-93.083333 ],
    [ u"mx",u"Coquimatlán",13061,19.2,-103.8 ],
    [ u"mx",u"Córdoba",134409,18.883333,-96.933333 ],
    [ u"mx",u"Coroneo",3177,20.133333,-100.333333 ],
    [ u"mx",u"Corral Nuevo",4547,18.133333,-95.15 ],
    [ u"mx",u"Cortazar",56363,20.483333,-100.933333 ],
    [ u"mx",u"Cosalá",5910,24.4125,-106.690833 ],
    [ u"mx",u"Cosamaloapan",28773,18.366667,-95.8 ],
    [ u"mx",u"Cosautlán",4575,19.333333,-96.983333 ],
    [ u"mx",u"Coscomatepec",12920,19.066667,-97.033333 ],
    [ u"mx",u"Cosío",4591,22.35,-102.3 ],
    [ u"mx",u"Cosolapa",7996,18.583333,-96.65 ],
    [ u"mx",u"Cosolapa",7996,18.608333,-96.675 ],
    [ u"mx",u"Cosoleacaque",20372,18,-94.616667 ],
    [ u"mx",u"Costa Rica",21665,24.5875,-107.3875 ],
    [ u"mx",u"Cotija",13939,19.816667,-102.683333 ],
    [ u"mx",u"Coxcatlán",5830,18.266667,-97.15 ],
    [ u"mx",u"Coxquihui",3716,20.183333,-97.583333 ],
    [ u"mx",u"Coyotepec",35795,19.775,-99.207222 ],
    [ u"mx",u"Coyotepec",3114,16.976944,-96.699167 ],
    [ u"mx",u"Coyuca",12487,17.033333,-100.066667 ],
    [ u"mx",u"Coyula",5408,20.633333,-103.2 ],
    [ u"mx",u"Coyutla",7939,20.241667,-97.65 ],
    [ u"mx",u"Cozumel",73938,20.508333,-86.945833 ],
    [ u"mx",u"Creel",5011,27.75,-107.633333 ],
    [ u"mx",u"Cristóbal Obregón",4242,16.35,-93.533333 ],
    [ u"mx",u"Cruz Grande",9876,16.733333,-99.133333 ],
    [ u"mx",u"Cuacnopalan",7888,18.816667,-97.5 ],
    [ u"mx",u"Cuajinicuilapa",9390,16.466667,-98.416667 ],
    [ u"mx",u"Cuanajo",5110,19.483333,-101.516667 ],
    [ u"mx",u"Cuanala",5230,19.1,-98.316667 ],
    [ u"mx",u"Cuapiaxtla",5781,18.916667,-97.816667 ],
    [ u"mx",u"Cuapiaxtla",7147,19.3,-97.766667 ],
    [ u"mx",u"Cuauhtémoc",90839,28.416667,-106.866667 ],
    [ u"mx",u"Cuauhtémoc",8986,19.333333,-103.6 ],
    [ u"mx",u"Cuauhtémoc",5924,22.533333,-98.15 ],
    [ u"mx",u"Cuauhtémoc",9426,22.183333,-97.833333 ],
    [ u"mx",u"Cuauhtenco",6674,19.250556,-99.733611 ],
    [ u"mx",u"Cuautepec",3483,16.7,-99 ],
    [ u"mx",u"Cuautepec",16543,20.033333,-98.3 ],
    [ u"mx",u"Cuautitlán",84741,19.671111,-99.182778 ],
    [ u"mx",u"Cuautitlán Izcalli",475199,19.646944,-99.246667 ],
    [ u"mx",u"Cuautla",146186,18.8,-98.95 ],
    [ u"mx",u"Cuautlalpan",8176,19.686667,-99.286944 ],
    [ u"mx",u"Cuautlancingo",17729,19.083333,-98.266667 ],
    [ u"mx",u"Cuautlapan",6928,18.866667,-97.033333 ],
    [ u"mx",u"Cuayucatepec",8699,18.5,-97.483333 ],
    [ u"mx",u"Cuencamé",8876,24.871111,-103.696389 ],
    [ u"mx",u"Cuerámaro",13937,20.616667,-101.716667 ],
    [ u"mx",u"Cuernavaca",343785,18.916667,-99.25 ],
    [ u"mx",u"Cuervos",8481,32.669722,-114.804444 ],
    [ u"mx",u"Cuetzalan",5785,20.033333,-97.516667 ],
    [ u"mx",u"Cuicatlan",3877,17.8,-96.966667 ],
    [ u"mx",u"Cuichapa",8268,18.766667,-96.866667 ],
    [ u"mx",u"Cuilápam",10782,17,-96.766667 ],
    [ u"mx",u"Cuitareo",4300,19.616667,-100.6 ],
    [ u"mx",u"Cuitláhuac",12331,18.816667,-96.716667 ],
    [ u"mx",u"Cuitzeo",5172,20.333333,-102.783333 ],
    [ u"mx",u"Cuitzeo",9057,19.983333,-101.15 ],
    [ u"mx",u"Culiacancito",4201,24.824722,-107.533056 ],
    [ u"mx",u"Culiacán",582489,24.799444,-107.389722 ],
    [ u"mx",u"Cúmpas",2979,29.983333,-109.783333 ],
    [ u"mx",u"Cunduacán",17904,18.066667,-93.166667 ],
    [ u"mx",u"Cutzamala",5057,18.466667,-100.566667 ],
    [ u"mx",u"Cuyutlán",5644,20.416667,-103.4 ],
    [ u"mx",u"Cuzamá",3459,20.733333,-89.316667 ],
    [ u"mx",u"Degollado",10753,20.466667,-102.15 ],
    [ u"mx",u"Delicias",102974,28.2,-105.5 ],
    [ u"mx",u"Delta",5698,32.355,-115.193056 ],
    [ u"mx",u"Doctor Arroyo",8435,23.666667,-100.183333 ],
    [ u"mx",u"Doctor Mora",4431,21.141667,-100.3125 ],
    [ u"mx",u"Dolores Hidalgo",55140,21.156111,-100.930833 ],
    [ u"mx",u"Domingo Arenas",5812,19.15,-98.433333 ],
    [ u"mx",u"Doxey",6339,20.083333,-99.233333 ],
    [ u"mx",u"Duarte",5969,21.083333,-101.516667 ],
    [ u"mx",u"Dulce Grande",5426,23,-102.166667 ],
    [ u"mx",u"Durango",457154,24.033333,-104.666667 ],
    [ u"mx",u"Dzan",4532,20.383333,-89.466667 ],
    [ u"mx",u"Dzemul",3072,21.2,-89.3 ],
    [ u"mx",u"Dzidzantún",8301,21.25,-89.05 ],
    [ u"mx",u"Dzilam González",5941,21.283333,-88.933333 ],
    [ u"mx",u"Dzitás",2909,20.85,-88.516667 ],
    [ u"mx",u"Dzitbalché",10902,20.316667,-90.05 ],
    [ u"mx",u"Ébano",21258,22.216667,-98.4 ],
    [ u"mx",u"Ébano",21258,22.216667,-98.383333 ],
    [ u"mx",u"Ecatepec",1806297,19.601111,-99.0525 ],
    [ u"mx",u"Ecatzingo",6373,18.933333,-98.75 ],
    [ u"mx",u"Ecuandureo",5098,20.166667,-102.183333 ],
    [ u"mx",u"Ejido Hermosillo",6399,32.510278,-114.923333 ],
    [ u"mx",u"Ejutla de Crespo",8117,16.566667,-96.733333 ],
    [ u"mx",u"El Arenal",3318,20.233333,-98.9 ],
    [ u"mx",u"El Arenal",10309,20.783333,-103.7 ],
    [ u"mx",u"El Bosque",4158,17.066667,-92.733333 ],
    [ u"mx",u"El Burrión",4169,25.533333,-108.4 ],
    [ u"mx",u"El Carrizo",4931,24.026111,-106.881389 ],
    [ u"mx",u"El Castillo",4107,19.533333,-96.85 ],
    [ u"mx",u"El Colomo",10908,19.05,-104.25 ],
    [ u"mx",u"El Colorado",4572,20.566667,-100.25 ],
    [ u"mx",u"El Coyote",8856,25.7,-103.266667 ],
    [ u"mx",u"Eldorado",14136,24.320278,-107.360278 ],
    [ u"mx",u"El Espinal",7616,16.333333,-94.066667 ],
    [ u"mx",u"El Fuerte",11171,26.418889,-108.619444 ],
    [ u"mx",u"El Grullo",21031,19.8,-104.216667 ],
    [ u"mx",u"El Higo",8175,21.766667,-98.466667 ],
    [ u"mx",u"El Limón",3312,19.816667,-104.183333 ],
    [ u"mx",u"El Llano",11794,20.047222,-99.3 ],
    [ u"mx",u"El Mante",79985,22.733333,-98.966667 ],
    [ u"mx",u"El Naranjo",9458,21.466667,-98.6 ],
    [ u"mx",u"El Ocotito",5983,17.25,-99.566667 ],
    [ u"mx",u"El Oro",6805,19.8,-100.133333 ],
    [ u"mx",u"El Pueblito",47203,20.533333,-100.45 ],
    [ u"mx",u"El Quince",11878,20.533333,-103.283333 ],
    [ u"mx",u"El Refugio",5694,20.666667,-103.733333 ],
    [ u"mx",u"El Rosario",14577,24.255556,-107.182778 ],
    [ u"mx",u"El Salto",22553,20.333333,-104.5 ],
    [ u"mx",u"El Sauzal",9085,31.9,-116.683333 ],
    [ u"mx",u"El Sauz",6569,20.466667,-100.1 ],
    [ u"mx",u"El Tejar",10511,19.05,-96.166667 ],
    [ u"mx",u"El Verde",7556,20.55,-103.266667 ],
    [ u"mx",u"Emiliano Zapata",8555,19.658333,-98.541667 ],
    [ u"mx",u"Emiliano Zapata",37726,18.833333,-99.183333 ],
    [ u"mx",u"Emiliano Zapata",18608,17.75,-91.766667 ],
    [ u"mx",u"Emilio Carranza",5887,19.966667,-96.6 ],
    [ u"mx",u"Empalme",38601,27.966667,-110.816667 ],
    [ u"mx",u"Encarnacion",21861,21.516667,-102.233333 ],
    [ u"mx",u"Ensenada",256577,31.866667,-116.616667 ],
    [ u"mx",u"Enthavi",4810,19.490833,-99.575833 ],
    [ u"mx",u"Escalerillas",4124,22.133333,-101.066667 ],
    [ u"mx",u"Escárcega",28165,18.616667,-90.716667 ],
    [ u"mx",u"Escuinapa",28249,22.85,-105.8 ],
    [ u"mx",u"Escuintla",8989,15.333333,-92.633333 ],
    [ u"mx",u"Esperanza",8190,18.866667,-97.4 ],
    [ u"mx",u"Espita",9960,21.016667,-88.316667 ],
    [ u"mx",u"Esqueda",6119,30.716667,-109.583333 ],
    [ u"mx",u"Estación Coahuila",7596,32.193889,-115.001667 ],
    [ u"mx",u"Etchojoa",8571,26.916667,-109.633333 ],
    [ u"mx",u"Etchoropo",4360,26.766667,-109.666667 ],
    [ u"mx",u"Etla",7327,17.060833,-96.794444 ],
    [ u"mx",u"Etzatlán",13183,20.766667,-104.083333 ],
    [ u"mx",u"Ezequiel Montes",12443,20.666667,-99.883333 ],
    [ u"mx",u"Felipe Carrillo Puerto",23109,19.583333,-88.05 ],
    [ u"mx",u"Fernández",29672,21.95,-100 ],
    [ u"mx",u"Filomeno Mata",8973,20.2,-97.7 ],
    [ u"mx",u"Fortín",20668,18.9,-97 ],
    [ u"mx",u"Fresnillo",105492,23.166667,-102.883333 ],
    [ u"mx",u"Frontera Comalapa",14917,15.65,-92.133333 ],
    [ u"mx",u"Frontera",64979,26.933333,-101.45 ],
    [ u"mx",u"Frontera",22621,18.425,-92.833333 ],
    [ u"mx",u"Frontera Hidalgo",3364,14.783333,-92.166667 ],
    [ u"mx",u"Gabriel Leyva Solano",27537,25.666667,-108.641667 ],
    [ u"mx",u"Galeana",6292,24.833333,-100.066667 ],
    [ u"mx",u"Garcia",26950,25.816667,-100.583333 ],
    [ u"mx",u"Garza García",130652,25.666667,-100.4 ],
    [ u"mx",u"General Bravo",4073,25.8,-99.166667 ],
    [ u"mx",u"General Cepeda",3916,25.383333,-101.45 ],
    [ u"mx",u"General Escobedo",308284,25.816667,-100.333333 ],
    [ u"mx",u"General Terán",7487,25.266667,-99.683333 ],
    [ u"mx",u"General Zuazua",5663,25.9,-100.116667 ],
    [ u"mx",u"Gómez Palacio",228585,25.566667,-103.5 ],
    [ u"mx",u"González",11098,22.8,-98.7 ],
    [ u"mx",u"Graciano Sánchez",4411,23.916667,-99.283333 ],
    [ u"mx",u"Guadalajara",1640649,20.666667,-103.333333 ],
    [ u"mx",u"Guadalupe",5169,15.7,-92.166667 ],
    [ u"mx",u"Guadalupe",724949,25.683333,-100.25 ],
    [ u"mx",u"Guadalupe",94110,22.75,-102.516667 ],
    [ u"mx",u"Guadalupe Victoria",18244,32.286944,-115.105 ],
    [ u"mx",u"Guadalupe Victoria",14269,24.449722,-104.1225 ],
    [ u"mx",u"Guadalupe Victoria",9272,19.291667,-97.345833 ],
    [ u"mx",u"Guadalupe y Calvo",3230,26.1,-106.966667 ],
    [ u"mx",u"Guamúchil",59279,25.366667,-108.366667 ],
    [ u"mx",u"Guanajuato",78368,21.016667,-101.25 ],
    [ u"mx",u"Guasave",68452,25.566667,-108.45 ],
    [ u"mx",u"Guaymas",103454,27.933333,-110.9 ],
    [ u"mx",u"Guelavia",3014,16.783333,-96.333333 ],
    [ u"mx",u"Guerrero",4384,26.783333,-99.333333 ],
    [ u"mx",u"Guerrero Negro",11479,27.976944,-114.061111 ],
    [ u"mx",u"Guichicovi",4371,16.966667,-95.1 ],
    [ u"mx",u"Gustavo Díaz Ordaz",12698,26.233333,-98.583333 ],
    [ u"mx",u"Gutiérrez Zamora",14735,20.45,-97.083333 ],
    [ u"mx",u"Halachó",9165,20.483333,-90.083333 ],
    [ u"mx",u"Hecelchakán",10153,20.166667,-90.133333 ],
    [ u"mx",u"Hermosillo",595833,29.066667,-110.966667 ],
    [ u"mx",u"Hidalgo",54996,19.683333,-100.566667 ],
    [ u"mx",u"Hidalgo",15227,25.8425,-99.616111 ],
    [ u"mx",u"Hidalgo",4810,26.05,-98.2 ],
    [ u"mx",u"Hidalgo",5802,19.966667,-96.866667 ],
    [ u"mx",u"Hidalgotitlán",3770,17.783333,-94.633333 ],
    [ u"mx",u"Higuerón",4603,18.583333,-99.166667 ],
    [ u"mx",u"Hocabá",3866,20.816667,-89.25 ],
    [ u"mx",u"Hoctún",4916,20.866667,-89.2 ],
    [ u"mx",u"Homún",5423,20.733333,-89.283333 ],
    [ u"mx",u"Hopelchén",7021,19.766667,-89.85 ],
    [ u"mx",u"Hostotipaquillo",3189,21.066667,-104.066667 ],
    [ u"mx",u"Huajuapan",47846,17.8,-97.766667 ],
    [ u"mx",u"Hualahuises",5439,24.884722,-99.673333 ],
    [ u"mx",u"Huamantla",45905,19.315278,-97.925 ],
    [ u"mx",u"Huamuxtitlán",5921,17.816667,-98.566667 ],
    [ u"mx",u"Huandacareo",6877,19.983333,-101.283333 ],
    [ u"mx",u"Huanímaro",4965,20.366667,-101.5 ],
    [ u"mx",u"Huaquechula",3380,18.766667,-98.55 ],
    [ u"mx",u"Huatabampo",30428,26.833333,-109.633333 ],
    [ u"mx",u"Huatulco",5472,15.843611,-96.326667 ],
    [ u"mx",u"Huatusco",29389,19.15,-96.95 ],
    [ u"mx",u"Huauchinango",49853,20.183333,-98.05 ],
    [ u"mx",u"Huautla",3407,21.033333,-98.283333 ],
    [ u"mx",u"Huautla",9972,18.133333,-96.85 ],
    [ u"mx",u"Huaxpaltepec",4212,16.316667,-97.933333 ],
    [ u"mx",u"Huayapam",3630,17.1,-96.666667 ],
    [ u"mx",u"Huazolotitlan",4506,16.283333,-97.933333 ],
    [ u"mx",u"Huehuetán",7265,15.016667,-92.366667 ],
    [ u"mx",u"Huehuetoca",6951,19.848889,-99.204167 ],
    [ u"mx",u"Huejotzingo",21763,19.15,-98.4 ],
    [ u"mx",u"Huejúcar",3551,22.35,-103.216667 ],
    [ u"mx",u"Huejuquilla el Alto",4640,22.6,-103.866667 ],
    [ u"mx",u"Huejutla",38491,21.133333,-98.416667 ],
    [ u"mx",u"Huetamo",21899,18.583333,-100.883333 ],
    [ u"mx",u"Hueyapan",6353,18.866667,-98.666667 ],
    [ u"mx",u"Hueyapan",3541,18.116667,-95.15 ],
    [ u"mx",u"Hueyotlipan",4921,18.9,-97.85 ],
    [ u"mx",u"Hueyotlipan",4798,19.483333,-98.35 ],
    [ u"mx",u"Hueypoxtla",3566,19.908333,-99.08 ],
    [ u"mx",u"Hueytamalco",4255,19.95,-97.266667 ],
    [ u"mx",u"Hueytamalco",4255,19.941667,-97.275 ],
    [ u"mx",u"Huhí",4367,20.716667,-89.166667 ],
    [ u"mx",u"Huichapan",8035,20.383333,-99.65 ],
    [ u"mx",u"Huilango",15551,19.686944,-99.25 ],
    [ u"mx",u"Huiloac",5247,19.4,-98.15 ],
    [ u"mx",u"Huiloapan",3780,18.75,-97.316667 ],
    [ u"mx",u"Huimanguillo",26602,17.85,-93.383333 ],
    [ u"mx",u"Huimilpan",3434,20.366667,-100.283333 ],
    [ u"mx",u"Huitziltepec",4419,17.816667,-99.466667 ],
    [ u"mx",u"Huitzo",4743,17.25,-96.866667 ],
    [ u"mx",u"Huitzuco",16238,18.3,-99.35 ],
    [ u"mx",u"Huixquilucan",124852,19.360278,-99.351389 ],
    [ u"mx",u"Huixtepec",8785,16.833333,-96.766667 ],
    [ u"mx",u"Huixtla",29257,15.15,-92.466667 ],
    [ u"mx",u"Hunucmá",22288,21.016667,-89.866667 ],
    [ u"mx",u"Ignacio de la Llave",4888,18.716667,-95.983333 ],
    [ u"mx",u"Ignacio Zaragoza",3455,28.383333,-107.216667 ],
    [ u"mx",u"Iguala",112111,18.35,-99.533333 ],
    [ u"mx",u"Imuris",6117,30.783333,-110.866667 ],
    [ u"mx",u"Indaparapeo",6907,19.783333,-100.966667 ],
    [ u"mx",u"Irámuco",6559,19.95,-100.916667 ],
    [ u"mx",u"Irapuato",339568,20.683333,-101.35 ],
    [ u"mx",u"Irimbo",2927,19.7,-100.479167 ],
    [ u"mx",u"Isla Aguada",4440,18.783333,-91.466667 ],
    [ u"mx",u"Isla del Bosque",5156,22.733333,-105.85 ],
    [ u"mx",u"Isla",24558,18.6,-96.15 ],
    [ u"mx",u"Isla Mujeres",12491,21.2,-86.716667 ],
    [ u"mx",u"Itzican",4713,20.333333,-102.95 ],
    [ u"mx",u"Itzincab",5013,20.916667,-89.7 ],
    [ u"mx",u"Ixcaquixtla",4716,18.45,-97.816667 ],
    [ u"mx",u"Ixcatepec",3655,21.216667,-98 ],
    [ u"mx",u"Ixcatlan",3273,18.15,-96.5 ],
    [ u"mx",u"Ixhuatan",3392,17.283333,-93.033333 ],
    [ u"mx",u"Ixhuatán",5654,16.356944,-94.4825 ],
    [ u"mx",u"Ixhuatlancillo",4680,18.9,-97.15 ],
    [ u"mx",u"Ixil",3375,21.15,-89.483333 ],
    [ u"mx",u"Ixmiquilpan",32475,20.483333,-99.233333 ],
    [ u"mx",u"Ixtacomitán",4478,17.416667,-93.1 ],
    [ u"mx",u"Ixtacuixtla",6160,19.333333,-98.366667 ],
    [ u"mx",u"Ixtaczoquitlán",23522,18.85,-97.066667 ],
    [ u"mx",u"Ixtapa",4559,16.8,-92.916667 ],
    [ u"mx",u"Ixtapa",5207,17.666667,-101.65 ],
    [ u"mx",u"Ixtapa",18717,20.7,-105.2 ],
    [ u"mx",u"Ixtapaluca",351015,19.316667,-98.883333 ],
    [ u"mx",u"Ixtenco",6304,19.25,-97.893056 ],
    [ u"mx",u"Ixtepec",23151,16.578056,-95.101389 ],
    [ u"mx",u"Ixtiyucan",6513,19.183333,-97.816667 ],
    [ u"mx",u"Ixtlahuacán de los Membrillos",5539,20.35,-103.183333 ],
    [ u"mx",u"Ixtlahuacán del Río",6000,20.866667,-103.25 ],
    [ u"mx",u"Ixtlán del Río",21646,21.033333,-104.366667 ],
    [ u"mx",u"Ixtlán",5017,20.183333,-102.4 ],
    [ u"mx",u"Izamal",14954,20.933333,-89.016667 ],
    [ u"mx",u"Jacala",3908,21.016667,-99.183333 ],
    [ u"mx",u"Jacona",48984,19.95,-102.266667 ],
    [ u"mx",u"Jajalpa",6012,19.133333,-99.516667 ],
    [ u"mx",u"Jalacingo",10216,19.8,-97.3 ],
    [ u"mx",u"Jala",9179,21.083333,-104.433333 ],
    [ u"mx",u"Jalapa",8289,16.5,-95.466667 ],
    [ u"mx",u"Jalapa",5025,17.725,-92.808333 ],
    [ u"mx",u"Jalapilla",5561,18.833333,-97.083333 ],
    [ u"mx",u"Jalcocotán",4370,21.466667,-105.116667 ],
    [ u"mx",u"Jalostotitlán",22407,21.2,-102.466667 ],
    [ u"mx",u"Jalpa",15320,18.133333,-93.083333 ],
    [ u"mx",u"Jalpa",13686,21.633333,-102.966667 ],
    [ u"mx",u"Jalpan",9291,21.233333,-99.483333 ],
    [ u"mx",u"Jaltenango",8880,15.916667,-92.716667 ],
    [ u"mx",u"Jaltenco",9603,19.750556,-99.095556 ],
    [ u"mx",u"Jaltepec",5275,19.733333,-98.633333 ],
    [ u"mx",u"Jáltipan",28525,17.966667,-94.7 ],
    [ u"mx",u"Jaltocán",5641,21.15,-98.533333 ],
    [ u"mx",u"Jamapa",3815,19.033333,-96.233333 ],
    [ u"mx",u"Jamay",16310,20.3,-102.716667 ],
    [ u"mx",u"Jamiltepec",9928,16.283333,-97.816667 ],
    [ u"mx",u"Jantetelco",4514,18.7,-98.766667 ],
    [ u"mx",u"Jaral del Progreso",17748,20.366667,-101.066667 ],
    [ u"mx",u"Jaumave",4421,23.416667,-99.383333 ],
    [ u"mx",u"Jerécuaro",7050,20.15,-100.516667 ],
    [ u"mx",u"Jerez",37835,22.65,-103 ],
    [ u"mx",u"Jesús Carranza",3615,17.433333,-95.033333 ],
    [ u"mx",u"Jesús del Monte",9649,19.108056,-99.994444 ],
    [ u"mx",u"Jesús María",8264,20.666667,-104.266667 ],
    [ u"mx",u"Jicayan",4405,16.416667,-97.983333 ],
    [ u"mx",u"Jilotepec",11641,19.916944,-99.565833 ],
    [ u"mx",u"Jilotepec",3219,19.6,-96.933333 ],
    [ u"mx",u"Jilotzingo",5065,19.539444,-99.400833 ],
    [ u"mx",u"Jiménez",31055,28.333333,-105.4 ],
    [ u"mx",u"Jiquilpan",25621,19.983333,-102.716667 ],
    [ u"mx",u"Jiquipilas",8951,16.666667,-93.65 ],
    [ u"mx",u"Jitotol",3278,17.033333,-92.866667 ],
    [ u"mx",u"Jiutepec",166340,18.866667,-99.183333 ],
    [ u"mx",u"Jocotepec",16459,20.3,-103.433333 ],
    [ u"mx",u"Jocotitlán",7610,19.705833,-99.787778 ],
    [ u"mx",u"Jojutla",20540,18.616667,-99.183333 ],
    [ u"mx",u"Jolalpan",7301,18.325,-98.841667 ],
    [ u"mx",u"Jonacatepec",8252,18.683333,-98.8 ],
    [ u"mx",u"Jonuta",6483,18.083333,-92.133333 ],
    [ u"mx",u"Joquicingo",4206,19.05,-99.466667 ],
    [ u"mx",u"Juanacatlán",8542,20.516667,-103.166667 ],
    [ u"mx",u"Juan Aldama",14162,24.290833,-103.394444 ],
    [ u"mx",u"Juárez",6839,17.65,-93.15 ],
    [ u"mx",u"Juárez",6210,24.820556,-104.0275 ],
    [ u"mx",u"Juarez",1403025,31.733333,-106.483333 ],
    [ u"mx",u"Juárez",14228,25.65,-100.083333 ],
    [ u"mx",u"Juchipila",6700,21.416667,-103.116667 ],
    [ u"mx",u"Juchitan",67640,16.433333,-95.016667 ],
    [ u"mx",u"Juchitepec",14870,19.1,-98.883333 ],
    [ u"mx",u"Juchitlán",3717,20.083333,-104.116667 ],
    [ u"mx",u"Jungapeo",5189,19.45,-100.483333 ],
    [ u"mx",u"Juquila",5318,16.233333,-97.3 ],
    [ u"mx",u"Juventino Rosas",38199,20.65,-101 ],
    [ u"mx",u"Juxtlahuaca",8309,17.333333,-98.016667 ],
    [ u"mx",u"Kanasín",40027,20.933333,-89.566667 ],
    [ u"mx",u"Kantunil",3414,20.8,-89.033333 ],
    [ u"mx",u"Kantunilkin",7205,21.091667,-87.45 ],
    [ u"mx",u"Kinchil",5634,20.916667,-89.95 ],
    [ u"mx",u"La Aldea",5171,20.9,-101.483333 ],
    [ u"mx",u"La Antigua",18070,19.333333,-96.3 ],
    [ u"mx",u"La Barca",34450,20.283333,-102.566667 ],
    [ u"mx",u"La Calera",5570,20.783333,-101.316667 ],
    [ u"mx",u"La Cañada",10089,20.616667,-100.316667 ],
    [ u"mx",u"La Ceiba",10190,20.766667,-97.766667 ],
    [ u"mx",u"La Concepción los Baños",6503,19.681944,-99.856944 ],
    [ u"mx",u"La Concordia",7423,16.083333,-92.633333 ],
    [ u"mx",u"La Cruz",11900,23.916667,-106.9 ],
    [ u"mx",u"La Ermita",5054,20.413889,-101.993611 ],
    [ u"mx",u"La Estancia",5579,20.416667,-100.066667 ],
    [ u"mx",u"Lagos de Moreno",84681,21.35,-101.916667 ],
    [ u"mx",u"Lagunillas",3793,21.033333,-104.533333 ],
    [ u"mx",u"La Huacana",9351,18.966667,-101.816667 ],
    [ u"mx",u"La Huerta",7601,19.466667,-104.65 ],
    [ u"mx",u"La Joya",19024,32.516667,-116.616667 ],
    [ u"mx",u"La Joya",13158,18.666667,-99.466667 ],
    [ u"mx",u"La Libertad",4393,14.591111,-92.193611 ],
    [ u"mx",u"La Lira",5328,20.466667,-100.15 ],
    [ u"mx",u"La Llave",5644,20.466667,-99.997222 ],
    [ u"mx",u"La Mira",14536,18.683333,-102.283333 ],
    [ u"mx",u"La Moncada",4730,20.266667,-100.8 ],
    [ u"mx",u"Lampazos de Naranjo",5104,27.016667,-100.516667 ],
    [ u"mx",u"La Orilla",16178,17.983333,-102.233333 ],
    [ u"mx",u"La Palma",8022,24.581944,-107.210833 ],
    [ u"mx",u"La Paz",171490,24.166667,-110.3 ],
    [ u"mx",u"La Perla",3249,18.925,-97.141667 ],
    [ u"mx",u"La Piedad",70241,20.35,-102 ],
    [ u"mx",u"La Pila",5149,22.05,-100.866667 ],
    [ u"mx",u"La Poza",16286,20.116667,-96.966667 ],
    [ u"mx",u"La Presa",4003,22.343889,-105.3925 ],
    [ u"mx",u"La Reforma",6145,24.697222,-99.539167 ],
    [ u"mx",u"La Reforma",6943,25.083333,-108.05 ],
    [ u"mx",u"Las Choapas",40306,17.904167,-94.095833 ],
    [ u"mx",u"Las Choapas",40306,17.933333,-94.083333 ],
    [ u"mx",u"Las Guacamayas",39448,18.016667,-102.216667 ],
    [ u"mx",u"Las Juntas",6259,19.416667,-104.7 ],
    [ u"mx",u"Las Margaritas",16201,16.316667,-91.983333 ],
    [ u"mx",u"Las Rosas",16752,16.4,-92.383333 ],
    [ u"mx",u"Las Varas",12837,21.166667,-105.166667 ],
    [ u"mx",u"Las Vigas",8037,19.633333,-97.083333 ],
    [ u"mx",u"La Tijera",5691,19.9,-104.4 ],
    [ u"mx",u"La Trinidad",4385,25.733333,-108.483333 ],
    [ u"mx",u"La Trinitaria",6655,16.116667,-92.05 ],
    [ u"mx",u"La Unión",3189,17.966667,-101.816667 ],
    [ u"mx",u"La Unión",5006,26.816667,-109.6 ],
    [ u"mx",u"La Venta del Astillero",4491,20.716667,-103.533333 ],
    [ u"mx",u"Lázaro Cárdenas",84005,17.958333,-102.2 ],
    [ u"mx",u"Leona Vicario",5731,20.966667,-87.191667 ],
    [ u"mx",u"León",1114662,21.116667,-101.666667 ],
    [ u"mx",u"Lerdo",63533,25.533333,-103.533333 ],
    [ u"mx",u"Lerma",18145,19.285,-99.515556 ],
    [ u"mx",u"Libres",13326,19.466667,-97.683333 ],
    [ u"mx",u"Linares",57731,24.857778,-99.567778 ],
    [ u"mx",u"Lo Arado",4005,19.616667,-104.583333 ],
    [ u"mx",u"Loma Bonita",30357,18.1,-95.883333 ],
    [ u"mx",u"Lombardía",11417,19.15,-102.033333 ],
    [ u"mx",u"López Mateos",521056,19.558333,-99.261389 ],
    [ u"mx",u"Loreto",19779,22.25,-102.008333 ],
    [ u"mx",u"Loreto",11227,26.016667,-111.35 ],
    [ u"mx",u"Loreto",19779,22.266667,-101.966667 ],
    [ u"mx",u"Los Altos",4771,21.516667,-97.766667 ],
    [ u"mx",u"Los Mochis",214610,25.766667,-108.966667 ],
    [ u"mx",u"Los Reyes Acozac",22133,19.766667,-98.983333 ],
    [ u"mx",u"Los Reyes",3681,19.808333,-98.248611 ],
    [ u"mx",u"Los Reyes",251179,19.35,-98.966667 ],
    [ u"mx",u"Los Reyes",37441,19.733333,-100.266667 ],
    [ u"mx",u"Los Zacatones",5913,22.95,-102.05 ],
    [ u"mx",u"Luis Gil Pérez",5489,17.866667,-93.05 ],
    [ u"mx",u"Luis Moya",5856,22.416667,-102.25 ],
    [ u"mx",u"Luvianos",9247,18.916667,-100.4 ],
    [ u"mx",u"Macultepec",6430,18.166667,-92.833333 ],
    [ u"mx",u"Macuspana",30410,17.766667,-92.6 ],
    [ u"mx",u"Madera",16087,29.2,-108.116667 ],
    [ u"mx",u"Madrid",4411,19.083333,-103.866667 ],
    [ u"mx",u"Magdalena",14177,20.916667,-103.95 ],
    [ u"mx",u"Magdalena Teitipac",3777,16.916667,-96.6 ],
    [ u"mx",u"Magdalena Tequisistlán",3890,16.406667,-95.609167 ],
    [ u"mx",u"Malacatepec",4234,18.933333,-98.3 ],
    [ u"mx",u"Malinalco",7220,18.95,-99.5 ],
    [ u"mx",u"Maltrata",10496,18.8,-97.266667 ],
    [ u"mx",u"Mamá",2823,20.483333,-89.366667 ],
    [ u"mx",u"Maneadero",17861,31.716667,-116.566667 ],
    [ u"mx",u"Maní",3978,20.383333,-89.4 ],
    [ u"mx",u"Manuel Doblado",13218,20.733333,-101.933333 ],
    [ u"mx",u"Manzanillo",110738,19.05,-104.333333 ],
    [ u"mx",u"Mapastepec",16082,15.433333,-92.9 ],
    [ u"mx",u"Mapimí",4548,25.816667,-103.85 ],
    [ u"mx",u"Maravatío",3955,20.166667,-101 ],
    [ u"mx",u"Maravatío",30413,19.9,-100.45 ],
    [ u"mx",u"Marfil",15241,21,-101.283333 ],
    [ u"mx",u"Margaritas",8579,22,-102.3 ],
    [ u"mx",u"Mariano Escobedo",3052,18.916667,-97.116667 ],
    [ u"mx",u"Marín",3299,25.866667,-100.05 ],
    [ u"mx",u"Marquelia",6874,16.583333,-98.816667 ],
    [ u"mx",u"Mascota",8322,20.516667,-104.783333 ],
    [ u"mx",u"Matamoros",46284,25.533333,-103.25 ],
    [ u"mx",u"Matamoros",435159,25.883333,-97.5 ],
    [ u"mx",u"Matatlan",3064,16.866667,-96.383333 ],
    [ u"mx",u"Matehuala",67720,23.65,-100.65 ],
    [ u"mx",u"Matías Romero",21064,16.883333,-95.033333 ],
    [ u"mx",u"Maxcanú",11930,20.583333,-89.983333 ],
    [ u"mx",u"Mazamitla",6615,19.916667,-103.033333 ],
    [ u"mx",u"Mazatán",5938,14.866667,-92.45 ],
    [ u"mx",u"Mazatecochco",8960,19.176389,-98.186111 ],
    [ u"mx",u"Mazatepec",4975,18.716667,-99.35 ],
    [ u"mx",u"Mazatlán",4948,17.45,-99.483333 ],
    [ u"mx",u"Mazatlán",354730,23.216667,-106.416667 ],
    [ u"mx",u"Mecatlán",4509,20.216667,-97.683333 ],
    [ u"mx",u"Mecatlán",4509,20.216667,-97.666667 ],
    [ u"mx",u"Mecayapan",5005,18.216667,-94.833333 ],
    [ u"mx",u"Mechoacan",4407,16.333333,-97.833333 ],
    [ u"mx",u"Medina",6997,21.15,-101.616667 ],
    [ u"mx",u"Melchor Ocampo",34491,19.699722,-99.1475 ],
    [ u"mx",u"Meoqui",21179,28.283333,-105.483333 ],
    [ u"mx",u"Mérida",717196,20.966667,-89.616667 ],
    [ u"mx",u"Metepec",172990,19.253611,-99.607778 ],
    [ u"mx",u"Metlaltoyuca",3989,20.666667,-97.816667 ],
    [ u"mx",u"Mexicali",597124,32.651944,-115.468333 ],
    [ u"mx",u"Mexicaltzingo",8287,19.209722,-99.588889 ],
    [ u"mx",u"Mexico",8720916,19.434167,-99.138611 ],
    [ u"mx",u"Mextepec",5142,19.654722,-99.9525 ],
    [ u"mx",u"Mexticacán",3792,21.216667,-102.716667 ],
    [ u"mx",u"Mezcala",4100,20.933333,-102.75 ],
    [ u"mx",u"Miacatlán",8253,18.766667,-99.366667 ],
    [ u"mx",u"Miahuatlán",17632,16.191667,-96.632222 ],
    [ u"mx",u"Miahuatlán",7943,18.283333,-97.283333 ],
    [ u"mx",u"Mier",7259,26.433333,-99.15 ],
    [ u"mx",u"Miguel Auza",12685,24.293333,-103.450278 ],
    [ u"mx",u"Miguel Hidalgo",4845,17.266667,-91.15 ],
    [ u"mx",u"Mina",3803,26.016667,-100.533333 ],
    [ u"mx",u"Minas de Barroterán",8482,27.633333,-101.283333 ],
    [ u"mx",u"Minatitlán",4691,19.366667,-104.066667 ],
    [ u"mx",u"Minatitlán",150902,17.983333,-94.516667 ],
    [ u"mx",u"Mineral del Monte",10790,20.133333,-98.666667 ],
    [ u"mx",u"Miramar",67692,22.266667,-97.8 ],
    [ u"mx",u"Misantla",23242,19.933333,-96.833333 ],
    [ u"mx",u"Mitla",7547,16.916667,-96.4 ],
    [ u"mx",u"Mixquiahuala",22610,20.233333,-99.216667 ],
    [ u"mx",u"Mixtepec",3816,16.283333,-96.333333 ],
    [ u"mx",u"Mixtepec",3006,16.083333,-97.1 ],
    [ u"mx",u"Mixtequilla",3526,16.406667,-95.609167 ],
    [ u"mx",u"Mochicahui",4999,25.933333,-108.933333 ],
    [ u"mx",u"Mochitlán",4387,17.45,-99.483333 ],
    [ u"mx",u"Mocorito",5304,25.483333,-107.916667 ],
    [ u"mx",u"Moctezuma",4000,22.75,-101.083333 ],
    [ u"mx",u"Moctezuma",4028,29.8,-109.666667 ],
    [ u"mx",u"Molango",3929,20.783333,-98.716667 ],
    [ u"mx",u"Momoxpan",16675,19.066667,-98.233333 ],
    [ u"mx",u"Monclova",195772,26.9,-101.416667 ],
    [ u"mx",u"Monte Blanco",7652,18.966667,-97.016667 ],
    [ u"mx",u"Montecillo",5138,19.45,-98.9 ],
    [ u"mx",u"Monte Escobedo",3776,22.3,-103.583333 ],
    [ u"mx",u"Montemorelos",37695,25.2,-99.816667 ],
    [ u"mx",u"Monterrey",1122912,25.666667,-100.316667 ],
    [ u"mx",u"Moralillo",9126,22.216667,-97.9 ],
    [ u"mx",u"Morelia",592820,19.7,-101.116667 ],
    [ u"mx",u"Morelos",5650,22.883333,-102.616667 ],
    [ u"mx",u"Moroleón",40064,20.133333,-101.2 ],
    [ u"mx",u"Motozintla",19092,15.366667,-92.233333 ],
    [ u"mx",u"Motul",21109,21.1,-89.283333 ],
    [ u"mx",u"Motzorongo",4014,18.633333,-96.733333 ],
    [ u"mx",u"Moyotzingo",24555,19.25,-98.4 ],
    [ u"mx",u"Mulegé",3851,26.883333,-111.983333 ],
    [ u"mx",u"Muna",11363,20.483333,-89.716667 ],
    [ u"mx",u"Mundo Nuevo",9288,18.7,-95.5 ],
    [ u"mx",u"Muzquiz",32804,27.883333,-101.516667 ],
    [ u"mx",u"Nacajuca",9471,18.133333,-93.016667 ],
    [ u"mx",u"Naco",5193,31.334722,-109.948333 ],
    [ u"mx",u"Nacozari",11872,30.4,-109.65 ],
    [ u"mx",u"Nadadores",4501,27.05,-101.6 ],
    [ u"mx",u"Nahuatzén",8164,19.7,-101.833333 ],
    [ u"mx",u"Naica",5494,27.85,-105.483333 ],
    [ u"mx",u"Nanacamilpa",11682,19.483333,-98.55 ],
    [ u"mx",u"Nanchital",25983,18.066667,-94.4 ],
    [ u"mx",u"Naolinco",8246,19.65,-96.85 ],
    [ u"mx",u"Naranjos",19689,21.35,-97.683333 ],
    [ u"mx",u"Natívitas",5634,19.578889,-99.610833 ],
    [ u"mx",u"Nativitas",7012,19.233333,-98.316667 ],
    [ u"mx",u"Naucalpan",846222,19.479444,-99.238333 ],
    [ u"mx",u"Nautla",2890,20.216667,-96.783333 ],
    [ u"mx",u"Nava",18639,28.416667,-100.766667 ],
    [ u"mx",u"Navolato",28462,24.767222,-107.694444 ],
    [ u"mx",u"Nazareno Etla",3463,17.171667,-96.800556 ],
    [ u"mx",u"Nazareno",6332,25.383333,-103.416667 ],
    [ u"mx",u"Nazas",3346,25.216667,-104.1 ],
    [ u"mx",u"Nealticán",11339,19.05,-98.416667 ],
    [ u"mx",u"Necaxa",8375,20.216667,-98 ],
    [ u"mx",u"Nextlalpan",12598,19.744167,-99.073333 ],
    [ u"mx",u"Nezahualcóyotl",1232565,19.413611,-99.033056 ],
    [ u"mx",u"Nicolás Bravo",4571,18.45,-88.916667 ],
    [ u"mx",u"Nicolás Romero",245394,19.621944,-99.313056 ],
    [ u"mx",u"Nicolás Ruiz",3268,16.4,-92.533333 ],
    [ u"mx",u"Nieves",5296,24,-103.016667 ],
    [ u"mx",u"Niltepec",3289,16.566667,-94.616667 ],
    [ u"mx",u"Nochistlán",15613,21.366667,-102.85 ],
    [ u"mx",u"Nocupétaro",3054,19.05,-101.15 ],
    [ u"mx",u"Nogales",185890,31.333333,-110.933333 ],
    [ u"mx",u"Nogales",19904,18.816667,-97.166667 ],
    [ u"mx",u"Nombre de Dios",4556,23.85,-104.233333 ],
    [ u"mx",u"Nopaltepec",3572,19.8,-98.7 ],
    [ u"mx",u"Nopalucan",5641,19.216667,-97.816667 ],
    [ u"mx",u"Nueva Italia de Ruiz",31426,19.016667,-102.1 ],
    [ u"mx",u"Nueva Rosita",36644,27.95,-101.216667 ],
    [ u"mx",u"Nuevo Casas Grandes",51358,30.416667,-107.916667 ],
    [ u"mx",u"Nuevo Ideal",8623,24.8875,-105.072778 ],
    [ u"mx",u"Nuevo Laredo",349562,27.5,-99.516667 ],
    [ u"mx",u"Nuevo México",28135,20.75,-103.433333 ],
    [ u"mx",u"Nuevo Progreso",9125,23.166667,-97.95 ],
    [ u"mx",u"Nuevo San Juan Parangaricutiro",12300,19.4,-102.133333 ],
    [ u"mx",u"Numarán",4524,20.25,-101.933333 ],
    [ u"mx",u"Nunkiní",5556,20.333333,-90.183333 ],
    [ u"mx",u"Oaxaca",262574,17.05,-96.716667 ],
    [ u"mx",u"Oaxtepec",6993,18.9,-98.966667 ],
    [ u"mx",u"Obregon",258174,27.483333,-109.933333 ],
    [ u"mx",u"Ocampo",2951,27.316667,-102.4 ],
    [ u"mx",u"Ocampo",6534,21.65,-101.5 ],
    [ u"mx",u"Ocampo",3217,19.583333,-100.333333 ],
    [ u"mx",u"Ocampo",5150,22.833333,-99.333333 ],
    [ u"mx",u"Ocosingo",28721,16.905556,-92.038889 ],
    [ u"mx",u"Ocotepec",4251,17.216667,-93.15 ],
    [ u"mx",u"Ocotepec",5251,16.8,-96.4 ],
    [ u"mx",u"Ocotitlán",4799,19.233333,-99.616667 ],
    [ u"mx",u"Ocotitlán",4749,19.033333,-97.95 ],
    [ u"mx",u"Ocotlán",81531,20.35,-102.766667 ],
    [ u"mx",u"Ocotlan",13266,16.716667,-96.7 ],
    [ u"mx",u"Ocotlán",9894,19.15,-98.266667 ],
    [ u"mx",u"Ocoyoacac",24647,19.271944,-99.458889 ],
    [ u"mx",u"Ocoyucan",4747,18.966667,-98.283333 ],
    [ u"mx",u"Ocozocoautla",31597,16.766667,-93.366667 ],
    [ u"mx",u"Octopan",12054,20.566667,-100.733333 ],
    [ u"mx",u"Ocuituco",4728,18.866667,-98.766667 ],
    [ u"mx",u"Ojinaga",22128,29.566667,-104.416667 ],
    [ u"mx",u"Ojitlan",6043,18.066667,-96.383333 ],
    [ u"mx",u"Ojo Caliente",18284,22.566667,-102.25 ],
    [ u"mx",u"Ojuelos de Jalisco",9827,21.866667,-101.583333 ],
    [ u"mx",u"Olinalá",5452,17.833333,-98.85 ],
    [ u"mx",u"Oluta",11489,17.916667,-94.9 ],
    [ u"mx",u"Omealca",3818,18.75,-96.766667 ],
    [ u"mx",u"Ometepec",17801,16.683333,-98.416667 ],
    [ u"mx",u"Opichén",4265,20.55,-89.85 ],
    [ u"mx",u"Opopeo",8601,19.4,-101.6 ],
    [ u"mx",u"Oriental",9770,19.366667,-97.616667 ],
    [ u"mx",u"Orizaba",121353,18.85,-97.1 ],
    [ u"mx",u"Orizatlán",6488,21.183333,-98.616667 ],
    [ u"mx",u"Ostuacán",3183,17.416667,-93.3 ],
    [ u"mx",u"Otatitlán",4653,18.2,-96.033333 ],
    [ u"mx",u"Oteapan",12378,18,-94.65 ],
    [ u"mx",u"Otumba",9718,19.7,-98.75 ],
    [ u"mx",u"Oxchuc",3421,16.791667,-92.338889 ],
    [ u"mx",u"Oxkutzcab",21508,20.3,-89.416667 ],
    [ u"mx",u"Oyamel",5110,19.428056,-99.580833 ],
    [ u"mx",u"Ozuluama",3733,21.666667,-97.85 ],
    [ u"mx",u"Ozumba",19929,19.05,-98.8 ],
    [ u"mx",u"Pabellón de Arteaga",26460,22.15,-102.25 ],
    [ u"mx",u"Pabellón de Hidalgo",4246,22.166667,-102.35 ],
    [ u"mx",u"Pachuca",319593,20.116667,-98.733333 ],
    [ u"mx",u"Pachuquilla",3338,20.066667,-98.7 ],
    [ u"mx",u"Padilla",5624,24.016667,-98.783333 ],
    [ u"mx",u"Pahuatlan",3490,20.283333,-98.15 ],
    [ u"mx",u"Pajacuarán",9611,20.116667,-102.566667 ],
    [ u"mx",u"Pajapan",7461,18.25,-94.7 ],
    [ u"mx",u"Palau",16904,27.916667,-101.416667 ],
    [ u"mx",u"Palenque",36670,17.516667,-91.966667 ],
    [ u"mx",u"Palizada",3169,18.25,-92.083333 ],
    [ u"mx",u"Palmar de Bravo",4504,18.833333,-97.566667 ],
    [ u"mx",u"Palo Alto",4610,21.916667,-101.966667 ],
    [ u"mx",u"Palomares",4465,17.15,-95.066667 ],
    [ u"mx",u"Panaba",5723,21.283333,-88.266667 ],
    [ u"mx",u"Panindicuaro",5982,19.966667,-101.766667 ],
    [ u"mx",u"Panixtlahuaca",5682,16.25,-97.383333 ],
    [ u"mx",u"Panotla",10644,19.316667,-98.266667 ],
    [ u"mx",u"Pantelhó",6124,16.933333,-92.55 ],
    [ u"mx",u"Panuco",4727,24.533333,-104.333333 ],
    [ u"mx",u"Pánuco",35318,22.05,-98.166667 ],
    [ u"mx",u"Papalotla",3546,19.566667,-98.85 ],
    [ u"mx",u"Papalotla",20759,19.1625,-98.204167 ],
    [ u"mx",u"Papantla",47961,20.45,-97.316667 ],
    [ u"mx",u"Papasquiaro",22751,24.8325,-105.336389 ],
    [ u"mx",u"Paracho",15965,19.65,-102.066667 ],
    [ u"mx",u"Parácuaro",5389,20.15,-100.766667 ],
    [ u"mx",u"Paraíso",23830,18.4,-93.233333 ],
    [ u"mx",u"Paraje Nuevo",4190,18.870833,-96.866667 ],
    [ u"mx",u"Paredón",6337,16.033333,-93.866667 ],
    [ u"mx",u"Parras",32255,25.416667,-102.183333 ],
    [ u"mx",u"Paso del Macho",12043,18.966667,-96.716667 ],
    [ u"mx",u"Paso del Toro",4139,19.033333,-96.116667 ],
    [ u"mx",u"Paso de Ovejas",6951,19.283333,-96.433333 ],
    [ u"mx",u"Pátzcuaro",49018,19.516667,-101.6 ],
    [ u"mx",u"Pedernales",6240,19.133333,-101.466667 ],
    [ u"mx",u"Pedro Escobedo",8920,20.5,-100.133333 ],
    [ u"mx",u"Pemex",6357,17.9,-92.5 ],
    [ u"mx",u"Penjamillo",3584,20.1,-101.9 ],
    [ u"mx",u"Pénjamo",33510,20.433333,-101.733333 ],
    [ u"mx",u"Peñón Blanco",5014,24.789722,-104.036944 ],
    [ u"mx",u"Periban",11877,19.516667,-102.416667 ],
    [ u"mx",u"Pericos",6638,25.05,-107.7 ],
    [ u"mx",u"Perote",32560,19.566667,-97.233333 ],
    [ u"mx",u"Pesquería",5689,25.783333,-100.05 ],
    [ u"mx",u"Petalcingo",6274,17.283333,-92.45 ],
    [ u"mx",u"Petapa",4560,16.816667,-95.15 ],
    [ u"mx",u"Petatlán",21038,17.516667,-101.266667 ],
    [ u"mx",u"Peto",17607,20.133333,-88.916667 ],
    [ u"mx",u"Pichátaro",4749,19.566667,-101.8 ],
    [ u"mx",u"Pichucalco",14220,17.516667,-93.066667 ],
    [ u"mx",u"Piedra Gorda",7135,22.516667,-102.333333 ],
    [ u"mx",u"Piedras Negras",139624,28.7,-100.516667 ],
    [ u"mx",u"Piedras Negras",8454,18.766667,-96.183333 ],
    [ u"mx",u"Pihuamo",7613,19.25,-103.383333 ],
    [ u"mx",u"Pijijiapan",15101,15.7,-93.233333 ],
    [ u"mx",u"Pilcaya",4718,18.733333,-99.683333 ],
    [ u"mx",u"Pinos",4631,22.3,-101.566667 ],
    [ u"mx",u"Pinotepa de Don Luis",5527,16.416667,-97.916667 ],
    [ u"mx",u"Pinotepa Nacional",25669,16.316667,-98.016667 ],
    [ u"mx",u"Pisté",4674,20.7,-88.583333 ],
    [ u"mx",u"Pitiquito",5157,30.7,-112.083333 ],
    [ u"mx",u"Plateros",4158,23.216667,-102.85 ],
    [ u"mx",u"Platón Sánchez",10169,21.283333,-98.366667 ],
    [ u"mx",u"Playa del Carmen",54346,20.616667,-87.066667 ],
    [ u"mx",u"Playa Vicente",7701,17.833333,-95.816667 ],
    [ u"mx",u"Poanas",10249,25.766667,-103.616667 ],
    [ u"mx",u"Pochutla",13078,15.733333,-96.466667 ],
    [ u"mx",u"Pomuch",7838,20.133333,-90.183333 ],
    [ u"mx",u"Poncitlán",13069,20.366667,-102.916667 ],
    [ u"mx",u"Potam",5859,27.6,-110.383333 ],
    [ u"mx",u"Potrero del Llano",4513,21.05,-97.683333 ],
    [ u"mx",u"Pozo de Gamboa",4178,22.95,-102.566667 ],
    [ u"mx",u"Praxédis Guerrero",3787,31.366667,-106.016667 ],
    [ u"mx",u"Primo Tapia",5039,32.22,-116.917222 ],
    [ u"mx",u"Progreso Industrial",10332,19.628611,-99.356111 ],
    [ u"mx",u"Progreso",5231,32.58,-115.583889 ],
    [ u"mx",u"Progreso",16548,20.25,-99.2 ],
    [ u"mx",u"Progreso",47124,21.283333,-89.666667 ],
    [ u"mx",u"Providencia",4916,28.716667,-111.583333 ],
    [ u"mx",u"Puebla",8700,32.564444,-115.353333 ],
    [ u"mx",u"Puebla",1392137,19.05,-98.2 ],
    [ u"mx",u"Pueblo Nuevo",19363,23.383333,-105.383333 ],
    [ u"mx",u"Pueblo Nuevo",3814,20.516667,-101.366667 ],
    [ u"mx",u"Pueblo Nuevo",5170,19.673056,-99.622222 ],
    [ u"mx",u"Pueblo Nuevo Solistahuacán",7769,17.1,-92.883333 ],
    [ u"mx",u"Puente de Ixtla",20673,18.616667,-99.3 ],
    [ u"mx",u"Puente Grande",5636,20.566667,-103.15 ],
    [ u"mx",u"Puerto Escondido",19488,15.85,-97.066667 ],
    [ u"mx",u"Puerto Madero",9652,14.733333,-92.416667 ],
    [ u"mx",u"Puerto Palomas",5659,31.766667,-107.616667 ],
    [ u"mx",u"Puerto Peñasco",33877,31.316667,-113.533333 ],
    [ u"mx",u"Puerto Vallarta",187143,20.616667,-105.25 ],
    [ u"mx",u"Puga",6361,21.583333,-104.816667 ],
    [ u"mx",u"Puntilla Aldama",4774,20.183333,-96.916667 ],
    [ u"mx",u"Purépero",14267,19.916667,-102.016667 ],
    [ u"mx",u"Purificación",4740,19.716667,-104.6 ],
    [ u"mx",u"Puruándiro",28351,20.083333,-101.5 ],
    [ u"mx",u"Puruarán",7403,19.1,-101.533333 ],
    [ u"mx",u"Putla",9486,17.033333,-97.933333 ],
    [ u"mx",u"Quecholac",8711,18.95,-97.666667 ],
    [ u"mx",u"Quechultenango",5112,17.416667,-99.216667 ],
    [ u"mx",u"Queréndaro",8770,19.8,-100.883333 ],
    [ u"mx",u"Querétaro",611803,20.6,-100.383333 ],
    [ u"mx",u"Quesería",8959,19.366667,-103.583333 ],
    [ u"mx",u"Quetzaltepec",3610,16.966667,-95.816667 ],
    [ u"mx",u"Quila",5603,24.422778,-107.22 ],
    [ u"mx",u"Quiroga",13511,19.666667,-101.533333 ],
    [ u"mx",u"Raboso",4374,18.566667,-98.45 ],
    [ u"mx",u"Rafael Delgado",7823,18.8,-97.066667 ],
    [ u"mx",u"Rafael Lara Grajales",11441,19.25,-97.783333 ],
    [ u"mx",u"Rafael Lucio",3116,19.583333,-96.966667 ],
    [ u"mx",u"Ramos Arizpe",38260,25.55,-100.966667 ],
    [ u"mx",u"Rayón",4643,17.2,-93 ],
    [ u"mx",u"Rayón",7445,19.144444,-99.583611 ],
    [ u"mx",u"Rayón",5298,21.85,-99.666667 ],
    [ u"mx",u"Reforma",24884,18.1,-91.016667 ],
    [ u"mx",u"Reynosa",498670,26.083333,-98.283333 ],
    [ u"mx",u"Rinconada",6687,19.35,-96.516667 ],
    [ u"mx",u"Rincón de Romos",24683,22.233333,-102.3 ],
    [ u"mx",u"Rincón de Tamayo",10015,20.416667,-100.75 ],
    [ u"mx",u"Rincón Viejo",8540,16.9,-95.05 ],
    [ u"mx",u"Río Bravo",85485,25.983333,-98.1 ],
    [ u"mx",u"Río Frío",5707,19.35,-98.666667 ],
    [ u"mx",u"Río Grande",29842,23.716667,-102.966667 ],
    [ u"mx",u"Río Muerto",7358,27.416667,-110.233333 ],
    [ u"mx",u"Rodeo",3846,25.183333,-104.55 ],
    [ u"mx",u"Romita",19351,20.866667,-101.516667 ],
    [ u"mx",u"Rosamorada",3634,22.122222,-105.205833 ],
    [ u"mx",u"Rosarito",66023,32.333333,-117.033333 ],
    [ u"mx",u"Ruiz",12745,21.95,-105.15 ],
    [ u"mx",u"Sabancuy",6290,18.966667,-91.183333 ],
    [ u"mx",u"Sabinas Hidalgo",32048,26.5,-100.166667 ],
    [ u"mx",u"Sabinas",49201,27.85,-101.116667 ],
    [ u"mx",u"Sacalum",3214,20.483333,-89.583333 ],
    [ u"mx",u"Sahagún",28648,19.766667,-98.583333 ],
    [ u"mx",u"Sahuaripa",4038,29.05,-109.233333 ],
    [ u"mx",u"Sahuayo",58516,20.066667,-102.716667 ],
    [ u"mx",u"Saín Alto",4653,23.583333,-103.25 ],
    [ u"mx",u"Salamanca",138620,20.566667,-101.2 ],
    [ u"mx",u"Salina Cruz",73651,16.166667,-95.2 ],
    [ u"mx",u"Salinas",13973,22.633333,-101.716667 ],
    [ u"mx",u"Salitral",4152,22.85,-102.083333 ],
    [ u"mx",u"Salitrillo",4829,19.433333,-99.85 ],
    [ u"mx",u"Saltabarranca",2959,18.6,-95.533333 ],
    [ u"mx",u"Saltillo",621270,25.416667,-101 ],
    [ u"mx",u"Salto de Agua",4864,17.616667,-92.366667 ],
    [ u"mx",u"Salvatierra",32973,20.216667,-100.883333 ],
    [ u"mx",u"San Agustin de las Juntas",4921,17.003889,-96.708056 ],
    [ u"mx",u"San Agustín",15107,20.533333,-103.466667 ],
    [ u"mx",u"San Antonio Buenavista",6365,19.260278,-99.713056 ],
    [ u"mx",u"San Antonio de la Cal",15673,17.030833,-96.6975 ],
    [ u"mx",u"San Antonio La Isla",11123,19.161111,-99.570833 ],
    [ u"mx",u"San Bartolo del Llano",10937,19.590833,-99.743889 ],
    [ u"mx",u"San Bartolo",5821,19.813611,-99.011667 ],
    [ u"mx",u"San Bernardino",5204,19.45,-98.9 ],
    [ u"mx",u"San Blas",9016,21.516667,-105.266667 ],
    [ u"mx",u"San Blas",6353,26.083333,-108.766667 ],
    [ u"mx",u"San Buenaventura",6168,29.85,-107.483333 ],
    [ u"mx",u"San Buenaventura",18822,27.083333,-101.533333 ],
    [ u"mx",u"San Buenaventura",9991,19.268889,-99.696389 ],
    [ u"mx",u"San Carlos",13054,17.55,-91.15 ],
    [ u"mx",u"San Ciro de Acosta",6771,21.633333,-99.816667 ],
    [ u"mx",u"San Cristóbal",3989,20.333611,-101.476389 ],
    [ u"mx",u"Sanctórum",22936,19.1,-98.25 ],
    [ u"mx",u"Sanctórum",4488,19.5,-98.466667 ],
    [ u"mx",u"San Diego de la Unión",6072,21.466667,-100.866667 ],
    [ u"mx",u"San Dionisio del Mar",3281,16.333333,-94.75 ],
    [ u"mx",u"San Felipe del Progreso",3909,19.712778,-99.951944 ],
    [ u"mx",u"San Felipe",15386,31,-114.866667 ],
    [ u"mx",u"San Felipe",26073,21.27,-101.492222 ],
    [ u"mx",u"San Fernando",9024,16.866667,-93.216667 ],
    [ u"mx",u"San Fernando",29173,24.85,-98.15 ],
    [ u"mx",u"San Francisco del Mar",4033,16.233333,-94.65 ],
    [ u"mx",u"San Francisco del Rincón",66951,21.016667,-101.85 ],
    [ u"mx",u"San Gabriel Casa Blanca",14940,18.15,-97.133333 ],
    [ u"mx",u"San Gabriel",4358,21.016667,-103.033333 ],
    [ u"mx",u"San Ignacio",4293,23.916667,-106.416667 ],
    [ u"mx",u"San Jeronimito",6385,17.55,-101.333333 ],
    [ u"mx",u"San Jerónimo",7326,17.133333,-100.466667 ],
    [ u"mx",u"San José de Gracia",4226,22.15,-102.416667 ],
    [ u"mx",u"San José de Gracia",5397,20.666667,-102.583333 ],
    [ u"mx",u"San José del Castillo",10280,20.533333,-103.233333 ],
    [ u"mx",u"San José el Alto",5957,20.65,-100.366667 ],
    [ u"mx",u"San José el Vidrio",4606,19.651111,-99.376667 ],
    [ u"mx",u"San José Iturbide",16702,21,-100.383333 ],
    [ u"mx",u"San José Temascatío",4827,20.683333,-101.266667 ],
    [ u"mx",u"San Juan de Abajo",9015,20.816667,-105.183333 ],
    [ u"mx",u"San Juan de las Huertas",11929,19.246389,-99.760556 ],
    [ u"mx",u"San Juan de la Vega",14209,20.633333,-100.766667 ],
    [ u"mx",u"San Juan de los Lagos",45673,21.25,-102.3 ],
    [ u"mx",u"San Juan del Río",118178,20.383333,-100 ],
    [ u"mx",u"San Juan Evangelista",4069,17.9,-95.133333 ],
    [ u"mx",u"San Juan Tepa",5139,20.216667,-99.066667 ],
    [ u"mx",u"San Juan Tilapa",8019,19.219444,-99.662222 ],
    [ u"mx",u"San Julián",12752,21.016667,-102.166667 ],
    [ u"mx",u"San Lorenzo Cuauhtenco",4569,19.195833,-99.633889 ],
    [ u"mx",u"San Lucas",4494,16.6,-92.716667 ],
    [ u"mx",u"San Lucas",3249,18.566667,-100.783333 ],
    [ u"mx",u"San Luis de la Paz",47323,21.3,-100.516667 ],
    [ u"mx",u"San Luis Potosí",677726,22.15,-100.983333 ],
    [ u"mx",u"San Luis Río Colorado",139261,32.463056,-114.776667 ],
    [ u"mx",u"San Luis",7872,28.4,-113.666667 ],
    [ u"mx",u"San Marcos",12278,16.8,-99.35 ],
    [ u"mx",u"San Marcos",10961,20.033333,-99.333333 ],
    [ u"mx",u"San Marcos",3253,20.783333,-104.183333 ],
    [ u"mx",u"San Marcos",6261,20.2,-96.95 ],
    [ u"mx",u"San Martín de Hidalgo",7855,20.45,-103.95 ],
    [ u"mx",u"San Martín de las Pirámides",13017,19.7,-98.833333 ],
    [ u"mx",u"San Mateo del Mar",5441,16.2,-95 ],
    [ u"mx",u"San Miguel el Alto",22204,21.016667,-102.35 ],
    [ u"mx",u"San Nicolás de los Garza",507837,25.75,-100.3 ],
    [ u"mx",u"San Nicolás Guadalupe",5228,19.6125,-100.033333 ],
    [ u"mx",u"San Nicolás",4632,20.483333,-99.916667 ],
    [ u"mx",u"San Pablo de las Salinas",173565,19.665833,-99.096389 ],
    [ u"mx",u"San Patricio",6713,19.216667,-104.7 ],
    [ u"mx",u"San Pedro Abajo",5581,19.482222,-99.565833 ],
    [ u"mx",u"San Pedro Arriba",6154,19.482222,-99.565833 ],
    [ u"mx",u"San Pedro Buenavista",8390,16.083333,-93.116667 ],
    [ u"mx",u"San Pedro de los Naranjos",4126,20.25,-100.983333 ],
    [ u"mx",u"San Pedro",41167,25.433333,-103.216667 ],
    [ u"mx",u"San Quintín",5433,30.483333,-115.95 ],
    [ u"mx",u"San Rafael",6441,20.2,-96.85 ],
    [ u"mx",u"San Roque",4875,20.966667,-101.85 ],
    [ u"mx",u"San Salvador el Seco",15271,19.133333,-97.65 ],
    [ u"mx",u"San Sebastián el Grande",15465,20.516667,-103.416667 ],
    [ u"mx",u"San Sebastián Villanueva",6293,19.05,-97.716667 ],
    [ u"mx",u"San Simón de la Laguna",4441,19.3,-100.083333 ],
    [ u"mx",u"Santa Ana",10277,30.55,-111.116667 ],
    [ u"mx",u"Santa Anita",13515,20.55,-103.45 ],
    [ u"mx",u"Santa Bárbara",10800,26.8,-105.816667 ],
    [ u"mx",u"Santa Catarina de Tepehuanes",4800,25.35,-105.733333 ],
    [ u"mx",u"Santa Catarina",4477,18.966667,-99.133333 ],
    [ u"mx",u"Santa Catarina",254483,25.683333,-100.466667 ],
    [ u"mx",u"Santa Clara",3953,24.475,-103.356944 ],
    [ u"mx",u"Santa Clara",3953,24.483333,-103.366667 ],
    [ u"mx",u"Santa Cruz de las Flores",8504,20.483333,-103.5 ],
    [ u"mx",u"Santa Cruz del Valle",14637,20.533333,-103.433333 ],
    [ u"mx",u"Santa Cruz de Rosales",5217,28.2,-105.55 ],
    [ u"mx",u"Santa Elena",3335,20.333333,-89.65 ],
    [ u"mx",u"Santa Engracia",6961,24.016667,-99.2 ],
    [ u"mx",u"Santa Fe de la Laguna",4359,19.666667,-101.55 ],
    [ u"mx",u"Santa Gertrudis",5185,19.733333,-99.366667 ],
    [ u"mx",u"Santa Isabel",21152,28.383333,-113.35 ],
    [ u"mx",u"Santa María del Monte",5299,19.287778,-99.822778 ],
    [ u"mx",u"Santa María del Oro",5710,25.933333,-105.366667 ],
    [ u"mx",u"Santa María del Oro",3596,21.333333,-104.583333 ],
    [ u"mx",u"Santa María del Río",12097,21.8,-100.75 ],
    [ u"mx",u"Santa María del Tule",7195,17.033333,-96.616667 ],
    [ u"mx",u"Santa María la Alta",6397,18.6,-97.666667 ],
    [ u"mx",u"Santander Jiménez",5562,24.216667,-98.466667 ],
    [ u"mx",u"Santa Rosalía",11899,27.316667,-112.283333 ],
    [ u"mx",u"Santa Rosalía",5533,18.066667,-93.383333 ],
    [ u"mx",u"Santa Teresa",4813,20.95,-101.316667 ],
    [ u"mx",u"Santiago de Cuenda",5012,20.6,-100.983333 ],
    [ u"mx",u"Santiago",35970,25.416667,-100.15 ],
    [ u"mx",u"Santiago Tuxtla",15681,18.466667,-95.3 ],
    [ u"mx",u"Santo Domingo de Guzmán",7378,19.588333,-99.774722 ],
    [ u"mx",u"Santos Reyes Nopala",4830,16.109167,-97.156111 ],
    [ u"mx",u"San Vicente",4675,21.95,-105.3 ],
    [ u"mx",u"Sarabia",5091,20.509167,-101.0925 ],
    [ u"mx",u"Saucillo",10595,28.016667,-105.283333 ],
    [ u"mx",u"Sayula",25312,19.866667,-103.616667 ],
    [ u"mx",u"Sayula",11059,17.866667,-94.95 ],
    [ u"mx",u"Seybaplaya",8884,19.65,-90.666667 ],
    [ u"mx",u"Seyé",7834,20.833333,-89.366667 ],
    [ u"mx",u"Silao",65198,20.933333,-101.433333 ],
    [ u"mx",u"Simojovel",8510,17.2,-92.633333 ],
    [ u"mx",u"Sinaloa",4297,25.833333,-108.233333 ],
    [ u"mx",u"Singuilucan",3627,19.966667,-98.516667 ],
    [ u"mx",u"Socoltenango",4843,16.216667,-92.25 ],
    [ u"mx",u"Soconusco",5082,17.966667,-94.866667 ],
    [ u"mx",u"Soltepec",6508,19.116667,-97.7 ],
    [ u"mx",u"Sombrerete",18805,23.633333,-103.65 ],
    [ u"mx",u"Sonoita",9783,31.85,-112.833333 ],
    [ u"mx",u"Soteapan",4140,18.233333,-94.866667 ],
    [ u"mx",u"Soto la Marina",9712,23.766667,-98.216667 ],
    [ u"mx",u"Sotuta",5291,20.6,-89.016667 ],
    [ u"mx",u"Soyaló",3442,16.9,-92.916667 ],
    [ u"mx",u"Soyaltepec",8116,18.211667,-96.483889 ],
    [ u"mx",u"Soyaniquilpan",3898,19.983333,-99.5 ],
    [ u"mx",u"Suchiapa",13282,16.616667,-93.083333 ],
    [ u"mx",u"Suchiate",13743,14.55,-92.216667 ],
    [ u"mx",u"Suchilquitongo",6314,17.25,-96.883333 ],
    [ u"mx",u"Suchil",4095,23.633333,-103.916667 ],
    [ u"mx",u"Suchitlán",4190,19.366667,-103.716667 ],
    [ u"mx",u"Sucilá",3910,21.15,-88.3125 ],
    [ u"mx",u"Sultepec",3979,18.866667,-99.95 ],
    [ u"mx",u"Tabasco",6626,21.866667,-102.916667 ],
    [ u"mx",u"Tacambaro",21059,19.233333,-101.466667 ],
    [ u"mx",u"Tacoaleche",6821,22.816667,-102.416667 ],
    [ u"mx",u"Tacotalpa",7460,17.6,-92.816667 ],
    [ u"mx",u"Tahmek",3596,20.883333,-89.266667 ],
    [ u"mx",u"Tala",30943,20.666667,-103.7 ],
    [ u"mx",u"Talpa",7665,20.383333,-104.816667 ],
    [ u"mx",u"Tamalín",4674,21.35,-97.8 ],
    [ u"mx",u"Tamasopo",3914,21.916667,-99.4 ],
    [ u"mx",u"Tamazulapam",5028,17.680556,-97.568889 ],
    [ u"mx",u"Tamazunchale",21532,21.266667,-98.783333 ],
    [ u"mx",u"Tamiahua",5265,21.266667,-97.45 ],
    [ u"mx",u"Tampico",309015,22.3,-97.85 ],
    [ u"mx",u"Tampico",309015,22.216667,-97.85 ],
    [ u"mx",u"Tamuín",14748,21.983333,-98.75 ],
    [ u"mx",u"Tamulté",8295,17.966667,-92.95 ],
    [ u"mx",u"Tancanhuitz",3039,21.6,-98.966667 ],
    [ u"mx",u"Tancítaro",5298,19.333333,-102.366667 ],
    [ u"mx",u"Tancuayalab",5913,21.733333,-98.566667 ],
    [ u"mx",u"Tangamandapio",9967,19.95,-102.433333 ],
    [ u"mx",u"Tangancicuaro",15182,19.9,-102.133333 ],
    [ u"mx",u"Tanhuato",8454,20.283333,-102.333333 ],
    [ u"mx",u"Tanquian",9201,21.616667,-98.633333 ],
    [ u"mx",u"Tantoyuca",26930,21.35,-98.233333 ],
    [ u"mx",u"Tapachula",197968,14.9,-92.283333 ],
    [ u"mx",u"Tapalpa",5858,19.95,-103.766667 ],
    [ u"mx",u"Tapanatepec",7208,16.35,-94.2 ],
    [ u"mx",u"Tapilula",6432,17.233333,-93.033333 ],
    [ u"mx",u"Tarandacuao",7256,20,-100.533333 ],
    [ u"mx",u"Tarecuato",8149,19.85,-102.483333 ],
    [ u"mx",u"Taretán",6449,19.333333,-101.916667 ],
    [ u"mx",u"Tarímbaro",5138,19.783333,-101.133333 ],
    [ u"mx",u"Tarimoro",12677,20.283333,-100.75 ],
    [ u"mx",u"Tasquillo",3583,20.55,-99.3 ],
    [ u"mx",u"Tatahuicapan",6869,18.233333,-94.75 ],
    [ u"mx",u"Taxco",53219,18.55,-99.6 ],
    [ u"mx",u"Tayoltita",3742,24.083333,-105.933333 ],
    [ u"mx",u"Teabo",5040,20.4,-89.283333 ],
    [ u"mx",u"Teacalco",3941,19.240278,-98.306944 ],
    [ u"mx",u"Teacapán",4421,22.55,-105.75 ],
    [ u"mx",u"Teapa",26331,17.55,-92.95 ],
    [ u"mx",u"Tecalco",4810,19.666667,-98.95 ],
    [ u"mx",u"Tecali",4508,18.9,-97.966667 ],
    [ u"mx",u"Tecalitlán",13500,19.466667,-103.3 ],
    [ u"mx",u"Tecamachalco",26227,18.883333,-97.733333 ],
    [ u"mx",u"Tecamac",15244,19.733333,-98.966667 ],
    [ u"mx",u"Tecate",58303,32.566667,-116.633333 ],
    [ u"mx",u"Techuchulco",4405,19.110833,-99.527778 ],
    [ u"mx",u"Tecoanapa",3675,16.516667,-98.75 ],
    [ u"mx",u"Tecoh",8700,20.75,-89.466667 ],
    [ u"mx",u"Tecolotlán",8602,20.216667,-104.05 ],
    [ u"mx",u"Tecolutilla",9779,18.283333,-93.316667 ],
    [ u"mx",u"Tecolutla",3879,20.483333,-97.016667 ],
    [ u"mx",u"Tecomán",79582,18.913889,-103.905556 ],
    [ u"mx",u"Tecozautla",5251,20.533333,-99.633333 ],
    [ u"mx",u"Tecpan",14638,17.25,-100.683333 ],
    [ u"mx",u"Tecpatán",4569,17.133333,-93.3 ],
    [ u"mx",u"Tecuala",14921,22.398611,-105.456944 ],
    [ u"mx",u"Tehuacán",241437,18.45,-97.383333 ],
    [ u"mx",u"Tehuantepec",37391,16.333333,-95.233333 ],
    [ u"mx",u"Tehuixtla",7075,18.55,-99.266667 ],
    [ u"mx",u"Teitipac",2970,16.916667,-96.6 ],
    [ u"mx",u"Tejupilco",25036,18.9,-100.15 ],
    [ u"mx",u"Tekanto",3425,21.016667,-89.1 ],
    [ u"mx",u"Tekax",22807,20.2,-89.283333 ],
    [ u"mx",u"Tekit",8852,20.533333,-89.333333 ],
    [ u"mx",u"Telchac",3464,21.2,-89.266667 ],
    [ u"mx",u"Telixtac",4294,18.566667,-98.766667 ],
    [ u"mx",u"Telixtlahuaca",9000,17.3,-96.9 ],
    [ u"mx",u"Teloloapan",21244,18.35,-99.85 ],
    [ u"mx",u"Temamatla",5150,19.2,-98.883333 ],
    [ u"mx",u"Temascalapa",5735,19.833333,-98.9 ],
    [ u"mx",u"Temascalcingo",12909,19.916667,-100 ],
    [ u"mx",u"Temax",6125,21.15,-88.933333 ],
    [ u"mx",u"Temixco",91064,18.85,-99.233333 ],
    [ u"mx",u"Temoac",5302,18.766667,-98.783333 ],
    [ u"mx",u"Temoaya",3382,19.470833,-99.591111 ],
    [ u"mx",u"Temozón",5441,20.8,-88.216667 ],
    [ u"mx",u"Tempoal",12558,21.516667,-98.383333 ],
    [ u"mx",u"Tenabó",6814,20.05,-90.233333 ],
    [ u"mx",u"Tenamaxtlán",4825,20.216667,-104.166667 ],
    [ u"mx",u"Tenancingo",34274,18.966667,-99.6 ],
    [ u"mx",u"Tenancingo",10960,19.147222,-98.180556 ],
    [ u"mx",u"Tenango de Arista",20969,19.101667,-99.593056 ],
    [ u"mx",u"Tenango del Aire",5237,19.166667,-98.85 ],
    [ u"mx",u"Tenango de Río Blanco",39545,18.833333,-97.15 ],
    [ u"mx",u"Tenango",4633,16.966667,-92.416667 ],
    [ u"mx",u"Tenango",4798,18.65,-98.183333 ],
    [ u"mx",u"Tenextatiloyan",4352,19.716667,-97.583333 ],
    [ u"mx",u"Tenochtitlán",5603,19.7525,-99.930833 ],
    [ u"mx",u"Tenosique",32415,17.483333,-91.433333 ],
    [ u"mx",u"Teocaltiche",22646,21.433333,-102.583333 ],
    [ u"mx",u"Teocelo",9259,19.383333,-96.966667 ],
    [ u"mx",u"Teocuitatlán de Corona",4304,20.116667,-103.4 ],
    [ u"mx",u"Teolocholco",15690,19.25,-98.183333 ],
    [ u"mx",u"Teoloyucan",61379,19.745556,-99.183333 ],
    [ u"mx",u"Teontepec",5475,18.5,-97.516667 ],
    [ u"mx",u"Teopantlán",3792,18.716667,-98.266667 ],
    [ u"mx",u"Teopisca",12096,16.516667,-92.483333 ],
    [ u"mx",u"Teotihuacán",22540,19.683333,-98.866667 ],
    [ u"mx",u"Teotitlan",6570,18.131944,-97.076667 ],
    [ u"mx",u"Teotlalcingo",6138,19.233333,-98.483333 ],
    [ u"mx",u"Tepalcatepec",15281,19.183333,-102.85 ],
    [ u"mx",u"Tepalcingo",11846,18.6,-98.85 ],
    [ u"mx",u"Tepango",3376,20,-97.816667 ],
    [ u"mx",u"Tepatepec",10032,20.233333,-99.083333 ],
    [ u"mx",u"Tepatitlan",83698,20.816667,-102.733333 ],
    [ u"mx",u"Tepatlaxco",15084,19.066667,-97.966667 ],
    [ u"mx",u"Tepeaca",24956,18.966667,-97.9 ],
    [ u"mx",u"Tepeapulco",14935,19.783333,-98.55 ],
    [ u"mx",u"Tepechitlán",4419,21.666667,-103.333333 ],
    [ u"mx",u"Tepecoacuilco",5922,18.3,-99.483333 ],
    [ u"mx",u"Tepeji",33198,19.905278,-99.343889 ],
    [ u"mx",u"Tepeojuma",5131,18.716667,-98.45 ],
    [ u"mx",u"Tepepa",4512,20.133333,-98.183333 ],
    [ u"mx",u"Tepetitlán",4590,19.633333,-99.916667 ],
    [ u"mx",u"Tepetitla",8034,19.283333,-98.383333 ],
    [ u"mx",u"Tepetlaoxtoc",5860,19.583333,-98.816667 ],
    [ u"mx",u"Tepetzintla",4930,21.166667,-97.833333 ],
    [ u"mx",u"Tepexi",4617,18.583333,-97.933333 ],
    [ u"mx",u"Tepexpan",7061,19.568056,-99.704167 ],
    [ u"mx",u"Tepeyanco",3370,19.245833,-98.233333 ],
    [ u"mx",u"Tepezalá",3868,22.216667,-102.166667 ],
    [ u"mx",u"Tepic",280602,21.5,-104.9 ],
    [ u"mx",u"Tepotzotlán",44519,19.713889,-99.224444 ],
    [ u"mx",u"Tepoztlán",15963,18.983333,-99.1 ],
    [ u"mx",u"Tepulco",6214,19.116667,-97.983333 ],
    [ u"mx",u"Tequila",25283,20.883333,-103.833333 ],
    [ u"mx",u"Tequila",3248,18.733333,-97.066667 ],
    [ u"mx",u"Tequisquiapan",28963,20.516667,-99.866667 ],
    [ u"mx",u"Tequixquiac",20975,19.908056,-99.1475 ],
    [ u"mx",u"Tequixquitla",12548,19.327778,-97.65 ],
    [ u"mx",u"Terrenate",4348,19.483333,-97.916667 ],
    [ u"mx",u"Tesistán",29253,20.783333,-103.483333 ],
    [ u"mx",u"Tetecala",5111,18.716667,-99.4 ],
    [ u"mx",u"Tetela del Volcán",9127,18.866667,-98.716667 ],
    [ u"mx",u"Tetela de Ocampo",4234,19.816667,-97.8 ],
    [ u"mx",u"Teteles",4750,19.866667,-97.433333 ],
    [ u"mx",u"Tetelzingo",4193,19.066667,-97.15 ],
    [ u"mx",u"Tetepango",7289,20.1,-99.166667 ],
    [ u"mx",u"Tetiz",3774,20.966667,-89.933333 ],
    [ u"mx",u"Tetlanohcan",9832,19.25,-98.15 ],
    [ u"mx",u"Tetla",12465,19.433333,-98.1 ],
    [ u"mx",u"Tetzoyocan",5593,18.75,-97.7 ],
    [ u"mx",u"Teuchitlán",3756,20.683333,-103.866667 ],
    [ u"mx",u"Teul",3168,21.466667,-103.483333 ],
    [ u"mx",u"Texcalac",5733,19.416667,-98.083333 ],
    [ u"mx",u"Texcalyacac",4038,19.131389,-99.503889 ],
    [ u"mx",u"Texcoco",115384,19.516667,-98.883333 ],
    [ u"mx",u"Texistepec",8758,17.883333,-94.783333 ],
    [ u"mx",u"Texmelucan",75906,19.283333,-98.433333 ],
    [ u"mx",u"Teziutlán",70822,19.816667,-97.35 ],
    [ u"mx",u"Tezonapa",5100,18.609167,-96.691667 ],
    [ u"mx",u"Tezontepec",5369,19.883333,-98.816667 ],
    [ u"mx",u"Tezoyuca",13504,19.591667,-98.916667 ],
    [ u"mx",u"Tianguismanalco",5310,18.95,-98.433333 ],
    [ u"mx",u"Tianguistenco",20104,19.179722,-99.470556 ],
    [ u"mx",u"Ticul",30282,20.4,-89.533333 ],
    [ u"mx",u"Tierra Blanca",45359,18.457222,-96.347778 ],
    [ u"mx",u"Tierra Colorada",10202,17.166667,-99.583333 ],
    [ u"mx",u"Tierranueva",5362,21.683333,-100.566667 ],
    [ u"mx",u"Tihuatlán",12047,20.716667,-97.533333 ],
    [ u"mx",u"Tijuana",1376494,32.533333,-117.016667 ],
    [ u"mx",u"Tila",6089,17.4,-92.483333 ],
    [ u"mx",u"Tilzapotla",5256,18.483333,-99.266667 ],
    [ u"mx",u"Timucuy",3532,20.816667,-89.516667 ],
    [ u"mx",u"Tingambato",6329,19.5,-101.866667 ],
    [ u"mx",u"Tinguindín",6303,19.75,-102.483333 ],
    [ u"mx",u"Tiquicheo",3446,18.883333,-100.733333 ],
    [ u"mx",u"Tixkokob",10228,21,-89.4 ],
    [ u"mx",u"Tixpehual",3334,20.983333,-89.516667 ],
    [ u"mx",u"Tixtla",21130,17.583333,-99.433333 ],
    [ u"mx",u"Tizapán el Alto",14385,20.166667,-103.066667 ],
    [ u"mx",u"Tizayuca",39325,19.833333,-98.983333 ],
    [ u"mx",u"Tizimín",41993,21.15,-88.15 ],
    [ u"mx",u"Tlachichuca",7096,19.1,-97.416667 ],
    [ u"mx",u"Tlacojalpan",4090,18.233333,-95.95 ],
    [ u"mx",u"Tlacolula",11689,16.95,-96.483333 ],
    [ u"mx",u"Tlacotalpan",8704,18.616667,-95.666667 ],
    [ u"mx",u"Tlacote el Bajo",5419,20.65,-100.5 ],
    [ u"mx",u"Tlacotepec",6513,17.766667,-99.983333 ],
    [ u"mx",u"Tlacotepec",4914,18.816667,-98.75 ],
    [ u"mx",u"Tlacotepec",8716,20.066667,-97.866667 ],
    [ u"mx",u"Tlacoyalco",9399,18.65,-97.583333 ],
    [ u"mx",u"Tlahualilo",8588,26.116667,-103.45 ],
    [ u"mx",u"Tlahuapan",7639,19.333333,-98.566667 ],
    [ u"mx",u"Tlahuelilpan",8137,20.133333,-99.233333 ],
    [ u"mx",u"Tlaixpan",9031,18.9,-97.733333 ],
    [ u"mx",u"Tlajomulco",17025,20.466667,-103.45 ],
    [ u"mx",u"Tlalancaleca",10406,19.316667,-98.5 ],
    [ u"mx",u"Tlalchapa",4183,18.4,-100.466667 ],
    [ u"mx",u"Tlalcilalcalpan",11059,19.292778,-99.777778 ],
    [ u"mx",u"Tlalixtac",6581,17.066667,-96.65 ],
    [ u"mx",u"Tlalmanalco",14952,19.216667,-98.8 ],
    [ u"mx",u"Tlalnepantla",715798,19.526944,-99.221667 ],
    [ u"mx",u"Tlalnepantla",3742,19,-98.983333 ],
    [ u"mx",u"Tlalpujahua",3420,19.8,-100.166667 ],
    [ u"mx",u"Tlaltelulco",14860,19.275,-98.193056 ],
    [ u"mx",u"Tlaltenango",5809,19.166667,-98.333333 ],
    [ u"mx",u"Tlaltenango",14240,21.783333,-103.316667 ],
    [ u"mx",u"Tlaltizapán",10465,18.683333,-99.116667 ],
    [ u"mx",u"Tlamacazapa",5168,18.516667,-99.5 ],
    [ u"mx",u"Tlanalapan",11792,19.25,-97.266667 ],
    [ u"mx",u"Tlanalapa",7511,19.816667,-98.6 ],
    [ u"mx",u"Tlanchinol",4180,20.983333,-98.65 ],
    [ u"mx",u"Tlancualpican",4293,18.433333,-98.7 ],
    [ u"mx",u"Tlanepantla",4476,18.85,-97.9 ],
    [ u"mx",u"Tlanisco",5411,19.061389,-99.655556 ],
    [ u"mx",u"Tlapacoyan",33669,19.966667,-97.216667 ],
    [ u"mx",u"Tlapa",36875,17.55,-98.55 ],
    [ u"mx",u"Tlapehuala",8651,18.216667,-100.516667 ],
    [ u"mx",u"Tlaquepaque",493667,20.65,-103.316667 ],
    [ u"mx",u"Tlaquiltenango",19056,18.633333,-99.166667 ],
    [ u"mx",u"Tlatenchi",4730,18.583333,-99.2 ],
    [ u"mx",u"Tlatlauquitepec",9720,19.841667,-97.5 ],
    [ u"mx",u"Tlaxcalancingo",20363,19.033333,-98.266667 ],
    [ u"mx",u"Tlaxcala",84674,19.313889,-98.241667 ],
    [ u"mx",u"Tlaxcoapan",12772,20.083333,-99.216667 ],
    [ u"mx",u"Tlaxco",5228,20.433333,-98.016667 ],
    [ u"mx",u"Tlaxco",12553,19.326389,-98.108333 ],
    [ u"mx",u"Tlaxiaca",8788,20.116667,-98.883333 ],
    [ u"mx",u"Tlaxiaco",14608,17.266667,-97.683333 ],
    [ u"mx",u"Tlayacapan",7785,18.933333,-98.983333 ],
    [ u"mx",u"Tlazazalca",3635,19.966667,-102.066667 ],
    [ u"mx",u"Tocatlán",5123,19.383333,-98.016667 ],
    [ u"mx",u"Tochimilco",3688,18.9,-98.566667 ],
    [ u"mx",u"Tochtepec",6050,18.833333,-97.816667 ],
    [ u"mx",u"Tocuila",4248,18.95,-97.016667 ],
    [ u"mx",u"Todos Santos",4419,23.45,-110.216667 ],
    [ u"mx",u"Tolcayuca",5964,19.95,-98.916667 ],
    [ u"mx",u"Toluca",505903,19.288333,-99.667222 ],
    [ u"mx",u"Tomatlán",8360,19.933333,-105.25 ],
    [ u"mx",u"Tomatlán",3883,19.033333,-97 ],
    [ u"mx",u"Tonalá",32856,16.083333,-93.75 ],
    [ u"mx",u"Tonalá",401616,20.616667,-103.233333 ],
    [ u"mx",u"Tonatico",8224,18.783333,-99.683333 ],
    [ u"mx",u"Tonaya",3475,19.783333,-103.966667 ],
    [ u"mx",u"Tonila",3345,19.433333,-103.516667 ],
    [ u"mx",u"Topolobampo",7580,25.6,-109.05 ],
    [ u"mx",u"Toribio",3825,22.816667,-102.683333 ],
    [ u"mx",u"Torreón",524084,25.55,-103.433333 ],
    [ u"mx",u"Totocuitlapilco",7966,19.233333,-99.583333 ],
    [ u"mx",u"Totolac",5774,19.325,-98.258333 ],
    [ u"mx",u"Totolapan",4064,18.133333,-100.383333 ],
    [ u"mx",u"Totolapan",5584,18.966667,-98.916667 ],
    [ u"mx",u"Totolapa",4267,16.6,-92.683333 ],
    [ u"mx",u"Totolapa",6477,18.516667,-96.183333 ],
    [ u"mx",u"Tototlán",11016,20.55,-102.8 ],
    [ u"mx",u"Trancoso",10459,22.733333,-102.366667 ],
    [ u"mx",u"Tres Marías",5713,19.052222,-99.243056 ],
    [ u"mx",u"Tres Palos",4764,18.183333,-101.616667 ],
    [ u"mx",u"Tres Picos",4881,15.866667,-93.533333 ],
    [ u"mx",u"Tula de Allende",27678,20.05,-99.35 ],
    [ u"mx",u"Tulancingo",102388,20.083333,-98.366667 ],
    [ u"mx",u"Tula",9054,23,-99.716667 ],
    [ u"mx",u"Tulcingo",5607,18.05,-98.433333 ],
    [ u"mx",u"Tultepec",54780,19.684722,-99.129167 ],
    [ u"mx",u"Tultitlán",24387,19.647222,-99.170833 ],
    [ u"mx",u"Tulum",8390,20.125,-87.45 ],
    [ u"mx",u"Tunkás",3070,20.9,-88.75 ],
    [ u"mx",u"Tutla",3318,17.75,-97.6 ],
    [ u"mx",u"Tuxpan",25664,19.55,-103.4 ],
    [ u"mx",u"Tuxpan",9324,19.566667,-100.466667 ],
    [ u"mx",u"Tuxpan",22762,21.95,-105.3 ],
    [ u"mx",u"Tuxtepec",92124,18.1,-96.116667 ],
    [ u"mx",u"Tuxtla Chico",7287,14.95,-92.166667 ],
    [ u"mx",u"Tuxtla Gutiérrez",481143,16.75,-93.116667 ],
    [ u"mx",u"Tuxtla",55699,18.45,-95.216667 ],
    [ u"mx",u"Tuzamapan",6563,19.4,-96.85 ],
    [ u"mx",u"Tzimol",4178,16.266667,-92.266667 ],
    [ u"mx",u"Tzintzuntzán",3233,19.616667,-101.583333 ],
    [ u"mx",u"Tzucacab",9819,20.066667,-89.05 ],
    [ u"mx",u"Umán",28473,20.883333,-89.75 ],
    [ u"mx",u"Unión de San Antonio",6648,21.1,-101.966667 ],
    [ u"mx",u"Unión de Tula",9119,19.966667,-104.266667 ],
    [ u"mx",u"Unión Hidalgo",12736,16.466667,-94.833333 ],
    [ u"mx",u"Ures",4199,29.433333,-110.4 ],
    [ u"mx",u"Uriangato",49747,20.15,-101.183333 ],
    [ u"mx",u"Ursulo Galván",5200,19.4,-96.35 ],
    [ u"mx",u"Uruapan",237319,19.416667,-102.066667 ],
    [ u"mx",u"Usila",5063,17.8975,-96.531111 ],
    [ u"mx",u"Usmajac",6627,19.866667,-103.566667 ],
    [ u"mx",u"Valentín Gómez Farías",5404,28.216667,-106.583333 ],
    [ u"mx",u"Valladolid",39663,20.683333,-88.2 ],
    [ u"mx",u"Valle de Allende",4198,26.933333,-105.4 ],
    [ u"mx",u"Valle de Banderas",5656,20.8,-105.233333 ],
    [ u"mx",u"Valle de Bravo",28280,19.183333,-100.133333 ],
    [ u"mx",u"Valle de Guadalupe",4397,21,-102.616667 ],
    [ u"mx",u"Valle de Juárez",4014,19.933333,-102.933333 ],
    [ u"mx",u"Valle de Santiago",60531,20.383333,-101.2 ],
    [ u"mx",u"Valle Hermoso",47838,25.666667,-97.833333 ],
    [ u"mx",u"Valle Nacional",6701,17.783333,-96.316667 ],
    [ u"mx",u"Valparaíso",10545,22.766667,-103.566667 ],
    [ u"mx",u"Valtierrilla",11970,20.485278,-101.251944 ],
    [ u"mx",u"Vega de Alatorre",6710,20.033333,-96.633333 ],
    [ u"mx",u"Veinte de Noviembre",4309,14.716667,-92.25 ],
    [ u"mx",u"Venado",4945,22.933333,-101.083333 ],
    [ u"mx",u"Venustiano Carranza",15074,16.35,-92.55 ],
    [ u"mx",u"Venustiano Carranza",4288,25.35,-102.95 ],
    [ u"mx",u"Venustiano Carranza",11627,20.116667,-102.65 ],
    [ u"mx",u"Veracruz",568336,19.2,-96.133333 ],
    [ u"mx",u"Vícam",8837,27.583333,-110.333333 ],
    [ u"mx",u"Vicente Guerrero",12829,30.75,-116 ],
    [ u"mx",u"Vicente Guerrero",6876,14.85,-92.2 ],
    [ u"mx",u"Vicente Guerrero",14559,23.75,-103.983333 ],
    [ u"mx",u"Vicente Guerrero",52594,19.119444,-98.170833 ],
    [ u"mx",u"Victoria",4053,21.210833,-100.211944 ],
    [ u"mx",u"Victor Rosales",25898,22.95,-102.7 ],
    [ u"mx",u"Viesca",3673,25.35,-102.8 ],
    [ u"mx",u"Villachuato",4310,20.166667,-101.583333 ],
    [ u"mx",u"Villa Corona",6803,20.416667,-103.683333 ],
    [ u"mx",u"Villa Corzo",9123,16.166667,-93.25 ],
    [ u"mx",u"Villa de Alvarez",95066,19.25,-103.733333 ],
    [ u"mx",u"Villa de Reyes",8787,21.8,-100.933333 ],
    [ u"mx",u"Villagrán",24155,20.516667,-100.983333 ],
    [ u"mx",u"Villa Guerrero",3892,21.983333,-103.6 ],
    [ u"mx",u"Villa Guerrero",9267,18.866667,-99.65 ],
    [ u"mx",u"Villahermosa",362416,17.983333,-92.916667 ],
    [ u"mx",u"Villa Juárez",4330,22.116667,-102.066667 ],
    [ u"mx",u"Villamar",3028,20.016667,-102.6 ],
    [ u"mx",u"Villanueva",11138,22.35,-102.883333 ],
    [ u"mx",u"Villa Union",5147,28.216667,-100.716667 ],
    [ u"mx",u"Villa Unión",13683,23.2,-106.233333 ],
    [ u"mx",u"Vista Hermosa",6344,19.516667,-99.216667 ],
    [ u"mx",u"Vista Hermosa",9581,20.266667,-102.483333 ],
    [ u"mx",u"Xadani",5895,15.933333,-96.066667 ],
    [ u"mx",u"Xalapa",425166,19.533333,-96.916667 ],
    [ u"mx",u"Xalatlaco",13663,19.178889,-99.4175 ],
    [ u"mx",u"Xalmimilulco",14144,19.216667,-98.383333 ],
    [ u"mx",u"Xalpatlahuac",4054,17.25,-98.666667 ],
    [ u"mx",u"Xalpa",10444,19.816667,-99.183333 ],
    [ u"mx",u"Xaltepec",7353,18.866667,-97.6 ],
    [ u"mx",u"Xaltianguis",6933,17.066667,-99.833333 ],
    [ u"mx",u"Xaltocan",4512,19.416667,-98.2 ],
    [ u"mx",u"X-Can",4148,20.833333,-87.716667 ],
    [ u"mx",u"Xicohtzinco",11094,19.173611,-98.233333 ],
    [ u"mx",u"Xicoténcatl",9346,23.016667,-98.883333 ],
    [ u"mx",u"Xico",365793,19.266667,-98.933333 ],
    [ u"mx",u"Xico",15292,19.416667,-97 ],
    [ u"mx",u"Xilitla",5906,21.333333,-98.966667 ],
    [ u"mx",u"Xiloxoxtla",3454,19.266667,-98.2 ],
    [ u"mx",u"Xitla",3515,16.316667,-96.666667 ],
    [ u"mx",u"Xiutetelco",6971,19.8,-97.333333 ],
    [ u"mx",u"Xochihuehuetlán",5158,17.916667,-98.433333 ],
    [ u"mx",u"Xochiltenango",8337,18.933333,-97.85 ],
    [ u"mx",u"Xochistlahuaca",3566,16.783333,-98.25 ],
    [ u"mx",u"Xochitepec",16768,18.783333,-99.233333 ],
    [ u"mx",u"Xochitlán",4659,18.7,-97.783333 ],
    [ u"mx",u"Xocotla",4736,19.033333,-97.1 ],
    [ u"mx",u"Xometla",4454,19.65,-98.883333 ],
    [ u"mx",u"Xonacatlán",19687,19.402222,-99.5325 ],
    [ u"mx",u"Xoxocotlan",61848,17.016667,-96.733333 ],
    [ u"mx",u"Xoxocotla",19790,18.683333,-99.25 ],
    [ u"mx",u"Xoxtla",10089,19.183333,-98.3 ],
    [ u"mx",u"Yachihuacaltepec",4597,19.324167,-99.679444 ],
    [ u"mx",u"Yago",4063,21.833333,-105.066667 ],
    [ u"mx",u"Yahualica",14971,21.133333,-102.85 ],
    [ u"mx",u"Yaitepec",3247,16.233333,-97.233333 ],
    [ u"mx",u"Yajalón",14763,17.233333,-92.333333 ],
    [ u"mx",u"Yanga",5300,18.833333,-96.8 ],
    [ u"mx",u"Yaonáhuac",4191,19.866667,-97.45 ],
    [ u"mx",u"Yaqui",14802,27.366667,-110.166667 ],
    [ u"mx",u"Yautepec",41388,18.883333,-99.066667 ],
    [ u"mx",u"Yavaros",4058,26.7,-109.516667 ],
    [ u"mx",u"Yecapixtla",14431,18.883333,-98.866667 ],
    [ u"mx",u"Yecuatla",3198,19.866667,-96.75 ],
    [ u"mx",u"Yehualtepec",6329,18.783333,-97.65 ],
    [ u"mx",u"Yerbabuena",4378,20.966667,-101.266667 ],
    [ u"mx",u"Yurécuaro",20833,20.333333,-102.3 ],
    [ u"mx",u"Yuriria",21776,20.2,-101.15 ],
    [ u"mx",u"Zaachila",12240,16.916667,-96.766667 ],
    [ u"mx",u"Zacacalco",7224,19.933333,-98.983333 ],
    [ u"mx",u"Zacamulpa",5985,19.356389,-99.333333 ],
    [ u"mx",u"Zacapoaxtla",8771,19.883333,-97.583333 ],
    [ u"mx",u"Zacapú",50115,19.833333,-101.716667 ],
    [ u"mx",u"Zacatecas",118566,22.783333,-102.583333 ],
    [ u"mx",u"Zacatelco",32573,19.215278,-98.238889 ],
    [ u"mx",u"Zacatepec",21534,18.65,-99.2 ],
    [ u"mx",u"Zacatepec",4444,16.766667,-97.983333 ],
    [ u"mx",u"Zacatepec",10204,19.266667,-97.533333 ],
    [ u"mx",u"Zacatlán",31708,19.933333,-97.966667 ],
    [ u"mx",u"Zacoalco",16468,20.233333,-103.583333 ],
    [ u"mx",u"Zacualpan",4100,17.083333,-100.333333 ],
    [ u"mx",u"Zacualpan",3360,18.716667,-99.783333 ],
    [ u"mx",u"Zacualpan",5236,21.25,-105.166667 ],
    [ u"mx",u"Zacualtipán",17090,20.65,-98.6 ],
    [ u"mx",u"Zamora",124922,19.983333,-102.266667 ],
    [ u"mx",u"Zanatepec",7025,16.483333,-94.35 ],
    [ u"mx",u"Zapopan",987555,20.716667,-103.4 ],
    [ u"mx",u"Zapote",4401,21.066667,-102.8 ],
    [ u"mx",u"Zapotiltic",22200,19.616667,-103.433333 ],
    [ u"mx",u"Zapotlanejo",29055,20.45,-103.166667 ],
    [ u"mx",u"Zapotlán",8344,19.966667,-98.85 ],
    [ u"mx",u"Zaragoza",10577,28.483333,-100.916667 ],
    [ u"mx",u"Zaragoza",6896,19.145833,-99.647222 ],
    [ u"mx",u"Zaragoza",10575,19.766667,-97.55 ],
    [ u"mx",u"Zaragoza",8296,22.033333,-100.733333 ],
    [ u"mx",u"Zaragoza",8260,21.283333,-97.716667 ],
    [ u"mx",u"Zempoala",5814,19.916667,-98.666667 ],
    [ u"mx",u"Zempoala",9436,19.45,-96.416667 ],
    [ u"mx",u"Zihuatanejo",61310,17.633333,-101.55 ],
    [ u"mx",u"Zimapán",12455,20.75,-99.35 ],
    [ u"mx",u"Zimatlán",10014,16.866667,-96.783333 ],
    [ u"mx",u"Zinacantán",3742,16.75,-92.7 ],
    [ u"mx",u"Zinacantepec",54222,19.281944,-99.738611 ],
    [ u"mx",u"Zinacatepec",14826,18.333333,-97.25 ],
    [ u"mx",u"Zinapécuaro",14931,19.866667,-100.816667 ],
    [ u"mx",u"Zirándaro",3663,18.45,-100.983333 ],
    [ u"mx",u"Zitácuaro",78954,19.4,-100.366667 ],
    [ u"mx",u"Zitlala",4974,17.633333,-99.083333 ],
    [ u"mx",u"Zitlaltepec",6800,19.206944,-97.908333 ],
    [ u"mx",u"Zolotepec",9857,19.415833,-99.494444 ],
    [ u"mx",u"Zongolica",6411,18.666667,-96.983333 ],
    [ u"mx",u"Zongozotla",4467,19.983333,-97.733333 ],
    [ u"mx",u"Zozocolco",3370,20.116667,-97.566667 ],
    [ u"mx",u"Zozutla",5933,18.75,-97.65 ],
    [ u"mx",u"Zumpahuacán",4450,18.9,-99.55 ],
    [ u"mx",u"Zumpango",21143,17.65,-99.5 ],
    [ u"mx",u"Zumpango",47517,19.797778,-99.101667 ],
    [ u"my",u"Alor Gajah",20163,2.3804,102.2089 ],
    [ u"my",u"Alor Setar",217378,6.121045,100.360137 ],
    [ u"my",u"Ayer Itam",115276,5.4,100.283333 ],
    [ u"my",u"Ayer Keroh",37717,2.2654,102.2801 ],
    [ u"my",u"Ayer Molek",15497,2.2028,102.3172 ],
    [ u"my",u"Ayer Tawar",20185,4.3055,100.7618 ],
    [ u"my",u"Bandar Maharani",127905,2.0442,102.5689 ],
    [ u"my",u"Bandar Penggaram",156245,1.8548,102.9325 ],
    [ u"my",u"Banting",75467,2.816667,101.5 ],
    [ u"my",u"Batang Berjuntai",20001,3.383333,101.416667 ],
    [ u"my",u"Batu Arang",22579,3.316667,101.466667 ],
    [ u"my",u"Batu Berendam",25028,2.2487,102.246 ],
    [ u"my",u"Batu Gajah",46197,4.469161,101.041069 ],
    [ u"my",u"Beaufort",15855,5.3473,115.7455 ],
    [ u"my",u"Bedong",47598,5.727435,100.508761 ],
    [ u"my",u"Bemban",14329,2.2684,102.3746 ],
    [ u"my",u"Bentong",49218,3.5316,101.9038 ],
    [ u"my",u"Beranang",14369,2.8733,101.8697 ],
    [ u"my",u"Bidor",30018,4.116667,101.283333 ],
    [ u"my",u"Bintulu",151718,3.166667,113.033333 ],
    [ u"my",u"Bukit Bakri",30282,2.0429,102.6576 ],
    [ u"my",u"Bukit Baru",55658,2.2102,102.2886 ],
    [ u"my",u"Bukit Mertajam",212387,5.363014,100.466701 ],
    [ u"my",u"Bukit Rambai",17391,2.2594,102.1838 ],
    [ u"my",u"Buloh Kasap",13088,2.5536,102.764 ],
    [ u"my",u"Butterworth",107597,5.399102,100.363818 ],
    [ u"my",u"Chaah",11844,2.249,103.048 ],
    [ u"my",u"Cukai",82434,4.25,103.416667 ],
    [ u"my",u"Gua Musang",19734,4.8823,101.9644 ],
    [ u"my",u"Gurun",15965,5.81717,100.473812 ],
    [ u"my",u"Ipoh",673346,4.5841,101.0829 ],
    [ u"my",u"Jenjarom",24858,2.883333,101.5 ],
    [ u"my",u"Jerantut",33608,3.936,102.3626 ],
    [ u"my",u"Jertih",13526,5.733596,102.489703 ],
    [ u"my",u"Jitra",63492,6.268122,100.421668 ],
    [ u"my",u"Johor Bahru",802525,1.4655,103.7578 ],
    [ u"my",u"Juru",12265,5.312009,100.442289 ],
    [ u"my",u"Kampar",19058,4.3,101.15 ],
    [ u"my",u"Kangar",63894,6.4414,100.198619 ],
    [ u"my",u"Kapit",15771,2.016667,112.933333 ],
    [ u"my",u"Kelapa Sawit",13239,1.6698,103.5327 ],
    [ u"my",u"Keningau",77703,5.3378,116.1602 ],
    [ u"my",u"Kepala Batas",17131,5.517069,100.426498 ],
    [ u"my",u"Kerteh",24430,4.5141,103.4483 ],
    [ u"my",u"Kinarut",15716,5.8231,116.0466 ],
    [ u"my",u"Klang",879887,3.033333,101.45 ],
    [ u"my",u"Kluang",169838,2.0251,103.3328 ],
    [ u"my",u"Kota Bahru",279343,6.133275,102.238603 ],
    [ u"my",u"Kota Belud",12825,6.351,116.4305 ],
    [ u"my",u"Kota Kinabalu",457375,5.9749,116.0724 ],
    [ u"my",u"Kota Tinggi",52746,1.7381,103.8999 ],
    [ u"my",u"Kuah",30227,6.326492,99.843201 ],
    [ u"my",u"Kuala Kangsar",39333,4.766667,100.933333 ],
    [ u"my",u"Kuala Kedah",19232,6.105146,100.285201 ],
    [ u"my",u"Kuala Krai",20874,5.531303,102.199249 ],
    [ u"my",u"Kuala Lipis",15450,4.1842,102.0468 ],
    [ u"my",u"Kuala Lumpur",1453978,3.166667,101.7 ],
    [ u"my",u"Kuala Perlis",13917,6.4,100.133333 ],
    [ u"my",u"Kuala Pilah",19511,2.7389,102.2487 ],
    [ u"my",u"Kuala Selangor",55896,3.35,101.25 ],
    [ u"my",u"Kuala Sungai Baru",12269,2.3594,102.0353 ],
    [ u"my",u"Kuala Terengganu",285091,5.3302,103.1408 ],
    [ u"my",u"Kuang",21184,3.2594,101.5541 ],
    [ u"my",u"Kuantan",366253,3.8077,103.326 ],
    [ u"my",u"Kuching",570579,1.55,110.333333 ],
    [ u"my",u"Kudat",32397,6.8837,116.8477 ],
    [ u"my",u"Kulai",63765,1.6561,103.6032 ],
    [ u"my",u"Kulim",170931,5.364991,100.561773 ],
    [ u"my",u"Labis",21907,2.385,103.021 ],
    [ u"my",u"Labuan",73664,5.276667,115.241667 ],
    [ u"my",u"Lahad Datu",105635,5.0268,118.327 ],
    [ u"my",u"Lawan Kuda Baharu",20238,4.4547,101.1606 ],
    [ u"my",u"Limbang",26201,4.75,115 ],
    [ u"my",u"Lumut",39627,4.2323,100.6298 ],
    [ u"my",u"Marang",21413,5.2056,103.2059 ],
    [ u"my",u"Masjid Tanah",29185,2.3585,102.1029 ],
    [ u"my",u"Melaka",180675,2.196,102.2405 ],
    [ u"my",u"Mentakab",42174,3.4854,102.3484 ],
    [ u"my",u"Mersing",22009,2.4312,103.8405 ],
    [ u"my",u"Miri",228227,4.4148,114.0089 ],
    [ u"my",u"Nibong Tebal",40085,5.165862,100.477927 ],
    [ u"my",u"Nilai",36720,2.8033,101.7972 ],
    [ u"my",u"Paka",21044,4.6374,103.4368 ],
    [ u"my",u"Pantai Remis",16318,4.4557,100.6288 ],
    [ u"my",u"Papar",19277,5.733333,115.933333 ],
    [ u"my",u"Parit Buntar",27322,5.126714,100.493156 ],
    [ u"my",u"Parit Raja",17440,1.8681,103.1124 ],
    [ u"my",u"Pasir Gudang",145739,1.462,103.9053 ],
    [ u"my",u"Pasir Mas",19020,6.049337,102.139873 ],
    [ u"my",u"Pekan Nenas",23293,1.51,103.5141 ],
    [ u"my",u"Pekan",31826,3.4836,103.3996 ],
    [ u"my",u"Pengkalan Kundang",23307,3.2856,101.519 ],
    [ u"my",u"Perai",65322,5.381365,100.389691 ],
    [ u"my",u"Peringat",23291,6.033333,102.283333 ],
    [ u"my",u"Permatang Kuching",27193,5.463393,100.381436 ],
    [ u"my",u"Petaling Jaya",520712,3.083333,101.65 ],
    [ u"my",u"Pontian Kecil",50839,1.4866,103.3896 ],
    [ u"my",u"Port Dickson",89203,2.5228,101.7959 ],
    [ u"my",u"Pulau Sebang",11879,2.455,102.2329 ],
    [ u"my",u"Putatan",78340,5.8947,116.0464 ],
    [ u"my",u"Ranau",19296,5.9538,116.6641 ],
    [ u"my",u"Raub",40027,3.7899,101.857 ],
    [ u"my",u"Rawang",120484,3.3213,101.5767 ],
    [ u"my",u"Sabak",17251,3.7698,100.9879 ],
    [ u"my",u"Sandakan",392332,5.8402,118.1179 ],
    [ u"my",u"Segamat",69821,2.5148,102.8158 ],
    [ u"my",u"Sekudai",159864,1.533333,103.666667 ],
    [ u"my",u"Semenyih",80576,2.9516,101.843 ],
    [ u"my",u"Semporna",62686,4.48178,118.611185 ],
    [ u"my",u"Senai",73201,1.6006,103.6419 ],
    [ u"my",u"Seremban",372931,2.7297,101.9381 ],
    [ u"my",u"Serendah",28483,3.3646,101.6041 ],
    [ u"my",u"Shah Alam",481670,3.083333,101.533333 ],
    [ u"my",u"Sibu",198252,2.3,111.816667 ],
    [ u"my",u"Simpang Empat",58037,4.95,100.633333 ],
    [ u"my",u"Simpang Rengam",17528,1.825,103.3107 ],
    [ u"my",u"Sri Aman",27218,1.247222,111.452778 ],
    [ u"my",u"Sungai Besar",26939,3.6746,100.9867 ],
    [ u"my",u"Sungai Pelek",13829,2.646,101.7222 ],
    [ u"my",u"Sungai Petani",228898,5.646997,100.487724 ],
    [ u"my",u"Sungai Siput Utara",37202,4.8151,101.0786 ],
    [ u"my",u"Sungai Udang",26044,2.269,102.1427 ],
    [ u"my",u"Taiping",217658,4.85,100.733333 ],
    [ u"my",u"Tampin",28240,2.4701,102.2302 ],
    [ u"my",u"Tanah Merah",29120,5.8,102.15 ],
    [ u"my",u"Tangkak",35111,2.2673,102.5453 ],
    [ u"my",u"Tanjong Karang",16393,3.4242,101.1849 ],
    [ u"my",u"Tanjong Malim",18184,3.681,101.5198 ],
    [ u"my",u"Tanjong Sepat",22339,2.6579,101.5629 ],
    [ u"my",u"Tanjong Tokong",24073,5.460613,100.307418 ],
    [ u"my",u"Tapah",27864,4.183333,101.266667 ],
    [ u"my",u"Tawau",306497,4.2498,117.8871 ],
    [ u"my",u"Teluk Intan",63357,4.0259,101.0213 ],
    [ u"my",u"Temerloh",59942,3.4506,102.4176 ],
    [ u"my",u"Tumpat",12281,6.197755,102.170976 ],
    [ u"my",u"Ulu Tiram",75396,1.5999,103.8214 ],
    [ u"my",u"Yong Peng",27139,2.0136,103.0659 ],
    [ u"mz",u"Angoche",74624,-16.2325,39.9086111 ],
    [ u"mz",u"Beira",530706,-19.8436111,34.8388889 ],
    [ u"mz",u"Chibuto",59165,-24.6866667,33.5305556 ],
    [ u"mz",u"Chimoio",256992,-19.1163889,33.4833333 ],
    [ u"mz",u"Chokwé",63695,-24.5333333,32.9833333 ],
    [ u"mz",u"Cuamba",73268,-14.8030556,36.5372222 ],
    [ u"mz",u"Dondo",78648,-19.6094444,34.7430556 ],
    [ u"mz",u"Inhambane",73903,-23.865,35.3833333 ],
    [ u"mz",u"Lichinga",109839,-13.3127778,35.2405556 ],
    [ u"mz",u"Macia",23156,-25.0269444,33.0988889 ],
    [ u"mz",u"Manica",25488,-18.9344444,32.8755556 ],
    [ u"mz",u"Manjacaze",25541,-24.7116667,33.8827778 ],
    [ u"mz",u"Maputo",1191613,-25.9652778,32.5891667 ],
    [ u"mz",u"Matola",543907,-25.9622222,32.4588889 ],
    [ u"mz",u"Maxixe",119868,-23.8597222,35.3472222 ],
    [ u"mz",u"Moçambique",54315,-15.0341667,40.7358333 ],
    [ u"mz",u"Mocuba",68984,-16.8402778,38.2569444 ],
    [ u"mz",u"Montepuez",72279,-13.1255556,38.9997222 ],
    [ u"mz",u"Nacala",224853,-14.5427778,40.6727778 ],
    [ u"mz",u"Nampula",388526,-15.1197222,39.2647222 ],
    [ u"mz",u"Pemba",108737,-12.9608333,40.5077778 ],
    [ u"mz",u"Quelimane",188964,-17.8786111,36.8883333 ],
    [ u"mz",u"Tete",129316,-16.1563889,33.5866667 ],
    [ u"mz",u"Xai-Xai",127366,-25.0519444,33.6441667 ],
    [ u"na",u"Arandis",4507,-22.4166667,14.9666667 ],
    [ u"na",u"Aranos",3431,-24.1333333,19.1166667 ],
    [ u"na",u"Bethanien",10400,-26.4833333,17.15 ],
    [ u"na",u"Eenhana",3405,-17.4666667,16.3333333 ],
    [ u"na",u"Gobabis",16323,-22.45,18.9666667 ],
    [ u"na",u"Grootfontein",24105,-19.5666667,18.1166667 ],
    [ u"na",u"Henties Bay",3837,-22.1166667,14.2833333 ],
    [ u"na",u"Karasburg",6055,-28.0166667,18.75 ],
    [ u"na",u"Karibib",6900,-21.9333333,15.8333333 ],
    [ u"na",u"Katima Mulilo",25034,-17.5,24.2666667 ],
    [ u"na",u"Keetmanshoop",15609,-26.5833333,18.1333333 ],
    [ u"na",u"Khorixas",12022,-20.3666667,14.9666667 ],
    [ u"na",u"Lüderitz",15138,-26.6480556,15.1594444 ],
    [ u"na",u"Maltahöhe",2329,-24.8333333,16.9833333 ],
    [ u"na",u"Mariental",13381,-24.6333333,17.9666667 ],
    [ u"na",u"Okahandja",20881,-21.9833333,16.9166667 ],
    [ u"na",u"Okakarara",5255,-20.5833333,17.4333333 ],
    [ u"na",u"Omaruru",11546,-21.4333333,15.9333333 ],
    [ u"na",u"Ondangwa",9125,-17.9166667,15.95 ],
    [ u"na",u"Ongandjera",2719,-17.8833333,15.0666667 ],
    [ u"na",u"Ongwediva",9654,-17.7833333,15.7666667 ],
    [ u"na",u"Opuwo",4857,-18.0666667,13.85 ],
    [ u"na",u"Oranjemund",8496,-28.55,16.4333333 ],
    [ u"na",u"Oshakati",33636,-17.7833333,15.6833333 ],
    [ u"na",u"Oshikango",2658,-17.4,15.8833333 ],
    [ u"na",u"Otavi",4562,-19.65,17.3333333 ],
    [ u"na",u"Otjimbingwe",7717,-22.35,16.1333333 ],
    [ u"na",u"Otjiwarongo",21226,-20.45,16.65 ],
    [ u"na",u"Outjo",6558,-20.1166667,16.15 ],
    [ u"na",u"Rehoboth",21378,-23.3166667,17.0833333 ],
    [ u"na",u"Rundu",58177,-17.9333333,19.7666667 ],
    [ u"na",u"Swakopmund",25047,-22.6833333,14.5333333 ],
    [ u"na",u"Tsumeb",12191,-19.2333333,17.7166667 ],
    [ u"na",u"Usakos",9194,-22.0,15.6 ],
    [ u"na",u"Walvis Bay",52064,-22.9575,14.5052778 ],
    [ u"na",u"Warmbad",6700,-28.45,18.7333333 ],
    [ u"na",u"Windhoek",268129,-22.57,17.0836111 ],
    [ u"nc",u"Bouloupari",1619,-21.8666667,166.05 ],
    [ u"nc",u"Bourail",4595,-21.5666667,165.4833333 ],
    [ u"nc",u"Canala",2857,-21.5333333,165.95 ],
    [ u"nc",u"Dumbéa",21031,-22.15,166.45 ],
    [ u"nc",u"Farino",260,-21.6666667,165.7666667 ],
    [ u"nc",u"Fayaoué",4239,-20.65,166.5333333 ],
    [ u"nc",u"Hienghène",2219,-20.6833333,164.9333333 ],
    [ u"nc",u"Koné",4775,-21.0666667,164.8666667 ],
    [ u"nc",u"Koumac",3153,-20.5666667,164.2833333 ],
    [ u"nc",u"La Foa",2778,-21.7166667,165.8166667 ],
    [ u"nc",u"Moindou",630,-21.7,165.6833333 ],
    [ u"nc",u"Mont-Dore",26237,-22.2833333,166.5833333 ],
    [ u"nc",u"Nouméa",93331,-22.2666667,166.45 ],
    [ u"nc",u"Ouégoa",2092,-20.35,164.4333333 ],
    [ u"nc",u"Païta",10436,-22.1333333,166.3666667 ],
    [ u"nc",u"Poindimié",5157,-20.9333333,165.3333333 ],
    [ u"nc",u"Ponérihouen",2934,-21.0833333,165.4 ],
    [ u"nc",u"Pouébo",2281,-20.4,164.5666667 ],
    [ u"nc",u"Pouembout",1592,-21.1333333,164.9 ],
    [ u"nc",u"Poum",1568,-20.2333333,164.0166667 ],
    [ u"nc",u"Poya",3394,-21.35,165.15 ],
    [ u"nc",u"Sarraméa",586,-21.65,165.85 ],
    [ u"nc",u"Tadine",8261,-21.55,167.8833333 ],
    [ u"nc",u"Thio",2732,-21.6166667,166.2166667 ],
    [ u"nc",u"Touho",2424,-20.7833333,165.2333333 ],
    [ u"nc",u"Vao",1807,-22.6666667,167.4833333 ],
    [ u"nc",u"Voh",2168,-20.9666667,164.7 ],
    [ u"nc",u"Wé",11176,-20.9,167.2666667 ],
    [ u"nc",u"Yaté",1674,-22.15,166.9 ],
    [ u"ne",u"Abalak",13555,15.4522222,6.2783333 ],
    [ u"ne",u"Agadez",88569,16.9738889,7.9908333 ],
    [ u"ne",u"Aguié",13153,13.5080556,7.7772222 ],
    [ u"ne",u"Arlit",83400,18.7325,7.3680556 ],
    [ u"ne",u"Ayorou",26290,14.7313889,0.9194444 ],
    [ u"ne",u"Bilma",2292,18.6866667,12.9191667 ],
    [ u"ne",u"Bouza",7142,14.4222222,6.0452778 ],
    [ u"ne",u"Dakoro",19799,14.5105556,6.765 ],
    [ u"ne",u"Diffa",27951,13.3155556,12.6088889 ],
    [ u"ne",u"Dogondoutchi",31770,13.6461111,4.0288889 ],
    [ u"ne",u"Dosso",49755,13.0444444,3.1947222 ],
    [ u"ne",u"Filingué",11678,14.35,3.3166667 ],
    [ u"ne",u"Gaya",33054,11.8877778,3.4466667 ],
    [ u"ne",u"Gouré",14640,13.9869444,10.27 ],
    [ u"ne",u"Illéla",16679,14.4616667,5.2475 ],
    [ u"ne",u"Keïta",8961,14.7572222,5.7805556 ],
    [ u"ne",u"Kollo",10377,13.3086111,2.3308333 ],
    [ u"ne",u"Madaoua",24806,14.0758333,5.9586111 ],
    [ u"ne",u"Madarounfa",9792,13.3075,7.1575 ],
    [ u"ne",u"Magaria",19421,12.9975,8.9105556 ],
    [ u"ne",u"Maïné-Soroa",10700,13.2177778,12.0266667 ],
    [ u"ne",u"Maradi",163501,13.4916667,7.0963889 ],
    [ u"ne",u"Matamèye",16846,13.4238889,8.4777778 ],
    [ u"ne",u"Mayahi",22185,13.9577778,7.6683333 ],
    [ u"ne",u"Niamey",774245,13.6666667,1.7833333 ],
    [ u"ne",u"Niamey",774245,13.5166667,2.1166667 ],
    [ u"ne",u"Ouallam",7501,14.3166667,2.0833333 ],
    [ u"ne",u"Say",10388,13.1080556,2.3597222 ],
    [ u"ne",u"Tahoua",80432,14.8902778,5.2677778 ],
    [ u"ne",u"Tanout",15205,14.9702778,8.8916667 ],
    [ u"ne",u"Téra",21097,14.0105556,0.7530556 ],
    [ u"ne",u"Tessaoua",35778,13.7533333,7.9863889 ],
    [ u"ne",u"Tibiri",20019,13.5705556,7.0444444 ],
    [ u"ne",u"Tillabéry",19263,14.2116667,1.4530556 ],
    [ u"ne",u"Zinder",191440,13.8,8.9833333 ],
    [ u"ng",u"Aba",897613,5.106576,7.366667 ],
    [ u"ng",u"Abakaliki",134113,6.316249,8.116908 ],
    [ u"ng",u"Abeokuta",593140,7.15,3.35 ],
    [ u"ng",u"Abonnema",68591,4.708438,6.793071 ],
    [ u"ng",u"Abuja",174152,9.180515,7.179327 ],
    [ u"ng",u"Afikpo",71872,5.893121,7.937353 ],
    [ u"ng",u"Agbor",67616,6.251827,6.193374 ],
    [ u"ng",u"Agulu",79027,6.11,7.0724 ],
    [ u"ng",u"Aku",73748,6.7081,7.3167 ],
    [ u"ng",u"Akure",420623,7.25256,5.193118 ],
    [ u"ng",u"Amaigbo",127309,5.789171,7.838294 ],
    [ u"ng",u"Ankpa",61691,7.370575,7.6253 ],
    [ u"ng",u"Apomu",71657,7.333333,4.183333 ],
    [ u"ng",u"Asaba",73381,6.200643,6.733845 ],
    [ u"ng",u"Auchi",62912,7.066667,6.266667 ],
    [ u"ng",u"Awka",167751,6.210095,7.074115 ],
    [ u"ng",u"Azare",105695,11.6765,10.1948 ],
    [ u"ng",u"Bama",118129,11.522103,13.685579 ],
    [ u"ng",u"Bauchi",316173,10.313441,9.843273 ],
    [ u"ng",u"Bende",79624,5.557182,7.636764 ],
    [ u"ng",u"Bénin",1125126,6.335045,5.627492 ],
    [ u"ng",u"Bida",171672,9.083333,6.016667 ],
    [ u"ng",u"Birnin Kebbi",108172,12.453889,4.1975 ],
    [ u"ng",u"Biu",95012,10.612854,12.194579 ],
    [ u"ng",u"Bugama",135417,4.734071,6.863451 ],
    [ u"ng",u"Calabar",461832,4.9517,8.322 ],
    [ u"ng",u"Damaturu",255913,11.747,11.9608 ],
    [ u"ng",u"Daura",78283,11.5538,11.4085 ],
    [ u"ng",u"Duku",87671,10.823056,10.771667 ],
    [ u"ng",u"Dutse",17129,11.759404,9.339207 ],
    [ u"ng",u"Ede",283728,7.733333,4.433333 ],
    [ u"ng",u"Effium",86952,6.629171,8.059249 ],
    [ u"ng",u"Eha Amufu",70785,6.652226,7.768373 ],
    [ u"ng",u"Ejigbo",138367,7.9,4.316667 ],
    [ u"ng",u"Ekpoma",59624,6.742063,6.139003 ],
    [ u"ng",u"Emure",90646,7.436137,5.459322 ],
    [ u"ng",u"Enugu",653436,6.4402,7.4943 ],
    [ u"ng",u"Epe",84719,6.583333,3.983333 ],
    [ u"ng",u"Eruwa",71027,7.533333,3.416667 ],
    [ u"ng",u"Fiditi",71460,7.713611,3.917222 ],
    [ u"ng",u"Funtua",136821,11.523252,7.30813 ],
    [ u"ng",u"Gashua",125827,12.871,11.0482 ],
    [ u"ng",u"Gboko",195710,7.3179,8.9951 ],
    [ u"ng",u"Gbongan",139494,7.466667,4.35 ],
    [ u"ng",u"Gombe",250278,10.28969,11.167288 ],
    [ u"ng",u"Gusau",226873,12.162784,6.661348 ],
    [ u"ng",u"Hadejia",110761,12.4498,10.0444 ],
    [ u"ng",u"Ibadan",3565810,7.387778,3.896389 ],
    [ u"ng",u"Idah",68709,7.106508,6.73415 ],
    [ u"ng",u"Idanre",86468,7.1127,5.1159 ],
    [ u"ng",u"Ife",372191,7.466667,4.566667 ],
    [ u"ng",u"Ifo",88278,6.814367,3.195753 ],
    [ u"ng",u"Igboho",136772,8.833333,3.75 ],
    [ u"ng",u"Igbo Ora",92725,7.433333,3.283333 ],
    [ u"ng",u"Igede",87282,7.666765,5.132047 ],
    [ u"ng",u"Ihiala",83272,5.853769,6.860265 ],
    [ u"ng",u"Ijero",167644,7.8139,5.0742 ],
    [ u"ng",u"Ikare",182779,7.516667,5.75 ],
    [ u"ng",u"Ikere",103062,7.491328,5.232248 ],
    [ u"ng",u"Ikire",222174,7.35,4.183333 ],
    [ u"ng",u"Ikirun",134246,7.916667,4.666667 ],
    [ u"ng",u"Ikole",110874,7.7897,5.5106 ],
    [ u"ng",u"Ikom",79110,5.961,8.7107 ],
    [ u"ng",u"Ikorodu",313468,6.615483,3.508673 ],
    [ u"ng",u"Ikot Ekpene",254821,5.181475,7.934195 ],
    [ u"ng",u"Ila",179204,8.016667,4.9 ],
    [ u"ng",u"Ilawe",182896,7.5986,5.1086 ],
    [ u"ng",u"Ilesha",277922,8.916667,3.416667 ],
    [ u"ng",u"Ilobu",118097,7.833333,4.483333 ],
    [ u"ng",u"Ilorin",814246,8.5,4.55 ],
    [ u"ng",u"Inisa",164172,7.8,4.283333 ],
    [ u"ng",u"Ipoti",82114,7.87377,5.076915 ],
    [ u"ng",u"Ise",190077,7.4632,5.4281 ],
    [ u"ng",u"Iseyin",340707,7.966667,3.6 ],
    [ u"ng",u"Iwo",250459,7.633333,4.183333 ],
    [ u"ng",u"Jalingo",117766,8.883333,11.366667 ],
    [ u"ng",u"Jega",73495,12.2175,4.379167 ],
    [ u"ng",u"Jimeta",248166,9.283333,12.466667 ],
    [ u"ng",u"Jos",816876,9.916667,8.9 ],
    [ u"ng",u"Kaduna",1582211,10.522239,7.43828 ],
    [ u"ng",u"Kafanchan",79529,9.583333,8.3 ],
    [ u"ng",u"Kagoro",77015,9.6,8.383333 ],
    [ u"ng",u"Kano",3626204,11.994354,8.513807 ],
    [ u"ng",u"Katsina",432179,12.989428,7.600628 ],
    [ u"ng",u"Kaura Namoda",69731,12.589788,6.577914 ],
    [ u"ng",u"Keffi",85919,8.848611,7.873611 ],
    [ u"ng",u"Kishi",155520,9.083333,3.85 ],
    [ u"ng",u"Kontagora",98763,10.399893,5.469491 ],
    [ u"ng",u"Kumo",35715,10.044687,11.21217 ],
    [ u"ng",u"Lafiagi",102780,8.866667,5.416667 ],
    [ u"ng",u"Lafia",127246,8.483333,8.516667 ],
    [ u"ng",u"Lagos",8789133,6.453056,3.395833 ],
    [ u"ng",u"Lalupon",81130,7.45,4.066667 ],
    [ u"ng",u"Lere",93289,10.386966,8.572617 ],
    [ u"ng",u"Lokoja",60585,7.802359,6.743005 ],
    [ u"ng",u"Maiduguri",1112511,11.846441,13.160274 ],
    [ u"ng",u"Makurdi",292664,7.7411,8.5121 ],
    [ u"ng",u"Malumfashi",70715,11.785288,7.621753 ],
    [ u"ng",u"Minna",291930,9.613889,6.556944 ],
    [ u"ng",u"Modakeke",119537,7.383333,4.266667 ],
    [ u"ng",u"Mubi",225721,10.267607,13.26436 ],
    [ u"ng",u"Nguru",111022,12.8791,10.4526 ],
    [ u"ng",u"Nkpor",103741,6.151641,6.844585 ],
    [ u"ng",u"Nkwerre",62997,5.75555,7.106273 ],
    [ u"ng",u"Nnewi",194002,6.019864,6.914775 ],
    [ u"ng",u"Nsukka",111026,6.8561,7.3927 ],
    [ u"ng",u"Numan",77622,9.466667,12.033333 ],
    [ u"ng",u"Obosi",136753,6.096967,6.818432 ],
    [ u"ng",u"Ode",75464,7.7899,5.7117 ],
    [ u"ng",u"Ode",75464,7.645671,5.552041 ],
    [ u"ng",u"Offa",113841,8.15,4.716667 ],
    [ u"ng",u"Ogaminana",84380,7.6004,6.2014 ],
    [ u"ng",u"Ogbomosho",861303,8.133333,4.266667 ],
    [ u"ng",u"Ohafia",73361,5.626051,7.830609 ],
    [ u"ng",u"Oka",78016,7.425424,5.919206 ],
    [ u"ng",u"Okitipupa",74062,6.504748,4.78391 ],
    [ u"ng",u"Okrika",133284,4.741589,7.084877 ],
    [ u"ng",u"Olupona",95002,7.6,4.183333 ],
    [ u"ng",u"Ondo",257023,7.1,4.833333 ],
    [ u"ng",u"Onitsha",561106,6.14543,6.788452 ],
    [ u"ng",u"Opobo",125398,4.564844,7.547802 ],
    [ u"ng",u"Opobo",125398,4.51142,7.540093 ],
    [ u"ng",u"Oron",112040,4.825614,8.234345 ],
    [ u"ng",u"Oshogbo",499444,7.766667,4.566667 ],
    [ u"ng",u"Otukpo",160830,6.815,8.6531 ],
    [ u"ng",u"Owerri",215053,5.483333,7.030407 ],
    [ u"ng",u"Owo",276593,7.196195,5.586806 ],
    [ u"ng",u"Oyan",73623,8.05,4.766667 ],
    [ u"ng",u"Oyo",736113,7.85,3.933333 ],
    [ u"ng",u"Ozubulu",73818,5.956656,6.849038 ],
    [ u"ng",u"Pindiga",106323,9.983333,10.933333 ],
    [ u"ng",u"Port Harcourt",1148753,4.777423,7.013404 ],
    [ u"ng",u"Potiskum",86003,11.7091,11.0694 ],
    [ u"ng",u"Sapele",161692,5.894053,5.67666 ],
    [ u"ng",u"Shagamu",214574,6.843226,3.647763 ],
    [ u"ng",u"Shaki",178688,8.666667,3.383333 ],
    [ u"ng",u"Sokoto",563899,13.048025,5.214285 ],
    [ u"ng",u"Suleja",162150,9.180515,7.179327 ],
    [ u"ng",u"Uga",64184,5.935755,7.079297 ],
    [ u"ng",u"Ugep",200293,5.8086,8.0812 ],
    [ u"ng",u"Ughelli",79993,5.371416,6.308984 ],
    [ u"ng",u"Umuahia",264680,5.526269,7.489589 ],
    [ u"ng",u"Uromi",108617,6.707294,6.328434 ],
    [ u"ng",u"Uyo",124690,5.033333,7.92657 ],
    [ u"ng",u"Warri",536068,5.516667,5.75 ],
    [ u"ng",u"Wukari",92940,7.85,9.783333 ],
    [ u"ng",u"Yenagoa",24335,4.924722,6.264167 ],
    [ u"ng",u"Yola",96013,9.2,12.483333 ],
    [ u"ng",u"Zaria",975228,11.113236,7.725176 ],
    [ u"ni",u"Acoyapa",10011,11.9666667,-85.1666667 ],
    [ u"ni",u"Belén",4968,11.5,-85.8833333 ],
    [ u"ni",u"Bluefields",50178,12.0,-83.75 ],
    [ u"ni",u"Boaco",22481,12.4666667,-85.6666667 ],
    [ u"ni",u"Bocana de Paiwas",4975,12.8,-85.1333333 ],
    [ u"ni",u"Bonanza",6129,14.0166667,-84.5833333 ],
    [ u"ni",u"Camoapa",14401,12.3833333,-85.5166667 ],
    [ u"ni",u"Chichigalpa",38066,12.5666667,-87.0333333 ],
    [ u"ni",u"Chinandega",128616,12.6166667,-87.15 ],
    [ u"ni",u"Ciudad Darío",12981,12.7305556,-86.125 ],
    [ u"ni",u"Condega",10067,13.35,-86.4 ],
    [ u"ni",u"Corinto",22354,12.4833333,-87.1666667 ],
    [ u"ni",u"Corn Island",7934,12.1666667,-83.0333333 ],
    [ u"ni",u"Diriamba",38018,11.85,-86.2333333 ],
    [ u"ni",u"Diriomo",9134,11.8666667,-86.05 ],
    [ u"ni",u"Dolores",6143,11.85,-86.2166667 ],
    [ u"ni",u"El Jícaro",9522,11.5833333,-86.1 ],
    [ u"ni",u"El Sauce",8559,12.8869444,-86.5380556 ],
    [ u"ni",u"El Viejo",44384,12.6666667,-87.1666667 ],
    [ u"ni",u"Estelí",91687,13.0833333,-86.35 ],
    [ u"ni",u"Granada",92630,11.9333333,-85.95 ],
    [ u"ni",u"Jalapa",33620,13.9166667,-86.1333333 ],
    [ u"ni",u"Jinotega",36824,13.1,-86.0 ],
    [ u"ni",u"Jinotepe",31267,11.85,-86.2 ],
    [ u"ni",u"Juigalpa",48899,12.0833333,-85.4 ],
    [ u"ni",u"La Concepción",12471,11.9333333,-86.1833333 ],
    [ u"ni",u"Laguna de Perlas",4944,12.35,-83.6666667 ],
    [ u"ni",u"La Paz Centro",20995,12.34,-86.6752778 ],
    [ u"ni",u"Larreynaga",6645,12.6744444,-86.5708333 ],
    [ u"ni",u"La Trinidad",9312,12.5666667,-86.1833333 ],
    [ u"ni",u"León",150327,12.4355556,-86.8794444 ],
    [ u"ni",u"Managua",1140499,12.1508333,-86.2683333 ],
    [ u"ni",u"Masatepe",17323,11.9166667,-86.15 ],
    [ u"ni",u"Masaya",123474,11.9666667,-86.1 ],
    [ u"ni",u"Matagalpa",79122,12.9166667,-85.9166667 ],
    [ u"ni",u"Mateare",15067,12.2391667,-86.4291667 ],
    [ u"ni",u"Matiguás",9769,12.8333333,-85.4666667 ],
    [ u"ni",u"Nagarote",35438,12.2675,-86.5652778 ],
    [ u"ni",u"Nandaime",18832,11.75,-86.05 ],
    [ u"ni",u"Nandasmo",6417,11.9333333,-86.1166667 ],
    [ u"ni",u"Nindirí",10496,12.0047222,-86.1194444 ],
    [ u"ni",u"Niquinohomo",7262,11.9,-86.1 ],
    [ u"ni",u"Nueva Guinea",46630,11.6833333,-84.45 ],
    [ u"ni",u"Ocotal",39199,13.6333333,-86.4833333 ],
    [ u"ni",u"Puerto Cabezas",31050,14.0333333,-83.3833333 ],
    [ u"ni",u"Puerto Morazán",5769,12.85,-87.1833333 ],
    [ u"ni",u"Quilalí",12211,13.5666667,-86.0333333 ],
    [ u"ni",u"Río Blanco",12311,12.9333333,-85.2166667 ],
    [ u"ni",u"Rivas",26046,11.4333333,-85.8333333 ],
    [ u"ni",u"Rosita",8151,13.8833333,-84.4 ],
    [ u"ni",u"San Carlos",12931,11.1166667,-84.7833333 ],
    [ u"ni",u"San Isidro",6366,12.55,-85.4833333 ],
    [ u"ni",u"San Jorge",7001,11.45,-85.8 ],
    [ u"ni",u"San Juan del Sur",6787,11.25,-85.8666667 ],
    [ u"ni",u"San Lorenzo",6885,12.3833333,-85.6666667 ],
    [ u"ni",u"San Marcos",19957,11.9166667,-86.2 ],
    [ u"ni",u"San Miguelito",4447,11.4,-84.9 ],
    [ u"ni",u"San Rafael del Sur",25184,11.85,-86.45 ],
    [ u"ni",u"Santa Teresa",5372,11.7333333,-86.2166667 ],
    [ u"ni",u"Santo Domingo",6212,12.2666667,-85.0833333 ],
    [ u"ni",u"Santo Tomás",13437,12.0666667,-85.0833333 ],
    [ u"ni",u"Sébaco",21449,12.8511111,-86.0994444 ],
    [ u"ni",u"Siuna",11725,13.7333333,-84.7666667 ],
    [ u"ni",u"Somotillo",13063,13.0333333,-86.9166667 ],
    [ u"ni",u"Somoto",18581,13.4833333,-86.5833333 ],
    [ u"ni",u"Telica",7550,12.5205556,-86.86 ],
    [ u"ni",u"Ticuantepe",10226,12.0233333,-86.2005556 ],
    [ u"ni",u"Tipitapa",89642,12.2005556,-86.0938889 ],
    [ u"ni",u"Villa Sandino",8234,12.05,-84.9833333 ],
    [ u"ni",u"Waslala",5611,13.2333333,-85.3833333 ],
    [ u"ni",u"Waspán",7287,14.7333333,-83.9666667 ],
    [ u"ni",u"Wiwilí",6508,13.6166667,-85.8333333 ],
    [ u"nl",u"Aalburg",12472,51.757179,5.130263 ],
    [ u"nl",u"Aalsmeer",22969,52.266667,4.766667 ],
    [ u"nl",u"Aalten",18856,51.92597,6.58045 ],
    [ u"nl",u"Alblasserdam",18888,51.866729,4.66268 ],
    [ u"nl",u"Alkmaar",93287,52.635818,4.75561 ],
    [ u"nl",u"Almelo",76332,52.359606,6.656797 ],
    [ u"nl",u"Almere",186457,52.388101,5.235395 ],
    [ u"nl",u"Alphen",72570,52.135141,4.654932 ],
    [ u"nl",u"Amersfoort",139208,52.156022,5.389526 ],
    [ u"nl",u"Amstelveen",77343,52.310658,4.876789 ],
    [ u"nl",u"Amsterdam",745811,52.35,4.916667 ],
    [ u"nl",u"Anna Paulowna",14379,52.866667,4.866667 ],
    [ u"nl",u"Apeldoorn",157763,52.216667,5.966667 ],
    [ u"nl",u"Appingedam",12621,53.322206,6.84878 ],
    [ u"nl",u"Arnhem",144959,51.979818,5.925636 ],
    [ u"nl",u"Assen",64940,52.994749,6.563223 ],
    [ u"nl",u"Asten",16199,51.405948,5.749224 ],
    [ u"nl",u"Axel",12421,51.267573,3.907652 ],
    [ u"nl",u"Baarn",24301,52.211494,5.29222 ],
    [ u"nl",u"Barendrecht",43123,51.853922,4.538639 ],
    [ u"nl",u"Barneveld",51158,52.141642,5.584486 ],
    [ u"nl",u"Bedum",11123,53.299126,6.604137 ],
    [ u"nl",u"Beek",16989,50.939978,5.796491 ],
    [ u"nl",u"Beesel",13656,51.266715,6.048432 ],
    [ u"nl",u"Bemmel",42751,51.890107,5.891289 ],
    [ u"nl",u"Bergeijk",18255,51.318699,5.359563 ],
    [ u"nl",u"Bergen",13647,51.600383,6.034003 ],
    [ u"nl",u"Bergen",32300,52.676543,4.702946 ],
    [ u"nl",u"Bergen op Zoom",67641,51.494492,4.283509 ],
    [ u"nl",u"Bergschenhoek",15080,51.987249,4.515815 ],
    [ u"nl",u"Best",30292,51.504884,5.392854 ],
    [ u"nl",u"Beuningen",26178,51.859898,5.766456 ],
    [ u"nl",u"Beverwijk",36466,52.49126,4.652082 ],
    [ u"nl",u"Bladel",19199,51.369191,5.218936 ],
    [ u"nl",u"Blaricum",8997,52.273551,5.24929 ],
    [ u"nl",u"Bleiswijk",10792,52.012887,4.527929 ],
    [ u"nl",u"Bloemendaal",17544,52.405912,4.609438 ],
    [ u"nl",u"Bodegraven",19920,52.086135,4.756828 ],
    [ u"nl",u"Borculo",10551,52.116011,6.520741 ],
    [ u"nl",u"Borne",19806,52.301356,6.748199 ],
    [ u"nl",u"Borsele",22723,51.423688,3.734448 ],
    [ u"nl",u"Boskoop",15469,52.069873,4.667693 ],
    [ u"nl",u"Boxmeer",29918,51.644012,5.960815 ],
    [ u"nl",u"Boxtel",29572,51.590116,5.328162 ],
    [ u"nl",u"Breda",168934,51.566667,4.8 ],
    [ u"nl",u"Breukelen",14540,52.177836,5.002248 ],
    [ u"nl",u"Brielle",16070,51.900408,4.171243 ],
    [ u"nl",u"Brummen",21675,52.089817,6.156512 ],
    [ u"nl",u"Brunssum",29914,50.95,5.966667 ],
    [ u"nl",u"Bunnik",14061,52.06574,5.207608 ],
    [ u"nl",u"Bunschoten",19494,52.233333,5.383333 ],
    [ u"nl",u"Bussum",31430,52.2655,5.179357 ],
    [ u"nl",u"Capelle",66878,51.929856,4.579586 ],
    [ u"nl",u"Castricum",35750,52.549912,4.670831 ],
    [ u"nl",u"Coevorden",35113,52.664762,6.742616 ],
    [ u"nl",u"Cranendonck",20427,51.303894,5.59804 ],
    [ u"nl",u"Cuijk",25012,51.728069,5.881147 ],
    [ u"nl",u"Culemborg",27869,51.951872,5.231729 ],
    [ u"nl",u"Dalfsen",26503,52.51078,6.258378 ],
    [ u"nl",u"De Bilt",43179,52.109948,5.185595 ],
    [ u"nl",u"Delft",98482,52.018601,4.378153 ],
    [ u"nl",u"Delfzijl",28473,53.332639,6.924231 ],
    [ u"nl",u"De Lier",11589,51.973195,4.261502 ],
    [ u"nl",u"Denekamp",26461,52.37917,7.00442 ],
    [ u"nl",u"Den Helder",59607,52.956142,4.759368 ],
    [ u"nl",u"Deurne",32182,51.460672,5.799131 ],
    [ u"nl",u"Deventer",87726,52.25,6.2 ],
    [ u"nl",u"Didam",16927,51.940861,6.138833 ],
    [ u"nl",u"Diemen",24146,52.337122,4.974383 ],
    [ u"nl",u"Doesburg",11692,52.014283,6.133922 ],
    [ u"nl",u"Doetinchem",51907,51.966667,6.3 ],
    [ u"nl",u"Dongen",25855,51.62786,4.935891 ],
    [ u"nl",u"Doorn",10402,52.036875,5.343049 ],
    [ u"nl",u"Dordrecht",121595,51.800653,4.698199 ],
    [ u"nl",u"Drimmelen",26911,51.7,4.783333 ],
    [ u"nl",u"Dronten",39509,52.522719,5.71876 ],
    [ u"nl",u"Druten",18544,51.894314,5.601302 ],
    [ u"nl",u"Duiven",27463,51.944895,6.024904 ],
    [ u"nl",u"Echt",19260,51.112082,5.870914 ],
    [ u"nl",u"Ede",106506,52.035253,5.677743 ],
    [ u"nl",u"Eersel",18551,51.356604,5.31992 ],
    [ u"nl",u"Eibergen",16888,52.100406,6.646741 ],
    [ u"nl",u"Eijsden",12079,50.777735,5.710742 ],
    [ u"nl",u"Eindhoven",210498,51.45,5.466667 ],
    [ u"nl",u"Elburg",21737,52.448691,5.833627 ],
    [ u"nl",u"Emmen",112333,52.792471,6.894744 ],
    [ u"nl",u"Enkhuizen",17943,52.712352,5.279958 ],
    [ u"nl",u"Enschede",154183,52.219515,6.891235 ],
    [ u"nl",u"Epe",33242,52.348095,5.984471 ],
    [ u"nl",u"Ermelo",26695,52.297759,5.632076 ],
    [ u"nl",u"Geertruidenberg",20912,51.701577,4.856165 ],
    [ u"nl",u"Geldermalsen",26526,51.883333,5.3 ],
    [ u"nl",u"Geldrop",28877,51.422362,5.571822 ],
    [ u"nl",u"Gendringen",21247,51.873406,6.373995 ],
    [ u"nl",u"Gennep",17002,51.694099,5.977146 ],
    [ u"nl",u"Goedereede",11661,51.818189,3.97772 ],
    [ u"nl",u"Goes",37275,51.503848,3.899894 ],
    [ u"nl",u"Goirle",22899,51.52349,5.071676 ],
    [ u"nl",u"Gorinchem",35730,51.82965,4.973111 ],
    [ u"nl",u"Gorssel",12824,52.200531,6.200275 ],
    [ u"nl",u"Gouda",71684,52.022582,4.707001 ],
    [ u"nl",u"Grave",12976,51.758614,5.739412 ],
    [ u"nl",u"Groesbeek",18757,51.773859,5.940149 ],
    [ u"nl",u"Groningen",179995,53.216667,6.55 ],
    [ u"nl",u"Grootegast",12862,53.211598,6.2752 ],
    [ u"nl",u"Haaksbergen",24493,52.156875,6.739496 ],
    [ u"nl",u"Haaren",14138,51.601402,5.225937 ],
    [ u"nl",u"Haarlem",147736,52.366667,4.65 ],
    [ u"nl",u"Haarlemmermeer",131698,52.312058,4.693128 ],
    [ u"nl",u"Haelen",10283,51.234708,5.951461 ],
    [ u"nl",u"Hardenberg",58361,52.574315,6.622013 ],
    [ u"nl",u"Harderwijk",41916,52.35,5.633333 ],
    [ u"nl",u"Haren",18775,53.176674,6.630369 ],
    [ u"nl",u"Harenkarspel",16422,52.733333,4.783333 ],
    [ u"nl",u"Harlingen",15615,53.173766,5.430244 ],
    [ u"nl",u"Hattem",11676,52.47238,6.069615 ],
    [ u"nl",u"Heemskerk",37598,52.511077,4.671646 ],
    [ u"nl",u"Heemstede",25770,52.35,4.616667 ],
    [ u"nl",u"Heerde",18163,52.389029,6.03942 ],
    [ u"nl",u"Heerenveen",43715,52.959349,5.918921 ],
    [ u"nl",u"Heerhugowaard",51004,52.663987,4.827289 ],
    [ u"nl",u"Heerlen",93518,50.882832,5.962319 ],
    [ u"nl",u"Heiloo",22526,52.60252,4.68815 ],
    [ u"nl",u"Helden",19787,51.32322,6.002627 ],
    [ u"nl",u"Hellendoorn",36565,52.391055,6.450765 ],
    [ u"nl",u"Hellevoetsluis",40803,51.827088,4.130596 ],
    [ u"nl",u"Helmond",88371,51.481431,5.700121 ],
    [ u"nl",u"Hendrik-Ido-Ambacht",22478,51.836059,4.653349 ],
    [ u"nl",u"Hengelo",82928,52.267379,6.789658 ],
    [ u"nl",u"Heusden",44200,51.734186,5.138513 ],
    [ u"nl",u"Heythuysen",12088,51.25072,5.896357 ],
    [ u"nl",u"Hillegom",20955,52.29385,4.593843 ],
    [ u"nl",u"Hilvarenbeek",15147,51.484585,5.132665 ],
    [ u"nl",u"Hilversum",83864,52.231896,5.179877 ],
    [ u"nl",u"Hoogeveen",53740,52.727704,6.489559 ],
    [ u"nl",u"Hoorn",70379,52.649035,5.063112 ],
    [ u"nl",u"Horst",28657,51.18875,5.710439 ],
    [ u"nl",u"Houten",40766,52.033333,5.166667 ],
    [ u"nl",u"Huizen",42669,52.303148,5.258999 ],
    [ u"nl",u"Hulst",20158,51.281099,4.052964 ],
    [ u"nl",u"IJsselstein",33489,52.024982,5.018862 ],
    [ u"nl",u"Kampen",49303,52.558086,5.897808 ],
    [ u"nl",u"Kapelle",12114,51.647731,3.963151 ],
    [ u"nl",u"Katwijk",42231,52.189287,4.408883 ],
    [ u"nl",u"Kerkrade",49327,50.867438,6.066076 ],
    [ u"nl",u"Kesteren",22527,51.934719,5.579645 ],
    [ u"nl",u"Kollumerland",13781,53.26265,6.080386 ],
    [ u"nl",u"Krimpen",29799,51.895158,4.627858 ],
    [ u"nl",u"Landsmeer",10338,52.431132,4.91894 ],
    [ u"nl",u"Langedijk",26276,52.7,4.816667 ],
    [ u"nl",u"Laren",11978,52.248702,5.230203 ],
    [ u"nl",u"Leek",19931,53.162932,6.371627 ],
    [ u"nl",u"Leerdam",21286,51.895588,5.09177 ],
    [ u"nl",u"Leeuwarden",92494,53.20139,5.808588 ],
    [ u"nl",u"Leiden",116928,52.176281,4.528154 ],
    [ u"nl",u"Leiderdorp",28563,52.15638,4.537878 ],
    [ u"nl",u"Lelystad",73426,52.51764,5.473989 ],
    [ u"nl",u"Leusden",29843,52.115122,5.40549 ],
    [ u"nl",u"Lichtenvoorde",19949,51.987502,6.56955 ],
    [ u"nl",u"Liesveld",9842,51.931352,4.833465 ],
    [ u"nl",u"Lisse",22059,52.253825,4.547463 ],
    [ u"nl",u"Lochem",19863,52.160808,6.4151 ],
    [ u"nl",u"Loon op Zand",23408,51.629225,5.072734 ],
    [ u"nl",u"Lopik",13904,51.973659,4.947496 ],
    [ u"nl",u"Losser",22618,52.260911,7.008838 ],
    [ u"nl",u"Maarsen",39269,52.143509,5.044809 ],
    [ u"nl",u"Maasbracht",13764,51.145124,5.889301 ],
    [ u"nl",u"Maasbree",12887,51.358522,6.048165 ],
    [ u"nl",u"Maassluis",32989,51.915011,4.273756 ],
    [ u"nl",u"Maastricht",122383,50.85,5.683333 ],
    [ u"nl",u"Margraten",13512,50.824097,5.817101 ],
    [ u"nl",u"Meerssen",19932,50.883747,5.758779 ],
    [ u"nl",u"Meppel",31049,52.7,6.2 ],
    [ u"nl",u"Middelburg",47307,51.50036,3.612964 ],
    [ u"nl",u"Middelharnis",17971,51.756017,4.163479 ],
    [ u"nl",u"Mierlo",10309,51.442222,5.619696 ],
    [ u"nl",u"Moerdijk",36518,51.701005,4.625543 ],
    [ u"nl",u"Monster",20629,52.026383,4.173593 ],
    [ u"nl",u"Montfoort",13385,52.048133,4.956201 ],
    [ u"nl",u"Naaldwijk",28916,51.997897,4.220444 ],
    [ u"nl",u"Naarden",17047,52.292164,5.149612 ],
    [ u"nl",u"Nederweert",16284,51.285013,5.749804 ],
    [ u"nl",u"Neede",11082,52.135118,6.611966 ],
    [ u"nl",u"Neerijnen",11782,51.83442,5.278538 ],
    [ u"nl",u"Nieuwegein",62806,52.014842,5.100406 ],
    [ u"nl",u"Nieuwkoop",11010,52.150919,4.779827 ],
    [ u"nl",u"Nijkerk",37845,52.221637,5.494962 ],
    [ u"nl",u"Nijmegen",158707,51.833333,5.866667 ],
    [ u"nl",u"Noordwijkerhout",14963,52.269556,4.488424 ],
    [ u"nl",u"Noordwijk",23908,52.237915,4.474689 ],
    [ u"nl",u"Nuenen",23755,51.466843,5.571992 ],
    [ u"nl",u"Nunspeet",26785,52.384479,5.799894 ],
    [ u"nl",u"Nuth",16257,50.917304,5.886024 ],
    [ u"nl",u"Oirschot",18057,51.50343,5.308304 ],
    [ u"nl",u"Oisterwijk",25544,51.583449,5.208564 ],
    [ u"nl",u"Oldebroek",23333,52.445567,5.901554 ],
    [ u"nl",u"Oldenzaal",31843,52.311841,6.929745 ],
    [ u"nl",u"Ommen",17301,52.52023,6.426631 ],
    [ u"nl",u"Oostburg",18437,51.328206,3.500821 ],
    [ u"nl",u"Oosterhout",54110,51.65,4.883333 ],
    [ u"nl",u"Ootmarsum",4748,52.409049,6.897143 ],
    [ u"nl",u"Opmeer",11755,52.705864,4.937754 ],
    [ u"nl",u"Oss",69965,51.766667,5.533333 ],
    [ u"nl",u"Oud-Beijerland",23787,51.817051,4.417294 ],
    [ u"nl",u"Oudewater",9755,52.025333,4.865822 ],
    [ u"nl",u"Papendrecht",31379,51.837307,4.698733 ],
    [ u"nl",u"Purmerend",80807,52.509624,4.963885 ],
    [ u"nl",u"Putten",23832,52.260897,5.613074 ],
    [ u"nl",u"Raalte",37298,52.383776,6.280611 ],
    [ u"nl",u"Reeuwijk",12970,52.046969,4.73107 ],
    [ u"nl",u"Renkum",32323,51.970509,5.732412 ],
    [ u"nl",u"Rheden",45374,52.001632,6.022799 ],
    [ u"nl",u"Rhenen",17957,51.963321,5.570359 ],
    [ u"nl",u"Ridderkerk",45568,51.872419,4.612876 ],
    [ u"nl",u"Rijnsburg",15297,52.198324,4.45467 ],
    [ u"nl",u"Rijssen",36244,52.308315,6.519603 ],
    [ u"nl",u"Rijswijk",48413,52.025498,4.310793 ],
    [ u"nl",u"Roermond",46558,51.192695,5.988403 ],
    [ u"nl",u"Roosendaal",81228,51.537721,4.492456 ],
    [ u"nl",u"Rotterdam",603851,51.916667,4.5 ],
    [ u"nl",u"Rozenburg",12960,52.283853,4.739689 ],
    [ u"nl",u"Rucphen",22872,51.532362,4.558424 ],
    [ u"nl",u"Sassenheim",15097,52.224359,4.522668 ],
    [ u"nl",u"Schagen",17416,52.787325,4.806897 ],
    [ u"nl",u"Scheemda",14363,53.17587,6.978039 ],
    [ u"nl",u"Schiedam",76874,51.932178,4.39268 ],
    [ u"nl",u"Schijndel",24324,51.622291,5.440344 ],
    [ u"nl",u"Schinnen",13365,50.943293,5.892579 ],
    [ u"nl",u"Schipluiden",1112,51.974596,4.319217 ],
    [ u"nl",u"Schoonhoven",12471,51.948241,4.847943 ],
    [ u"nl",u"Simpelveld",11276,50.834094,5.97529 ],
    [ u"nl",u"Sint Anthonis",12007,51.627215,5.880679 ],
    [ u"nl",u"Sint-Oedenrode",17119,51.568126,5.457817 ],
    [ u"nl",u"Sliedrecht",23758,51.827601,4.773104 ],
    [ u"nl",u"Slochteren",15317,53.218315,6.810277 ],
    [ u"nl",u"Sneek",34562,53.032883,5.663313 ],
    [ u"nl",u"Soest",45752,52.180667,5.302906 ],
    [ u"nl",u"Someren",18786,51.385715,5.712161 ],
    [ u"nl",u"Son en Breugel",15366,51.516667,5.5 ],
    [ u"nl",u"Spijkenisse",78642,51.841105,4.315098 ],
    [ u"nl",u"Stadskanaal",34316,53.00692,6.9225 ],
    [ u"nl",u"Staphorst",15821,52.644273,6.210885 ],
    [ u"nl",u"Steenbergen",23793,51.585542,4.322397 ],
    [ u"nl",u"Steenwijk",42799,52.78565,6.137477 ],
    [ u"nl",u"Stein",26602,50.968414,5.767249 ],
    [ u"nl",u"Strijen",9190,51.744569,4.55104 ],
    [ u"nl",u"Susteren",13006,51.062965,5.851675 ],
    [ u"nl",u"Terneuzen",34771,51.331784,3.840803 ],
    [ u"nl",u"The Hague",476587,52.083333,4.3 ],
    [ u"nl",u"Tholen",24399,51.538943,4.217106 ],
    [ u"nl",u"Tiel",43643,51.889251,5.442649 ],
    [ u"nl",u"Tilburg",206858,51.576922,5.106331 ],
    [ u"nl",u"Tubbergen",20542,52.405786,6.786368 ],
    [ u"nl",u"Tynaarlo",32389,53.078792,6.618141 ],
    [ u"nl",u"Uden",41221,51.663777,5.62398 ],
    [ u"nl",u"Uitgeest",12293,52.531713,4.705922 ],
    [ u"nl",u"Uithoorn",27154,52.246485,4.849644 ],
    [ u"nl",u"Urk",17887,52.661259,5.594415 ],
    [ u"nl",u"Utrecht",267044,52.093813,5.119095 ],
    [ u"nl",u"Vaals",10679,50.769835,5.994864 ],
    [ u"nl",u"Valkenburg",17778,50.864835,5.827774 ],
    [ u"nl",u"Valkenswaard",31158,51.352662,5.456101 ],
    [ u"nl",u"Veendam",28099,53.114857,6.896614 ],
    [ u"nl",u"Veenendaal",63119,52.024371,5.559791 ],
    [ u"nl",u"Veere",21939,51.548193,3.668182 ],
    [ u"nl",u"Veghel",37273,51.618548,5.550439 ],
    [ u"nl",u"Veldhoven",43615,51.416667,5.416667 ],
    [ u"nl",u"Velsen",68513,52.460671,4.648334 ],
    [ u"nl",u"Venlo",91783,51.370837,6.175101 ],
    [ u"nl",u"Venray",40518,51.524517,5.975006 ],
    [ u"nl",u"Vianen",20029,51.987057,5.095258 ],
    [ u"nl",u"Vlaardingen",74210,51.921038,4.321877 ],
    [ u"nl",u"Vlagtwedde",17047,53.027478,7.115137 ],
    [ u"nl",u"Vlissingen",45816,51.449399,3.572279 ],
    [ u"nl",u"Vlist",9874,51.983806,4.815229 ],
    [ u"nl",u"Voerendaal",13132,50.879763,5.934949 ],
    [ u"nl",u"Voorhout",16650,52.222592,4.482752 ],
    [ u"nl",u"Voorschoten",22271,52.13098,4.465828 ],
    [ u"nl",u"Voorst",24046,51.875462,6.41863 ],
    [ u"nl",u"Vriezenveen",33809,52.41012,6.623554 ],
    [ u"nl",u"Vught",26082,51.655197,5.294188 ],
    [ u"nl",u"Waalre",16596,51.390482,5.43095 ],
    [ u"nl",u"Waalwijk",46197,51.685764,5.072072 ],
    [ u"nl",u"Wageningen",35080,51.973279,5.667556 ],
    [ u"nl",u"Wassenaar",25317,52.110844,4.355982 ],
    [ u"nl",u"Wateringen",17050,52.023061,4.274782 ],
    [ u"nl",u"Weert",49614,51.250562,5.717901 ],
    [ u"nl",u"Weesp",17833,52.30773,5.039749 ],
    [ u"nl",u"Werkendam",26986,51.809796,4.89371 ],
    [ u"nl",u"Westervoort",16208,51.963667,5.971273 ],
    [ u"nl",u"Wierden",23783,52.362795,6.590944 ],
    [ u"nl",u"Wijchen",40392,51.816174,5.749562 ],
    [ u"nl",u"Winschoten",18703,53.144032,7.03518 ],
    [ u"nl",u"Winsum",14355,53.32724,6.530143 ],
    [ u"nl",u"Winterswijk",29098,51.971776,6.719631 ],
    [ u"nl",u"Wisch",19389,51.933333,6.316667 ],
    [ u"nl",u"Woensdrecht",22318,51.42964,4.302153 ],
    [ u"nl",u"Woerden",48653,52.092526,4.905165 ],
    [ u"nl",u"Woudenberg",11182,52.08016,5.420615 ],
    [ u"nl",u"Woudrichem",14762,51.811967,4.99719 ],
    [ u"nl",u"Zaanstad",141800,52.45,4.833333 ],
    [ u"nl",u"Zaltbommel",26178,51.806782,5.243605 ],
    [ u"nl",u"Zandvoort",17893,52.371424,4.527049 ],
    [ u"nl",u"Zeewolde",22932,52.330224,5.536412 ],
    [ u"nl",u"Zeist",60233,52.094411,5.241944 ],
    [ u"nl",u"Zelhem",11039,52.006954,6.348991 ],
    [ u"nl",u"Zevenaar",25576,51.925387,6.095747 ],
    [ u"nl",u"Zijpe",11334,51.65,4.1 ],
    [ u"nl",u"Zoetermeer",114144,52.027803,4.512315 ],
    [ u"nl",u"Zuidhorn",18338,53.25101,6.408798 ],
    [ u"nl",u"Zundert",20656,51.469444,4.658109 ],
    [ u"nl",u"Zutphen",38399,52.140449,6.204791 ],
    [ u"nl",u"Zwijndrecht",41148,51.816684,4.61763 ],
    [ u"nl",u"Zwolle",114924,52.505751,6.085822 ],
    [ u"no",u"Å",1145,63.966667,10.216667 ],
    [ u"no",u"Å",1145,63.966667,10.2 ],
    [ u"no",u"Ådalsbruk",541,60.783333,11.3 ],
    [ u"no",u"Ågotnes",1431,60.406111,5.018889 ],
    [ u"no",u"Ål",2291,60.633333,8.566667 ],
    [ u"no",u"Alnes",203,62.483333,5.966667 ],
    [ u"no",u"Alsvåg",335,68.9,15.283333 ],
    [ u"no",u"Alta",12101,69.966667,23.241667 ],
    [ u"no",u"Alvdal",697,62.116667,10.65 ],
    [ u"no",u"Ålvik",584,60.416667,6.366667 ],
    [ u"no",u"Åmli",561,58.45,8.333333 ],
    [ u"no",u"Åmot",603,59.583333,8 ],
    [ u"no",u"Andenes",2789,69.320278,16.142778 ],
    [ u"no",u"Andselv",700,69.066667,18.566667 ],
    [ u"no",u"Åneby",1354,60.083333,10.866667 ],
    [ u"no",u"Årås",602,60.778056,4.933056 ],
    [ u"no",u"Årdalstangen",1495,61.233333,7.716667 ],
    [ u"no",u"Årnes",3113,60.15,11.466667 ],
    [ u"no",u"Åros",1123,59.703056,10.513611 ],
    [ u"no",u"Årøysund",2102,59.180556,10.455 ],
    [ u"no",u"Årset",467,62.7,7.583333 ],
    [ u"no",u"Ås",7891,59.666667,10.8 ],
    [ u"no",u"Åsen",447,63.583333,11 ],
    [ u"no",u"Åsgårdstrand",2932,59.348889,10.4675 ],
    [ u"no",u"Ask",1084,60.083333,11.033333 ],
    [ u"no",u"Askim",12488,59.583333,11.166667 ],
    [ u"no",u"Askøy",17352,60.4,5.183333 ],
    [ u"no",u"Aukra",712,62.783333,6.9 ],
    [ u"no",u"Aurdal",703,60.933333,9.4 ],
    [ u"no",u"Austnes",397,62.633333,6.266667 ],
    [ u"no",u"Bagn",606,60.816667,9.566667 ],
    [ u"no",u"Balestrand",799,61.2,6.533333 ],
    [ u"no",u"Ballangen",1001,68.335278,16.821111 ],
    [ u"no",u"Ballstad",763,68.066667,13.55 ],
    [ u"no",u"Bangsund",885,64.4,11.4 ],
    [ u"no",u"Barkåker",1218,59.316667,10.383333 ],
    [ u"no",u"Batnfjordsøra",339,62.883333,7.7 ],
    [ u"no",u"Båtsfjord",2216,70.632222,29.699722 ],
    [ u"no",u"Beisfjord",626,68.368056,17.588889 ],
    [ u"no",u"Bekkjarvik",371,60.002778,5.200278 ],
    [ u"no",u"Berg",469,65.366667,12.2 ],
    [ u"no",u"Bergen",214154,60.391111,5.324722 ],
    [ u"no",u"Berger",1134,59.545,10.371389 ],
    [ u"no",u"Berkåk",905,62.833333,10 ],
    [ u"no",u"Berlevåg",1087,70.85,29.1 ],
    [ u"no",u"Birkeland",2209,58.333333,8.233333 ],
    [ u"no",u"Bjerka",449,66.15,13.883333 ],
    [ u"no",u"Bjerkvik",1207,68.559722,17.518889 ],
    [ u"no",u"Bjørkelangen",2360,59.883333,11.566667 ],
    [ u"no",u"Bjørnevatn",2343,69.667222,29.984722 ],
    [ u"no",u"Bjørnli",288,63.133333,9.683333 ],
    [ u"no",u"Blakstad",1944,59.819167,10.474722 ],
    [ u"no",u"Bleik",481,69.283056,15.998333 ],
    [ u"no",u"Bø",718,68.366667,16.9 ],
    [ u"no",u"Bö",2478,59.15,8.816667 ],
    [ u"no",u"Bodø",33811,67.283333,14.383333 ],
    [ u"no",u"Bogen",388,68.533333,17 ],
    [ u"no",u"Borgen",583,60.083333,11.216667 ],
    [ u"no",u"Borkenes",1458,68.783333,16.183333 ],
    [ u"no",u"Botngard",1146,63.766667,9.816667 ],
    [ u"no",u"Brandal",308,62.4,6 ],
    [ u"no",u"Brandsøy",474,61.616667,5.133333 ],
    [ u"no",u"Braskereidfoss",267,60.716667,11.783333 ],
    [ u"no",u"Brattvåg",2192,62.6,6.45 ],
    [ u"no",u"Brekstad",1879,63.683333,9.683333 ],
    [ u"no",u"Bremsnes",417,63.1,7.666667 ],
    [ u"no",u"Brønnøysund",4352,65.466667,12.216667 ],
    [ u"no",u"Brumunddal",8385,60.883333,10.933333 ],
    [ u"no",u"Brusand",399,58.533333,5.766667 ],
    [ u"no",u"Bryggja",386,61.933333,5.383333 ],
    [ u"no",u"Bud",779,62.916667,6.916667 ],
    [ u"no",u"Byglandsfjord",328,58.683333,7.8 ],
    [ u"no",u"Bykle",226,59.35,7.333333 ],
    [ u"no",u"Byrknes",291,60.9,4.833333 ],
    [ u"no",u"Dale",1242,60.283333,5.7 ],
    [ u"no",u"Dale",784,61.783333,9.5 ],
    [ u"no",u"Dale",961,61.233333,6.1 ],
    [ u"no",u"Dalen",810,59.45,8.35 ],
    [ u"no",u"Dimmelsvik",223,59.95,5.983333 ],
    [ u"no",u"Disenå",280,60.2,11.65 ],
    [ u"no",u"Dokka",2868,60.833333,10.083333 ],
    [ u"no",u"Dombås",1195,62.083333,9.133333 ],
    [ u"no",u"Dovre",459,61.983333,9.25 ],
    [ u"no",u"Drammen",90692,59.7425,10.211667 ],
    [ u"no",u"Drøbak",11261,59.663333,10.631111 ],
    [ u"no",u"Egersund",9547,58.45,6 ],
    [ u"no",u"Eggkleiva",235,63.283333,10.05 ],
    [ u"no",u"Eidfjord",575,60.466667,7.083333 ],
    [ u"no",u"Eidsvåg",886,62.781944,8.071111 ],
    [ u"no",u"Eidsvoll",3432,60.316667,11.233333 ],
    [ u"no",u"Eikeland",406,58.8,9.1 ],
    [ u"no",u"Eikelandsosen",422,60.239444,5.753889 ],
    [ u"no",u"Eina",652,60.633333,10.6 ],
    [ u"no",u"Elverum",12585,60.883333,11.566667 ],
    [ u"no",u"Ersfjordbotn",301,69.691944,18.618333 ],
    [ u"no",u"Espeland",1782,60.383333,5.466667 ],
    [ u"no",u"Etne",973,59.666667,5.933333 ],
    [ u"no",u"Evenskjær",641,68.583333,16.566667 ],
    [ u"no",u"Fagernes",1813,60.983333,9.25 ],
    [ u"no",u"Fagerstrand",2018,59.734722,10.593056 ],
    [ u"no",u"Farsund",3088,58.083333,6.8 ],
    [ u"no",u"Fauske",5974,67.25,15.4 ],
    [ u"no",u"Feda",407,58.266667,6.833333 ],
    [ u"no",u"Fedje",480,60.781111,4.713056 ],
    [ u"no",u"Fetsund",6480,59.933333,11.166667 ],
    [ u"no",u"Fevik",5070,58.383333,8.7 ],
    [ u"no",u"Fillan",532,63.6,8.983333 ],
    [ u"no",u"Finnsnes",3942,69.233333,17.983333 ],
    [ u"no",u"Fitjar",1321,59.9175,5.322778 ],
    [ u"no",u"Fjelldal",327,68.55,16.55 ],
    [ u"no",u"Fjellsrud",427,59.883333,11.216667 ],
    [ u"no",u"Fjellstrand",825,59.795278,10.610556 ],
    [ u"no",u"Flateby",3186,59.833333,11.166667 ],
    [ u"no",u"Flekkefjord",5707,58.283333,6.683333 ],
    [ u"no",u"Flesland",303,60.293889,5.215278 ],
    [ u"no",u"Florø",8169,61.6,5 ],
    [ u"no",u"Folkestad",430,59.433333,9.066667 ],
    [ u"no",u"Follafoss",484,63.983333,11.1 ],
    [ u"no",u"Folldal",564,62.133333,10.05 ],
    [ u"no",u"Follebu",926,61.233333,10.283333 ],
    [ u"no",u"Førde",375,59.608889,5.466111 ],
    [ u"no",u"Forset",653,61.2,10.15 ],
    [ u"no",u"Fosby",324,59.216667,11.7 ],
    [ u"no",u"Fosser",569,59.816667,11.483333 ],
    [ u"no",u"Fotlandsvåg",248,60.6,5.5 ],
    [ u"no",u"Frekhaug",1633,60.517222,5.246111 ],
    [ u"no",u"Frogner",1142,60.016667,11.1 ],
    [ u"no",u"Fuglevik",470,59.385,10.655 ],
    [ u"no",u"Furuflaten",227,69.45,20.15 ],
    [ u"no",u"Fyresdal",354,59.183333,8.1 ],
    [ u"no",u"Geilo",2289,60.516667,8.2 ],
    [ u"no",u"Gibostad",384,69.35,18.066667 ],
    [ u"no",u"Gilja",254,58.8,6.266667 ],
    [ u"no",u"Gjerstad",353,58.866667,9 ],
    [ u"no",u"Gjølme",473,63.316667,9.816667 ],
    [ u"no",u"Gjøvik",17733,60.8,10.7 ],
    [ u"no",u"Gjusvik",1635,58.2,8.033333 ],
    [ u"no",u"Gladstad",302,65.683333,11.966667 ],
    [ u"no",u"Glomfjord",1196,66.8,13.933333 ],
    [ u"no",u"Gol",2521,60.7,8.95 ],
    [ u"no",u"Granvin",469,60.55,6.716667 ],
    [ u"no",u"Gravdal",1628,68.121389,13.503056 ],
    [ u"no",u"Grimstad",9581,58.340556,8.588611 ],
    [ u"no",u"Grinder",231,60.383333,12.05 ],
    [ u"no",u"Grøa",500,62.65,8.716667 ],
    [ u"no",u"Grødås",386,61.966667,6.533333 ],
    [ u"no",u"Grong",1073,64.45,12.333333 ],
    [ u"no",u"Grov",282,68.680833,17.125556 ],
    [ u"no",u"Grua",1491,60.266667,10.666667 ],
    [ u"no",u"Gryllefjord",459,69.366667,17.016667 ],
    [ u"no",u"Gullhaug",1948,59.5,10.25 ],
    [ u"no",u"Gvarv",891,59.383333,9.15 ],
    [ u"no",u"Haddal",314,62.283333,5.883333 ],
    [ u"no",u"Haga",910,60.387778,5.770556 ],
    [ u"no",u"Hagavik",1375,60.183333,5.433333 ],
    [ u"no",u"Håkvik",545,68.4,17.316667 ],
    [ u"no",u"Halden",22029,59.15,11.383333 ],
    [ u"no",u"Hallingby",740,60.266667,10.2 ],
    [ u"no",u"Hammarsland",409,60.2525,5.073333 ],
    [ u"no",u"Hammerfest",6730,70.661667,23.688333 ],
    [ u"no",u"Hamnås",207,59.616667,11.416667 ],
    [ u"no",u"Hansnes",330,69.966667,19.6 ],
    [ u"no",u"Hardbakke",234,61.083333,4.85 ],
    [ u"no",u"Hareid",3617,62.366667,6.033333 ],
    [ u"no",u"Harpefoss",453,61.583333,9.85 ],
    [ u"no",u"Harstad",19574,68.8025,16.545556 ],
    [ u"no",u"Hasvik",392,70.483333,22.15 ],
    [ u"no",u"Hauge",322,59.1,10.883333 ],
    [ u"no",u"Hauge",2146,58.35,6.283333 ],
    [ u"no",u"Haugland",438,60.283333,5.466667 ],
    [ u"no",u"Hauknes",1860,66.283333,14.066667 ],
    [ u"no",u"Havøysund",1149,71.000556,24.696111 ],
    [ u"no",u"Hegra",637,63.466667,11.116667 ],
    [ u"no",u"Heiås",661,59.7,11.3 ],
    [ u"no",u"Hell",1003,63.433333,10.9 ],
    [ u"no",u"Hellvik",649,58.483333,5.9 ],
    [ u"no",u"Hemnesberget",1240,66.233333,13.633333 ],
    [ u"no",u"Hemnes",611,59.716667,11.466667 ],
    [ u"no",u"Hemsedal",659,60.866667,8.566667 ],
    [ u"no",u"Henningsvær",407,68.15,14.216667 ],
    [ u"no",u"Heradsbygd",466,60.816667,11.633333 ],
    [ u"no",u"Herøysund",391,59.917222,5.789444 ],
    [ u"no",u"Herre",1347,59.1,9.566667 ],
    [ u"no",u"Hestvika",235,63.566667,9.183333 ],
    [ u"no",u"Hillestad",344,59.583333,9.666667 ],
    [ u"no",u"Hjelset",1008,62.783333,7.483333 ],
    [ u"no",u"Hjukse",376,59.516667,9.316667 ],
    [ u"no",u"Hof",818,60.55,12.016667 ],
    [ u"no",u"Høle",301,58.883333,6 ],
    [ u"no",u"Hølen",388,59.539722,10.739722 ],
    [ u"no",u"Holevik",341,61.928889,5.079722 ],
    [ u"no",u"Høllen",462,58.083333,7.816667 ],
    [ u"no",u"Holme",643,59.651389,5.161389 ],
    [ u"no",u"Holmestrand",6076,59.488333,10.302778 ],
    [ u"no",u"Holmsbu",345,59.561389,10.4275 ],
    [ u"no",u"Hommelvik",4013,63.416667,10.8 ],
    [ u"no",u"Hommersåk",5796,58.931667,5.851111 ],
    [ u"no",u"Hønefoss",13826,60.166667,10.3 ],
    [ u"no",u"Honningsvåg",2561,70.983333,25.983333 ],
    [ u"no",u"Horten",17876,59.413611,10.466944 ],
    [ u"no",u"Hovden",293,59.533333,7.35 ],
    [ u"no",u"Hov",2150,60.7,10.35 ],
    [ u"no",u"Hovin",592,63.116667,10.25 ],
    [ u"no",u"Høyanger",2293,61.216667,6.083333 ],
    [ u"no",u"Hundorp",601,61.55,9.9 ],
    [ u"no",u"Hvittingfoss",1026,59.483333,10.016667 ],
    [ u"no",u"Hyggen",394,59.716667,10.355278 ],
    [ u"no",u"Hylkje",1801,60.510278,5.354444 ],
    [ u"no",u"Hylla",353,63.833333,11.383333 ],
    [ u"no",u"Ibestad",464,68.8,17.133333 ],
    [ u"no",u"Ikornnes",817,62.383333,6.566667 ],
    [ u"no",u"Indre Arna",6202,60.424722,5.476389 ],
    [ u"no",u"Inndyr",662,67.033333,14.033333 ],
    [ u"no",u"Innvik",363,61.85,6.616667 ],
    [ u"no",u"Ise",717,59.3,11.233333 ],
    [ u"no",u"Jessheim",12245,60.15,11.183333 ],
    [ u"no",u"Jevnaker",4347,60.25,10.466667 ],
    [ u"no",u"Jørpeland",5539,59.016667,6.05 ],
    [ u"no",u"Judaberg",555,59.183333,5.85 ],
    [ u"no",u"Kabelvåg",1654,68.211389,14.481667 ],
    [ u"no",u"Kalvåg",369,61.766667,4.883333 ],
    [ u"no",u"Karasjok",1928,69.45,25.5 ],
    [ u"no",u"Karlshus",1780,59.35,10.866667 ],
    [ u"no",u"Kasfjord",281,68.834167,16.355 ],
    [ u"no",u"Kaupanger",874,61.183333,7.233333 ],
    [ u"no",u"Kautokeino",1349,68.983333,23.133333 ],
    [ u"no",u"Kiberg",262,70.283333,31 ],
    [ u"no",u"Kil",936,58.866667,9.316667 ],
    [ u"no",u"Kirkenær",1220,60.466667,12.05 ],
    [ u"no",u"Kirkenes",3314,69.725,30.051667 ],
    [ u"no",u"Kjellmyra",414,60.65,12.033333 ],
    [ u"no",u"Kjøllefjord",1014,70.933333,27.35 ],
    [ u"no",u"Kjøpsvik",964,68.1025,16.350556 ],
    [ u"no",u"Klæbu",2992,64.083333,11.733333 ],
    [ u"no",u"Kleive",516,62.816667,7.666667 ],
    [ u"no",u"Klofta",6036,60.066667,11.15 ],
    [ u"no",u"Klokkarvik",658,60.2225,5.155556 ],
    [ u"no",u"Knappskog",1091,60.381944,5.055833 ],
    [ u"no",u"Knarvik",4288,60.542222,5.288333 ],
    [ u"no",u"Kolvereid",1499,64.85,11.6 ],
    [ u"no",u"Kongsberg",17849,59.65,9.65 ],
    [ u"no",u"Kongsvinger",11147,60.2,12 ],
    [ u"no",u"Kopervik",6465,59.283333,5.3 ],
    [ u"no",u"Koppang",1166,61.566667,11.066667 ],
    [ u"no",u"Kopperå",210,63.4,11.85 ],
    [ u"no",u"Korgen",877,66.083333,13.833333 ],
    [ u"no",u"Korsvegen",495,63.166667,10.1 ],
    [ u"no",u"Kragerø",5266,58.866667,9.416667 ],
    [ u"no",u"Kristiansand",63784,58.166667,8 ],
    [ u"no",u"Kristiansund",16904,63.116667,7.75 ],
    [ u"no",u"Krøderen",532,60.15,9.816667 ],
    [ u"no",u"Krokeidet",415,60.226389,5.301389 ],
    [ u"no",u"Kvål",463,63.233333,10.3 ],
    [ u"no",u"Kvalsvik",261,62.366667,5.566667 ],
    [ u"no",u"Kvalvåg",258,63.066667,7.883333 ],
    [ u"no",u"Kvam",863,61.666667,9.7 ],
    [ u"no",u"Kvelde",864,59.183333,9.983333 ],
    [ u"no",u"Kviteseid",644,59.4,8.5 ],
    [ u"no",u"Kvithammer",235,63.483333,10.883333 ],
    [ u"no",u"Kylstad",294,60.866667,11.05 ],
    [ u"no",u"Kyrkjebø",254,61.166667,5.916667 ],
    [ u"no",u"Kyrksæterøra",2497,63.283333,9.1 ],
    [ u"no",u"Lærdalsøyri",1117,61.1,7.483333 ],
    [ u"no",u"Lakselv",2167,70.05,24.933333 ],
    [ u"no",u"Lalm",294,61.816667,9.266667 ],
    [ u"no",u"Langangen",507,59.1,9.8 ],
    [ u"no",u"Langevåg",726,59.600833,5.215278 ],
    [ u"no",u"Langset",325,60.4,11.25 ],
    [ u"no",u"Larkollen",1380,59.333889,10.665556 ],
    [ u"no",u"Larsnes",519,62.216667,5.6 ],
    [ u"no",u"Larvik",23222,59.066667,10 ],
    [ u"no",u"Lauvsnes",441,64.5,10.916667 ],
    [ u"no",u"Leira",792,60.966667,9.3 ],
    [ u"no",u"Leirvik",10991,59.78,5.499444 ],
    [ u"no",u"Leland",563,66.066667,12.95 ],
    [ u"no",u"Lena",1122,60.666667,10.8 ],
    [ u"no",u"Ler",459,63.2,10.333333 ],
    [ u"no",u"Lervik",2284,59.266667,10.75 ],
    [ u"no",u"Levanger",8304,63.75,11.3 ],
    [ u"no",u"Lia",258,61.65,9.65 ],
    [ u"no",u"Liland",304,68.475833,16.882778 ],
    [ u"no",u"Li",342,60.305278,5.128333 ],
    [ u"no",u"Lillehammer",19223,61.133333,10.5 ],
    [ u"no",u"Lillesand",5992,58.252222,8.378333 ],
    [ u"no",u"Lindås",1070,60.738056,5.16 ],
    [ u"no",u"Lindeberg",550,60.033333,11.133333 ],
    [ u"no",u"Lødingen",1845,68.407222,15.991944 ],
    [ u"no",u"Løding",2880,67.3,14.75 ],
    [ u"no",u"Lofthus",564,60.333333,6.666667 ],
    [ u"no",u"Løken",941,59.8,11.483333 ],
    [ u"no",u"Løkken Verk",916,63.133333,9.7 ],
    [ u"no",u"Lonevåg",523,60.533333,5.5 ],
    [ u"no",u"Løpsmarka",2302,67.316667,14.45 ],
    [ u"no",u"Lørenfallet",944,60.016667,11.216667 ],
    [ u"no",u"Løten",2480,60.816667,11.316667 ],
    [ u"no",u"Lovund",356,66.366667,12.383333 ],
    [ u"no",u"Lundamo",1102,63.133333,10.3 ],
    [ u"no",u"Lyngdal",3719,58.133333,7.083333 ],
    [ u"no",u"Lyngseidet",840,69.583333,20.216667 ],
    [ u"no",u"Lysøysund",310,63.883333,9.866667 ],
    [ u"no",u"Magnor",1006,59.95,12.2 ],
    [ u"no",u"Malm",1234,64.066667,11.216667 ],
    [ u"no",u"Måløy",3070,61.938333,5.113333 ],
    [ u"no",u"Mandal",10233,58.033333,7.45 ],
    [ u"no",u"Manger",820,60.641667,5.039167 ],
    [ u"no",u"Maura",2460,60.25,11.016667 ],
    [ u"no",u"Mehamn",733,71.033333,27.85 ],
    [ u"no",u"Melbu",2143,68.504444,14.829722 ],
    [ u"no",u"Melhus",4602,63.283333,10.266667 ],
    [ u"no",u"Melsomvik",1549,59.223889,10.344722 ],
    [ u"no",u"Midsund",438,62.683333,6.683333 ],
    [ u"no",u"Miland",400,59.916667,8.75 ],
    [ u"no",u"Minnesund",485,60.383333,11.233333 ],
    [ u"no",u"Misje",227,60.451389,4.965833 ],
    [ u"no",u"Misvær",242,67.116667,15 ],
    [ u"no",u"Moelv",4113,60.933333,10.7 ],
    [ u"no",u"Moen",857,69.118333,17.800556 ],
    [ u"no",u"Moi",1705,58.466667,6.533333 ],
    [ u"no",u"Mo i Rana",17926,66.316667,14.166667 ],
    [ u"no",u"Molde",18603,62.733333,7.183333 ],
    [ u"no",u"Mo",409,60.416667,12.033333 ],
    [ u"no",u"Mosjøen",9620,65.833333,13.2 ],
    [ u"no",u"Mosterhamn",1156,59.7,5.383333 ],
    [ u"no",u"Movik",363,69.716667,19.1 ],
    [ u"no",u"Muruvik",341,63.433333,10.85 ],
    [ u"no",u"Myklebost",276,62.5,6.3 ],
    [ u"no",u"Myra",549,58.75,8.866667 ],
    [ u"no",u"Myre",2004,69.103611,15.949167 ],
    [ u"no",u"Mysen",5502,59.55,11.333333 ],
    [ u"no",u"Nærbø",4952,58.666667,5.65 ],
    [ u"no",u"Nakkerud",353,60.05,10.05 ],
    [ u"no",u"Namsos",8946,64.483333,11.5 ],
    [ u"no",u"Narvik",14178,68.435556,17.437222 ],
    [ u"no",u"Naustdal",1055,61.516667,5.716667 ],
    [ u"no",u"Nedstrand",233,59.35,5.85 ],
    [ u"no",u"Nerland",219,62.7,8 ],
    [ u"no",u"Nesbyen",2067,60.566667,9.1 ],
    [ u"no",u"Nesjestranda",331,62.7,7.45 ],
    [ u"no",u"Nesna",1194,66.2,13.033333 ],
    [ u"no",u"Nesoddtangen",10940,59.866667,10.65 ],
    [ u"no",u"Nodeland",1815,58.15,7.85 ],
    [ u"no",u"Nordfjordeid",2535,61.9,6 ],
    [ u"no",u"Nordkisa",900,60.183333,11.266667 ],
    [ u"no",u"Nordkjosbotn",391,69.216667,19.566667 ],
    [ u"no",u"Nordvågen",445,70.983333,26.033333 ],
    [ u"no",u"Nordvik",364,60.232778,5.366667 ],
    [ u"no",u"Noresund",367,60.166667,9.616667 ],
    [ u"no",u"Norheimsund",2121,60.366667,6.133333 ],
    [ u"no",u"Notodden",8306,59.566667,9.283333 ],
    [ u"no",u"Nybergsund",329,61.25,12.316667 ],
    [ u"no",u"Nykirke",663,59.421944,10.380833 ],
    [ u"no",u"Odda",5515,60.066667,6.55 ],
    [ u"no",u"Ogna",324,58.516667,5.8 ],
    [ u"no",u"Øksfjord",527,70.239167,22.371389 ],
    [ u"no",u"Olden",545,63.866667,9.933333 ],
    [ u"no",u"Olderdalen",317,69.616667,20.533333 ],
    [ u"no",u"Ølen",905,59.603611,5.8075 ],
    [ u"no",u"Oltedal",719,58.833333,6.033333 ],
    [ u"no",u"Oppdal",3786,62.6,9.666667 ],
    [ u"no",u"Opphaug",358,63.733333,9.7 ],
    [ u"no",u"Ørje",1744,59.483333,11.65 ],
    [ u"no",u"Ørnes",1549,66.866667,13.7 ],
    [ u"no",u"Ørsta",6425,62.2,6.15 ],
    [ u"no",u"Oslo",808690,59.916667,10.75 ],
    [ u"no",u"Os",662,62.5,11.2 ],
    [ u"no",u"Os",16055,60.183944,5.475833 ],
    [ u"no",u"Østhusvik",298,59.1,5.783333 ],
    [ u"no",u"Otnes",311,62.033333,5.483333 ],
    [ u"no",u"Otta",1623,61.766667,9.533333 ],
    [ u"no",u"Ottersbo",339,63.7,9.75 ],
    [ u"no",u"Øvre Årdal",3439,61.316667,7.8 ],
    [ u"no",u"Øyslebø",380,58.166667,7.55 ],
    [ u"no",u"Øystese",1636,60.383333,6.216667 ],
    [ u"no",u"Pollestad",467,58.716667,5.583333 ],
    [ u"no",u"Prestfoss",486,60.033333,9.633333 ],
    [ u"no",u"Rafsbotn",364,70.016667,23.533333 ],
    [ u"no",u"Rakkestad",3813,59.433333,11.35 ],
    [ u"no",u"Ramsund",306,68.483333,16.533333 ],
    [ u"no",u"Ranemsletta",299,64.5,11.95 ],
    [ u"no",u"Raudeberg",707,61.980556,5.133611 ],
    [ u"no",u"Raufoss",6071,60.716667,10.616667 ],
    [ u"no",u"Rausand",305,62.834722,8.122222 ],
    [ u"no",u"Reine",356,67.933333,13.1 ],
    [ u"no",u"Reinsvoll",1157,60.683333,10.616667 ],
    [ u"no",u"Reipå",307,66.9,13.65 ],
    [ u"no",u"Rena",2051,61.133333,11.366667 ],
    [ u"no",u"Rensvik",2139,63.1,7.816667 ],
    [ u"no",u"Rindal",658,63.05,9.216667 ],
    [ u"no",u"Ringebu",1332,61.516667,10.166667 ],
    [ u"no",u"Risør",4450,58.716667,9.233333 ],
    [ u"no",u"Risøyhamn",208,68.966667,15.633333 ],
    [ u"no",u"Rjukan",3576,59.866667,8.566667 ],
    [ u"no",u"Roald",678,62.583333,6.133333 ],
    [ u"no",u"Rød",345,59.066667,10.95 ],
    [ u"no",u"Rognan",2492,67.1,15.383333 ],
    [ u"no",u"Rokland",498,66.983333,15.316667 ],
    [ u"no",u"Røra",493,63.866667,11.4 ],
    [ u"no",u"Røros",3499,62.583333,11.4 ],
    [ u"no",u"Rørvik",2621,64.85,11.233333 ],
    [ u"no",u"Rosendal",965,59.983333,6.016667 ],
    [ u"no",u"Røsvik",216,67.483333,15.466667 ],
    [ u"no",u"Rotnes",4766,60.05,10.883333 ],
    [ u"no",u"Roverud",882,60.25,12.05 ],
    [ u"no",u"Røyken",2902,59.7475,10.393611 ],
    [ u"no",u"Røyrvik",247,64.883333,13.55 ],
    [ u"no",u"Rubbestadneset",1132,59.814722,5.268056 ],
    [ u"no",u"Rypefjord",1741,70.633333,23.666667 ],
    [ u"no",u"Sæbøvik",832,59.7975,5.714722 ],
    [ u"no",u"Sætre",3037,59.681667,10.524722 ],
    [ u"no",u"Sagvåg",3308,59.778611,5.396111 ],
    [ u"no",u"Sandane",2137,61.766667,6.216667 ],
    [ u"no",u"Sandeid",570,59.55,5.833333 ],
    [ u"no",u"Sander",319,60.216667,11.816667 ],
    [ u"no",u"Sande",533,61.333333,5.8 ],
    [ u"no",u"Sande",1335,59.6,10.2 ],
    [ u"no",u"Sandnes",383,68.583333,14.883333 ],
    [ u"no",u"Sandnessjøen",5708,66.016667,12.633333 ],
    [ u"no",u"Sand",977,60.383333,11.55 ],
    [ u"no",u"Sandve",323,59.183333,5.2 ],
    [ u"no",u"Sauda",4313,59.65,6.333333 ],
    [ u"no",u"Segalstad",899,61.233333,10.233333 ],
    [ u"no",u"Selbekken",361,63.5,9.833333 ],
    [ u"no",u"Selje",714,62.049167,5.348056 ],
    [ u"no",u"Seljord",1187,59.483333,8.616667 ],
    [ u"no",u"Selvik",1866,59.568889,10.258333 ],
    [ u"no",u"Sem",1852,59.283333,10.333333 ],
    [ u"no",u"Setermoen",2358,68.866667,18.366667 ],
    [ u"no",u"Sigerfjord",771,68.646111,15.538333 ],
    [ u"no",u"Siljan",966,59.3,9.7 ],
    [ u"no",u"Sira",600,58.416667,6.633333 ],
    [ u"no",u"Sirevåg",398,58.5,5.783333 ],
    [ u"no",u"Sistranda",678,63.716667,8.833333 ],
    [ u"no",u"Sjøholt",1123,62.483333,6.8 ],
    [ u"no",u"Sjøvegan",716,68.873333,17.864444 ],
    [ u"no",u"Skage",635,64.466667,11.75 ],
    [ u"no",u"Skånevik",615,59.733333,5.983333 ],
    [ u"no",u"Skarnes",2129,60.25,11.683333 ],
    [ u"no",u"Skibotn",500,69.4,20.266667 ],
    [ u"no",u"Skjærhollen",631,59.033333,11.033333 ],
    [ u"no",u"Skjeberg",1876,59.233333,11.2 ],
    [ u"no",u"Skjervøy",2376,70.033333,20.983333 ],
    [ u"no",u"Skjold",612,59.516667,5.583333 ],
    [ u"no",u"Skjold",222,69.033333,19.283333 ],
    [ u"no",u"Skodje",1599,62.516667,6.716667 ],
    [ u"no",u"Skogn",1916,63.633333,11.216667 ],
    [ u"no",u"Skoppum",1567,59.383333,10.416667 ],
    [ u"no",u"Skotterud",1357,59.983333,12.116667 ],
    [ u"no",u"Skreia",1304,60.65,10.933333 ],
    [ u"no",u"Slevik",983,59.2,10.833333 ],
    [ u"no",u"Småland",349,63.6,10.716667 ],
    [ u"no",u"Smestad",582,59.933333,10.433333 ],
    [ u"no",u"Snåsa",748,64.25,12.366667 ],
    [ u"no",u"Søgne",7728,58.083333,7.816667 ],
    [ u"no",u"Sokna",543,60.233333,9.9 ],
    [ u"no",u"Soknedal",282,62.95,10.183333 ],
    [ u"no",u"Solsvik",531,60.436667,4.968611 ],
    [ u"no",u"Sommarøy",276,69.633056,18.008611 ],
    [ u"no",u"Sørkjosen",865,69.8,20.933333 ],
    [ u"no",u"Sørland",589,67.666667,12.7 ],
    [ u"no",u"Sortland",4609,68.701944,15.423889 ],
    [ u"no",u"Sørumsand",3698,59.966667,11.25 ],
    [ u"no",u"Sørvær",198,70.633333,21.983333 ],
    [ u"no",u"Sørvågen",477,67.883333,13.033333 ],
    [ u"no",u"Søvik",728,60.216111,5.387222 ],
    [ u"no",u"Sövik",599,62.55,6.3 ],
    [ u"no",u"Sparbu",619,63.916667,11.433333 ],
    [ u"no",u"Sponvika",421,59.1,11.233333 ],
    [ u"no",u"Spydeberg",3161,59.6,11.083333 ],
    [ u"no",u"Stamsund",1010,68.125833,13.805278 ],
    [ u"no",u"Stange",2494,60.716667,11.183333 ],
    [ u"no",u"Stanghelle",772,60.55,5.733333 ],
    [ u"no",u"Stavanger",173535,58.966667,5.75 ],
    [ u"no",u"Stavern",5577,58.966667,10.083333 ],
    [ u"no",u"Steinkjer",11198,64.016667,11.5 ],
    [ u"no",u"Steinshamn",473,62.783333,6.483333 ],
    [ u"no",u"Stjørdalshalsen",9848,63.466667,10.933333 ],
    [ u"no",u"Stokke",2625,59.216667,10.283333 ],
    [ u"no",u"Stokmarknes",3135,68.561944,14.908611 ],
    [ u"no",u"Storås",323,63.1,9.6 ],
    [ u"no",u"Storebö",1090,60.1,5.233333 ],
    [ u"no",u"Storforshei",687,66.4,14.516667 ],
    [ u"no",u"Storslett",1444,69.583333,20.583333 ],
    [ u"no",u"Storsteinnes",914,69.233333,19.233333 ],
    [ u"no",u"Strai",1389,58.2,7.9 ],
    [ u"no",u"Stranda",2537,62.316667,6.9 ],
    [ u"no",u"Strand",562,68.7,15.45 ],
    [ u"no",u"Straumen",815,67.35,15.6 ],
    [ u"no",u"Straumen",1173,63.866667,11.3 ],
    [ u"no",u"Straume",282,68.683333,14.466667 ],
    [ u"no",u"Strømsnes",497,67.973056,15.927222 ],
    [ u"no",u"Stryn",2119,61.916667,6.783333 ],
    [ u"no",u"Sulitjelma",488,67.15,16.05 ],
    [ u"no",u"Sundvollen",734,60.066667,10.333333 ],
    [ u"no",u"Sunndalsøra",4223,62.666667,8.55 ],
    [ u"no",u"Svarstad",575,61.7,11.216667 ],
    [ u"no",u"Sveio",957,59.544722,5.349167 ],
    [ u"no",u"Svelgen",1204,61.766667,5.3 ],
    [ u"no",u"Svelvik",3972,59.610833,10.405833 ],
    [ u"no",u"Svene",317,59.8,9.583333 ],
    [ u"no",u"Svenevik",203,58.05,7.2 ],
    [ u"no",u"Sviland",340,58.833333,5.833333 ],
    [ u"no",u"Svolvær",4188,68.233333,14.566667 ],
    [ u"no",u"Sylling",537,59.9,10.283333 ],
    [ u"no",u"Sylte",318,62.833333,7.216667 ],
    [ u"no",u"Tælavåg",493,60.259167,4.985833 ],
    [ u"no",u"Tananger",5823,58.933333,5.6 ],
    [ u"no",u"Tanem",970,63.316667,10.45 ],
    [ u"no",u"Tangen",475,60.616667,11.266667 ],
    [ u"no",u"Tau",2507,59.066667,5.9 ],
    [ u"no",u"Tennevoll",254,68.75,17.8 ],
    [ u"no",u"Terråk",611,65.083333,12.416667 ],
    [ u"no",u"Tjøme",2376,59.116667,10.4 ],
    [ u"no",u"Tjørvåg",361,62.283333,5.716667 ],
    [ u"no",u"Tjøtta",232,65.833333,12.4 ],
    [ u"no",u"Tofte",3191,59.548333,10.566111 ],
    [ u"no",u"Tolga",651,62.416667,11 ],
    [ u"no",u"Tomra",1152,62.583333,6.933333 ],
    [ u"no",u"Tomter",1305,59.65,11 ],
    [ u"no",u"Tonstad",756,58.666667,6.716667 ],
    [ u"no",u"Tornes",431,62.85,7.033333 ],
    [ u"no",u"Torpo",389,60.666667,8.716667 ],
    [ u"no",u"Torsken",196,69.333333,17.1 ],
    [ u"no",u"Tovik",208,68.673611,16.89 ],
    [ u"no",u"Tranby",5501,59.816667,10.25 ],
    [ u"no",u"Tretten",872,61.316667,10.316667 ],
    [ u"no",u"Trofors",797,65.566667,13.416667 ],
    [ u"no",u"Trolla",461,63.45,10.316667 ],
    [ u"no",u"Tromsø",52747,69.666667,18.966667 ],
    [ u"no",u"Trondheim",146930,63.416667,10.416667 ],
    [ u"no",u"Trones",415,64.733333,12.833333 ],
    [ u"no",u"Tvedestrand",1975,58.624444,8.928611 ],
    [ u"no",u"Tveitsund",347,59.016667,8.533333 ],
    [ u"no",u"Tveit",1392,58.233333,8.133333 ],
    [ u"no",u"Tynset",2368,62.283333,10.783333 ],
    [ u"no",u"Tyristrand",794,60.1,10.1 ],
    [ u"no",u"Tyssedal",715,60.116667,6.566667 ],
    [ u"no",u"Ulefoss",2746,59.283333,9.266667 ],
    [ u"no",u"Ulsteinvik",5150,62.333333,5.883333 ],
    [ u"no",u"Ulvik",693,60.566667,6.9 ],
    [ u"no",u"Undheim",454,58.683333,5.783333 ],
    [ u"no",u"Uskedal",698,59.93,5.859444 ],
    [ u"no",u"Utgård",315,59.083333,10.866667 ],
    [ u"no",u"Uthaug",415,63.716667,9.6 ],
    [ u"no",u"Vadsø",5190,70.073056,29.769722 ],
    [ u"no",u"Vågåmo",1483,61.883333,9.1 ],
    [ u"no",u"Våge",515,59.85,5.7 ],
    [ u"no",u"Vågsvåg",223,61.937778,5.049722 ],
    [ u"no",u"Vaksdal",870,60.483333,5.733333 ],
    [ u"no",u"Våler",1167,60.666667,11.833333 ],
    [ u"no",u"Valvatna",607,59.766667,5.416667 ],
    [ u"no",u"Vanse",1941,58.116667,6.7 ],
    [ u"no",u"Vardø",2023,70.366667,31.1 ],
    [ u"no",u"Varhaug",2419,58.616667,5.65 ],
    [ u"no",u"Vassenden",246,61.5,6.116667 ],
    [ u"no",u"Vatne",1585,62.566667,6.65 ],
    [ u"no",u"Veggli",307,60.05,9.15 ],
    [ u"no",u"Velde",441,64.116667,11.4 ],
    [ u"no",u"Verdalsøra",7225,63.8,11.483333 ],
    [ u"no",u"Vestbygda",1111,58.1,6.583333 ],
    [ u"no",u"Vestby",5443,59.6,10.75 ],
    [ u"no",u"Vestnes",2102,62.633333,7.083333 ],
    [ u"no",u"Vigeland",1255,58.083333,7.3 ],
    [ u"no",u"Vigrestad",1768,58.566667,5.7 ],
    [ u"no",u"Vikedal",407,59.5,5.916667 ],
    [ u"no",u"Vikersund",2496,59.983333,10.033333 ],
    [ u"no",u"Vikeså",713,58.633333,6.1 ],
    [ u"no",u"Vikevåg",531,59.098056,5.698056 ],
    [ u"no",u"Viksøyri",1101,61.166667,6.583333 ],
    [ u"no",u"Vik",381,65.3,12.15 ],
    [ u"no",u"Vinstra",2467,61.6,9.75 ],
    [ u"no",u"Visnes",609,59.355556,5.224167 ],
    [ u"no",u"Volda",5438,62.15,6.1 ],
    [ u"no",u"Voll",461,62.466667,6.85 ],
    [ u"no",u"Vormsund",485,60.15,11.433333 ],
    [ u"no",u"Vossevangen",5551,60.633333,6.433333 ],
    [ u"no",u"Yli",316,59.566667,9.183333 ],
    [ u"no",u"Ytre Arna",2526,60.466667,5.433333 ],
    [ u"np",u"Baglung",23297,28.2666667,83.6 ],
    [ u"np",u"Banepa",17154,27.6333333,85.5166667 ],
    [ u"np",u"Bhadrapur",19524,26.5333333,88.0833333 ],
    [ u"np",u"Bhaktapur",76890,27.6666667,85.4166667 ],
    [ u"np",u"Bharatpur",107162,27.6833333,84.4333333 ],
    [ u"np",u"Biratnagar",182331,26.4833333,87.2833333 ],
    [ u"np",u"Birganj",133244,27.0,84.8666667 ],
    [ u"np",u"Butwal",91737,27.7,83.45 ],
    [ u"np",u"Dhangadhi",92326,28.6833333,80.6 ],
    [ u"np",u"Dhankuta",22085,26.9833333,87.3333333 ],
    [ u"np",u"Dharan",108605,26.8166667,87.2833333 ],
    [ u"np",u"Gaur",27327,26.7666667,85.2666667 ],
    [ u"np",u"Gulariya",53110,28.2333333,81.3333333 ],
    [ u"np",u"Hetauda",84800,27.4166667,85.0333333 ],
    [ u"np",u"Ilam",17492,26.9,87.9333333 ],
    [ u"np",u"Itahari",47987,26.6666667,87.2833333 ],
    [ u"np",u"Janakpur",93796,26.7,85.9166667 ],
    [ u"np",u"Jumla",9073,29.25,82.25 ],
    [ u"np",u"Kalaiya",39367,27.0333333,85.0 ],
    [ u"np",u"Kathmandu",790612,27.7166667,85.3166667 ],
    [ u"np",u"Khandbari",22904,27.3666667,87.2166667 ],
    [ u"np",u"Kirtipur",44635,27.6666667,85.2833333 ],
    [ u"np",u"Lahan",31497,26.7166667,86.4833333 ],
    [ u"np",u"Lalitpur",183316,27.6666667,85.3333333 ],
    [ u"np",u"Mahendranagar",88386,28.9166667,80.3333333 ],
    [ u"np",u"Malangwa",20285,26.8666667,85.5666667 ],
    [ u"np",u"Nepalganj",61477,28.05,81.6166667 ],
    [ u"np",u"Pokhara",186410,28.2333333,83.9833333 ],
    [ u"np",u"Rajbiraj",33063,26.5333333,86.75 ],
    [ u"np",u"Siddharthanagar",63372,27.5,83.45 ],
    [ u"np",u"Siraha",24659,26.65,86.2 ],
    [ u"np",u"Tansen",23190,27.8666667,83.4833333 ],
    [ u"np",u"Tikapur",44762,28.5,81.1333333 ],
    [ u"np",u"Tulsipur",39061,28.1333333,82.3 ],
    [ u"np",u"Waling",21869,27.9833333,83.7666667 ],
    [ u"nu",u"Alofi",624,-19.0166667,-169.9166667 ],
    [ u"nu",u"Avatele",122,-19.1,-169.9166667 ],
    [ u"nu",u"Hakupu",221,-19.1,-169.8333333 ],
    [ u"nu",u"Lakepa",86,-18.9833333,-169.8 ],
    [ u"nu",u"Liku",71,-19.0333333,-169.7833333 ],
    [ u"nu",u"Makefu",85,-18.9833333,-169.9166667 ],
    [ u"nu",u"Mutalau",129,-18.9333333,-169.8333333 ],
    [ u"nu",u"Namukulu",14,-18.95,-169.9 ],
    [ u"nu",u"Tuapa",126,-18.95,-169.9 ],
    [ u"nz",u"Ahipara",1093,-35.166667,173.166667 ],
    [ u"nz",u"Amberley",1105,-43.166667,172.733333 ],
    [ u"nz",u"Athenree",563,-37.466667,175.916667 ],
    [ u"nz",u"Auckland",417910,-36.866667,174.766667 ],
    [ u"nz",u"Awanui",388,-35.05,173.25 ],
    [ u"nz",u"Balclutha",4441,-46.233889,169.75 ],
    [ u"nz",u"Blackball",321,-42.366667,171.416667 ],
    [ u"nz",u"Bluff",1938,-46.6,168.333333 ],
    [ u"nz",u"Bombay",740,-37.166667,174.983333 ],
    [ u"nz",u"Brightwater",1677,-41.383333,173.116667 ],
    [ u"nz",u"Bulls",1781,-40.166667,175.383333 ],
    [ u"nz",u"Burnham",1239,-43.616667,172.316667 ],
    [ u"nz",u"Cheviot",425,-42.816667,173.266667 ],
    [ u"nz",u"Christchurch",363925,-43.533333,172.633333 ],
    [ u"nz",u"Clinton",343,-46.2,169.366667 ],
    [ u"nz",u"Clyde",890,-45.183333,169.316667 ],
    [ u"nz",u"Coromandel",1502,-36.766667,175.5 ],
    [ u"nz",u"Culverden",432,-42.766667,172.85 ],
    [ u"nz",u"Darfield",1593,-43.483333,172.116667 ],
    [ u"nz",u"Dargaville",4672,-35.933333,173.883333 ],
    [ u"nz",u"Dobson",738,-42.45,171.3 ],
    [ u"nz",u"Dunedin",114346,-45.866667,170.5 ],
    [ u"nz",u"Dunsandel",438,-43.666667,172.183333 ],
    [ u"nz",u"Edendale",583,-46.316667,168.783333 ],
    [ u"nz",u"Edgecumbe",1642,-37.983333,176.833333 ],
    [ u"nz",u"Egmont Village",479,-39.15,174.15 ],
    [ u"nz",u"Eltham",2235,-39.429167,174.3 ],
    [ u"nz",u"Fairlie",788,-44.1,170.833333 ],
    [ u"nz",u"Foxton",4780,-40.466667,175.3 ],
    [ u"nz",u"Franz Josef",315,-43.4,170.183333 ],
    [ u"nz",u"Frasertown",302,-38.968611,177.400556 ],
    [ u"nz",u"Gisborne",34274,-38.653333,178.004167 ],
    [ u"nz",u"Greymouth",9418,-42.466667,171.2 ],
    [ u"nz",u"Halcombe",446,-40.15,175.5 ],
    [ u"nz",u"Hamilton",152642,-37.783333,175.283333 ],
    [ u"nz",u"Hanmer Springs",784,-42.516667,172.816667 ],
    [ u"nz",u"Harihari",345,-43.15,170.55 ],
    [ u"nz",u"Hastings",61696,-39.65,176.833333 ],
    [ u"nz",u"Havelock",504,-41.283333,173.766667 ],
    [ u"nz",u"Hawera",11069,-39.591667,174.283333 ],
    [ u"nz",u"Himatangi",538,-40.4,175.316667 ],
    [ u"nz",u"Hokitika",3401,-42.716667,170.966667 ],
    [ u"nz",u"Hunterville",520,-39.933333,175.566667 ],
    [ u"nz",u"Invercargill",47287,-46.4,168.35 ],
    [ u"nz",u"Kaeo",508,-35.1,173.783333 ],
    [ u"nz",u"Kaitangata",851,-46.275,169.85 ],
    [ u"nz",u"Kaiwaka",565,-36.166667,174.45 ],
    [ u"nz",u"Kakanui",443,-45.183333,170.9 ],
    [ u"nz",u"Kaponga",357,-39.433333,174.15 ],
    [ u"nz",u"Karamea",500,-41.25,172.116667 ],
    [ u"nz",u"Karitane",427,-45.65,170.666667 ],
    [ u"nz",u"Katikati",3232,-37.55,175.916667 ],
    [ u"nz",u"Kawakawa",1399,-35.383333,174.066667 ],
    [ u"nz",u"Kawerau",6702,-38.1,176.7 ],
    [ u"nz",u"Kawhia",543,-38.066667,174.816667 ],
    [ u"nz",u"Kerepehi",537,-37.3,175.533333 ],
    [ u"nz",u"Kerikeri",5654,-35.216667,173.966667 ],
    [ u"nz",u"Kurow",422,-44.733333,170.466667 ],
    [ u"nz",u"Lake Tekapo",330,-44.016667,170.5 ],
    [ u"nz",u"Leeston",1272,-43.766667,172.3 ],
    [ u"nz",u"Leigh",499,-36.283333,174.816667 ],
    [ u"nz",u"Levin",19790,-40.633333,175.275 ],
    [ u"nz",u"Lincoln",2235,-43.65,172.483333 ],
    [ u"nz",u"Lower Hutt",101194,-41.216667,174.916667 ],
    [ u"nz",u"Lumsden",463,-45.733333,168.45 ],
    [ u"nz",u"Maketu",1083,-37.766667,176.45 ],
    [ u"nz",u"Mamaku",751,-38.1,176.083333 ],
    [ u"nz",u"Manaia",902,-39.55,174.133333 ],
    [ u"nz",u"Manapouri",248,-45.566667,167.6 ],
    [ u"nz",u"Manutuke",685,-38.683333,177.916667 ],
    [ u"nz",u"Mapua",1819,-41.25,173.1 ],
    [ u"nz",u"Masterton",20698,-40.959722,175.6575 ],
    [ u"nz",u"Matata",722,-37.883333,176.75 ],
    [ u"nz",u"Maungatapere",1007,-35.75,174.2 ],
    [ u"nz",u"Maungaturoto",790,-36.1,174.366667 ],
    [ u"nz",u"Meremere",379,-39.583333,174.383333 ],
    [ u"nz",u"Methven",1236,-43.633333,171.65 ],
    [ u"nz",u"Milton",2009,-46.120833,169.969444 ],
    [ u"nz",u"Moerewa",1662,-35.383333,174.033333 ],
    [ u"nz",u"Murchison",624,-41.8,172.333333 ],
    [ u"nz",u"Muriwai Beach",2183,-36.816667,174.45 ],
    [ u"nz",u"Murupara",1876,-38.466667,176.7 ],
    [ u"nz",u"Napier",56787,-39.483333,176.916667 ],
    [ u"nz",u"Nelson",60481,-41.283333,173.283333 ],
    [ u"nz",u"New Plymouth",49169,-39.066667,174.083333 ],
    [ u"nz",u"Ngatea",1151,-37.283333,175.5 ],
    [ u"nz",u"Ngunguru",1358,-35.616667,174.5 ],
    [ u"nz",u"North Shore",207865,-36.8,174.75 ],
    [ u"nz",u"Nuhaka",342,-39.05,177.75 ],
    [ u"nz",u"Ohaeawai",764,-35.35,173.883333 ],
    [ u"nz",u"Ohai",408,-45.916667,167.95 ],
    [ u"nz",u"Ohura",225,-38.833333,174.983333 ],
    [ u"nz",u"Okaihau",726,-35.316667,173.783333 ],
    [ u"nz",u"Okato",528,-39.2,173.883333 ],
    [ u"nz",u"Omarama",304,-44.483333,169.966667 ],
    [ u"nz",u"Opotiki",4044,-38.083333,177.283333 ],
    [ u"nz",u"Opunake",1495,-39.455556,173.858333 ],
    [ u"nz",u"Otaki",6086,-40.758333,175.15 ],
    [ u"nz",u"Otane",566,-39.883333,176.633333 ],
    [ u"nz",u"Otautau",745,-46.15,168 ],
    [ u"nz",u"Otematata",265,-44.616667,170.266667 ],
    [ u"nz",u"Otorohanga",2673,-38.183333,175.2 ],
    [ u"nz",u"Outram",657,-45.866667,170.233333 ],
    [ u"nz",u"Owaka",395,-46.45,169.666667 ],
    [ u"nz",u"Oxford",1776,-43.3,172.183333 ],
    [ u"nz",u"Paengaroa",901,-37.816667,176.416667 ],
    [ u"nz",u"Paeroa",3994,-37.366667,175.666667 ],
    [ u"nz",u"Paihia",1944,-35.283333,174.083333 ],
    [ u"nz",u"Palmerston North",75997,-40.35,175.616667 ],
    [ u"nz",u"Parakai",1390,-36.65,174.433333 ],
    [ u"nz",u"Pareora",503,-44.5,171.2 ],
    [ u"nz",u"Patea",1286,-39.758333,174.483333 ],
    [ u"nz",u"Patutahi",386,-38.616667,177.9 ],
    [ u"nz",u"Piopio",502,-38.466667,175.016667 ],
    [ u"nz",u"Pleasant Point",1187,-44.266667,171.133333 ],
    [ u"nz",u"Porirua",50914,-41.133333,174.85 ],
    [ u"nz",u"Raglan",2863,-37.8,174.883333 ],
    [ u"nz",u"Rahotu",302,-39.333333,173.8 ],
    [ u"nz",u"Rakaia",1043,-43.75,172.016667 ],
    [ u"nz",u"Ranfurly",793,-45.133333,170.1 ],
    [ u"nz",u"Ratana",437,-40.045833,175.175 ],
    [ u"nz",u"Rawene",486,-35.4,173.5 ],
    [ u"nz",u"Reefton",980,-42.116667,171.866667 ],
    [ u"nz",u"Reporoa",595,-38.433333,176.35 ],
    [ u"nz",u"Riversdale",371,-45.9,168.75 ],
    [ u"nz",u"Riverton",1651,-46.35,168.016667 ],
    [ u"nz",u"Riwaka",986,-41.083333,173 ],
    [ u"nz",u"Rolleston",3124,-43.583333,172.383333 ],
    [ u"nz",u"Rongotea",631,-40.3,175.416667 ],
    [ u"nz",u"Ruatoria",897,-37.883333,178.333333 ],
    [ u"nz",u"Ruawai",477,-36.133333,174.033333 ],
    [ u"nz",u"Russell",839,-35.266667,174.116667 ],
    [ u"nz",u"Sanson",508,-40.216667,175.416667 ],
    [ u"nz",u"Seddon",511,-41.666667,174.083333 ],
    [ u"nz",u"Sefton",546,-43.25,172.666667 ],
    [ u"nz",u"Southbridge",785,-43.816667,172.25 ],
    [ u"nz",u"Stirling",320,-46.25,169.783333 ],
    [ u"nz",u"Tairua",1588,-37.016667,175.85 ],
    [ u"nz",u"Takaka",1223,-40.85,172.8 ],
    [ u"nz",u"Takapau",597,-40.033333,176.35 ],
    [ u"nz",u"Taneatua",813,-38.066667,177.016667 ],
    [ u"nz",u"Tapawera",432,-41.4,172.816667 ],
    [ u"nz",u"Taupo",22469,-38.683333,176.083333 ],
    [ u"nz",u"Tauranga",110338,-37.686111,176.166667 ],
    [ u"nz",u"Te Anau",2074,-45.416667,167.716667 ],
    [ u"nz",u"Te Horo",698,-40.8,175.1 ],
    [ u"nz",u"Te Kaha",403,-37.733333,177.683333 ],
    [ u"nz",u"Te Karaka",592,-38.466667,177.866667 ],
    [ u"nz",u"Te Kauwhata",1174,-37.4,175.15 ],
    [ u"nz",u"Thames",7136,-37.133333,175.533333 ],
    [ u"nz",u"Timaru",28007,-44.4,171.25 ],
    [ u"nz",u"Tirau",778,-37.983333,175.75 ],
    [ u"nz",u"Tokomaru Bay",495,-38.133333,178.3 ],
    [ u"nz",u"Tokomaru",563,-40.466667,175.5 ],
    [ u"nz",u"Tokoroa",14277,-38.233333,175.866667 ],
    [ u"nz",u"Tolaga Bay",932,-38.366667,178.3 ],
    [ u"nz",u"Tuai",280,-38.816667,177.166667 ],
    [ u"nz",u"Tuatapere",696,-46.133333,167.683333 ],
    [ u"nz",u"Turangi",3401,-39,175.933333 ],
    [ u"nz",u"Urenui",421,-39,174.383333 ],
    [ u"nz",u"Waharoa",569,-37.766667,175.766667 ],
    [ u"nz",u"Waihi Beach",2014,-37.4,175.933333 ],
    [ u"nz",u"Waihi",4619,-37.383333,175.833333 ],
    [ u"nz",u"Waikuku",804,-43.3,172.683333 ],
    [ u"nz",u"Waimana",709,-38.15,177.083333 ],
    [ u"nz",u"Waiouru",1347,-39.483333,175.666667 ],
    [ u"nz",u"Waipawa",1899,-41.412222,175.515278 ],
    [ u"nz",u"Wairoa",4260,-39.033333,177.366667 ],
    [ u"nz",u"Waitakere",166237,-36.85,174.55 ],
    [ u"nz",u"Waitara",6319,-38.925,174.25 ],
    [ u"nz",u"Waitati",534,-45.75,170.566667 ],
    [ u"nz",u"Waitoa",386,-37.616667,175.633333 ],
    [ u"nz",u"Waiuku",7555,-37.25,174.75 ],
    [ u"nz",u"Wakefield",1663,-41.4,173.05 ],
    [ u"nz",u"Wallacetown",638,-46.333333,168.266667 ],
    [ u"nz",u"Wanaka",4428,-44.7,169.15 ],
    [ u"nz",u"Wanganui",40269,-39.933333,175.05 ],
    [ u"nz",u"Warkworth",3441,-36.4,174.666667 ],
    [ u"nz",u"Warrington",427,-45.716667,170.583333 ],
    [ u"nz",u"Waverley",919,-39.766667,174.633333 ],
    [ u"nz",u"Wellington",179240,-41.3,174.783333 ],
    [ u"nz",u"Wellsford",1986,-36.283333,174.516667 ],
    [ u"nz",u"Westport",3629,-41.75,171.566667 ],
    [ u"nz",u"Whakatane",18602,-37.983333,177 ],
    [ u"nz",u"Whangamata",4253,-37.2,175.866667 ],
    [ u"nz",u"Whangarei",49711,-35.72,174.33 ],
    [ u"nz",u"Whitianga",3367,-36.833333,175.7 ],
    [ u"nz",u"Winton",2193,-46.15,168.333333 ],
    [ u"nz",u"Woodend",3059,-43.316667,172.666667 ],
    [ u"nz",u"Woodlands",285,-46.366667,168.55 ],
    [ u"nz",u"Wyndham",586,-46.333333,168.85 ],
    [ u"om",u"Ibra",21389,22.6902778,58.5469444 ],
    [ u"om",u"Muscat",67445,23.6133333,58.5933333 ],
    [ u"om",u"Nizwá",86619,22.9333333,57.5333333 ],
    [ u"om",u"Qurayyat",29615,23.2627778,58.9161111 ],
    [ u"om",u"Ruwi",85601,23.5905556,58.55 ],
    [ u"om",u"Salalah",178469,17.0175,54.0827778 ],
    [ u"om",u"Sur",77419,22.5666667,59.5288889 ],
    [ u"pa",u"Achutupo",1753,9.2,-77.9833333 ],
    [ u"pa",u"Agua Buena",1069,7.5333333,-80.1833333 ],
    [ u"pa",u"Aguadulce",17238,8.25,-80.55 ],
    [ u"pa",u"Ailigandí",1652,9.2333333,-78.0166667 ],
    [ u"pa",u"Alanje",1361,8.4,-82.55 ],
    [ u"pa",u"Almirante",8114,9.3,-82.4 ],
    [ u"pa",u"Alto de la Estancia",1081,8.6,-80.1666667 ],
    [ u"pa",u"Alto del Espino",3672,8.8333333,-79.85 ],
    [ u"pa",u"Ancón",9170,8.9666667,-79.55 ],
    [ u"pa",u"Antón",13852,8.4,-80.2666667 ],
    [ u"pa",u"Arraiján",76829,8.95,-79.65 ],
    [ u"pa",u"Aserrío de Gariché",1658,8.4833333,-82.8 ],
    [ u"pa",u"Atalaya",2857,8.05,-80.9333333 ],
    [ u"pa",u"Bágala",910,8.4666667,-82.5333333 ],
    [ u"pa",u"Balboa",807,8.95,-79.5666667 ],
    [ u"pa",u"Barranco",1398,9.5166667,-82.7 ],
    [ u"pa",u"Bejuco",3420,8.6,-79.8833333 ],
    [ u"pa",u"Bella Vista",1104,7.75,-80.2333333 ],
    [ u"pa",u"Bisira",914,8.9,-81.8666667 ],
    [ u"pa",u"Boca de Parita",1047,8.0166667,-80.45 ],
    [ u"pa",u"Bocas del Toro",3501,9.3333333,-82.25 ],
    [ u"pa",u"Boquerón",1345,8.5,-82.5666667 ],
    [ u"pa",u"Boquete",6123,8.7833333,-82.4333333 ],
    [ u"pa",u"Buena Vista",3060,9.2747222,-79.6952778 ],
    [ u"pa",u"Bugaba",2582,8.4833333,-82.6166667 ],
    [ u"pa",u"Burica",1360,8.0333333,-82.8666667 ],
    [ u"pa",u"Cabra",1415,9.1166667,-79.3166667 ],
    [ u"pa",u"Caimitillo",1101,9.15,-79.5333333 ],
    [ u"pa",u"Caimito",906,8.55,-82.4333333 ],
    [ u"pa",u"Caimito",911,8.6166667,-80.2333333 ],
    [ u"pa",u"Calobre",937,8.3166667,-80.85 ],
    [ u"pa",u"Calzada Larga",1427,9.1666667,-79.5666667 ],
    [ u"pa",u"Cañaveral",874,8.5166667,-80.4333333 ],
    [ u"pa",u"Cañazas",2964,8.3166667,-81.2166667 ],
    [ u"pa",u"Cañita",1258,9.2097222,-78.8811111 ],
    [ u"pa",u"Canoa",3061,8.4333333,-81.7833333 ],
    [ u"pa",u"Capellanía",2252,8.3,-80.55 ],
    [ u"pa",u"Capira",3376,8.75,-79.8833333 ],
    [ u"pa",u"Cativá",29609,9.3605556,-79.8436111 ],
    [ u"pa",u"Celmira",950,8.5333333,-82.8 ],
    [ u"pa",u"Cermeño",928,8.7333333,-79.85 ],
    [ u"pa",u"Cerro Azul",1287,9.1666667,-79.4166667 ],
    [ u"pa",u"Cerro Cama",1274,9.03,-79.905 ],
    [ u"pa",u"Cerro Punta",2957,8.85,-82.5666667 ],
    [ u"pa",u"Chame",2313,8.5833333,-79.8833333 ],
    [ u"pa",u"Changuinola",22902,9.4333333,-82.5166667 ],
    [ u"pa",u"Chepo",15338,9.1666667,-79.1 ],
    [ u"pa",u"Chichica",787,8.35,-81.6666667 ],
    [ u"pa",u"Chigoré",2212,8.5333333,-80.35 ],
    [ u"pa",u"Chiguirí Arriba",987,8.6666667,-80.1833333 ],
    [ u"pa",u"Chilibre",33536,9.15,-79.6166667 ],
    [ u"pa",u"Chimán",786,8.7169444,-78.6338889 ],
    [ u"pa",u"Chiriquí",2431,8.4,-82.3166667 ],
    [ u"pa",u"Chiriquí Grande",1429,8.95,-82.1166667 ],
    [ u"pa",u"Chitré",43967,7.9666667,-80.4333333 ],
    [ u"pa",u"Churuquita Chiquita",1142,8.5666667,-80.2833333 ],
    [ u"pa",u"Churuquita Grande",1685,8.6,-80.2666667 ],
    [ u"pa",u"Coclé",1226,8.45,-80.4333333 ],
    [ u"pa",u"Coetupo",930,8.9,-77.7 ],
    [ u"pa",u"Coloncito",918,8.5666667,-79.9 ],
    [ u"pa",u"Colón",76646,9.3591667,-79.9013889 ],
    [ u"pa",u"David",82863,8.4333333,-82.4333333 ],
    [ u"pa",u"Divalá",2493,8.4166667,-82.7166667 ],
    [ u"pa",u"Dolega",1653,8.5666667,-82.4166667 ],
    [ u"pa",u"El Caño",1247,8.4,-80.5166667 ],
    [ u"pa",u"El Coco",1078,8.4,-80.35 ],
    [ u"pa",u"El Coco",12125,8.8702778,-79.815 ],
    [ u"pa",u"El Copé",1179,8.6166667,-80.6 ],
    [ u"pa",u"El Cortezo",1103,8.35,-80.6 ],
    [ u"pa",u"El Cristo",1096,8.25,-80.6166667 ],
    [ u"pa",u"El Ejido",1120,7.9166667,-80.3833333 ],
    [ u"pa",u"El Espino de Santa Rosa",1048,8.1,-80.8166667 ],
    [ u"pa",u"El Espino",1717,8.8394444,-79.85 ],
    [ u"pa",u"El Giral",1310,9.2491667,-79.6927778 ],
    [ u"pa",u"El Porvenir",10,9.5652778,-78.9533333 ],
    [ u"pa",u"El Progreso",4292,9.2666667,-79.1166667 ],
    [ u"pa",u"El Real de Santa María",804,8.1333333,-77.7166667 ],
    [ u"pa",u"El Rincón",1364,8.1166667,-80.6166667 ],
    [ u"pa",u"El Roble",1610,8.1666667,-80.65 ],
    [ u"pa",u"El Silencio",987,9.3833333,-82.5333333 ],
    [ u"pa",u"El Uvito",858,8.1166667,-80.9833333 ],
    [ u"pa",u"El Valle de la Unión",888,9.2394444,-79.6591667 ],
    [ u"pa",u"Escobal",1790,9.1472222,-79.9619444 ],
    [ u"pa",u"Finca Blanco",1618,8.3833333,-82.8666667 ],
    [ u"pa",u"Finca Cincuenta y Uno",1000,9.4833333,-82.6 ],
    [ u"pa",u"Finca Corredor",1372,8.35,-82.85 ],
    [ u"pa",u"Garachiné",1350,8.0647222,-78.3627778 ],
    [ u"pa",u"Gariché",900,8.4833333,-82.7833333 ],
    [ u"pa",u"Gatun",1553,9.2916667,-79.7688889 ],
    [ u"pa",u"Gómez",1186,8.5666667,-82.7333333 ],
    [ u"pa",u"Guabito",5988,9.5,-82.6166667 ],
    [ u"pa",u"Guadalupe",8409,8.8558333,-79.8133333 ],
    [ u"pa",u"Gualaca",2754,8.5333333,-82.3 ],
    [ u"pa",u"Guararé",2104,7.8166667,-80.2833333 ],
    [ u"pa",u"Guarumal",1526,8.35,-82.5333333 ],
    [ u"pa",u"Horconcitos",877,8.3166667,-82.1666667 ],
    [ u"pa",u"Icantí",644,9.2144444,-78.6833333 ],
    [ u"pa",u"Ipetí",652,8.9686111,-78.505 ],
    [ u"pa",u"Jaqué",1357,7.5175,-78.1702778 ],
    [ u"pa",u"Juan Díaz",1348,8.4666667,-80.2833333 ],
    [ u"pa",u"La Cabima",17545,9.1333333,-79.5333333 ],
    [ u"pa",u"La Candelaria",934,8.6333333,-80.3166667 ],
    [ u"pa",u"La Chorrera",61235,8.8802778,-79.7833333 ],
    [ u"pa",u"La Colorada",1246,8.0166667,-80.9833333 ],
    [ u"pa",u"La Concepción",16912,8.5166667,-82.6166667 ],
    [ u"pa",u"La Esperanza",1952,8.4,-82.8 ],
    [ u"pa",u"La Espigadilla",1317,7.8833333,-80.3833333 ],
    [ u"pa",u"La Estrella",945,8.5166667,-82.6666667 ],
    [ u"pa",u"La Herradura",3347,8.8522222,-79.8072222 ],
    [ u"pa",u"La Loma",1654,8.1666667,-80.6333333 ],
    [ u"pa",u"La Mata",959,8.0833333,-80.8833333 ],
    [ u"pa",u"La Mesa",1127,9.1833333,-79.2666667 ],
    [ u"pa",u"La Mesa",2228,8.15,-81.1833333 ],
    [ u"pa",u"La Mitra",4778,8.8422222,-79.7866667 ],
    [ u"pa",u"La Palma",1845,8.4027778,-78.1452778 ],
    [ u"pa",u"La Palma",1283,7.4333333,-80.4833333 ],
    [ u"pa",u"La Peña",2274,8.05,-81.2333333 ],
    [ u"pa",u"La Pintada",1938,8.6,-80.45 ],
    [ u"pa",u"La Raya de Santa María",933,8.1666667,-80.8166667 ],
    [ u"pa",u"Las Colinas",1447,8.55,-80.0833333 ],
    [ u"pa",u"Las Cumbres",69130,9.0833333,-79.5333333 ],
    [ u"pa",u"Las Lomas",11727,8.4333333,-82.4 ],
    [ u"pa",u"Las Lomas",1062,8.5,-80.3833333 ],
    [ u"pa",u"Las Palmas",1489,8.1333333,-81.45 ],
    [ u"pa",u"Las Tablas",8570,7.7666667,-80.2833333 ],
    [ u"pa",u"La Tiza",1091,7.75,-80.2833333 ],
    [ u"pa",u"La Victoria",1163,8.45,-82.25 ],
    [ u"pa",u"Lídice",4059,8.75,-79.9 ],
    [ u"pa",u"Llano de Piedra",1105,7.6666667,-80.5666667 ],
    [ u"pa",u"Llano Largo",1077,7.9,-80.4333333 ],
    [ u"pa",u"Llano Marín",1264,8.5,-80.3333333 ],
    [ u"pa",u"Los Algarrobos",2028,8.5,-82.4333333 ],
    [ u"pa",u"Los Algarrobos",1611,8.0166667,-81.35 ],
    [ u"pa",u"Los Anastacios",1123,8.5333333,-82.4166667 ],
    [ u"pa",u"Los Boquerones",1038,8.0833333,-80.85 ],
    [ u"pa",u"Los Lotes",1319,9.1333333,-79.3 ],
    [ u"pa",u"Los Pozos",846,7.7833333,-80.6333333 ],
    [ u"pa",u"Los Santos",5971,7.9333333,-80.4166667 ],
    [ u"pa",u"Macaracas",2192,7.7333333,-80.55 ],
    [ u"pa",u"Margarita",3303,9.3313889,-79.8888889 ],
    [ u"pa",u"María Chiquita",1146,9.4430556,-79.7558333 ],
    [ u"pa",u"Mata del Nance",1051,8.45,-82.4 ],
    [ u"pa",u"Metetí",1347,8.5,-77.9666667 ],
    [ u"pa",u"Monte Lirio",2823,8.7833333,-82.8333333 ],
    [ u"pa",u"Montijo",1873,7.9922222,-81.0544444 ],
    [ u"pa",u"Mortí",528,8.85,-77.9166667 ],
    [ u"pa",u"Mulatupo",1303,8.95,-77.75 ],
    [ u"pa",u"Narganá",1090,9.4427778,-78.5905556 ],
    [ u"pa",u"Natá",5619,8.3333333,-80.5166667 ],
    [ u"pa",u"Nueva Gorgona",1517,8.55,-79.8666667 ],
    [ u"pa",u"Nuevo Arraiján",23594,8.9166667,-79.7166667 ],
    [ u"pa",u"Nuevo Emperador",1723,8.9988889,-79.7272222 ],
    [ u"pa",u"Nuevo Guararé",856,8.9333333,-79.7166667 ],
    [ u"pa",u"Nuevo San Juan",1232,9.2233333,-79.6619444 ],
    [ u"pa",u"Nuevo Vigía",2163,9.2447222,-79.6086111 ],
    [ u"pa",u"Ocú",2987,7.95,-80.7833333 ],
    [ u"pa",u"Olá",583,8.4166667,-80.65 ],
    [ u"pa",u"Pacora",55530,9.0833333,-79.2833333 ],
    [ u"pa",u"Palmas Bellas",1274,9.2319444,-80.0866667 ],
    [ u"pa",u"Palmira",1144,8.7166667,-82.45 ],
    [ u"pa",u"Panamá",408188,8.9666667,-79.5333333 ],
    [ u"pa",u"Paraíso",1177,9.0333333,-79.6333333 ],
    [ u"pa",u"Parita",2875,8.0,-80.5166667 ],
    [ u"pa",u"Paso Blanco",2735,9.1333333,-79.2333333 ],
    [ u"pa",u"Pedasí",1558,7.5333333,-80.0333333 ],
    [ u"pa",u"Pedregal",16287,8.3666667,-82.4333333 ],
    [ u"pa",u"Penonomé",12394,8.5166667,-80.3666667 ],
    [ u"pa",u"Pesé",3141,7.9,-80.6166667 ],
    [ u"pa",u"Plaza de Caisán",1121,8.7333333,-82.8166667 ],
    [ u"pa",u"Pocrí",11447,8.2666667,-80.55 ],
    [ u"pa",u"Pocrí",705,7.65,-80.1166667 ],
    [ u"pa",u"Portobelo",1274,9.55,-79.65 ],
    [ u"pa",u"Potrerillos Abajo",1182,8.65,-82.4833333 ],
    [ u"pa",u"Potrerillos Arriba",1045,8.6833333,-82.5 ],
    [ u"pa",u"Potrero Grande",4044,8.8844444,-79.8294444 ],
    [ u"pa",u"Progreso",2107,8.45,-82.8333333 ],
    [ u"pa",u"Pueblo Nuevo",1169,8.5666667,-82.4166667 ],
    [ u"pa",u"Pueblo Viejo",1042,8.25,-81.6666667 ],
    [ u"pa",u"Puerto Armuelles",18796,8.2833333,-82.8666667 ],
    [ u"pa",u"Puerto Caimito",1674,8.8666667,-79.7166667 ],
    [ u"pa",u"Puerto Escondido",12371,9.1933333,-80.0883333 ],
    [ u"pa",u"Puerto Pilón",5688,9.3644444,-79.7933333 ],
    [ u"pa",u"Quebrada Bonita Adentro",1807,9.3,-79.7 ],
    [ u"pa",u"Quiteno",1146,8.4666667,-82.4 ],
    [ u"pa",u"Remedios",976,8.2333333,-81.85 ],
    [ u"pa",u"Río Alejandro",3632,9.3763889,-79.7911111 ],
    [ u"pa",u"Río de Jesús",1180,7.9844444,-81.1630556 ],
    [ u"pa",u"Río Duque",1166,9.2666667,-79.6833333 ],
    [ u"pa",u"Río Grande",1127,8.4166667,-80.4833333 ],
    [ u"pa",u"Río Hato",4752,8.3833333,-80.1666667 ],
    [ u"pa",u"Río Rita",1216,9.3038889,-79.7944444 ],
    [ u"pa",u"Río Sereno",1908,8.8166667,-82.8666667 ],
    [ u"pa",u"Sabanitas",12872,9.3422222,-79.8011111 ],
    [ u"pa",u"Sajalices",945,8.6833333,-79.8666667 ],
    [ u"pa",u"Salamanca",981,9.3361111,-79.6025 ],
    [ u"pa",u"San Andrés",1242,8.6,-82.7333333 ],
    [ u"pa",u"San Antonio",1232,8.0833333,-80.9333333 ],
    [ u"pa",u"San Carlos",810,8.4833333,-79.95 ],
    [ u"pa",u"San Félix",1049,8.2833333,-81.8666667 ],
    [ u"pa",u"San Francisco",1898,8.0666667,-81.3666667 ],
    [ u"pa",u"San Miguelito",321516,9.0333333,-79.5 ],
    [ u"pa",u"San Miguel",751,8.4572222,-78.9369444 ],
    [ u"pa",u"Santa Ana Arriba",984,7.9333333,-80.3666667 ],
    [ u"pa",u"Santa Clara",1410,9.0352778,-79.7522222 ],
    [ u"pa",u"Santa Fé",1234,8.6519444,-78.1491667 ],
    [ u"pa",u"Santa Fe",950,8.5166667,-81.0833333 ],
    [ u"pa",u"Santa María",1739,8.1166667,-80.6666667 ],
    [ u"pa",u"Santa Marta",1952,8.5166667,-82.7 ],
    [ u"pa",u"Santa Rita Arriba",1960,9.3377778,-79.78 ],
    [ u"pa",u"Santa Rita",987,8.8605556,-79.8791667 ],
    [ u"pa",u"Santiago",45358,8.1,-80.9833333 ],
    [ u"pa",u"Santo Domingo",1172,8.5,-82.7166667 ],
    [ u"pa",u"Santo Domingo",1876,7.75,-80.25 ],
    [ u"pa",u"San Vicente de Bique",1784,8.9166667,-79.6833333 ],
    [ u"pa",u"Sioguí Abajo",2675,8.5,-82.6666667 ],
    [ u"pa",u"Sioguí Arriba",1102,8.5333333,-82.6833333 ],
    [ u"pa",u"Soná",7401,8.0166667,-81.3166667 ],
    [ u"pa",u"Sortová",1678,8.55,-82.65 ],
    [ u"pa",u"Taboga",983,8.8,-79.55 ],
    [ u"pa",u"Tigre",817,9.4333333,-78.5333333 ],
    [ u"pa",u"Tijeras",1148,8.4666667,-82.55 ],
    [ u"pa",u"Tocumen",88543,9.0833333,-79.3833333 ],
    [ u"pa",u"Tolé",1253,8.2333333,-81.6833333 ],
    [ u"pa",u"Tubualá",1061,9.5166667,-79.0333333 ],
    [ u"pa",u"Ustupo",2514,9.1333333,-77.9333333 ],
    [ u"pa",u"Veracruz",16172,8.8833333,-79.6333333 ],
    [ u"pa",u"Villa Carmen",1256,8.8,-79.8666667 ],
    [ u"pa",u"Villa Rosario",2947,8.7833333,-79.8666667 ],
    [ u"pa",u"Vista Alegre",41786,8.9333333,-79.7 ],
    [ u"pa",u"Vista Hermosa",2725,8.5333333,-80.3666667 ],
    [ u"pa",u"Volcán",11246,8.7666667,-82.6333333 ],
    [ u"pa",u"Wala",532,8.9819444,-78.0583333 ],
    [ u"pa",u"Yaviza",1611,8.1833333,-77.6833333 ],
    [ u"pe",u"Abancay",55299,-13.6338889,-72.8813889 ],
    [ u"pe",u"Acarí",4465,-15.4311111,-74.6158333 ],
    [ u"pe",u"Acobamba",7193,-12.8666667,-74.5666667 ],
    [ u"pe",u"Acolla",6836,-11.7333333,-75.5666667 ],
    [ u"pe",u"Aguas Verdes",9147,-3.4813889,-80.245 ],
    [ u"pe",u"Ambo",6896,-10.1308333,-76.2047222 ],
    [ u"pe",u"Andahuaylas",17522,-13.6605556,-73.3866667 ],
    [ u"pe",u"Anta",5886,-13.4630556,-72.1552778 ],
    [ u"pe",u"Arequipa",844000,-16.3988889,-71.535 ],
    [ u"pe",u"Ascope",14078,-7.7144444,-79.1077778 ],
    [ u"pe",u"Ayabaca",5294,-4.6333333,-79.7166667 ],
    [ u"pe",u"Ayacucho",140510,-13.1583333,-74.2238889 ],
    [ u"pe",u"Ayaviri",19397,-14.8863889,-70.5888889 ],
    [ u"pe",u"Ayna",4609,-12.65,-73.9166667 ],
    [ u"pe",u"Azángaro",13350,-14.9166667,-70.2166667 ],
    [ u"pe",u"Bagua Grande",20474,-5.7561111,-78.4411111 ],
    [ u"pe",u"Bambamarca",13411,-6.6833333,-78.5333333 ],
    [ u"pe",u"Barranca",51078,-10.75,-77.7666667 ],
    [ u"pe",u"Barranca",5805,-4.8333333,-76.7 ],
    [ u"pe",u"Bellavista",6349,-5.6622222,-78.6755556 ],
    [ u"pe",u"Bellavista",15300,-7.0666667,-76.5333333 ],
    [ u"pe",u"Bernal",5943,-5.45,-80.75 ],
    [ u"pe",u"Buenos Aires",7967,-5.2608333,-79.9641667 ],
    [ u"pe",u"Cajabamba",13546,-7.6166667,-78.05 ],
    [ u"pe",u"Cajamarca",132622,-7.1666667,-78.5166667 ],
    [ u"pe",u"Cajaruro",7313,-5.7363889,-78.4255556 ],
    [ u"pe",u"Calca",9220,-13.3333333,-71.95 ],
    [ u"pe",u"Caleta de Carquín",6085,-11.1,-77.6 ],
    [ u"pe",u"Camaná",16509,-16.6227778,-72.7111111 ],
    [ u"pe",u"Campoverde",8985,-8.4752778,-74.8058333 ],
    [ u"pe",u"Caraz",10976,-9.0666667,-77.8166667 ],
    [ u"pe",u"Carhuamayo",9163,-10.9166667,-76.0333333 ],
    [ u"pe",u"Carhuaz",5067,-9.2666667,-77.6333333 ],
    [ u"pe",u"Cascas",4318,-7.4833333,-78.8166667 ],
    [ u"pe",u"Casma",21263,-9.4666667,-78.3166667 ],
    [ u"pe",u"Catacaos",57903,-5.2666667,-80.6833333 ],
    [ u"pe",u"Celendín",14726,-6.8702778,-78.1516667 ],
    [ u"pe",u"Cerro de Pasco",79183,-10.6833333,-76.2666667 ],
    [ u"pe",u"Chachapoyas",20348,-6.2166667,-77.85 ],
    [ u"pe",u"Chancay",29746,-11.5597222,-77.2711111 ],
    [ u"pe",u"Chaupimarca",28795,-10.4069444,-76.4619444 ],
    [ u"pe",u"Chazuta",8065,-6.5741667,-76.1366667 ],
    [ u"pe",u"Chepén",42181,-7.2166667,-79.45 ],
    [ u"pe",u"Chicama",14982,-7.7025,-79.4391667 ],
    [ u"pe",u"Chicla",7354,-11.7063889,-76.2683333 ],
    [ u"pe",u"Chiclayo",582597,-6.7736111,-79.8416667 ],
    [ u"pe",u"Chilca",14216,-12.5333333,-76.7333333 ],
    [ u"pe",u"Chimbote",320119,-9.0833333,-78.6 ],
    [ u"pe",u"Chincha Alta",154561,-13.45,-76.1333333 ],
    [ u"pe",u"Chivay",4563,-15.6383333,-71.6011111 ],
    [ u"pe",u"Chocope",32515,-7.7913889,-79.2216667 ],
    [ u"pe",u"Chongoyape",16133,-6.6405556,-79.3891667 ],
    [ u"pe",u"Chosica",110536,-11.9430556,-76.7094444 ],
    [ u"pe",u"Chota",14304,-6.55,-78.65 ],
    [ u"pe",u"Chulucanas",69145,-5.0925,-80.1625 ],
    [ u"pe",u"Chupaca",9921,-12.0666667,-75.2833333 ],
    [ u"pe",u"Cocachacra",8838,-17.0883333,-71.7575 ],
    [ u"pe",u"Colán",14274,-5.0027778,-81.0547222 ],
    [ u"pe",u"Concepción",11381,-11.9166667,-75.2833333 ],
    [ u"pe",u"Contamana",13947,-7.3333333,-75.0166667 ],
    [ u"pe",u"Coracora",7453,-15.0333333,-73.7833333 ],
    [ u"pe",u"Corrales",19856,-15.9336111,-72.6588889 ],
    [ u"pe",u"Cusco",313210,-13.5183333,-71.9780556 ],
    [ u"pe",u"Cutervo",14565,-6.3666667,-78.85 ],
    [ u"pe",u"Desaguadero",5353,-16.5666667,-69.05 ],
    [ u"pe",u"El Alto",9345,-4.2641667,-81.2183333 ],
    [ u"pe",u"Eten",13755,-6.9080556,-79.8641667 ],
    [ u"pe",u"Ferreñafe",34512,-6.6388889,-79.7888889 ],
    [ u"pe",u"Guadalupe",25491,-7.25,-79.4833333 ],
    [ u"pe",u"Huacho",53852,-11.1066667,-77.6102778 ],
    [ u"pe",u"Huallanca",5665,-9.85,-76.9333333 ],
    [ u"pe",u"Hualmay",29416,-11.0902778,-77.6294444 ],
    [ u"pe",u"Huamachuco",21866,-7.8,-78.0666667 ],
    [ u"pe",u"Huancabamba",8591,-5.2444444,-79.4516667 ],
    [ u"pe",u"Huancavelica",41719,-12.7666667,-74.9833333 ],
    [ u"pe",u"Huancayo",380098,-12.0666667,-75.2333333 ],
    [ u"pe",u"Huanta",18711,-12.9333333,-74.25 ],
    [ u"pe",u"Huánuco",148466,-9.9166667,-76.2333333 ],
    [ u"pe",u"Huaral",68606,-11.4975,-77.2033333 ],
    [ u"pe",u"Huaraz",87233,-9.5333333,-77.5333333 ],
    [ u"pe",u"Huari",4235,-9.3333333,-77.2333333 ],
    [ u"pe",u"Huarmey",16245,-10.0666667,-78.1666667 ],
    [ u"pe",u"Huasahuasi",5169,-11.265,-75.6508333 ],
    [ u"pe",u"Huaura",22867,-11.0647222,-77.6 ],
    [ u"pe",u"Huayucachi",5854,-12.1333333,-75.2333333 ],
    [ u"pe",u"Huicungo",6788,-7.2833333,-76.8 ],
    [ u"pe",u"Iberia",4406,-11.35,-69.5833333 ],
    [ u"pe",u"Ica",247687,-14.0680556,-75.7255556 ],
    [ u"pe",u"Ilabaya",9534,-17.4208333,-70.5133333 ],
    [ u"pe",u"Ilave",16105,-16.0833333,-69.6666667 ],
    [ u"pe",u"Íllimo",5709,-6.475,-79.8541667 ],
    [ u"pe",u"Ilo",53717,-17.6394444,-71.3375 ],
    [ u"pe",u"Imperial",35689,-13.0666667,-76.35 ],
    [ u"pe",u"Iquitos",439114,-3.7480556,-73.2472222 ],
    [ u"pe",u"Jaén",52730,-5.705,-78.8063889 ],
    [ u"pe",u"Jauja",21152,-11.8,-75.5 ],
    [ u"pe",u"Jayanca",6153,-6.3908333,-79.8219444 ],
    [ u"pe",u"Jepelacio",7182,-6.1166667,-76.95 ],
    [ u"pe",u"Juanjuí",37885,-7.1833333,-76.75 ],
    [ u"pe",u"Juliaca",247949,-15.5,-70.1333333 ],
    [ u"pe",u"Juli",7342,-16.2166667,-69.45 ],
    [ u"pe",u"Junín",15389,-11.1588889,-75.9930556 ],
    [ u"pe",u"La Arena",32914,-5.3333333,-80.7333333 ],
    [ u"pe",u"La Brea",17773,-4.2608333,-80.8875 ],
    [ u"pe",u"Lagunas",9238,-5.2269444,-75.6752778 ],
    [ u"pe",u"La Huaca",8506,-4.9116667,-80.96 ],
    [ u"pe",u"Lamas",13755,-6.4166667,-76.5333333 ],
    [ u"pe",u"Lambayeque",43907,-6.7011111,-79.9061111 ],
    [ u"pe",u"Lampa",4801,-15.35,-70.3666667 ],
    [ u"pe",u"La Oroya",33495,-11.5333333,-75.9 ],
    [ u"pe",u"La Peca",27167,-5.6111111,-78.435 ],
    [ u"pe",u"Laredo",24802,-8.1,-78.95 ],
    [ u"pe",u"Las Lomas",9493,-4.6533333,-80.2466667 ],
    [ u"pe",u"La Unión",4809,-9.7666667,-76.8 ],
    [ u"pe",u"La Unión",34991,-5.2166667,-80.65 ],
    [ u"pe",u"Lima",7646786,-12.05,-77.05 ],
    [ u"pe",u"Lircay",5260,-13.0,-74.7166667 ],
    [ u"pe",u"Llata",4606,-9.4166667,-76.7833333 ],
    [ u"pe",u"Lluta",6025,-16.0147222,-72.0141667 ],
    [ u"pe",u"Los Aquíjes",7883,-14.0958333,-75.6911111 ],
    [ u"pe",u"Macusani",6071,-14.0833333,-70.4333333 ],
    [ u"pe",u"Mala",19045,-12.65,-76.6333333 ],
    [ u"pe",u"Máncora",9142,-4.1041667,-81.0458333 ],
    [ u"pe",u"Marcavelica",25760,-4.8777778,-80.7052778 ],
    [ u"pe",u"Marcona",15548,-15.2119444,-75.1102778 ],
    [ u"pe",u"Matucana",4985,-11.85,-76.4 ],
    [ u"pe",u"Mazamari",6856,-11.35,-74.5666667 ],
    [ u"pe",u"Moche",22683,-8.1833333,-79.0333333 ],
    [ u"pe",u"Mochumí",7494,-6.5469444,-79.8630556 ],
    [ u"pe",u"Mollendo",29084,-17.0230556,-72.0147222 ],
    [ u"pe",u"Monsefú",25822,-6.8780556,-79.8722222 ],
    [ u"pe",u"Moquegua",54703,-17.1955556,-70.9352778 ],
    [ u"pe",u"Morococha",7926,-11.5997222,-76.1411111 ],
    [ u"pe",u"Mórrope",6692,-6.5416667,-80.0111111 ],
    [ u"pe",u"Morropón",12362,-5.1822222,-79.9688889 ],
    [ u"pe",u"Motupe",13743,-6.1519444,-79.7141667 ],
    [ u"pe",u"Moyobamba",44428,-6.05,-76.9666667 ],
    [ u"pe",u"Nauta",11757,-4.5333333,-73.55 ],
    [ u"pe",u"Nazca",23662,-14.8333333,-74.95 ],
    [ u"pe",u"Nicolas de Pierola",5826,-11.95,-76.7 ],
    [ u"pe",u"Nuevo Imperial",35689,-13.0833333,-76.3333333 ],
    [ u"pe",u"Ñuñoa",4290,-14.48,-70.6411111 ],
    [ u"pe",u"Olmos",9845,-5.9847222,-79.7452778 ],
    [ u"pe",u"Orcopampa",5668,-15.2661111,-72.3416667 ],
    [ u"pe",u"Orcotuna",4218,-11.9666667,-75.3333333 ],
    [ u"pe",u"Oropesa",4040,-13.5927778,-71.7719444 ],
    [ u"pe",u"Otuzco",10180,-7.9,-78.5833333 ],
    [ u"pe",u"Oxapampa",7777,-10.5666667,-75.4 ],
    [ u"pe",u"Oyón",6925,-10.6680556,-76.7730556 ],
    [ u"pe",u"Oyotún",6359,-6.8519444,-79.3036111 ],
    [ u"pe",u"Pacanga",8789,-7.1666667,-79.5 ],
    [ u"pe",u"Pacasmayo",29296,-7.4005556,-79.5713889 ],
    [ u"pe",u"Pacocha",7622,-17.5833333,-71.3333333 ],
    [ u"pe",u"Paiján",21223,-7.7333333,-79.3022222 ],
    [ u"pe",u"Paita",56404,-5.0841667,-81.1105556 ],
    [ u"pe",u"Palpa",5909,-14.5336111,-75.1855556 ],
    [ u"pe",u"Pampas",5545,-12.4,-74.9 ],
    [ u"pe",u"Pangoa",6667,-12.1166667,-73.0 ],
    [ u"pe",u"Papayal",5509,-4.0422222,-80.9580556 ],
    [ u"pe",u"Paramonga",30490,-10.6666667,-77.8333333 ],
    [ u"pe",u"Pativilca",14988,-10.7,-77.7833333 ],
    [ u"pe",u"Paucartambo",5423,-13.3155556,-71.5916667 ],
    [ u"pe",u"Perené",6875,-10.9666667,-75.2166667 ],
    [ u"pe",u"Picota",6727,-6.9163889,-76.3330556 ],
    [ u"pe",u"Picsi",43806,-6.7177778,-79.7697222 ],
    [ u"pe",u"Pilcomayo",8206,-12.05,-75.2666667 ],
    [ u"pe",u"Pimentel",15622,-6.8366667,-79.9341667 ],
    [ u"pe",u"Pisco",62148,-13.7,-76.2166667 ],
    [ u"pe",u"Piura",326592,-5.2,-80.6333333 ],
    [ u"pe",u"Pomabamba",4473,-8.8333333,-77.4666667 ],
    [ u"pe",u"Pucallpa",311793,-8.3825,-74.5380556 ],
    [ u"pe",u"Pucará",3970,-7.5172222,-77.8452778 ],
    [ u"pe",u"Pueblo Nuevo",5792,-7.1880556,-79.5152778 ],
    [ u"pe",u"Pueblo Nuevo",12527,-5.7166667,-79.8833333 ],
    [ u"pe",u"Puerto Maldonado",37742,-12.6,-69.1833333 ],
    [ u"pe",u"Puno",116951,-15.8333333,-70.0333333 ],
    [ u"pe",u"Punta de Bombón",6364,-17.1716667,-71.7930556 ],
    [ u"pe",u"Puquio",10538,-14.7,-74.1333333 ],
    [ u"pe",u"Putina",8155,-15.4666667,-69.4333333 ],
    [ u"pe",u"Querecotillo",25511,-4.8377778,-80.6455556 ],
    [ u"pe",u"Quilmaná",7109,-12.95,-76.3833333 ],
    [ u"pe",u"Quiruvilca",9268,-7.9666667,-78.2 ],
    [ u"pe",u"Ramón Castilla",5520,-4.2569444,-69.9594444 ],
    [ u"pe",u"Requena",20494,-5.05,-73.8333333 ],
    [ u"pe",u"Reque",9852,-6.8655556,-79.8177778 ],
    [ u"pe",u"Ricardo Palma",5343,-11.9180556,-76.6663889 ],
    [ u"pe",u"Río Grande",4710,-14.5197222,-75.2013889 ],
    [ u"pe",u"Rioja",25170,-6.0833333,-77.15 ],
    [ u"pe",u"Salas",10734,-6.2747222,-79.6041667 ],
    [ u"pe",u"Salaverry",10112,-8.2333333,-78.9666667 ],
    [ u"pe",u"Salitral",5409,-4.8572222,-80.6811111 ],
    [ u"pe",u"San Agustín",6025,-11.9666667,-75.25 ],
    [ u"pe",u"Saña",39377,-6.9222222,-79.5841667 ],
    [ u"pe",u"San Clemente",15886,-13.6666667,-76.15 ],
    [ u"pe",u"San Ignacio",7947,-5.1458333,-79.0013889 ],
    [ u"pe",u"San Jerónimo de Tunán",8812,-11.95,-75.25 ],
    [ u"pe",u"San Jerónimo",5635,-13.6505556,-73.365 ],
    [ u"pe",u"San José de Sisa",9520,-6.6166667,-76.65 ],
    [ u"pe",u"San José",7468,-6.4147222,-79.8233333 ],
    [ u"pe",u"San Juan Bautista",6902,-14.0108333,-75.7358333 ],
    [ u"pe",u"San Luis",9778,-12.0666667,-77.0 ],
    [ u"pe",u"San Miguel de Cauri",5350,-10.1,-76.5833333 ],
    [ u"pe",u"San Miguel",6332,-13.0122222,-73.9805556 ],
    [ u"pe",u"San Pedro de Cajas",5784,-11.2511111,-75.8616667 ],
    [ u"pe",u"San Pedro de Lloc",16323,-7.4327778,-79.5058333 ],
    [ u"pe",u"San Ramón",14774,-11.1333333,-75.3333333 ],
    [ u"pe",u"Santa Ana",25259,-12.8666667,-72.7166667 ],
    [ u"pe",u"Santa Eulalia",7068,-11.85,-76.6833333 ],
    [ u"pe",u"Santa Lucía",4339,-15.7,-70.6052778 ],
    [ u"pe",u"Santa Maria",16390,-12.0,-76.9 ],
    [ u"pe",u"Santa Rosa",10673,-6.7666667,-79.8333333 ],
    [ u"pe",u"Santa",14130,-8.9833333,-78.6 ],
    [ u"pe",u"Santiago de Cao",22081,-7.9588889,-79.2391667 ],
    [ u"pe",u"Santiago de Chuco",6790,-8.15,-78.1833333 ],
    [ u"pe",u"Santiago",10496,-14.1886111,-75.7141667 ],
    [ u"pe",u"Santo Tomas",4152,-14.4455556,-72.0841667 ],
    [ u"pe",u"San Vicente de Cañete",28157,-13.0833333,-76.4 ],
    [ u"pe",u"Saposoa",14961,-6.9333333,-76.8 ],
    [ u"pe",u"Saquena",4381,-4.6666667,-73.5166667 ],
    [ u"pe",u"Satipo",15602,-11.2666667,-74.6833333 ],
    [ u"pe",u"Sauce",7113,-6.6913889,-76.2147222 ],
    [ u"pe",u"Sayán",6837,-11.1341667,-77.1938889 ],
    [ u"pe",u"Sechura",23124,-5.5530556,-80.8202778 ],
    [ u"pe",u"Sicaya",6872,-12.0333333,-75.2833333 ],
    [ u"pe",u"Sicuani",33726,-14.2694444,-71.2261111 ],
    [ u"pe",u"Soritor",10907,-6.1,-77.0666667 ],
    [ u"pe",u"Subtanjalla",9137,-14.0188889,-75.7580556 ],
    [ u"pe",u"Sullana",162493,-4.9038889,-80.6852778 ],
    [ u"pe",u"Supe",15138,-10.8,-77.7333333 ],
    [ u"pe",u"Tabalosos",14811,-6.35,-76.6833333 ],
    [ u"pe",u"Tacna",280996,-18.0055556,-70.2483333 ],
    [ u"pe",u"Talara",100105,-4.5772222,-81.2719444 ],
    [ u"pe",u"Talavera",7414,-13.6530556,-73.4288889 ],
    [ u"pe",u"Tamarindo",4836,-4.8772222,-80.9730556 ],
    [ u"pe",u"Tambo Grande",30169,-4.9269444,-80.3447222 ],
    [ u"pe",u"Tambopata",39142,-12.7333333,-69.1833333 ],
    [ u"pe",u"Tambo",5054,-14.55,-73.7666667 ],
    [ u"pe",u"Tarata",4936,-17.4744444,-70.0327778 ],
    [ u"pe",u"Tarma",51581,-11.4197222,-75.6908333 ],
    [ u"pe",u"Tingo María",53416,-9.3,-75.9833333 ],
    [ u"pe",u"Tinyahuarco",5089,-10.75,-76.3 ],
    [ u"pe",u"Tocache",29160,-8.1841667,-76.5125 ],
    [ u"pe",u"Torata",7086,-17.0769444,-70.8433333 ],
    [ u"pe",u"Trujillo",750004,-8.1166667,-79.0333333 ],
    [ u"pe",u"Túcume",7074,-6.51,-79.8583333 ],
    [ u"pe",u"Tumbes",109599,-3.5666667,-80.4413889 ],
    [ u"pe",u"Uchiza",17822,-8.4166667,-76.3833333 ],
    [ u"pe",u"Urcos",5504,-13.6861111,-71.6227778 ],
    [ u"pe",u"Urubamba",7574,-13.3077778,-72.1152778 ],
    [ u"pe",u"Végueta",6862,-11.0233333,-77.6463889 ],
    [ u"pe",u"Vice",12973,-5.4166667,-80.7833333 ],
    [ u"pe",u"Vichayal",5687,-4.865,-81.0733333 ],
    [ u"pe",u"Villa Rica",7482,-10.7166667,-75.2833333 ],
    [ u"pe",u"Virú",20867,-8.4166667,-78.75 ],
    [ u"pe",u"Vista Alegre",10267,-14.0580556,-75.7152778 ],
    [ u"pe",u"Yanacancha",23280,-10.4666667,-76.5333333 ],
    [ u"pe",u"Yanahuanca",6019,-10.5166667,-76.4986111 ],
    [ u"pe",u"Yauya",9133,-8.9833333,-77.3 ],
    [ u"pe",u"Yungay",5292,-9.15,-77.7333333 ],
    [ u"pe",u"Yunguyo",10210,-17.1688889,-70.8819444 ],
    [ u"pe",u"Yura",5712,-16.2508333,-71.6813889 ],
    [ u"pe",u"Yurimaguas",42016,-5.9,-76.0833333 ],
    [ u"pe",u"Zarumilla",16983,-3.5030556,-80.2730556 ],
    [ u"pe",u"Zorritos",12317,-3.6666667,-80.6666667 ],
    [ u"pf",u"Afaahiti",5186,-17.75,-149.2833333 ],
    [ u"pf",u"Afareaitu",3213,-17.55,-149.7833333 ],
    [ u"pf",u"Amaru",238,-22.6333333,-152.8333333 ],
    [ u"pf",u"Anapoto",233,-22.6333333,-152.8666667 ],
    [ u"pf",u"Anatonu",247,-23.8833333,-147.6333333 ],
    [ u"pf",u"Anau",1413,-16.5166667,-151.7333333 ],
    [ u"pf",u"Arue",9492,-17.5166667,-149.5 ],
    [ u"pf",u"Atuona",1762,-9.8,-139.0333333 ],
    [ u"pf",u"Avera",711,-22.45,-151.35 ],
    [ u"pf",u"Faaa",29389,-17.55,-149.6 ],
    [ u"pf",u"Faanui",2061,-16.4833333,-151.75 ],
    [ u"pf",u"Faaone",1747,-17.6666667,-149.3 ],
    [ u"pf",u"Fare",1540,-16.7,-151.0166667 ],
    [ u"pf",u"Fitii",1154,-16.7333333,-151.0333333 ],
    [ u"pf",u"Haapiti",3959,-17.5666667,-149.8666667 ],
    [ u"pf",u"Haapu",579,-16.7666667,-151.0 ],
    [ u"pf",u"Hitiaa",1826,-17.6,-149.3 ],
    [ u"pf",u"Mahaena",960,-17.5666667,-149.3166667 ],
    [ u"pf",u"Mahina",14225,-17.5,-149.45 ],
    [ u"pf",u"Mahu",462,-23.4,-149.45 ],
    [ u"pf",u"Maroe",498,-16.75,-150.9833333 ],
    [ u"pf",u"Mataiea",4609,-17.7666667,-149.4166667 ],
    [ u"pf",u"Mataiva",242,-17.75,-149.1833333 ],
    [ u"pf",u"Mataura",913,-23.3666667,-149.4666667 ],
    [ u"pf",u"Moerai",1044,-22.4333333,-151.3333333 ],
    [ u"pf",u"Paea",13359,-17.6833333,-149.5833333 ],
    [ u"pf",u"Paopao",4221,-17.5,-149.8166667 ],
    [ u"pf",u"Papara",10361,-17.75,-149.55 ],
    [ u"pf",u"Papeari",4131,-17.75,-149.35 ],
    [ u"pf",u"Papeete",26358,-17.5333333,-149.5666667 ],
    [ u"pf",u"Papetoai",1964,-17.4833333,-149.8666667 ],
    [ u"pf",u"Pirae",14729,-17.5166667,-149.5333333 ],
    [ u"pf",u"Pueu",1968,-17.7333333,-149.2166667 ],
    [ u"pf",u"Punaauia",25751,-17.6333333,-149.6 ],
    [ u"pf",u"Rairua",486,-23.8666667,-147.6833333 ],
    [ u"pf",u"Rikitea",1103,-23.1202778,-134.9691667 ],
    [ u"pf",u"Tautira",2293,-17.7333333,-149.15 ],
    [ u"pf",u"Teahupoo",1423,-17.8333333,-149.2666667 ],
    [ u"pf",u"Teavaro",2289,-17.5,-149.7666667 ],
    [ u"pf",u"Tevaitoa",1851,-16.7833333,-151.5 ],
    [ u"pf",u"Tiarei",2795,-17.5333333,-149.3333333 ],
    [ u"pf",u"Toahotu",2842,-17.75,-149.3166667 ],
    [ u"pf",u"Uturoa",3668,-16.7333333,-151.4333333 ],
    [ u"pf",u"Vairao",2423,-17.7833333,-149.2833333 ],
    [ u"pf",u"Vaitape",4680,-16.5166667,-151.75 ],
    [ u"pf",u"Vaitoare",436,-16.6833333,-151.45 ],
    [ u"pf",u"Vaiuru",235,-23.8666667,-147.65 ],
    [ u"pg",u"Aitape",5547,-3.1333333,142.35 ],
    [ u"pg",u"Alotau",12095,-10.3,150.4166667 ],
    [ u"pg",u"Ambunti",2073,-4.2333333,142.8333333 ],
    [ u"pg",u"Angoram",1603,-4.0666667,144.0666667 ],
    [ u"pg",u"Arawa",40266,-6.2166667,155.55 ],
    [ u"pg",u"Balimo",3601,-8.05,142.95 ],
    [ u"pg",u"Buin",750,-6.8333333,155.7333333 ],
    [ u"pg",u"Bulolo",16042,-7.2,146.65 ],
    [ u"pg",u"Daru",15215,-9.0833333,143.2 ],
    [ u"pg",u"Finschhafen",1054,-6.6,147.85 ],
    [ u"pg",u"Goroka",18502,-6.0833333,145.3833333 ],
    [ u"pg",u"Ialibu",6915,-6.2833333,143.9833333 ],
    [ u"pg",u"Kainantu",8509,-6.2833333,145.8666667 ],
    [ u"pg",u"Kandrian",1014,-6.2166667,149.55 ],
    [ u"pg",u"Kavieng",14491,-2.5666667,150.8 ],
    [ u"pg",u"Kerema",5645,-7.9666667,145.7666667 ],
    [ u"pg",u"Kieta",3611,-6.2166667,155.6333333 ],
    [ u"pg",u"Kimbe",18849,-5.55,150.15 ],
    [ u"pg",u"Kiunga",11540,-6.1166667,141.3 ],
    [ u"pg",u"Kokoda",6199,-8.8833333,147.7333333 ],
    [ u"pg",u"Kokopo",26334,-4.35,152.2666667 ],
    [ u"pg",u"Kundiawa",9383,-6.0166667,144.9666667 ],
    [ u"pg",u"Lae",76254,-6.7333333,147.0 ],
    [ u"pg",u"Laiagam",921,-5.2833333,143.7666667 ],
    [ u"pg",u"Lorengau",5807,-2.0166667,147.2666667 ],
    [ u"pg",u"Madang",27420,-5.2166667,145.8 ],
    [ u"pg",u"Mendi",26251,-6.15,143.65 ],
    [ u"pg",u"Morehead",2246,-8.55,141.65 ],
    [ u"pg",u"Mount Hagen",33622,-5.8666667,144.2166667 ],
    [ u"pg",u"Namatanai",1376,-3.6666667,152.4333333 ],
    [ u"pg",u"Panguna",2916,-6.25,155.5 ],
    [ u"pg",u"Popondetta",28199,-8.7666667,148.2333333 ],
    [ u"pg",u"Porgera",1578,-5.4666667,143.2 ],
    [ u"pg",u"Port Moresby",283733,-9.4647222,147.1925 ],
    [ u"pg",u"Rabaul",8085,-4.2,152.1833333 ],
    [ u"pg",u"Samarai",1638,-10.6166667,150.6666667 ],
    [ u"pg",u"Tari",10333,-5.7,142.95 ],
    [ u"pg",u"Vanimo",11204,-2.6666667,141.2666667 ],
    [ u"pg",u"Wabag",3959,-5.4833333,143.7 ],
    [ u"pg",u"Wau",14628,-7.3333333,146.7166667 ],
    [ u"pg",u"Wewak",18230,-3.55,143.6333333 ],
    [ u"ph",u"Abaca",2480,9.9204,124.5051 ],
    [ u"ph",u"Abaca",2139,11.1342,122.7156 ],
    [ u"ph",u"Abangay",2207,10.966667,122.65 ],
    [ u"ph",u"Abiera",2394,11.5749,122.09 ],
    [ u"ph",u"Abilay",2195,10.733333,122.5 ],
    [ u"ph",u"Abis",2603,9.7173,122.9438 ],
    [ u"ph",u"Aborlan",4790,9.435158,118.549199 ],
    [ u"ph",u"Abra de Ilog",2971,13.4437,120.7291 ],
    [ u"ph",u"Abucay",35508,14.722222,120.538333 ],
    [ u"ph",u"Abucay",2863,12.9403,123.6727 ],
    [ u"ph",u"Abucayan",2204,9.929,123.9146 ],
    [ u"ph",u"Abulug",2412,18.445278,121.453333 ],
    [ u"ph",u"Abut",2387,17.352328,121.603645 ],
    [ u"ph",u"Abuyog",15632,10.747,125.0107 ],
    [ u"ph",u"Abuyog",3377,12.9461,124.0519 ],
    [ u"ph",u"Abuyon",4342,13.6,122.533333 ],
    [ u"ph",u"Acao",4307,16.525556,120.376389 ],
    [ u"ph",u"Accusilian",2377,17.7543,121.4723 ],
    [ u"ph",u"Acli",2555,15.124,120.6428 ],
    [ u"ph",u"Adela",3926,12.441643,120.972913 ],
    [ u"ph",u"Adlay",2548,9.409722,125.8975 ],
    [ u"ph",u"Adtuyon",3380,7.811944,124.854444 ],
    [ u"ph",u"Aga",5218,14.096499,120.80217 ],
    [ u"ph",u"Aganan",2522,10.783333,122.533333 ],
    [ u"ph",u"Agay",3977,9.053611,125.586667 ],
    [ u"ph",u"Agbannawag",3782,15.6792,121.0833 ],
    [ u"ph",u"Agbannawag",3186,17.374927,121.549346 ],
    [ u"ph",u"Agdangan",3918,13.8751,121.9136 ],
    [ u"ph",u"Aggugaddan",2364,17.705406,121.810648 ],
    [ u"ph",u"Aglalana",2868,11.1803,122.6574 ],
    [ u"ph",u"Aglayan",5761,8.055,125.134167 ],
    [ u"ph",u"Agno",2638,16.1161,119.7993 ],
    [ u"ph",u"Agoo",28971,16.083333,120.1 ],
    [ u"ph",u"Agpangi",2150,10.577158,123.423202 ],
    [ u"ph",u"Aguada",2552,12.816667,123.833333 ],
    [ u"ph",u"Aguilar",9801,15.8884,120.2378 ],
    [ u"ph",u"Aguining",2488,10.0861,124.5944 ],
    [ u"ph",u"Aguisan",11798,10.1603,122.8615 ],
    [ u"ph",u"Agutaya",4989,11.148,120.9417 ],
    [ u"ph",u"Ajuy",8695,11.1724,123.0197 ],
    [ u"ph",u"Akle",3381,15.0482,121.0733 ],
    [ u"ph",u"Alabat",7910,14.101,122.0125 ],
    [ u"ph",u"Alabel",43312,6.101792,125.290478 ],
    [ u"ph",u"Alac",3430,15.9877,120.8065 ],
    [ u"ph",u"Alacaygan",2598,10.840141,123.058304 ],
    [ u"ph",u"Alacaygan",2598,10.86324,123.082704 ],
    [ u"ph",u"Alad",2543,12.616824,122.247513 ],
    [ u"ph",u"Alae",5121,8.424444,124.812778 ],
    [ u"ph",u"Alamada",4987,7.333333,124.566667 ],
    [ u"ph",u"Alaminos",31427,14.063914,121.246488 ],
    [ u"ph",u"Alaminos",10488,16.1547,119.9805 ],
    [ u"ph",u"Alangalang",8095,11.206111,124.846667 ],
    [ u"ph",u"Alangilan",4613,9.2793,122.8789 ],
    [ u"ph",u"Alangilanan",2365,9.642,123.1059 ],
    [ u"ph",u"Alanib",4207,8.027778,124.986111 ],
    [ u"ph",u"Alannay",2128,18.057387,121.577551 ],
    [ u"ph",u"Alayao",2406,14.2818,122.5524 ],
    [ u"ph",u"Albuera",4968,10.9158,124.6945 ],
    [ u"ph",u"Albuquerque",2730,9.608056,123.958056 ],
    [ u"ph",u"Alcala",4668,17.902096,121.65595 ],
    [ u"ph",u"Alcala",8883,15.847222,120.524167 ],
    [ u"ph",u"Alcantara",4447,9.975556,123.406111 ],
    [ u"ph",u"Alcantara",2251,12.2589,122.0544 ],
    [ u"ph",u"Alcoy",3016,9.7102,123.5067 ],
    [ u"ph",u"Alegria",4578,8.506667,126.011944 ],
    [ u"ph",u"Alegria",2539,9.7289,123.3398 ],
    [ u"ph",u"Alegria",5811,12.3984,124.3261 ],
    [ u"ph",u"Alegria",2780,10.643455,123.083603 ],
    [ u"ph",u"Alegria",5891,9.466944,125.577222 ],
    [ u"ph",u"Alejal",8075,7.384167,125.66 ],
    [ u"ph",u"Alfaco",2599,10.24378,123.6825 ],
    [ u"ph",u"Alfonso",9446,14.140833,120.853889 ],
    [ u"ph",u"Algeciras",4007,11.4154,120.8168 ],
    [ u"ph",u"Aliaga",34020,15.5,120.843 ],
    [ u"ph",u"Aliang",2642,14.283333,120.883333 ],
    [ u"ph",u"Alibagu",4446,17.1,121.85 ],
    [ u"ph",u"Alibog",2576,12.229056,121.228112 ],
    [ u"ph",u"Alibunan",2798,11.146523,122.459106 ],
    [ u"ph",u"Alicante",8606,10.897038,123.018504 ],
    [ u"ph",u"Alicia",4415,9.8949,124.4422 ],
    [ u"ph",u"Alicia",3306,7.513889,122.93 ],
    [ u"ph",u"Alijis",2132,10.4459,122.8599 ],
    [ u"ph",u"Alim",3732,9.5649,122.4876 ],
    [ u"ph",u"Alimanguan",3324,10.611774,119.326804 ],
    [ u"ph",u"Alimodian",7302,10.821389,122.431111 ],
    [ u"ph",u"Alimono",2708,11.1855,122.7129 ],
    [ u"ph",u"Alitagtag",3960,13.8645,121.0041 ],
    [ u"ph",u"Allacapan",3645,18.225977,121.556152 ],
    [ u"ph",u"Allangigan",2219,17.166667,120.5 ],
    [ u"ph",u"Allen",7502,12.5006,124.2849 ],
    [ u"ph",u"Almaguer",3368,16.3497,121.0926 ],
    [ u"ph",u"Almendras",2626,15.275762,120.698731 ],
    [ u"ph",u"Almeria",2960,11.6197,124.3803 ],
    [ u"ph",u"Aloguinsan",2721,10.2219,123.5483 ],
    [ u"ph",u"Aloleng",2389,16.1307,119.7824 ],
    [ u"ph",u"Altavas",2736,11.538,122.487 ],
    [ u"ph",u"Alua",4943,15.3076,120.8905 ],
    [ u"ph",u"Alubijid",2700,8.962778,125.425833 ],
    [ u"ph",u"Alubijid",3320,8.573333,124.473611 ],
    [ u"ph",u"Alugan",2131,12.2188,125.4808 ],
    [ u"ph",u"Alupay",3981,13.841944,121.295833 ],
    [ u"ph",u"Amacalan",2693,15.5815,120.6112 ],
    [ u"ph",u"Amadeo",16618,14.170556,120.923611 ],
    [ u"ph",u"Amaga",2230,8.530833,126.070278 ],
    [ u"ph",u"Amagbagan",2443,16.0914,120.5232 ],
    [ u"ph",u"Amas",6219,7.056944,124.983889 ],
    [ u"ph",u"Ambuclao",2822,16.483333,120.75 ],
    [ u"ph",u"Ambulong",9074,14.088044,121.061272 ],
    [ u"ph",u"Amdus",2247,9.8821,123.0972 ],
    [ u"ph",u"Amio",2349,9.3571,122.9413 ],
    [ u"ph",u"Amio",2349,9.3992,122.9047 ],
    [ u"ph",u"Amlimay",2405,16.693773,120.837041 ],
    [ u"ph",u"Ampatuan",3962,6.866667,124.466667 ],
    [ u"ph",u"Amucao",2478,15.46405,120.686432 ],
    [ u"ph",u"Amulung",2354,17.835699,121.723749 ],
    [ u"ph",u"Amuñgan",12357,15.3652,119.9582 ],
    [ u"ph",u"Anahawan",2640,10.3429,124.8782 ],
    [ u"ph",u"Anakan",3825,8.847778,125.151389 ],
    [ u"ph",u"Anao",4669,15.1405,120.6926 ],
    [ u"ph",u"Anda",3160,16.2892,119.95 ],
    [ u"ph",u"Andalan",2644,5.959444,121.390278 ],
    [ u"ph",u"Andili",4400,7.462,125.9701 ],
    [ u"ph",u"Andres Bonifacio",6493,10.916667,123.25 ],
    [ u"ph",u"Angadanan",4487,16.755263,121.748341 ],
    [ u"ph",u"Angad",2223,17.5849,120.6257 ],
    [ u"ph",u"Angat",41235,14.9285,121.03 ],
    [ u"ph",u"Angatel",2359,15.8057,120.3431 ],
    [ u"ph",u"Angeles",298948,15.1406,120.591 ],
    [ u"ph",u"Angono",87199,14.5266,121.1536 ],
    [ u"ph",u"Anibongan",2468,7.393333,125.718889 ],
    [ u"ph",u"Ani-e",3324,8.613611,124.870556 ],
    [ u"ph",u"Anilao",2677,12.714022,121.512415 ],
    [ u"ph",u"Anislag",4061,13.0748,123.703 ],
    [ u"ph",u"Anito",2070,12.44972,125.288608 ],
    [ u"ph",u"Anoling",2670,13.2093,123.6761 ],
    [ u"ph",u"Anonang",5660,11.0578,123.9773 ],
    [ u"ph",u"Anonang",7036,16.1069,120.4373 ],
    [ u"ph",u"Anoring",2860,11.25,123.033333 ],
    [ u"ph",u"Antagan",4065,17.276431,121.904345 ],
    [ u"ph",u"Anticala",3246,9.004444,125.645278 ],
    [ u"ph",u"Antipolo",2257,13.3927,123.5231 ],
    [ u"ph",u"Antipolo",4530,11.166667,123.95 ],
    [ u"ph",u"Antipolo",3486,15.6181,121.19 ],
    [ u"ph",u"Antipolo",7398,10.3565,122.9646 ],
    [ u"ph",u"Antipolo",549541,14.5886,121.1757 ],
    [ u"ph",u"Anulid",2177,15.8395,120.4967 ],
    [ u"ph",u"Anuling",3905,14.123882,120.892201 ],
    [ u"ph",u"Anuling",10039,6.035556,121.006667 ],
    [ u"ph",u"Apad",2755,13.815,122.7664 ],
    [ u"ph",u"Apalit",77418,14.953333,120.77 ],
    [ u"ph",u"Apitong",2402,13.2391,121.2075 ],
    [ u"ph",u"Aplaya",9737,13.7726,121.0259 ],
    [ u"ph",u"Aplaya",3730,8.608611,124.768056 ],
    [ u"ph",u"Aplaya",3446,14.32106,121.113686 ],
    [ u"ph",u"Aporawan",2943,9.5994,118.3489 ],
    [ u"ph",u"Apud",2071,13.13928,123.291644 ],
    [ u"ph",u"Aquino",2607,11.8221,122.1088 ],
    [ u"ph",u"Araceli",3111,10.5529,119.9913 ],
    [ u"ph",u"Aramaywan",3487,9.170077,118.187198 ],
    [ u"ph",u"Aranas",4479,11.5635,122.3901 ],
    [ u"ph",u"Aranda",3100,10.2365,122.9467 ],
    [ u"ph",u"Arcangel",3470,11.5395,122.3455 ],
    [ u"ph",u"Arenas",4108,15.1704,120.6876 ],
    [ u"ph",u"Aringay",29825,16.394,120.3545 ],
    [ u"ph",u"Aritao",7972,16.2979,121.0345 ],
    [ u"ph",u"Armenia",3658,12.253241,123.74361 ],
    [ u"ph",u"Armenia",3468,15.435352,120.563932 ],
    [ u"ph",u"Arteche",5025,12.2645,125.4048 ],
    [ u"ph",u"Asia",23547,9.5506,122.5164 ],
    [ u"ph",u"Asin",3550,15.8229,120.438 ],
    [ u"ph",u"Astorga",2702,11.254486,122.801802 ],
    [ u"ph",u"Astorga",10712,6.907222,125.455833 ],
    [ u"ph",u"Asturias",7779,10.5669,123.7161 ],
    [ u"ph",u"Atabayan",2362,10.683333,122.416667 ],
    [ u"ph",u"Atipuluan",3940,10.513364,122.962102 ],
    [ u"ph",u"Atok",2092,16.5724,120.6808 ],
    [ u"ph",u"Atop-atop",2844,11.2322,123.7602 ],
    [ u"ph",u"Atulayan",6374,17.6648,121.6937 ],
    [ u"ph",u"Atulayan",6374,17.6342,121.7219 ],
    [ u"ph",u"Aumbay",3397,7.1026,125.7837 ],
    [ u"ph",u"Aureliana",2172,10.8849,121.9769 ],
    [ u"ph",u"Aurora",2681,8.593056,125.8375 ],
    [ u"ph",u"Aurora",4500,16.99065,121.636643 ],
    [ u"ph",u"Aurora",3481,13.2322,121.1203 ],
    [ u"ph",u"Aurora",16177,13.3476,122.5195 ],
    [ u"ph",u"Aurora",9157,7.9506,123.5826 ],
    [ u"ph",u"Avila",2349,10.692,122.709 ],
    [ u"ph",u"Awallan",2144,17.924392,121.91305 ],
    [ u"ph",u"Awang",8417,7.153056,124.221111 ],
    [ u"ph",u"Aya",2924,13.8945,121.1139 ],
    [ u"ph",u"Ayugan",2613,13.5469,123.3217 ],
    [ u"ph",u"Ayusan",3715,14.016667,121.4 ],
    [ u"ph",u"Azagra",4688,9.4779,123.1367 ],
    [ u"ph",u"Baao",19613,13.4549,123.3653 ],
    [ u"ph",u"Baay",3045,18.1188,120.5753 ],
    [ u"ph",u"Babag",3215,7.731111,126.070833 ],
    [ u"ph",u"Bacabac",2190,15.733333,120.416667 ],
    [ u"ph",u"Bacag",5509,15.93,120.582222 ],
    [ u"ph",u"Bacalan",2060,11.5464,122.0849 ],
    [ u"ph",u"Bacarra",9636,18.2529,120.6125 ],
    [ u"ph",u"Bacayawan",3234,7.766667,124.233333 ],
    [ u"ph",u"Bacnar",4606,15.8852,120.3415 ],
    [ u"ph",u"Bacnor",2216,16.983333,121.633333 ],
    [ u"ph",u"Bacnotan",3142,16.722222,120.3525 ],
    [ u"ph",u"Baco",2903,13.3573,121.0983 ],
    [ u"ph",u"Bacolod",5294,8.116667,123.916667 ],
    [ u"ph",u"Bacolod",2773,12.228544,123.50851 ],
    [ u"ph",u"Bacolod",2171,8.931667,126.289444 ],
    [ u"ph",u"Bacolod",453954,10.6677,122.9533 ],
    [ u"ph",u"Bacon",5010,13.037778,124.041111 ],
    [ u"ph",u"Bacong",2287,9.7393,124.5656 ],
    [ u"ph",u"Bacong",5091,9.2464,123.2956 ],
    [ u"ph",u"Bacoor",356987,14.459027,120.929034 ],
    [ u"ph",u"Bacsay",2615,15.65,120.333333 ],
    [ u"ph",u"Bactad",3610,15.979167,120.618611 ],
    [ u"ph",u"Bacuag",5420,9.6086,125.6387 ],
    [ u"ph",u"Bacuit",7801,11.185833,119.395556 ],
    [ u"ph",u"Baculin",2971,7.4525,126.584167 ],
    [ u"ph",u"Baculongan",11742,16.8,120.8333 ],
    [ u"ph",u"Baculong",3655,15.5379,120.6385 ],
    [ u"ph",u"Bacungan",3771,8.1551,122.9311 ],
    [ u"ph",u"Bacungan",3975,9.9115,118.7036 ],
    [ u"ph",u"Bacuyangan",7506,9.637,122.4721 ],
    [ u"ph",u"Badak",6653,6.8275,124.754722 ],
    [ u"ph",u"Badian",2706,13.031667,123.307778 ],
    [ u"ph",u"Badian",3613,9.864722,123.396389 ],
    [ u"ph",u"Badlan",2041,11.1414,122.52 ],
    [ u"ph",u"Badoc",4319,17.9265,120.4764 ],
    [ u"ph",u"Badtasan",2174,6.004961,124.612657 ],
    [ u"ph",u"Bagabag",24967,16.505882,121.190139 ],
    [ u"ph",u"Bagacay",3090,10.15209,124.258568 ],
    [ u"ph",u"Bagacay",2991,13.777,123.3032 ],
    [ u"ph",u"Bagacay",3158,12.9821,124.1415 ],
    [ u"ph",u"Bagac",3969,14.5962,120.3928 ],
    [ u"ph",u"Bagahanglad",2649,12.5797,123.6688 ],
    [ u"ph",u"Bagakay",3136,8.1454,123.8157 ],
    [ u"ph",u"Bagan",2230,6.925556,124.420278 ],
    [ u"ph",u"Baganga",10106,7.573889,126.56 ],
    [ u"ph",u"Bagay",4977,11.1964,124.035 ],
    [ u"ph",u"Bago",76721,10.5355,122.8357 ],
    [ u"ph",u"Bagong Barrio",4205,14.9,120.95 ],
    [ u"ph",u"Bagong Sikat",5468,12.367447,121.061713 ],
    [ u"ph",u"Bagong Tanza",2404,16.98435,121.612143 ],
    [ u"ph",u"Bagontapay",6747,6.858889,124.908889 ],
    [ u"ph",u"Bagroy",2361,10.2031,122.9362 ],
    [ u"ph",u"Bagtic",3835,9.6864,123.0122 ],
    [ u"ph",u"Bagting",19206,15.5544,121.2469 ],
    [ u"ph",u"Bagu",2120,18.422778,121.358333 ],
    [ u"ph",u"Baguer",3228,7.256111,124.504167 ],
    [ u"ph",u"Baguinge",2078,16.777666,121.106241 ],
    [ u"ph",u"Baguio",272732,16.416389,120.593056 ],
    [ u"ph",u"Bagumbayan",2990,13.45,123.666667 ],
    [ u"ph",u"Bagumbayan",2163,18.196878,121.663252 ],
    [ u"ph",u"Bagumbayan",2095,13.4653,123.3899 ],
    [ u"ph",u"Bagumbayan",2577,10.446,122.8348 ],
    [ u"ph",u"Bagumbong",2984,14.3413,121.3775 ],
    [ u"ph",u"Bagupaye",2578,13.539722,122.421944 ],
    [ u"ph",u"Bahay",2501,13.5437,123.0407 ],
    [ u"ph",u"Bahay Pare",9726,15.0336,120.8817 ],
    [ u"ph",u"Bahile",2255,9.996,118.7857 ],
    [ u"ph",u"Baikingon",2164,8.469722,124.571389 ],
    [ u"ph",u"Bailan",2885,11.433,122.8411 ],
    [ u"ph",u"Bail",2120,16.2768,120.4209 ],
    [ u"ph",u"Bais",65594,9.591111,123.122778 ],
    [ u"ph",u"Bais",65594,9.5375,123.0981 ],
    [ u"ph",u"Baka",2404,7.276111,124.264167 ],
    [ u"ph",u"Bakhawan",2661,11.2067,123.9634 ],
    [ u"ph",u"Bakong",3185,4.891111,119.794167 ],
    [ u"ph",u"Balabac",9880,7.9868,117.0645 ],
    [ u"ph",u"Balabagan",2422,7.526389,124.114167 ],
    [ u"ph",u"Balabag",4692,11.97,121.919167 ],
    [ u"ph",u"Balabag",3027,10.763333,122.493056 ],
    [ u"ph",u"Balabag",3027,10.766667,122.533333 ],
    [ u"ph",u"Balading",2755,13.3906,123.7121 ],
    [ u"ph",u"Balagon",2691,8.0063,123.2396 ],
    [ u"ph",u"Balagtas",59826,14.816667,120.866667 ],
    [ u"ph",u"Balagtas",2293,11.1333,124.5192 ],
    [ u"ph",u"Balagtasin",4050,13.9018,121.0889 ],
    [ u"ph",u"Balagunan",4528,7.492222,125.521111 ],
    [ u"ph",u"Balanacan",3547,13.5289,121.8677 ],
    [ u"ph",u"Balangbalang",2135,9.056944,125.622778 ],
    [ u"ph",u"Balangiga",5592,11.109722,125.3875 ],
    [ u"ph",u"Balangkayan",3159,11.471389,125.510556 ],
    [ u"ph",u"Balaoan",2928,16.8219,120.4045 ],
    [ u"ph",u"Balaoang",3724,15.6633,120.5147 ],
    [ u"ph",u"Balaogan",2841,13.4328,123.2818 ],
    [ u"ph",u"Balaquid",2502,11.4737,124.5133 ],
    [ u"ph",u"Balasan",4051,11.4728,123.0878 ],
    [ u"ph",u"Balas",2295,6.6875,122.138056 ],
    [ u"ph",u"Balas",2517,15.0335,120.6059 ],
    [ u"ph",u"Balasing",4768,14.8545,121.0127 ],
    [ u"ph",u"Balatan",4451,13.321111,123.233333 ],
    [ u"ph",u"Balatero",3746,13.5021,120.9244 ],
    [ u"ph",u"Balayang",2923,15.5495,120.6943 ],
    [ u"ph",u"Balayong",2469,9.4744,123.0623 ],
    [ u"ph",u"Balaytigui",2341,14.1312,120.6013 ],
    [ u"ph",u"Balbalan",2195,17.4408,121.2026 ],
    [ u"ph",u"Balele",6496,14.065321,121.093632 ],
    [ u"ph",u"Baleno",3741,12.4739,123.4982 ],
    [ u"ph",u"Balete",3220,13.8754,121.204 ],
    [ u"ph",u"Balete",8588,13.019167,124.031944 ],
    [ u"ph",u"Balete",4360,15.646944,120.638333 ],
    [ u"ph",u"Balibagan",2263,10.8,122.516667 ],
    [ u"ph",u"Balibago",3121,13.6093,121.2971 ],
    [ u"ph",u"Baligang",5781,13.1537,123.6432 ],
    [ u"ph",u"Balila",2511,8.002778,125.013056 ],
    [ u"ph",u"Balili",2485,7.895,123.7337 ],
    [ u"ph",u"Balilihan",2931,9.7561,123.973 ],
    [ u"ph",u"Balinad",3032,13.2926,123.5454 ],
    [ u"ph",u"Balingasay",3720,16.3573,119.8564 ],
    [ u"ph",u"Balingcanaway",5870,15.482149,120.685432 ],
    [ u"ph",u"Balingueo",2906,15.9555,120.4081 ],
    [ u"ph",u"Balinsasayao",2404,10.681,124.9595 ],
    [ u"ph",u"Balite",2564,14.9,120.783333 ],
    [ u"ph",u"Balite",7495,14.166898,120.976849 ],
    [ u"ph",u"Balite",2502,12.931008,121.470616 ],
    [ u"ph",u"Balitoc",3121,13.862687,120.635545 ],
    [ u"ph",u"Baliton",5809,5.743611,125.236389 ],
    [ u"ph",u"Baliuag",135627,14.954722,120.896944 ],
    [ u"ph",u"Baliuag",4601,13.5214,123.2016 ],
    [ u"ph",u"Baliwagan",2838,8.718611,124.790556 ],
    [ u"ph",u"Baliwagan",2883,10.3971,122.8911 ],
    [ u"ph",u"Ballesteros",5591,18.4126,121.5152 ],
    [ u"ph",u"Balocawe",2142,12.2013,123.8426 ],
    [ u"ph",u"Balocawehay",3528,10.7182,124.9642 ],
    [ u"ph",u"Baloc",10566,15.6435,120.8852 ],
    [ u"ph",u"Balogo",3908,13.2871,123.5496 ],
    [ u"ph",u"Balogo",3190,13.5016,123.0638 ],
    [ u"ph",u"Balogo",3308,10.1148,123.1706 ],
    [ u"ph",u"Balogo",2298,15.9898,120.2822 ],
    [ u"ph",u"Balogo",3063,7.282298,124.463882 ],
    [ u"ph",u"Baloi",7700,8.117222,124.218611 ],
    [ u"ph",u"Bal-os",3206,9.4416,122.6257 ],
    [ u"ph",u"Baloy",2308,15.7533,120.7832 ],
    [ u"ph",u"Balsic",5661,14.858889,120.483611 ],
    [ u"ph",u"Balucuc",9214,14.963611,120.837778 ],
    [ u"ph",u"Balud",3586,10.1476,123.6953 ],
    [ u"ph",u"Balud",2295,12.036859,123.193509 ],
    [ u"ph",u"Balugo",6704,10.8868,124.7105 ],
    [ u"ph",u"Balugo",2666,12.579231,121.439314 ],
    [ u"ph",u"Balutakay",2817,6.721111,125.351667 ],
    [ u"ph",u"Balut",2348,14.683333,120.55 ],
    [ u"ph",u"Balutu",3539,15.29886,120.692831 ],
    [ u"ph",u"Baluyot",3176,15.8017,120.4621 ],
    [ u"ph",u"Bamban",2783,15.8414,119.9518 ],
    [ u"ph",u"Bamban",2511,15.6747,120.3315 ],
    [ u"ph",u"Bambang",22831,16.3865,121.1066 ],
    [ u"ph",u"Banaba",4387,14.216667,120.85 ],
    [ u"ph",u"Banaba",2778,13.8966,121.21 ],
    [ u"ph",u"Banalo",2310,13.6464,121.1817 ],
    [ u"ph",u"Banaoang",4168,15.9948,120.424 ],
    [ u"ph",u"Banaue",2497,16.913559,121.061842 ],
    [ u"ph",u"Banawang",2306,14.6121,120.39 ],
    [ u"ph",u"Banaybanay",8304,13.8997,121.1053 ],
    [ u"ph",u"Banaybanay",8304,13.9331,121.1151 ],
    [ u"ph",u"Bancal",4295,11.5591,123.1551 ],
    [ u"ph",u"Bancasi",3607,8.966667,125.466667 ],
    [ u"ph",u"Bañga",2136,11.6387,122.3341 ],
    [ u"ph",u"Banga",2058,10.5018,122.8289 ],
    [ u"ph",u"Bangad",2216,17.495719,121.781846 ],
    [ u"ph",u"Bangad",3321,12.161249,123.40131 ],
    [ u"ph",u"Bangad",4498,15.487746,121.053932 ],
    [ u"ph",u"Bangahan",2728,7.804444,124.728889 ],
    [ u"ph",u"Banganan",2595,16.3144,121.0544 ],
    [ u"ph",u"Bangan-Oda",3456,16.1087,119.8307 ],
    [ u"ph",u"Bangao",3902,16.8211,120.8404 ],
    [ u"ph",u"Bangar",11068,16.8936,120.4243 ],
    [ u"ph",u"Bangkal",2288,6.066667,121.066667 ],
    [ u"ph",u"Bangonay",2643,9.314444,125.553889 ],
    [ u"ph",u"Bangued",14017,17.5982,120.6155 ],
    [ u"ph",u"Bangui",2458,18.5376,120.7671 ],
    [ u"ph",u"Banhigan",2359,9.854722,123.385833 ],
    [ u"ph",u"Bani",11569,16.185,119.8613 ],
    [ u"ph",u"Bani",3066,15.5823,119.9335 ],
    [ u"ph",u"Banilad",4031,14.0667,120.7347 ],
    [ u"ph",u"Banisilan",5748,7.490833,124.724167 ],
    [ u"ph",u"Banna",3566,17.9809,120.6569 ],
    [ u"ph",u"Bannawag",3060,7.153611,124.866667 ],
    [ u"ph",u"Banocboc",3963,14.3,122.583333 ],
    [ u"ph",u"Banog",3700,16.1672,119.8941 ],
    [ u"ph",u"Banquero",2173,17.023047,121.778343 ],
    [ u"ph",u"Banquerohan",9040,13.0553,123.7468 ],
    [ u"ph",u"Bansud",13758,12.860912,121.489215 ],
    [ u"ph",u"Bantacan",3299,7.604,126.1298 ],
    [ u"ph",u"Bantayan",3976,12.5237,124.8283 ],
    [ u"ph",u"Bantay",10091,17.584722,120.389167 ],
    [ u"ph",u"Bantigue",2026,10.9245,124.4154 ],
    [ u"ph",u"Bantilan",5406,14.758138,121.669019 ],
    [ u"ph",u"Bantog",4111,16.0091,120.6929 ],
    [ u"ph",u"Bantogon",5379,6.533333,124.033333 ],
    [ u"ph",u"Bantuanon",4673,8.015278,125.070833 ],
    [ u"ph",u"Banugao",2795,14.748248,121.618405 ],
    [ u"ph",u"Bao",6672,7.405278,124.649722 ],
    [ u"ph",u"Baod",3059,11.2111,123.7031 ],
    [ u"ph",u"Baon",3601,6.795621,126.087783 ],
    [ u"ph",u"Baquero",5145,15.7162,120.5543 ],
    [ u"ph",u"Bara",2084,12.0717,123.6395 ],
    [ u"ph",u"Baracatan",7298,6.9675,125.415833 ],
    [ u"ph",u"Barahan",6414,13.0121,120.762 ],
    [ u"ph",u"Barangobong",3644,15.877778,120.548333 ],
    [ u"ph",u"Baraoas",3556,16.633333,120.4 ],
    [ u"ph",u"Baras",2764,11.183333,125.016667 ],
    [ u"ph",u"Baras",20250,14.5234,121.2651 ],
    [ u"ph",u"Barayong",2433,13.1,123.716667 ],
    [ u"ph",u"Barcelona",3258,12.8683,124.1419 ],
    [ u"ph",u"Barcelona",3541,8.159167,126.434167 ],
    [ u"ph",u"Barcelona",2255,8.5275,123.4587 ],
    [ u"ph",u"Barira",3717,7.487222,124.299167 ],
    [ u"ph",u"Bariw",2070,13.133333,123.733333 ],
    [ u"ph",u"Baro",2906,15.983333,120.666667 ],
    [ u"ph",u"Barobo",9893,8.535278,126.121389 ],
    [ u"ph",u"Barong",2392,18.0576,120.734 ],
    [ u"ph",u"Barongis",2987,7.261111,124.564167 ],
    [ u"ph",u"Barotac Nuevo",11641,10.894167,122.704444 ],
    [ u"ph",u"Barotac Viejo",8611,11.041944,122.852222 ],
    [ u"ph",u"Baroy",3195,8.0269,123.7784 ],
    [ u"ph",u"Barra",12442,8.510278,124.604444 ],
    [ u"ph",u"Barugo",6655,11.324167,124.738333 ],
    [ u"ph",u"Barurao",2990,6.898056,124.5975 ],
    [ u"ph",u"Basa",2323,8.072222,126.064167 ],
    [ u"ph",u"Basag",2799,8.924722,125.617778 ],
    [ u"ph",u"Basak",2457,8.041111,124.862778 ],
    [ u"ph",u"Basak",3705,10.2264,123.3064 ],
    [ u"ph",u"Basak",3781,6.727357,124.151173 ],
    [ u"ph",u"Basay",4307,9.4087,122.64 ],
    [ u"ph",u"Bascaran",3261,13.1029,123.6999 ],
    [ u"ph",u"Basco",7297,20.448649,121.970172 ],
    [ u"ph",u"Basdiot",4015,9.941389,123.376111 ],
    [ u"ph",u"Basey",7844,11.281667,125.068333 ],
    [ u"ph",u"Basiad",2849,14.156174,122.337487 ],
    [ u"ph",u"Basiao",2475,11.548611,122.6375 ],
    [ u"ph",u"Basiawan",6351,6.509444,125.508333 ],
    [ u"ph",u"Basing",2367,15.9758,120.2531 ],
    [ u"ph",u"Basista",2781,15.8524,120.3976 ],
    [ u"ph",u"Basud",5232,14.065,122.9642 ],
    [ u"ph",u"Basud",2980,11.3663,124.3631 ],
    [ u"ph",u"Basud",2178,12.988889,123.95 ],
    [ u"ph",u"Batakil",2504,16.155278,120.5275 ],
    [ u"ph",u"Batal",7274,16.6945,121.5928 ],
    [ u"ph",u"Batan",4495,11.5857,122.4971 ],
    [ u"ph",u"Batangas",238907,13.7567,121.0584 ],
    [ u"ph",u"Batang",3017,13.2498,123.5641 ],
    [ u"ph",u"Bataraza",6169,8.661667,117.622222 ],
    [ u"ph",u"Batasan",4752,12.766667,120.783333 ],
    [ u"ph",u"Batasan",4966,15.1444,120.9415 ],
    [ u"ph",u"Batasan",2231,7.033333,125.05 ],
    [ u"ph",u"Batas",2591,14.2,120.816667 ],
    [ u"ph",u"Bateria",3629,11.1416,124.0267 ],
    [ u"ph",u"Batiano",2410,7.5534,126.4907 ],
    [ u"ph",u"Batitang",3306,15.4045,120.8079 ],
    [ u"ph",u"Batobalani",5025,14.233333,122.75 ],
    [ u"ph",u"Bato",16939,13.3528,123.3677 ],
    [ u"ph",u"Bato",2117,13.6068,124.2986 ],
    [ u"ph",u"Bato",9952,10.327778,124.791111 ],
    [ u"ph",u"Bato",2789,8.6027,123.6449 ],
    [ u"ph",u"Bato",2615,10.825,119.471 ],
    [ u"ph",u"Bato",5008,7.05,125.433333 ],
    [ u"ph",u"Batobato",9714,6.825219,126.084583 ],
    [ u"ph",u"Bato",5008,7.043056,125.473056 ],
    [ u"ph",u"Bato",5665,10.808542,123.373303 ],
    [ u"ph",u"Battung",2350,17.716667,121.483333 ],
    [ u"ph",u"Batuan",4052,9.7808,124.1484 ],
    [ u"ph",u"Batuan",2516,12.4215,123.7818 ],
    [ u"ph",u"Batu",2966,7.753333,122.829444 ],
    [ u"ph",u"Bauan",8165,17.7156,121.6913 ],
    [ u"ph",u"Bautista",3097,15.8112,120.4737 ],
    [ u"ph",u"Bautista",2458,13.994444,121.277778 ],
    [ u"ph",u"Bawisan",3461,5.9375,120.8745 ],
    [ u"ph",u"Bayabas",2165,16.45,120.516667 ],
    [ u"ph",u"Bayanan",3579,13.3592,121.1699 ],
    [ u"ph",u"Bayanga",5087,7.537778,124.24 ],
    [ u"ph",u"Bayañga",5087,7.466667,124.233333 ],
    [ u"ph",u"Bay-ang",2477,11.034722,122.941667 ],
    [ u"ph",u"Bayang",6176,7.792778,124.191667 ],
    [ u"ph",u"Bayas",2275,11.4336,123.1816 ],
    [ u"ph",u"Bayasong",2990,6.648889,124.873056 ],
    [ u"ph",u"Bay",33547,14.1831,121.2848 ],
    [ u"ph",u"Baybay",2212,13.4083,123.7135 ],
    [ u"ph",u"Baybay",2914,15.8977,120.2305 ],
    [ u"ph",u"Baybayin",2451,13.82,121.270833 ],
    [ u"ph",u"Baylo",3552,7.853889,126.058056 ],
    [ u"ph",u"Bayog",4284,7.866667,123.066667 ],
    [ u"ph",u"Bayugan",40561,8.756111,125.7675 ],
    [ u"ph",u"Bayuin",3069,13.041101,121.388516 ],
    [ u"ph",u"Beberon",2250,13.5444,123.1405 ],
    [ u"ph",u"Becerril",2416,9.6531,123.4344 ],
    [ u"ph",u"Beddeng",2565,14.977284,120.084929 ],
    [ u"ph",u"Begang",2384,6.6909,122.0168 ],
    [ u"ph",u"Belance",2233,16.183333,121.25 ],
    [ u"ph",u"Belison",4711,10.8384,121.9605 ],
    [ u"ph",u"Benito Soliven",4926,16.981548,121.959942 ],
    [ u"ph",u"Besao",2241,17.095,120.8579 ],
    [ u"ph",u"Betwagan",2132,17.083333,120.966667 ],
    [ u"ph",u"Biabas",2381,9.8,124.466667 ],
    [ u"ph",u"Bialong",8639,6.980556,124.888889 ],
    [ u"ph",u"Biao",12043,7.163333,125.521111 ],
    [ u"ph",u"Biasong",2163,10.5229,123.736 ],
    [ u"ph",u"Biay",2257,15.7402,119.9067 ],
    [ u"ph",u"Bibiclat",7039,15.524,120.8659 ],
    [ u"ph",u"Bical",3550,15.8143,120.4346 ],
    [ u"ph",u"Bicos",3962,15.6166,120.996 ],
    [ u"ph",u"Bidduang",2133,18.466389,121.341111 ],
    [ u"ph",u"Bien Unido",5304,10.137288,124.377609 ],
    [ u"ph",u"Bigaa",14510,13.1993,123.7566 ],
    [ u"ph",u"Bigaan",2744,8.317222,126.281111 ],
    [ u"ph",u"Biga",3096,13.904012,120.648754 ],
    [ u"ph",u"Biga",2365,13.2694,121.1473 ],
    [ u"ph",u"Biga",4232,14.250833,120.976667 ],
    [ u"ph",u"Biga",2830,8.357778,124.259722 ],
    [ u"ph",u"Biking",2907,9.592222,123.846111 ],
    [ u"ph",u"Bilad",2778,15.7334,120.4356 ],
    [ u"ph",u"Bilao",5805,11.488,122.5599 ],
    [ u"ph",u"Bilaran",4577,14.0432,120.6892 ],
    [ u"ph",u"Biliran",4699,11.467035,124.473959 ],
    [ u"ph",u"Bilwang",2808,10.8834,124.4667 ],
    [ u"ph",u"Binabalian",3298,16.4202,119.9279 ],
    [ u"ph",u"Binahaan",4843,13.9901,121.7554 ],
    [ u"ph",u"Binalan",2276,18.3275,121.5451 ],
    [ u"ph",u"Binalbagan",38567,10.1948,122.8581 ],
    [ u"ph",u"Binalonan",8145,16.0503,120.5926 ],
    [ u"ph",u"Biñan",2094,14.263732,121.052638 ],
    [ u"ph",u"Binangonan",219203,14.4646,121.1929 ],
    [ u"ph",u"Binanwanaan",3034,13.7,123.3 ],
    [ u"ph",u"Binay",2828,13.5019,122.5983 ],
    [ u"ph",u"Bincungan",3810,7.366667,125.75 ],
    [ u"ph",u"Binday",2236,16.1271,120.4525 ],
    [ u"ph",u"Bindoy",3600,9.759,123.1412 ],
    [ u"ph",u"Bingawan",3657,11.233,122.5672 ],
    [ u"ph",u"Binguang",2082,17.461944,121.782778 ],
    [ u"ph",u"Binidayan",3848,7.806677,124.168461 ],
    [ u"ph",u"Binitayan",4802,13.2945,123.7579 ],
    [ u"ph",u"Binitinan",3101,8.71,124.775556 ],
    [ u"ph",u"Binlod",2941,9.911944,123.609722 ],
    [ u"ph",u"Binodegahan",2471,13.061397,123.457897 ],
    [ u"ph",u"Binon-an",3442,11.3947,123.1426 ],
    [ u"ph",u"Bintakay",2593,13.4986,121.8768 ],
    [ u"ph",u"Bintawan",4971,16.575878,121.18764 ],
    [ u"ph",u"Binuangan",5754,8.915278,124.788333 ],
    [ u"ph",u"Binuang",3159,5.956944,121.06 ],
    [ u"ph",u"Binubusan",6714,13.962826,120.637713 ],
    [ u"ph",u"Binucayan",2875,8.25,125.716667 ],
    [ u"ph",u"Binulasan",2292,14.731592,121.697811 ],
    [ u"ph",u"Binuntucan",4213,11.4073,122.8602 ],
    [ u"ph",u"Biri",2597,12.683333,124.363611 ],
    [ u"ph",u"Bislig",2704,11.0725,125.033611 ],
    [ u"ph",u"Bislig",68892,8.215278,126.316389 ],
    [ u"ph",u"Bitadton",3017,11.496901,122.085108 ],
    [ u"ph",u"Bitag",4006,17.900794,121.85065 ],
    [ u"ph",u"Bitangan",3284,14.253889,120.878333 ],
    [ u"ph",u"Bitanhuan",2841,10.5955,124.7663 ],
    [ u"ph",u"Bitaogan",2145,6.768423,126.077383 ],
    [ u"ph",u"Bitin",5758,14.093889,121.212778 ],
    [ u"ph",u"Bitoon",2395,10.0804,123.4587 ],
    [ u"ph",u"Biwang",2334,6.597222,124.555278 ],
    [ u"ph",u"Blensong",4151,7.018056,124.180556 ],
    [ u"ph",u"Blingkong",4954,6.572222,124.877222 ],
    [ u"ph",u"Bobonan",2454,16.1348,120.5271 ],
    [ u"ph",u"Bobon",4515,6.867815,126.328382 ],
    [ u"ph",u"Bobon",4150,15.6691,120.3854 ],
    [ u"ph",u"Bobon",4775,12.5246,124.5636 ],
    [ u"ph",u"Bocana",4464,10.0116,122.7217 ],
    [ u"ph",u"Bocaue",98649,14.798333,120.926111 ],
    [ u"ph",u"Bocos",2428,16.926458,121.057342 ],
    [ u"ph",u"Bogo",23562,11.0517,124.0055 ],
    [ u"ph",u"Bogtong",3999,15.7536,120.3285 ],
    [ u"ph",u"Bolaoit",2386,15.934,120.432 ],
    [ u"ph",u"Bolboc",2437,13.983333,120.716667 ],
    [ u"ph",u"Bolila",2125,6.371667,125.571389 ],
    [ u"ph",u"Bolilao",2651,10.862222,122.747222 ],
    [ u"ph",u"Bolisong",2802,9.6899,123.153 ],
    [ u"ph",u"Bolitoc",3131,15.7395,119.8769 ],
    [ u"ph",u"Boljoon",3313,9.6281,123.4785 ],
    [ u"ph",u"Bolo",8310,13.789906,120.981726 ],
    [ u"ph",u"Bolo",2548,13.753,122.9658 ],
    [ u"ph",u"Bolo",2784,15.9948,120.1647 ],
    [ u"ph",u"Bolo",4705,11.540278,122.757222 ],
    [ u"ph",u"Bolo",2705,12.4109,123.5672 ],
    [ u"ph",u"Bolong",2899,10.816667,122.516667 ],
    [ u"ph",u"Bolong",5189,7.100144,122.237908 ],
    [ u"ph",u"Bombon",4913,13.6887,123.2077 ],
    [ u"ph",u"Bonawon",9189,9.134,122.9193 ],
    [ u"ph",u"Bonbon",2215,9.105278,124.733889 ],
    [ u"ph",u"Bonbon",6122,10.2245,123.5573 ],
    [ u"ph",u"Bone",6573,16.2446,120.9958 ],
    [ u"ph",u"Bongabon",36168,15.6321,121.1448 ],
    [ u"ph",u"Bonga",2528,13.216667,123.55 ],
    [ u"ph",u"Bongabong",3888,7.2221,125.8731 ],
    [ u"ph",u"Boñgalon",2181,16.00022,120.159036 ],
    [ u"ph",u"Bongued",2684,7.116667,124.4 ],
    [ u"ph",u"Bontoc",10440,17.0899,120.978 ],
    [ u"ph",u"Bood",2320,9.7433,123.8294 ],
    [ u"ph",u"Boot",4884,14.04556,121.077218 ],
    [ u"ph",u"Borbon",2105,8.484167,125.893056 ],
    [ u"ph",u"Borbon",4703,10.838,124.0297 ],
    [ u"ph",u"Boston",2891,7.871111,126.364167 ],
    [ u"ph",u"Botao",2719,15.916667,120.416667 ],
    [ u"ph",u"Botigues",2973,11.0995,123.6675 ],
    [ u"ph",u"Botolan",22994,15.2896,120.0245 ],
    [ u"ph",u"Boton",2336,12.9287,124.0479 ],
    [ u"ph",u"Bualan",3007,7.395833,124.306944 ],
    [ u"ph",u"Bual",2857,7.1825,124.505833 ],
    [ u"ph",u"Buan",2646,5.5508,120.8815 ],
    [ u"ph",u"Buan",2930,5.1608,120.0426 ],
    [ u"ph",u"Buang",2402,13.3115,123.6421 ],
    [ u"ph",u"Buanoy",10955,10.467464,123.699901 ],
    [ u"ph",u"Buanza",3196,6.0258,120.9614 ],
    [ u"ph",u"Buayan",14607,6.116389,125.234722 ],
    [ u"ph",u"Bubog",4880,12.373247,121.041713 ],
    [ u"ph",u"Bucal",3254,13.9132,121.5264 ],
    [ u"ph",u"Buclad",2620,7.527778,125.750556 ],
    [ u"ph",u"Bued",2392,15.833333,120.65 ],
    [ u"ph",u"Bued",2471,16.1622,119.9973 ],
    [ u"ph",u"Buenavista",2454,9.840556,124.2225 ],
    [ u"ph",u"Buenavista",2197,13.867,123.302 ],
    [ u"ph",u"Buenavista",2351,10.1776,123.6013 ],
    [ u"ph",u"Buenavista",4087,10.701111,122.6275 ],
    [ u"ph",u"Buenavista",2743,13.255115,121.941492 ],
    [ u"ph",u"Buenavista",3021,12.176389,123.790556 ],
    [ u"ph",u"Buenavista",4442,10.1379,123.2439 ],
    [ u"ph",u"Buenavista",2564,9.115,126.160833 ],
    [ u"ph",u"Buenavista",6132,7.235792,122.252503 ],
    [ u"ph",u"Buenavista",2428,10.54406,123.447802 ],
    [ u"ph",u"Buenavista",3787,10.798742,123.554403 ],
    [ u"ph",u"Buenlag",11103,15.9602,120.4017 ],
    [ u"ph",u"Buenlag",2545,15.6304,120.5827 ],
    [ u"ph",u"Buensuceso",3729,15.1437,120.7056 ],
    [ u"ph",u"Buer",3088,15.8397,120.2614 ],
    [ u"ph",u"Bugaan",3907,14.039871,120.936094 ],
    [ u"ph",u"Buga",3666,13.2966,123.3596 ],
    [ u"ph",u"Bugasan",7754,7.440833,124.259167 ],
    [ u"ph",u"Bugas",2261,9.894167,123.444167 ],
    [ u"ph",u"Bugasong",2828,11.0439,122.0659 ],
    [ u"ph",u"Bugayong",2910,16.0813,120.5812 ],
    [ u"ph",u"Bugcaon",4218,8.045833,125.112778 ],
    [ u"ph",u"Bugko",3120,12.5356,124.7923 ],
    [ u"ph",u"Bugo",45787,8.508333,124.759444 ],
    [ u"ph",u"Bugsoc",2871,9.7834,124.2712 ],
    [ u"ph",u"Buguey",3111,18.289272,121.831153 ],
    [ u"ph",u"Buguias",6192,16.722672,120.828341 ],
    [ u"ph",u"Buhangin",4391,6.491111,125.5475 ],
    [ u"ph",u"Buhatan",2556,12.9755,124.0478 ],
    [ u"ph",u"Bukal",2919,13.938056,121.385556 ],
    [ u"ph",u"Bukay Pait",3356,6.564167,124.7675 ],
    [ u"ph",u"Bukid",2232,5.571667,125.405556 ],
    [ u"ph",u"Bula",3060,11.448,122.5685 ],
    [ u"ph",u"Bulacan",4518,6.563056,125.41 ],
    [ u"ph",u"Bulacnin",7985,13.9903,121.139 ],
    [ u"ph",u"Bulad",2013,10.2548,122.9983 ],
    [ u"ph",u"Bulalacao",3112,16.8358,120.8085 ],
    [ u"ph",u"Bulalacao",12027,12.325349,121.343513 ],
    [ u"ph",u"Bulalacao",2387,11.7435,120.1715 ],
    [ u"ph",u"Bulanon",8127,10.9171,123.4734 ],
    [ u"ph",u"Bulaon",131818,15.0879,120.6667 ],
    [ u"ph",u"Bularit",2512,15.5684,120.6173 ],
    [ u"ph",u"Bulasa",3419,9.932778,123.614722 ],
    [ u"ph",u"Bulata",5151,9.8599,122.4016 ],
    [ u"ph",u"Bulatukan",4305,6.9025,125.160833 ],
    [ u"ph",u"Bulawen",3612,15.4173,119.9564 ],
    [ u"ph",u"Bulihan",2499,14.156,120.6441 ],
    [ u"ph",u"Bulihan",4869,14.883333,120.9 ],
    [ u"ph",u"Bulihan",13979,14.269741,120.995459 ],
    [ u"ph",u"Buliok",3713,7.016667,124.7 ],
    [ u"ph",u"Buliran",3476,15.266667,120.866667 ],
    [ u"ph",u"Buliran",2753,15.5598,120.9713 ],
    [ u"ph",u"Bulit",2219,7.115278,124.789444 ],
    [ u"ph",u"Buliwao",2380,16.483333,121.233333 ],
    [ u"ph",u"Bulod",2140,9.683333,123.15 ],
    [ u"ph",u"Bulualto",2671,15.2212,120.9516 ],
    [ u"ph",u"Buluan",28025,6.720278,124.801944 ],
    [ u"ph",u"Buluangan",12249,10.387072,123.338101 ],
    [ u"ph",u"Buluang",5758,13.3068,123.3425 ],
    [ u"ph",u"Buluang",2566,12.233362,119.875812 ],
    [ u"ph",u"Bulusan",6648,12.7518,124.1373 ],
    [ u"ph",u"Bulwang",3462,11.7206,122.353 ],
    [ u"ph",u"Bunawan",15471,8.167222,125.990833 ],
    [ u"ph",u"Bunawan",2120,8.318611,124.293889 ],
    [ u"ph",u"Bunga",2025,10.7731,124.7847 ],
    [ u"ph",u"Bunga",3775,11.4838,124.5918 ],
    [ u"ph",u"Bungahan",3340,13.942863,120.661775 ],
    [ u"ph",u"Bungoy",3591,13.994444,121.366111 ],
    [ u"ph",u"Bungsuan",4089,11.2404,122.6976 ],
    [ u"ph",u"Bunguiao",6728,7.103898,122.196051 ],
    [ u"ph",u"Bunog",2228,9.140278,117.781667 ],
    [ u"ph",u"Bunol",3021,15.6671,120.8344 ],
    [ u"ph",u"Burabod",2286,13.2686,123.4162 ],
    [ u"ph",u"Buracan",2309,13.6,123.5 ],
    [ u"ph",u"Buray",3863,10.715,122.459444 ],
    [ u"ph",u"Burdeos",4548,14.843024,121.969061 ],
    [ u"ph",u"Burgos",2139,16.827959,121.736041 ],
    [ u"ph",u"Burgos",3727,16.07181,121.049536 ],
    [ u"ph",u"Burgos",3236,16.0583,119.865 ],
    [ u"ph",u"Burgos",3513,9.266389,126.188333 ],
    [ u"ph",u"Burgos",2578,15.49465,120.404532 ],
    [ u"ph",u"Burgos",3080,13.9193,121.8122 ],
    [ u"ph",u"Burias",4281,11.4463,122.5497 ],
    [ u"ph",u"Burias",4066,5.717778,125.253611 ],
    [ u"ph",u"Burirao",2626,9.2,118.1 ],
    [ u"ph",u"Buru-un",15490,8.188611,124.170833 ],
    [ u"ph",u"Busay",5503,10.5378,122.886 ],
    [ u"ph",u"Busdi",2168,8.276111,125.251389 ],
    [ u"ph",u"Busilac",2814,16.4775,121.1241 ],
    [ u"ph",u"Busing",2062,13.151389,122.971389 ],
    [ u"ph",u"Busok",3463,6.506111,124.598889 ],
    [ u"ph",u"Bustos",42139,14.958056,120.917778 ],
    [ u"ph",u"Butag",2833,12.6292,123.9335 ],
    [ u"ph",u"Butason",3232,11.3072,124.462 ],
    [ u"ph",u"Butig",6016,7.724444,124.300833 ],
    [ u"ph",u"Butuan",250200,8.949167,125.543611 ],
    [ u"ph",u"Butubut",3193,16.8034,120.4344 ],
    [ u"ph",u"Butulan",2436,5.614444,125.431667 ],
    [ u"ph",u"Buug",8559,7.7294,123.0598 ],
    [ u"ph",u"Buyabod",2991,13.4666,122.0526 ],
    [ u"ph",u"Buyo",3579,13.1144,123.8666 ],
    [ u"ph",u"Buyo",2879,13.6813,123.4733 ],
    [ u"ph",u"Caba",4806,16.4316,120.3446 ],
    [ u"ph",u"Cabacao",4486,13.3356,120.6588 ],
    [ u"ph",u"Cabacungan",7200,10.3237,123.1331 ],
    [ u"ph",u"Cabadiangan",3002,12.6643,125.0456 ],
    [ u"ph",u"Cabadiangan",3125,10.1459,122.9431 ],
    [ u"ph",u"Cabadiangan",3433,9.7534,122.4739 ],
    [ u"ph",u"Cabagan",25304,17.427823,121.769546 ],
    [ u"ph",u"Cabalantian",3242,8.370833,124.3275 ],
    [ u"ph",u"Cabalaoangan",2674,15.983333,120.783333 ],
    [ u"ph",u"Cabalawan",2859,10.741389,123.9525 ],
    [ u"ph",u"Cabalitian",2253,16.0883,120.7922 ],
    [ u"ph",u"Cabaluay",3586,7.00033,122.178502 ],
    [ u"ph",u"Cabanatuan",220095,15.4867,120.9676 ],
    [ u"ph",u"Cabanbanan",4469,14.2404,121.4341 ],
    [ u"ph",u"Cabanbanan",2061,10.0852,122.9579 ],
    [ u"ph",u"Cabangahan",2709,8.022778,125.1375 ],
    [ u"ph",u"Cabangahan",3861,9.0781,122.9469 ],
    [ u"ph",u"Cabangan",3092,15.158,120.0569 ],
    [ u"ph",u"Cabanglasan",5423,8.090833,125.301944 ],
    [ u"ph",u"Cabannungan",2147,17.12264,121.852443 ],
    [ u"ph",u"Cabano",5812,10.5869,122.7002 ],
    [ u"ph",u"Cabaritan",9348,18.420556,121.489722 ],
    [ u"ph",u"Cabarroguis",6974,16.5143,121.5216 ],
    [ u"ph",u"Cabatang",4211,13.973333,121.379444 ],
    [ u"ph",u"Cabatuan",6106,10.8794,122.486 ],
    [ u"ph",u"Cabatuan",2381,12.5228,125.2202 ],
    [ u"ph",u"Cabayangan",16539,7.407222,125.733056 ],
    [ u"ph",u"Cabayaoasan",2798,15.6719,120.5653 ],
    [ u"ph",u"Cabay",2297,11.445556,125.493333 ],
    [ u"ph",u"Cabay",3277,13.878333,121.377222 ],
    [ u"ph",u"Cabcab",2613,13.6268,124.0515 ],
    [ u"ph",u"Cabcaben",5948,14.454,120.5914 ],
    [ u"ph",u"Cabiguan",2270,12.905833,123.731389 ],
    [ u"ph",u"Cabilao",2668,11.5396,123.1436 ],
    [ u"ph",u"Cabilauan",2077,10.861,122.5734 ],
    [ u"ph",u"Cabilocaan",2488,16.0874,119.9245 ],
    [ u"ph",u"Cabinuangan",10777,7.683333,126.033333 ],
    [ u"ph",u"Cabiraoan",2932,18.323768,122.085953 ],
    [ u"ph",u"Cabitan",3468,12.29434,123.34121 ],
    [ u"ph",u"Cabittaogan",2455,17.582778,120.365556 ],
    [ u"ph",u"Cabog",2967,15.3153,121.3703 ],
    [ u"ph",u"Cabra",3261,13.888333,120.049444 ],
    [ u"ph",u"Cabucgayan",2700,11.473,124.5726 ],
    [ u"ph",u"Cabugao",2642,13.5962,124.2804 ],
    [ u"ph",u"Cabugao",6874,17.7931,120.4578 ],
    [ u"ph",u"Cabugao",4267,10.810278,122.544722 ],
    [ u"ph",u"Cabul-an",3850,10.15,124.05 ],
    [ u"ph",u"Cabulay",2829,16.7203,121.5043 ],
    [ u"ph",u"Cabulohan",2637,8.043333,125.276667 ],
    [ u"ph",u"Cabungahan",2307,10.516667,123.983333 ],
    [ u"ph",u"Cabungan",3059,16.3365,119.9991 ],
    [ u"ph",u"Cabusao",2269,13.7227,123.1169 ],
    [ u"ph",u"Cabuynan",2569,11.080556,125.024722 ],
    [ u"ph",u"Cadagmayan",2212,10.816667,122.5 ],
    [ u"ph",u"Caditaan",3126,12.805278,123.849167 ],
    [ u"ph",u"Cadiz",131106,10.9465,123.288 ],
    [ u"ph",u"Cafe",2339,15.30686,120.702931 ],
    [ u"ph",u"Cagamutan",2688,12.355826,125.283907 ],
    [ u"ph",u"Cagayan de Oro",445212,8.481111,124.643056 ],
    [ u"ph",u"Cagayan de Tawi-Tawi",3847,6.9747,118.5144 ],
    [ u"ph",u"Cagbang",3856,10.7,122.498889 ],
    [ u"ph",u"Cagdianao",2676,9.921111,125.669167 ],
    [ u"ph",u"Cagliliog",2738,13.9039,123.2925 ],
    [ u"ph",u"Cagmanaba",2773,13.055008,123.297061 ],
    [ u"ph",u"Cagsiay",10173,14.216667,121.75 ],
    [ u"ph",u"Caibiran",6461,11.571667,124.582222 ],
    [ u"ph",u"Caidquid",2162,11.4232,122.5539 ],
    [ u"ph",u"Cainta",283177,14.5786,121.1222 ],
    [ u"ph",u"Cajimos",2739,12.594626,122.275313 ],
    [ u"ph",u"Calabaca",2749,14.300095,122.433642 ],
    [ u"ph",u"Calaba",2482,17.6178,120.6162 ],
    [ u"ph",u"Calaba",4229,15.2953,120.8701 ],
    [ u"ph",u"Calabasa",2419,7.246242,122.233751 ],
    [ u"ph",u"Calamagui",2671,17.442122,121.782446 ],
    [ u"ph",u"Calamba",2713,9.103611,125.594167 ],
    [ u"ph",u"Calamba",6738,8.5587,123.6425 ],
    [ u"ph",u"Calamba",2719,10.1755,123.2826 ],
    [ u"ph",u"Calamba",316633,14.2118,121.1655 ],
    [ u"ph",u"Calampisawan",2382,10.609855,123.476502 ],
    [ u"ph",u"Calancuasan",2453,15.8,120.65 ],
    [ u"ph",u"Calansayan",3252,13.766667,121.066667 ],
    [ u"ph",u"Calantac",2541,17.906495,121.72625 ],
    [ u"ph",u"Calantas",2564,13.972019,120.774562 ],
    [ u"ph",u"Calantas",4519,15.0198,120.519 ],
    [ u"ph",u"Calaoagan",2471,18.042787,121.723251 ],
    [ u"ph",u"Calape",3367,9.8922,123.8748 ],
    [ u"ph",u"Calape",2832,11.1756,124.0335 ],
    [ u"ph",u"Calapi",2587,11.9425,125.021389 ],
    [ u"ph",u"Calapi",2954,10.2736,122.9743 ],
    [ u"ph",u"Calasgasan",2447,14.083333,122.933333 ],
    [ u"ph",u"Calasuche",2278,12.217745,123.53061 ],
    [ u"ph",u"Calatagan",16111,13.832236,120.632195 ],
    [ u"ph",u"Calatagan",7132,13.5885,124.2065 ],
    [ u"ph",u"Calategas",4542,9.168977,118.223498 ],
    [ u"ph",u"Calatrava",2225,12.6198,122.0714 ],
    [ u"ph",u"Calauan",36580,14.1447,121.3152 ],
    [ u"ph",u"Calawag",4379,10.668169,119.570505 ],
    [ u"ph",u"Calayaan",2285,15.5662,120.5158 ],
    [ u"ph",u"Calaya",2713,10.4916,122.6255 ],
    [ u"ph",u"Calbayog",67921,12.0668,124.5962 ],
    [ u"ph",u"Calbiga",2920,11.624722,125.016389 ],
    [ u"ph",u"Calian",3488,6.123056,125.700278 ],
    [ u"ph",u"Calibutbut",5282,15.1114,120.6053 ],
    [ u"ph",u"Caliling",4840,9.9804,122.4814 ],
    [ u"ph",u"Calinaoan",2083,17.361427,121.742345 ],
    [ u"ph",u"Calingcuan",3208,15.333333,120.583333 ],
    [ u"ph",u"Calintaan",11476,12.573534,120.942714 ],
    [ u"ph",u"Calituban",3950,10.239948,124.291899 ],
    [ u"ph",u"Calizo",3527,11.5819,122.3857 ],
    [ u"ph",u"Callaguip",2105,18.071389,120.486667 ],
    [ u"ph",u"Caloc-an",3390,9.046944,125.530556 ],
    [ u"ph",u"Calog",2959,18.360833,121.384444 ],
    [ u"ph",u"Calolbon",5005,13.596,124.0991 ],
    [ u"ph",u"Calomboyan",2809,15.9449,120.3003 ],
    [ u"ph",u"Calongbuyan",2324,17.183333,120.466667 ],
    [ u"ph",u"Caloocan",4245,14.6505,120.9743 ],
    [ u"ph",u"Caloocan",4245,14.633333,121.05 ],
    [ u"ph",u"Calsib",2157,15.8464,120.2744 ],
    [ u"ph",u"Calubcub",5019,13.740278,121.436111 ],
    [ u"ph",u"Caluluan",4121,15.426352,120.724932 ],
    [ u"ph",u"Calumboyan",2339,10.791667,124.026667 ],
    [ u"ph",u"Calumpang",2422,13.842386,120.975552 ],
    [ u"ph",u"Calumpang",3403,14.1597,121.4233 ],
    [ u"ph",u"Calumpang",2498,13.9897,121.5494 ],
    [ u"ph",u"Calumpit",91865,14.916389,120.765833 ],
    [ u"ph",u"Camachile",2766,14.643611,120.580833 ],
    [ u"ph",u"Cama Juan",2357,15.3987,120.7639 ],
    [ u"ph",u"Camaley",2297,15.9966,120.3017 ],
    [ u"ph",u"Camaligan",5950,13.6224,123.1667 ],
    [ u"ph",u"Camalobalo",2539,10.2731,122.9505 ],
    [ u"ph",u"Camambugan",2265,10.058439,124.438107 ],
    [ u"ph",u"Camanci",2986,11.7367,122.3617 ],
    [ u"ph",u"Camandag",4058,10.333333,123.066667 ],
    [ u"ph",u"Camangcamang",4131,10.1791,122.9865 ],
    [ u"ph",u"Cambaly",2083,16.608333,120.439444 ],
    [ u"ph",u"Cambanay",2658,10.543611,123.986111 ],
    [ u"ph",u"Cambuga",6432,13.616667,122.45 ],
    [ u"ph",u"Camflora",6146,13.3508,122.6641 ],
    [ u"ph",u"Camias",7412,15.1736,120.9651 ],
    [ u"ph",u"Caminawit",11161,12.33135,121.082513 ],
    [ u"ph",u"Camindangan",5100,9.9184,122.6296 ],
    [ u"ph",u"Camingawan",7820,9.8958,122.8625 ],
    [ u"ph",u"Camohaguin",4363,13.9089,122.1666 ],
    [ u"ph",u"Campokpok",5688,11.2962,124.405 ],
    [ u"ph",u"Campuyo",2794,9.6564,123.1479 ],
    [ u"ph",u"Camudmud",2189,7.176111,125.693333 ],
    [ u"ph",u"Canaman",3010,13.648,123.1699 ],
    [ u"ph",u"Canan",2780,15.9073,120.4871 ],
    [ u"ph",u"Canapi",2815,17.201736,121.865244 ],
    [ u"ph",u"Can-asujan",6994,10.1299,123.6574 ],
    [ u"ph",u"Canaway",3712,9.0651,123.0524 ],
    [ u"ph",u"Canayan",4639,8.183611,125.169167 ],
    [ u"ph",u"Candabong",2405,9.7343,124.5383 ],
    [ u"ph",u"Candabong",2367,9.6859,123.0728 ],
    [ u"ph",u"Candating",4307,15.1481,120.822 ],
    [ u"ph",u"Candawaga",5164,8.862,117.4893 ],
    [ u"ph",u"Candelaria",2178,11.2893,122.5228 ],
    [ u"ph",u"Candiis",2323,8.970278,125.184167 ],
    [ u"ph",u"Candijay",4125,9.8182,124.4977 ],
    [ u"ph",u"Candoni",6191,9.817,122.6043 ],
    [ u"ph",u"Canhandugan",2104,11.135,124.779722 ],
    [ u"ph",u"Canhaway",3157,9.7501,124.4722 ],
    [ u"ph",u"Caningay",3296,9.8297,122.6442 ],
    [ u"ph",u"Canjulao",2693,9.6605,124.3532 ],
    [ u"ph",u"Canlaon",44850,10.386972,123.222701 ],
    [ u"ph",u"Canmaya",2610,9.9384,124.0942 ],
    [ u"ph",u"Canocotan",9025,7.3998,125.7727 ],
    [ u"ph",u"Canroma",2170,10.3606,122.879 ],
    [ u"ph",u"Cansilayan",3809,10.559761,123.018402 ],
    [ u"ph",u"Cansuje",2436,9.916667,123.55 ],
    [ u"ph",u"Cantao-an",4177,10.24258,123.7496 ],
    [ u"ph",u"Cantapoy",2259,9.490556,125.436389 ],
    [ u"ph",u"Cantilan",9408,9.333611,125.9775 ],
    [ u"ph",u"Cantil",2648,12.6176,121.5136 ],
    [ u"ph",u"Cantoria",2552,16.8401,120.4 ],
    [ u"ph",u"Canturay",5135,9.7937,122.4543 ],
    [ u"ph",u"Canubing",9569,13.3561,121.1441 ],
    [ u"ph",u"Caoayan",3386,17.561944,120.3975 ],
    [ u"ph",u"Caoayan",2091,16.082216,120.047036 ],
    [ u"ph",u"Capagao",2801,11.4379,122.7479 ],
    [ u"ph",u"Capalayan",2151,9.740556,125.544444 ],
    [ u"ph",u"Capalonga",3900,14.3306,122.4937 ],
    [ u"ph",u"Capandanan",2462,15.95,120.683333 ],
    [ u"ph",u"Capissayan",2882,18.0509,121.8177 ],
    [ u"ph",u"Capoocan",8474,11.293333,124.641944 ],
    [ u"ph",u"Capulaan",2949,15.9,120.540833 ],
    [ u"ph",u"Capul",4756,12.4237,124.1811 ],
    [ u"ph",u"Capuluan",2234,13.8162,122.5158 ],
    [ u"ph",u"Capuy",2328,12.980833,123.935556 ],
    [ u"ph",u"Capuy",2328,12.983333,123.933333 ],
    [ u"ph",u"Carabalan",7557,10.0964,122.946 ],
    [ u"ph",u"Caraga",4410,7.329722,126.5675 ],
    [ u"ph",u"Caramay",2524,10.181504,119.236002 ],
    [ u"ph",u"Caramoan",3471,13.7707,123.8631 ],
    [ u"ph",u"Caramoran",4791,13.9849,124.1347 ],
    [ u"ph",u"Caramutan",6525,15.916667,120.616667 ],
    [ u"ph",u"Caranan",7265,13.5167,123.0156 ],
    [ u"ph",u"Caraycaray",3174,11.5551,124.415 ],
    [ u"ph",u"Caraycayon",3016,13.616667,123.483333 ],
    [ u"ph",u"Cardona",30221,14.486,121.2289 ],
    [ u"ph",u"Cardona",2594,15.5722,120.5897 ],
    [ u"ph",u"Caridad",3688,10.8315,124.7518 ],
    [ u"ph",u"Caridad",3267,10.4799,122.9225 ],
    [ u"ph",u"Carigara",17495,11.299167,124.675556 ],
    [ u"ph",u"Carig",2924,17.670663,121.751889 ],
    [ u"ph",u"Carlagan",2562,14.975,122.045556 ],
    [ u"ph",u"Carmelo",2175,10.7051,123.7935 ],
    [ u"ph",u"Carmelo",2678,11.016667,122.816667 ],
    [ u"ph",u"Carmen",4847,8.988611,125.2925 ],
    [ u"ph",u"Carmen",8214,9.8223,124.1964 ],
    [ u"ph",u"Carmen",21898,10.593056,124.017778 ],
    [ u"ph",u"Carmen",2835,15.4428,120.8231 ],
    [ u"ph",u"Carmen",10250,15.883333,120.6 ],
    [ u"ph",u"Carmen",2677,12.6171,122.1211 ],
    [ u"ph",u"Carmen",8759,7.204444,124.791667 ],
    [ u"ph",u"Carmen",2805,9.226389,126.017222 ],
    [ u"ph",u"Carmen",4945,10.3787,122.9156 ],
    [ u"ph",u"Carmona",55886,14.3132,121.0576 ],
    [ u"ph",u"Carosucan",7083,15.968611,120.637778 ],
    [ u"ph",u"Carot",2939,16.3467,119.9834 ],
    [ u"ph",u"Carranglan",11017,15.9613,121.0641 ],
    [ u"ph",u"Carrascal",4385,9.370278,125.949167 ],
    [ u"ph",u"Carriedo",2524,16.031,120.7549 ],
    [ u"ph",u"Carriedo",2091,12.9344,124.105 ],
    [ u"ph",u"Cartagena",3396,9.8203,122.4004 ],
    [ u"ph",u"Caruray",4115,10.309396,119.012803 ],
    [ u"ph",u"Casala-an",2875,9.116667,123.05 ],
    [ u"ph",u"Casambalangan",3281,18.376464,122.127453 ],
    [ u"ph",u"Casanayan",3453,11.5169,123.0512 ],
    [ u"ph",u"Casay",3631,9.8204,123.5496 ],
    [ u"ph",u"Casay",3596,13.2632,122.5217 ],
    [ u"ph",u"Casian",2677,11.035,119.7136 ],
    [ u"ph",u"Casiguran",8605,12.873611,124.009722 ],
    [ u"ph",u"Casisang",13721,8.138056,125.125 ],
    [ u"ph",u"Castañas",9040,13.8744,121.5533 ],
    [ u"ph",u"Castilla",2771,12.948611,123.882222 ],
    [ u"ph",u"Castillejos",27301,14.930386,120.201428 ],
    [ u"ph",u"Castillo",4203,13.7313,123.1166 ],
    [ u"ph",u"Catabangan",3665,13.8777,122.6615 ],
    [ u"ph",u"Catablan",5090,15.9757,120.4953 ],
    [ u"ph",u"Cataingan",7809,12.003,123.992 ],
    [ u"ph",u"Catarman",3688,9.602222,123.864444 ],
    [ u"ph",u"Catarman",2521,9.125556,124.675556 ],
    [ u"ph",u"Catayauan",3843,18.16358,121.652752 ],
    [ u"ph",u"Catbalogan",67958,11.775278,124.886111 ],
    [ u"ph",u"Cateel",6624,7.791389,126.453333 ],
    [ u"ph",u"Caterman",2195,17.203611,120.421389 ],
    [ u"ph",u"Caticlan",4223,11.927672,121.95361 ],
    [ u"ph",u"Caticugan",2558,9.1,123 ],
    [ u"ph",u"Catmon",7811,10.716667,124 ],
    [ u"ph",u"Catmondaan",2861,10.686111,124.013889 ],
    [ u"ph",u"Cato",4530,15.8362,119.9151 ],
    [ u"ph",u"Catubig",4728,12.4098,125.0548 ],
    [ u"ph",u"Catuday",2149,16.2923,119.8062 ],
    [ u"ph",u"Catungan",2318,10.7706,122.0149 ],
    [ u"ph",u"Catungawan",3342,9.7817,124.4693 ],
    [ u"ph",u"Causip",2033,13.5159,123.2834 ],
    [ u"ph",u"Causwagan",2225,8.4475,125.840278 ],
    [ u"ph",u"Cavinti",9758,14.244817,121.507974 ],
    [ u"ph",u"Cavite",2402,15.6655,120.7693 ],
    [ u"ph",u"Cavite",115920,14.477831,120.893222 ],
    [ u"ph",u"Cawayan Bugtong",3605,15.6348,120.7944 ],
    [ u"ph",u"Cawayan",3122,11.6237,122.4649 ],
    [ u"ph",u"Cawayan",2705,9.8053,123.5341 ],
    [ u"ph",u"Cawayan",2892,12.6557,121.5456 ],
    [ u"ph",u"Cawayan",5549,13.3672,122.5094 ],
    [ u"ph",u"Cayang",6353,11.066667,123.983333 ],
    [ u"ph",u"Cayangwan",2070,11.689,122.2909 ],
    [ u"ph",u"Cayhagan",3363,9.6783,122.4335 ],
    [ u"ph",u"Cayungnan",2082,16.116667,119.866667 ],
    [ u"ph",u"Cebuano",5430,6.388056,124.968333 ],
    [ u"ph",u"Cebu",758597,10.311111,123.891667 ],
    [ u"ph",u"Cervantes",3099,16.9909,120.7359 ],
    [ u"ph",u"Cervantes",2344,12.368611,124.659722 ],
    [ u"ph",u"Cervantes",2520,10.8726,123.5209 ],
    [ u"ph",u"Chambery",3108,10.9768,123.1682 ],
    [ u"ph",u"Cigaras",2775,14.2266,121.4298 ],
    [ u"ph",u"Clarin",3200,9.9616,124.0252 ],
    [ u"ph",u"Clarin",7125,8.2023,123.8582 ],
    [ u"ph",u"Claver",5906,9.5749,125.7307 ],
    [ u"ph",u"Claveria",10618,18.607419,121.08322 ],
    [ u"ph",u"Claveria",6185,12.9035,123.2457 ],
    [ u"ph",u"Claveria",7784,8.61,124.894722 ],
    [ u"ph",u"Codcod",13026,10.463367,123.249502 ],
    [ u"ph",u"Cogon",3811,11.4618,122.8164 ],
    [ u"ph",u"Cogon",2402,10.7133,123.8284 ],
    [ u"ph",u"Cogon",2238,7.150833,125.717222 ],
    [ u"ph",u"Cogtong",3074,9.8374,124.5291 ],
    [ u"ph",u"Colacling",2965,13.7815,122.8767 ],
    [ u"ph",u"Colonia",2259,10.6553,123.7911 ],
    [ u"ph",u"Colonia",2587,6.643611,122.1575 ],
    [ u"ph",u"Columbio",5516,6.696389,124.937222 ],
    [ u"ph",u"Comagascas",2914,9.139722,125.559722 ],
    [ u"ph",u"Comillas",3148,16.959,120.7469 ],
    [ u"ph",u"Comillas",4809,15.398154,120.700732 ],
    [ u"ph",u"Compostela",18727,10.455,124.0106 ],
    [ u"ph",u"Comunal",2773,13.2548,121.1366 ],
    [ u"ph",u"Concepcion",6769,11.2161,123.1073 ],
    [ u"ph",u"Concepcion",2347,16.216,120.4785 ],
    [ u"ph",u"Concepcion",2180,10.405278,124.783056 ],
    [ u"ph",u"Concepcion",3196,15.2208,120.8315 ],
    [ u"ph",u"Concepcion",4685,12.3975,122.093611 ],
    [ u"ph",u"Concepcion",64402,15.325459,120.657231 ],
    [ u"ph",u"Concepcion",25628,13.926667,121.493333 ],
    [ u"ph",u"Concepcion",8903,10.692,123.0608 ],
    [ u"ph",u"Concordia",3091,10.507667,122.549603 ],
    [ u"ph",u"Conel",8519,6.200741,125.18825 ],
    [ u"ph",u"Conner",2401,17.8009,121.3209 ],
    [ u"ph",u"Consolacion",2092,11.3284,122.6332 ],
    [ u"ph",u"Constancia",2713,10.59596,122.641503 ],
    [ u"ph",u"Consuegra",3337,11.2976,124.5124 ],
    [ u"ph",u"Consuelo",4888,10.6348,124.301 ],
    [ u"ph",u"Consuelo",3128,8.901667,125.1875 ],
    [ u"ph",u"Consuelo",4543,9.9996,122.758 ],
    [ u"ph",u"Conversion",2853,15.8984,121.1277 ],
    [ u"ph",u"Cordoba",29288,10.251944,123.949444 ],
    [ u"ph",u"Cordon",4514,16.6744,121.4658 ],
    [ u"ph",u"Cordova",2588,10.730278,122.401389 ],
    [ u"ph",u"Coron",8723,11.9986,120.2043 ],
    [ u"ph",u"Coronon",6854,6.879167,125.448889 ],
    [ u"ph",u"Corrooy",2233,16.7962,120.4453 ],
    [ u"ph",u"Cortes",2390,11.5301,122.3975 ],
    [ u"ph",u"Cortes",3026,9.279722,126.191111 ],
    [ u"ph",u"Cosina",3117,8.106111,124.619722 ],
    [ u"ph",u"Cotabato",179445,7.223611,124.246389 ],
    [ u"ph",u"Cotcot",4067,10.425,124.0005 ],
    [ u"ph",u"Cotmon",2770,13.1175,123.6637 ],
    [ u"ph",u"Cuambog",6383,7.308611,125.848056 ],
    [ u"ph",u"Cuanos",2205,10.282977,123.78 ],
    [ u"ph",u"Cuartero",3520,11.3407,122.6694 ],
    [ u"ph",u"Cuenca",21558,13.902,121.0521 ],
    [ u"ph",u"Cuevas",2243,8.019167,126.094167 ],
    [ u"ph",u"Culaba",6232,11.657778,124.5425 ],
    [ u"ph",u"Culaman",3523,5.960278,125.658611 ],
    [ u"ph",u"Culasian",2475,11.306944,124.610556 ],
    [ u"ph",u"Culasi",4385,11.427206,122.056007 ],
    [ u"ph",u"Culasi",4123,11.079167,122.981944 ],
    [ u"ph",u"Culianan",5915,6.980278,122.146667 ],
    [ u"ph",u"Culianin",7565,14.906667,120.899444 ],
    [ u"ph",u"Culipapa",7680,9.4726,122.5616 ],
    [ u"ph",u"Culit",2881,8.947222,125.356944 ],
    [ u"ph",u"Cullalabo",4907,17.100343,121.703043 ],
    [ u"ph",u"Culubasa",2268,15.142,120.655 ],
    [ u"ph",u"Cumadcad",5203,12.980556,123.789167 ],
    [ u"ph",u"Curry",2358,13.6,123.3 ],
    [ u"ph",u"Curuan",6776,7.205676,122.233045 ],
    [ u"ph",u"Cutcut",7143,15.47065,120.659532 ],
    [ u"ph",u"Cuyo",7549,10.8525,121.008611 ],
    [ u"ph",u"Daan Banua",4036,10.903537,123.059704 ],
    [ u"ph",u"Da-an",2085,11.2322,122.4207 ],
    [ u"ph",u"Dacudao",3670,7.215278,125.471389 ],
    [ u"ph",u"Dadiangas",432571,6.112778,125.171667 ],
    [ u"ph",u"Dados",2325,7.0575,124.321667 ],
    [ u"ph",u"Daet",78812,14.1122,122.9553 ],
    [ u"ph",u"Dagami",4387,11.060833,124.902778 ],
    [ u"ph",u"Dagatan",2619,13.7389,121.199 ],
    [ u"ph",u"Dagatan",2948,14.0017,121.3767 ],
    [ u"ph",u"Dagohoy",2741,9.8927,124.2727 ],
    [ u"ph",u"Daguit",3391,14.1895,122.7266 ],
    [ u"ph",u"Daguma",3785,6.586667,124.547222 ],
    [ u"ph",u"Dagumba-an",6635,8.153056,124.590833 ],
    [ u"ph",u"Dagupan",2305,17.7061,121.5047 ],
    [ u"ph",u"Dagupan",135933,16.1,120.516667 ],
    [ u"ph",u"Dagup",2090,16.637222,120.445556 ],
    [ u"ph",u"Dalaoig",2485,17.933,121.7155 ],
    [ u"ph",u"Daliao",2335,5.861111,124.953333 ],
    [ u"ph",u"Dalipey",2125,16.8,120.716667 ],
    [ u"ph",u"Dalipuga",14242,8.316111,124.250556 ],
    [ u"ph",u"Dalirig",3660,8.377222,124.901389 ],
    [ u"ph",u"Dalumangcob",9424,7.216667,124.3 ],
    [ u"ph",u"Dalupaon",3901,13.5517,122.9457 ],
    [ u"ph",u"Dalupirip",2580,16.325833,120.725556 ],
    [ u"ph",u"Dalwangan",4906,8.200556,125.040556 ],
    [ u"ph",u"Damabalas",3230,7.015556,124.514167 ],
    [ u"ph",u"Damayan",2308,11.4936,122.5531 ],
    [ u"ph",u"Damilag",11000,8.354722,124.812222 ],
    [ u"ph",u"Damolog",2946,10.766667,124 ],
    [ u"ph",u"Damortis",2272,16.2423,120.4051 ],
    [ u"ph",u"Dampol",2796,14.884444,120.811944 ],
    [ u"ph",u"Damulog",8789,7.483611,124.943056 ],
    [ u"ph",u"Danao",3369,9.633333,124.2 ],
    [ u"ph",u"Danao",70271,10.520833,124.027222 ],
    [ u"ph",u"Dancalan",2167,12.9168,123.5838 ],
    [ u"ph",u"Dancalan",9862,9.9821,122.7386 ],
    [ u"ph",u"Dangcagan",4864,7.609167,125.004167 ],
    [ u"ph",u"Danlugan",2666,7.8922,123.3712 ],
    [ u"ph",u"Dansolihon",3595,8.315,124.586111 ],
    [ u"ph",u"Dansuli",4561,6.6425,124.578611 ],
    [ u"ph",u"Dao",2893,10.515,121.9461 ],
    [ u"ph",u"Dao",10743,11.3937,122.6856 ],
    [ u"ph",u"Dao",2361,12.0998,125.4372 ],
    [ u"ph",u"Dapa",8822,9.759444,126.053056 ],
    [ u"ph",u"Dapawan",2929,12.406944,122.027778 ],
    [ u"ph",u"Dapdapan",3040,11.4943,122.6314 ],
    [ u"ph",u"Dapdap",2223,12.062,125.4881 ],
    [ u"ph",u"Dapdap",2127,12.2155,123.7662 ],
    [ u"ph",u"Dapitan",50517,8.6561,123.4227 ],
    [ u"ph",u"Daragutan",2336,17,122.033333 ],
    [ u"ph",u"Daraitan",3742,14.6028,121.4319 ],
    [ u"ph",u"Daram",3069,11.6341,124.7947 ],
    [ u"ph",u"Darapidap",2684,17.213056,120.411389 ],
    [ u"ph",u"Dasmariñas",441878,14.329444,120.936667 ],
    [ u"ph",u"Dasol",3892,15.9902,119.8828 ],
    [ u"ph",u"Dassun",6030,17.7204,121.6816 ],
    [ u"ph",u"Datagon",2584,9.4461,123.0891 ],
    [ u"ph",u"Datu Paglas",3851,6.766667,124.85 ],
    [ u"ph",u"Dauin",3305,9.1914,123.2654 ],
    [ u"ph",u"Dauis",2553,9.625278,123.865833 ],
    [ u"ph",u"Davao",1212285,7.073056,125.612778 ],
    [ u"ph",u"Davila",3465,18.4726,120.5763 ],
    [ u"ph",u"Dawan",4048,6.914867,126.153226 ],
    [ u"ph",u"Dayapan",2396,13.920295,120.878673 ],
    [ u"ph",u"Dayap",5092,14.1793,121.3368 ],
    [ u"ph",u"De la Paz",3144,9.6984,123.866 ],
    [ u"ph",u"Del Carmen",4053,14.9334,120.5619 ],
    [ u"ph",u"Del Carmen",4053,15,120.533333 ],
    [ u"ph",u"Del Carmen",4276,9.869444,125.969722 ],
    [ u"ph",u"Del Gallego",4070,13.9223,122.5954 ],
    [ u"ph",u"Delicioso",2301,9.9859,122.7618 ],
    [ u"ph",u"Del Monte",2213,7.725833,123.008056 ],
    [ u"ph",u"Del Pilar",2511,9.151944,125.584722 ],
    [ u"ph",u"Del Pilar",4062,7.563056,125.826667 ],
    [ u"ph",u"Del Pilar",37329,15.027,120.6968 ],
    [ u"ph",u"Diadi",2157,16.662,121.3658 ],
    [ u"ph",u"Diamantina",2367,16.919054,121.629342 ],
    [ u"ph",u"Dian-ay",3195,10.833333,123.55 ],
    [ u"ph",u"Diaz",4017,15.8463,120.8347 ],
    [ u"ph",u"Dibuluan",2384,16.5206,121.7631 ],
    [ u"ph",u"Dicabisagan",3503,17.081839,122.415743 ],
    [ u"ph",u"Dicamay",2370,16.756062,122.003741 ],
    [ u"ph",u"Dicoyong",2075,8.2206,123.0338 ],
    [ u"ph",u"Diffun",9414,16.59,121.5057 ],
    [ u"ph",u"Digal",6810,6.753056,124.796389 ],
    [ u"ph",u"Digkilaan",4349,8.258611,124.323333 ],
    [ u"ph",u"Digos",117536,6.749722,125.357222 ],
    [ u"ph",u"Dilan",4031,16.0879,120.5207 ],
    [ u"ph",u"Diliman",3792,15.025,120.9502 ],
    [ u"ph",u"Dimaluna",3187,8.1218,123.7995 ],
    [ u"ph",u"Dimasalang",3018,12.1923,123.8592 ],
    [ u"ph",u"Dimataling",4273,7.5344,123.3738 ],
    [ u"ph",u"Dimayon",2571,8.066667,124.15 ],
    [ u"ph",u"Dinagat",2600,9.956111,125.593333 ],
    [ u"ph",u"Dinahican",7062,14.693375,121.719168 ],
    [ u"ph",u"Dinalaoan",3492,15.9957,120.3406 ],
    [ u"ph",u"Dingalan",7316,15.3897,121.3929 ],
    [ u"ph",u"Dinganen",4623,7.328333,124.378333 ],
    [ u"ph",u"Dingle",6171,10.9995,122.6711 ],
    [ u"ph",u"Dingras",6866,18.1032,120.6967 ],
    [ u"ph",u"Diplahan",3338,7.716667,123.016667 ],
    [ u"ph",u"Dipolo",2679,7.7828,123.1158 ],
    [ u"ph",u"Dipolog",94139,8.5883,123.3409 ],
    [ u"ph",u"Divisoria",2068,17.520817,121.775547 ],
    [ u"ph",u"Dodan",3002,17.64111,121.800148 ],
    [ u"ph",u"Dogongan",2144,14.1025,122.9066 ],
    [ u"ph",u"Doljo",2760,9.589444,123.726944 ],
    [ u"ph",u"Dolo",3973,6.810278,125.191667 ],
    [ u"ph",u"Dologon",15128,7.840833,125.044444 ],
    [ u"ph",u"Dolores",2378,17.6477,120.7091 ],
    [ u"ph",u"Dolores",9274,12.0371,125.4825 ],
    [ u"ph",u"Dolores",4522,15.0941,120.5287 ],
    [ u"ph",u"Dolores",2265,11.061389,124.613333 ],
    [ u"ph",u"Dolores",7633,14.0165,121.4011 ],
    [ u"ph",u"Domalandan",15108,16.00292,120.211536 ],
    [ u"ph",u"Domanpot",5340,16,120.65 ],
    [ u"ph",u"Dongon",3181,11.7196,122.316 ],
    [ u"ph",u"Don Marcelino",7983,6.264444,125.667778 ],
    [ u"ph",u"Don Pedro",2854,15.8894,120.4281 ],
    [ u"ph",u"Donsol",6198,12.9055,123.5949 ],
    [ u"ph",u"Doong",2554,11.0786,123.6395 ],
    [ u"ph",u"Doos",2744,10.465278,124.729444 ],
    [ u"ph",u"Doroñgan",5336,15.8145,120.3209 ],
    [ u"ph",u"Dos Hermanas",9270,10.7421,123.0377 ],
    [ u"ph",u"Doyong",3398,15.9675,120.3515 ],
    [ u"ph",u"Doyong",3398,15.9503,120.3536 ],
    [ u"ph",u"Dualing",2323,7.151667,124.568333 ],
    [ u"ph",u"Dubduban",2271,12.5747,122.1138 ],
    [ u"ph",u"Dueñas",3705,11.0672,122.6191 ],
    [ u"ph",u"Dukay",2484,6.648056,124.579167 ],
    [ u"ph",u"Dulag",10151,10.9525,125.031667 ],
    [ u"ph",u"Dulangan",5339,11.4561,122.9557 ],
    [ u"ph",u"Dulangan",2663,13.4685,120.9803 ],
    [ u"ph",u"Dulao",7403,10.541763,122.938302 ],
    [ u"ph",u"Dulian",2722,7.121389,122.178889 ],
    [ u"ph",u"Dulig",2572,16.00212,120.168636 ],
    [ u"ph",u"Dumabato",2590,16.316667,121.7 ],
    [ u"ph",u"Dumaguete",113588,9.307,123.3074 ],
    [ u"ph",u"Dumaguil",2238,6.62,124.653333 ],
    [ u"ph",u"Dumalag",3039,11.308,122.6236 ],
    [ u"ph",u"Dumalaguing",2417,8.346944,125.055 ],
    [ u"ph",u"Dumalinao",3966,7.8191,123.3694 ],
    [ u"ph",u"Dumanjug",3613,10.057,123.4361 ],
    [ u"ph",u"Dumarais",3587,15.434552,120.692132 ],
    [ u"ph",u"Dumarao",3187,11.2518,122.6654 ],
    [ u"ph",u"Dumingag",6534,8.169167,123.350556 ],
    [ u"ph",u"Dumlan",2661,7.4275,125.8819 ],
    [ u"ph",u"Dumpay",5414,15.8807,120.389 ],
    [ u"ph",u"Duran",3097,11.2618,122.5917 ],
    [ u"ph",u"East Migpulao",2689,7.6325,123.359167 ],
    [ u"ph",u"East Valencia",2444,10.668,122.71 ],
    [ u"ph",u"Edcor",2483,7.440556,124.397222 ],
    [ u"ph",u"Eden",2136,17.036547,121.598043 ],
    [ u"ph",u"Egaña",2723,10.7472,122.00984 ],
    [ u"ph",u"Eguia",3033,15.9065,119.8858 ],
    [ u"ph",u"El Pardo",2768,9.66,123.4944 ],
    [ u"ph",u"Enrile",9650,17.5596,121.6974 ],
    [ u"ph",u"Entablado",5202,15.2875,120.8653 ],
    [ u"ph",u"Erenas",2243,12.4245,124.3238 ],
    [ u"ph",u"Ermita",2304,10.9,122.716667 ],
    [ u"ph",u"Esmeralda",2674,15.867222,120.715 ],
    [ u"ph",u"España",2624,12.384139,122.499012 ],
    [ u"ph",u"Esperanza",6193,8.676944,125.646944 ],
    [ u"ph",u"Esperanza",3251,10.7027,124.4143 ],
    [ u"ph",u"Esperanza",2180,17.007549,121.674743 ],
    [ u"ph",u"Esperanza",2141,8.180833,124.007222 ],
    [ u"ph",u"Esperanza",2398,6.499444,124.666111 ],
    [ u"ph",u"Esperanza",6009,6.723056,124.519722 ],
    [ u"ph",u"Esperanza",2723,7.491667,125.728056 ],
    [ u"ph",u"Estaca",2661,9.6933,124.2722 ],
    [ u"ph",u"Estancia",3708,13.3589,123.6796 ],
    [ u"ph",u"Estancia",11050,11.4551,123.152 ],
    [ u"ph",u"Estefania",2165,17.797601,121.725349 ],
    [ u"ph",u"Estipona",4351,15.5902,120.6377 ],
    [ u"ph",u"Estrella",2615,13.328982,121.310918 ],
    [ u"ph",u"Estrella",4463,15.75,121.033333 ],
    [ u"ph",u"Eustaquio Lopez",14408,10.8195,123.0412 ],
    [ u"ph",u"Evangelista",2585,13.3335,121.0972 ],
    [ u"ph",u"Fabrica",3641,13.49,123.294 ],
    [ u"ph",u"Faire",4916,17.8861,121.5691 ],
    [ u"ph",u"Famy",3758,14.4376,121.4482 ],
    [ u"ph",u"Feliciano",2484,11.5787,122.3583 ],
    [ u"ph",u"Flora",4213,18.2163,121.4185 ],
    [ u"ph",u"Florida",4141,7.6775,125.673611 ],
    [ u"ph",u"Fuerte",2558,17.538056,120.364444 ],
    [ u"ph",u"Furao",2344,17.032946,121.798143 ],
    [ u"ph",u"Gabaldon",7259,15.4522,121.3387 ],
    [ u"ph",u"Gabao",3600,12.730556,123.961389 ],
    [ u"ph",u"Gabas",2255,10.7297,124.7961 ],
    [ u"ph",u"Gabawan",2382,12.4175,122.013889 ],
    [ u"ph",u"Gabi",2189,11.5956,123.3376 ],
    [ u"ph",u"Gabi",3939,7.6215,126.092 ],
    [ u"ph",u"Gabuyan",4402,7.608056,125.668889 ],
    [ u"ph",u"Gadu",2902,17.6292,121.6105 ],
    [ u"ph",u"Gadung",2456,6.8025,124.02 ],
    [ u"ph",u"Gainza",2173,13.6165,123.1419 ],
    [ u"ph",u"Gamay",9125,12.3638,125.2366 ],
    [ u"ph",u"Gambang",3370,16.75,120.7833 ],
    [ u"ph",u"Gammad",2639,17.7104,121.7437 ],
    [ u"ph",u"Gamu",5545,17.049745,121.836043 ],
    [ u"ph",u"Gamut",2246,9.004444,126.169722 ],
    [ u"ph",u"Ganassi",2412,7.826937,124.103445 ],
    [ u"ph",u"Gandara",3982,12.013,124.8118 ],
    [ u"ph",u"Gandiangan",2169,7.678889,122.909444 ],
    [ u"ph",u"Gang",3317,7.245833,124.266389 ],
    [ u"ph",u"Gansing",5031,6.740278,124.658889 ],
    [ u"ph",u"Gapan",79278,15.3072,120.9464 ],
    [ u"ph",u"Gappal",2495,16.836458,121.821841 ],
    [ u"ph",u"Garchitorena",4909,13.8804,123.6946 ],
    [ u"ph",u"Garcia Hernandez",2643,9.6144,124.2946 ],
    [ u"ph",u"Gasan",2228,13.323719,121.846754 ],
    [ u"ph",u"Gatbo",2385,13.583333,123.383333 ],
    [ u"ph",u"Gatbo",2349,13.018611,124.1025 ],
    [ u"ph",u"Gatbo",2349,12.9924,124.0169 ],
    [ u"ph",u"Gattaran",3613,18.055687,121.640951 ],
    [ u"ph",u"Gayaman",3765,16.0136,120.3063 ],
    [ u"ph",u"General Emilio Aguinaldo",12243,14.184167,120.795833 ],
    [ u"ph",u"General Luna",2774,15.61667,121 ],
    [ u"ph",u"General Luna",9177,13.6866,122.1709 ],
    [ u"ph",u"General Luna",3132,10.833333,123.566667 ],
    [ u"ph",u"General MacArthur",4491,11.246389,125.539444 ],
    [ u"ph",u"General Mamerto Natividad",18393,15.6025,121.0515 ],
    [ u"ph",u"General Nakar",3532,14.763652,121.635586 ],
    [ u"ph",u"Getulio",2063,10.747,122.666 ],
    [ u"ph",u"Gibato",2360,11.2251,122.8143 ],
    [ u"ph",u"Gibgos",2477,13.859,123.7675 ],
    [ u"ph",u"Gibon",6919,11.863376,122.03941 ],
    [ u"ph",u"Gigaquit",3064,9.5951,125.6968 ],
    [ u"ph",u"Gigmoto",3259,13.7796,124.39 ],
    [ u"ph",u"Gimangpang",2472,8.471389,124.296667 ],
    [ u"ph",u"Ginatilan",2699,9.5694,123.3128 ],
    [ u"ph",u"Gines",2476,10.933333,122.483333 ],
    [ u"ph",u"Gingoog",70943,8.827778,125.099722 ],
    [ u"ph",u"Giporlos",5257,11.12,125.449444 ],
    [ u"ph",u"Glad",5746,7.148333,124.518056 ],
    [ u"ph",u"Glamang",4467,6.162549,125.083915 ],
    [ u"ph",u"Glan Padidu",3716,5.855,125.218611 ],
    [ u"ph",u"Gloria",6137,12.983333,121.466667 ],
    [ u"ph",u"Goa",20936,13.6978,123.4892 ],
    [ u"ph",u"Goma",4275,6.791944,125.320833 ],
    [ u"ph",u"Gonzaga",7228,18.259372,121.994952 ],
    [ u"ph",u"Granada",2269,11.633333,123.35 ],
    [ u"ph",u"Guadalupe",3381,8.582778,125.708056 ],
    [ u"ph",u"Guadalupe",11121,10.1165,123.6072 ],
    [ u"ph",u"Guadalupe",11053,10.454467,123.373201 ],
    [ u"ph",u"Guagua",9519,14.9653,120.6325 ],
    [ u"ph",u"Guba",2195,10.3131,123.2667 ],
    [ u"ph",u"Guibuangan",2209,10.1157,123.4944 ],
    [ u"ph",u"Guiguinto",76613,14.833333,120.883333 ],
    [ u"ph",u"Guihing",12465,6.684444,125.3525 ],
    [ u"ph",u"Guijalo",2604,13.7373,123.868 ],
    [ u"ph",u"Guiling",2873,15.849722,120.613333 ],
    [ u"ph",u"Guiljungan",14876,9.9805,122.6742 ],
    [ u"ph",u"Guimbal",7232,10.6633,122.3228 ],
    [ u"ph",u"Guinabsan",4358,8.8975,125.416111 ],
    [ u"ph",u"Guinacutan",2861,14.1569,122.868 ],
    [ u"ph",u"Guinayangan",2732,13.8971,122.454 ],
    [ u"ph",u"Guinbaliwan",2503,11.6576,122.3851 ],
    [ u"ph",u"Guindapunan",2279,11.302778,124.705833 ],
    [ u"ph",u"Guindulman",4686,9.7629,124.4878 ],
    [ u"ph",u"Guinsang-an",3847,6.48,124.680556 ],
    [ u"ph",u"Guinsiliban",2074,9.096389,124.782778 ],
    [ u"ph",u"Guinticgan",7452,11.5641,123.1236 ],
    [ u"ph",u"Guintubhan",2330,10.2074,122.9627 ],
    [ u"ph",u"Guio-ang",2652,9.7922,124.509 ],
    [ u"ph",u"Guiong",2477,6.418611,122.025833 ],
    [ u"ph",u"Guipos",4050,7.7161,123.3219 ],
    [ u"ph",u"Guirang",2504,11.35,125.116667 ],
    [ u"ph",u"Guiset",21995,16.066667,120.666667 ],
    [ u"ph",u"Guisguis",3128,15.7928,119.9766 ],
    [ u"ph",u"Guisguis",5741,13.8738,121.5189 ],
    [ u"ph",u"Guisijan",2196,11.0932,122.0461 ],
    [ u"ph",u"Guiuan",11041,11.033333,125.724722 ],
    [ u"ph",u"Gulod",2705,13.875139,120.633588 ],
    [ u"ph",u"Gumalang",4313,7.208333,125.403611 ],
    [ u"ph",u"Gumaus",2346,14.3103,122.7229 ],
    [ u"ph",u"Gumian",3695,14.710064,121.61867 ],
    [ u"ph",u"Gupitan",8235,7.775833,125.640556 ],
    [ u"ph",u"Guruyan",2675,12.738889,123.939167 ],
    [ u"ph",u"Gutad",2623,14.9274,120.4894 ],
    [ u"ph",u"Guyam",3050,14.1525,120.861111 ],
    [ u"ph",u"Hacienda",2540,15.936,120.1786 ],
    [ u"ph",u"Hagdan",3120,11.333333,123.9 ],
    [ u"ph",u"Hagnaya",3391,11.0924,123.9435 ],
    [ u"ph",u"Hagonoy",123789,14.8321,120.7336 ],
    [ u"ph",u"Hagonoy",7409,6.683333,125.325556 ],
    [ u"ph",u"Haguimit",4008,10.3999,123.0178 ],
    [ u"ph",u"Halapitan",10870,7.9175,125.33 ],
    [ u"ph",u"Halayhay",10630,14.373889,120.813333 ],
    [ u"ph",u"Halayhayin",3834,14.1891,121.4075 ],
    [ u"ph",u"Haligue",2607,13.666667,121.116667 ],
    [ u"ph",u"Halog",2496,16.3668,120.4147 ],
    [ u"ph",u"Hamtic",4816,10.7023,121.9824 ],
    [ u"ph",u"Hapao",2188,16.879661,121.016042 ],
    [ u"ph",u"Harigue",2105,11.865379,121.44041 ],
    [ u"ph",u"Harrison",2349,13.45,120.433333 ],
    [ u"ph",u"Hermosa",33714,14.8314,120.5081 ],
    [ u"ph",u"Hernani",2159,11.325833,125.619444 ],
    [ u"ph",u"Herrera",2198,13.2693,123.5769 ],
    [ u"ph",u"Hibaiyo",5209,10.2726,123.321 ],
    [ u"ph",u"Hijo",3014,7.381,125.8296 ],
    [ u"ph",u"Hilantagaan",3396,11.1943,123.8131 ],
    [ u"ph",u"Hilotongan",2919,11.144,123.6426 ],
    [ u"ph",u"Himaao",3865,13.5448,123.3005 ],
    [ u"ph",u"Himaya",3296,10.4516,122.8325 ],
    [ u"ph",u"Himensulan",2343,10.5967,124.2821 ],
    [ u"ph",u"Hinabuyan",2391,11.2383,124.4047 ],
    [ u"ph",u"Hinaplanan",2695,8.640278,124.873056 ],
    [ u"ph",u"Hinatuan",10055,8.372222,126.334167 ],
    [ u"ph",u"Hindang",4106,10.434167,124.729167 ],
    [ u"ph",u"Hingatungan",2019,10.584,125.1852 ],
    [ u"ph",u"Hinlayagan",2788,10.030607,124.334573 ],
    [ u"ph",u"Hinundayan",2693,10.3523,125.2506 ],
    [ u"ph",u"Hipona",2380,11.4174,122.8825 ],
    [ u"ph",u"Hobo",3373,13.5101,123.1792 ],
    [ u"ph",u"Hondagua",4587,13.9455,122.2417 ],
    [ u"ph",u"Hukay",2230,13.845194,120.702869 ],
    [ u"ph",u"Ibaan",9430,13.8176,121.133 ],
    [ u"ph",u"Iba",4574,15.455052,120.413032 ],
    [ u"ph",u"Iba",26935,15.3276,119.978 ],
    [ u"ph",u"Ibajay",2654,11.8199,122.162 ],
    [ u"ph",u"Ibarra",3065,10.124722,124.884167 ],
    [ u"ph",u"Ibung",4462,16.609376,121.18614 ],
    [ u"ph",u"Ichon",3821,10.109722,124.901667 ],
    [ u"ph",u"Idio",2102,11.6238,122.0979 ],
    [ u"ph",u"Idtig",3969,6.798889,124.772778 ],
    [ u"ph",u"Igang",3468,10.916,122.6388 ],
    [ u"ph",u"Igbaras",5974,10.715654,122.265704 ],
    [ u"ph",u"Igbon",2367,11.2142,123.1655 ],
    [ u"ph",u"Igcocolo",2297,10.689655,122.319304 ],
    [ u"ph",u"Igmaya-an",3164,10.549861,123.220602 ],
    [ u"ph",u"Igpit",3238,6.700833,125.291944 ],
    [ u"ph",u"Igpit",5753,8.510833,124.586667 ],
    [ u"ph",u"Ilasan",3054,14.063,121.6328 ],
    [ u"ph",u"Ilaya",3123,8.5459,123.4308 ],
    [ u"ph",u"Ilaya",3200,5.815278,125.226667 ],
    [ u"ph",u"Iligan",267854,8.230833,124.236111 ],
    [ u"ph",u"Ilihan",3246,10.9054,123.9704 ],
    [ u"ph",u"Ilihan",3544,13.631,121.0709 ],
    [ u"ph",u"Ilog",6741,10.0266,122.7684 ],
    [ u"ph",u"Iloilo",387748,10.696944,122.564444 ],
    [ u"ph",u"Imbatug",2480,8.054444,125.283889 ],
    [ u"ph",u"Imelda",3466,14.033333,122.883333 ],
    [ u"ph",u"Imelda",5640,7.65,123.95 ],
    [ u"ph",u"Impalutao",2431,8.257778,125.0275 ],
    [ u"ph",u"Inabaan",2830,16.263,120.4781 ],
    [ u"ph",u"Inangatan",3215,11.25,124.4 ],
    [ u"ph",u"Inapatan",2698,13.3964,123.3227 ],
    [ u"ph",u"Inawayan",5345,6.960833,125.473333 ],
    [ u"ph",u"Inayagan",6610,10.23478,123.769 ],
    [ u"ph",u"Inayawan",9963,9.9005,122.434 ],
    [ u"ph",u"Indang",41158,14.195278,120.876944 ],
    [ u"ph",u"Indulang",3387,8.05,124.64 ],
    [ u"ph",u"Ineangan",3670,16.3181,121.093 ],
    [ u"ph",u"Infanta",3161,15.8264,119.9077 ],
    [ u"ph",u"Infanta",5321,14.744949,121.649533 ],
    [ u"ph",u"Inicbulan",2570,13.820435,120.983452 ],
    [ u"ph",u"Initao",9922,8.499722,124.303889 ],
    [ u"ph",u"Inobulan",2561,8.886389,124.794722 ],
    [ u"ph",u"Intampilan",2226,11.4813,122.7434 ],
    [ u"ph",u"Ipilan",5076,8.843056,117.903333 ],
    [ u"ph",u"Ipil",2468,13.5132,121.9841 ],
    [ u"ph",u"Ipil",3854,10.9758,124.6332 ],
    [ u"ph",u"Ipil",3333,9.7907,125.4386 ],
    [ u"ph",u"Ipil",19196,7.784444,122.586111 ],
    [ u"ph",u"Iraan",5262,9.062887,117.701597 ],
    [ u"ph",u"Iraga",3937,17.7015,121.6546 ],
    [ u"ph",u"Iraray",2790,8.993611,118.051111 ],
    [ u"ph",u"Irasan",2170,8.526,123.206 ],
    [ u"ph",u"Irawan",4141,9.8019,118.6991 ],
    [ u"ph",u"Iraya",2727,13.25,123.516667 ],
    [ u"ph",u"Iriga",94846,13.4324,123.4115 ],
    [ u"ph",u"Iriron",3926,12.616032,120.930614 ],
    [ u"ph",u"Irosin",20716,12.7026,124.0362 ],
    [ u"ph",u"Isabang",3497,13.9577,121.5709 ],
    [ u"ph",u"Isabang",3497,13.966667,121.566667 ],
    [ u"ph",u"Isabela",67341,6.7085,121.9711 ],
    [ u"ph",u"Isabela",15898,10.2048,122.9888 ],
    [ u"ph",u"Isabel",8596,10.9267,124.434 ],
    [ u"ph",u"Isla",2447,15.8954,120.2995 ],
    [ u"ph",u"Isugod",3665,9.340766,118.119598 ],
    [ u"ph",u"Ivisan",5036,11.521667,122.690833 ],
    [ u"ph",u"Jabonga",3245,9.343056,125.515556 ],
    [ u"ph",u"Jaclupan",9652,10.301376,123.8165 ],
    [ u"ph",u"Jaena",4272,11.416667,122.4 ],
    [ u"ph",u"Jaguimitan",2461,11.14,122.7236 ],
    [ u"ph",u"Jaguimitan",2461,11.1422,122.6897 ],
    [ u"ph",u"Jagupit",2157,9.242222,125.558056 ],
    [ u"ph",u"Jalaud",2239,10.893333,122.7475 ],
    [ u"ph",u"Jamabalud",2742,10.8788,122.6212 ],
    [ u"ph",u"Jamorawon",3089,12.225644,123.55151 ],
    [ u"ph",u"Jampang",2189,9.9,123.583333 ],
    [ u"ph",u"Janagdong",5174,13.9034,121.5134 ],
    [ u"ph",u"Jandayan",2815,10.166667,124.183333 ],
    [ u"ph",u"Janopol",5297,14.085864,121.094886 ],
    [ u"ph",u"Jantianon",2322,9.4442,123.1657 ],
    [ u"ph",u"Japitan",3222,10.1279,123.5035 ],
    [ u"ph",u"Japitan",2736,10.765244,123.544403 ],
    [ u"ph",u"Jaro",7934,11.188333,124.7825 ],
    [ u"ph",u"Jasaan",16435,8.654167,124.755556 ],
    [ u"ph",u"Javalera",3421,14.254901,120.916617 ],
    [ u"ph",u"Javier",2949,10.7921,124.9364 ],
    [ u"ph",u"Javier",2276,8.488889,126.085 ],
    [ u"ph",u"Jetafe",4489,10.147222,124.153889 ],
    [ u"ph",u"Jiabong",4076,11.7625,124.951944 ],
    [ u"ph",u"Jibao-an",2677,10.75,122.5 ],
    [ u"ph",u"Jimalalud",3212,9.9797,123.1999 ],
    [ u"ph",u"Jimenez",6662,8.3365,123.8383 ],
    [ u"ph",u"Jipapad",3797,12.2855,125.2361 ],
    [ u"ph",u"Jolo",102222,6.052222,121.002222 ],
    [ u"ph",u"Jomalig",2270,14.7147,122.3684 ],
    [ u"ph",u"Jones",5227,16.5571,121.7029 ],
    [ u"ph",u"Jordan",8255,10.658356,122.596303 ],
    [ u"ph",u"Joroan",2596,13.4885,123.6189 ],
    [ u"ph",u"Josefina",3152,8.2,123.533333 ],
    [ u"ph",u"Joson",3462,15.949,120.9778 ],
    [ u"ph",u"Jovellar",3936,13.0695,123.5999 ],
    [ u"ph",u"Jovellar",2357,7.0635,126.455582 ],
    [ u"ph",u"Juban",4075,12.847778,123.987778 ],
    [ u"ph",u"Jubasan",2328,12.4844,124.2872 ],
    [ u"ph",u"Jugas",2072,11.613,122.3822 ],
    [ u"ph",u"Jugno",3778,9.4683,123.2038 ],
    [ u"ph",u"Julita",2997,10.974722,124.961667 ],
    [ u"ph",u"Kabacan",31768,7.106667,124.829167 ],
    [ u"ph",u"Kabac",4149,11.2353,123.6979 ],
    [ u"ph",u"Kabankalan",138314,9.9902,122.8142 ],
    [ u"ph",u"Kablon",4852,6.319444,125.010556 ],
    [ u"ph",u"Kabugao",2337,18.021667,121.184167 ],
    [ u"ph",u"Kabulusan",3811,14.3615,121.4004 ],
    [ u"ph",u"Kadingilan",7020,7.601111,124.908611 ],
    [ u"ph",u"Kagawasan",2224,7.8657,123.3973 ],
    [ u"ph",u"Kagay",2318,6.0088,120.9074 ],
    [ u"ph",u"Kajatian",5436,6.031111,120.991944 ],
    [ u"ph",u"Kalabugao",5982,8.456389,125.158889 ],
    [ u"ph",u"Kalaisan",2494,7.010278,125.045 ],
    [ u"ph",u"Kalamansig",12820,6.55187,124.051111 ],
    [ u"ph",u"Kalandagan",2137,6.678611,124.723333 ],
    [ u"ph",u"Kalanganan",2331,8.083333,124.246667 ],
    [ u"ph",u"Kalang",2323,5.919722,121.363056 ],
    [ u"ph",u"Kalawit",8499,8.066667,122.516667 ],
    [ u"ph",u"Kalayaan",7306,14.35,121.566667 ],
    [ u"ph",u"Kalbay",4339,5.723333,125.498611 ],
    [ u"ph",u"Kalbugan",3227,6.959722,124.659167 ],
    [ u"ph",u"Kalian",2815,7.5916,123.2319 ],
    [ u"ph",u"Kaligutan",2789,7.703056,125.813056 ],
    [ u"ph",u"Kalilangan",14456,7.821111,124.731389 ],
    [ u"ph",u"Kalugmanan",2675,8.277778,124.859722 ],
    [ u"ph",u"Kambing",2373,5.946464,121.307573 ],
    [ u"ph",u"Kananga",7647,11.1867,124.5601 ],
    [ u"ph",u"Kanlagay",2211,5.875685,121.291456 ],
    [ u"ph",u"Kanluran",2312,14.416667,120.85 ],
    [ u"ph",u"Kaongkod",2329,11.250278,123.755556 ],
    [ u"ph",u"Kapatagan",9664,7.9003,123.7692 ],
    [ u"ph",u"Kapatalan",2719,14.4741,121.4903 ],
    [ u"ph",u"Kapatan",2902,5.900556,125.2375 ],
    [ u"ph",u"Kapaya",4201,6.571111,124.563056 ],
    [ u"ph",u"Kapingkong",3129,6.669167,124.631111 ],
    [ u"ph",u"Kapitan Ramon",4640,10.7602,123.1148 ],
    [ u"ph",u"Karomatan",5329,7.7959,123.7145 ],
    [ u"ph",u"Karungdong",7269,5.8844,121.263 ],
    [ u"ph",u"Katangawan",8476,6.172712,125.218695 ],
    [ u"ph",u"Katidtuan",4710,7.165556,124.364167 ],
    [ u"ph",u"Katipunan",4172,8.514,123.2829 ],
    [ u"ph",u"Katipunan",10637,7.5825,122.830556 ],
    [ u"ph",u"Katubao",4177,5.889167,124.829444 ],
    [ u"ph",u"Katuli",4732,7.433333,124.216667 ],
    [ u"ph",u"Kauran",5120,6.785556,124.473333 ],
    [ u"ph",u"Kauswagan",2939,8.516667,125.75 ],
    [ u"ph",u"Kauswagan",6851,8.191667,124.084722 ],
    [ u"ph",u"Kauswagan",2268,8.789722,124.775556 ],
    [ u"ph",u"Kawayan",2154,7.538333,122.8725 ],
    [ u"ph",u"Kawit",73204,14.444259,120.901639 ],
    [ u"ph",u"Kawit",5771,11.186,123.9459 ],
    [ u"ph",u"Kawit",2257,8.1875,124.066667 ],
    [ u"ph",u"Kaytitinga",4610,14.107222,120.829167 ],
    [ u"ph",u"Kiamba",10979,5.989444,124.624167 ],
    [ u"ph",u"Kibangay",6539,8.049722,124.893056 ],
    [ u"ph",u"Kibawe",5081,7.568611,124.987778 ],
    [ u"ph",u"Kiblawan",4464,6.614167,125.236667 ],
    [ u"ph",u"Kibungan",7912,16.695,120.6553 ],
    [ u"ph",u"Kilim",3262,10.7118,124.7968 ],
    [ u"ph",u"Kimanait",3589,7.757778,124.733611 ],
    [ u"ph",u"Kimaya",3944,8.564722,124.839722 ],
    [ u"ph",u"Kinabjangan",2626,8.969167,125.3575 ],
    [ u"ph",u"Kinablañgan",5423,7.694722,126.550278 ],
    [ u"ph",u"Kinalaglagan",2397,14.001493,121.097716 ],
    [ u"ph",u"Kinalansan",2137,13.7036,123.5531 ],
    [ u"ph",u"Kinamayan",4300,7.499444,125.673611 ],
    [ u"ph",u"Kinangan",4561,6.301389,125.585 ],
    [ u"ph",u"Kinatakutan",2703,13.955,122.4678 ],
    [ u"ph",u"Kipalbig",5070,6.410833,124.925 ],
    [ u"ph",u"Kipit",2325,8.046111,122.532222 ],
    [ u"ph",u"Kisante",4815,6.923056,125.155 ],
    [ u"ph",u"Kisolon",8105,8.33,124.976944 ],
    [ u"ph",u"Kitango",2608,6.948333,124.441111 ],
    [ u"ph",u"Kitaotao",3893,7.639722,125.008889 ],
    [ u"ph",u"Kitapok",2924,6.953333,124.425556 ],
    [ u"ph",u"Kitcharao",7213,9.455,125.573056 ],
    [ u"ph",u"Klinan",3017,6.186833,125.136841 ],
    [ u"ph",u"Kolambugan",2427,8.1144,123.8971 ],
    [ u"ph",u"Koronadal",123765,6.503056,124.846944 ],
    [ u"ph",u"Koronadal Proper",4352,6.253333,124.995 ],
    [ u"ph",u"Kulaman",3380,6.459444,124.089167 ],
    [ u"ph",u"Kulasi",7148,5.9052,120.9569 ],
    [ u"ph",u"Kumalarang",6870,7.7478,123.1445 ],
    [ u"ph",u"Kumaliskis",2837,10.507264,123.203002 ],
    [ u"ph",u"Kungtad",2464,5.5572,120.8472 ],
    [ u"ph",u"Labangan",10781,7.8654,123.5123 ],
    [ u"ph",u"Labasan",4217,12.777318,121.469215 ],
    [ u"ph",u"Labayug",2874,16.1528,120.5661 ],
    [ u"ph",u"Labney",2150,16.1028,120.4655 ],
    [ u"ph",u"Labnig",2983,13.3769,123.6788 ],
    [ u"ph",u"Labog",3466,9.0558,118.0495 ],
    [ u"ph",u"Labrador",2108,16.028119,120.144236 ],
    [ u"ph",u"Labuan",12949,7.100748,121.90238 ],
    [ u"ph",u"Labu-o",3267,7.114167,125.045278 ],
    [ u"ph",u"Lacag",2207,13.1553,123.6812 ],
    [ u"ph",u"La Carlota",41313,10.4242,122.9212 ],
    [ u"ph",u"Lacaron",2301,11.422,122.7422 ],
    [ u"ph",u"Lacaron",2751,6.448889,125.579167 ],
    [ u"ph",u"Lacdayan",2642,13.6,122.533333 ],
    [ u"ph",u"Lacson",3970,7.211944,125.442222 ],
    [ u"ph",u"La Curva",3359,12.404845,121.045913 ],
    [ u"ph",u"La Dicha",2725,7.6633,123.0106 ],
    [ u"ph",u"La Fortuna",2496,8.279722,125.001389 ],
    [ u"ph",u"Lagasit",3147,15.9934,120.794 ],
    [ u"ph",u"Lagawe",6820,16.799965,121.119241 ],
    [ u"ph",u"Lagonglong",9043,8.807222,124.790278 ],
    [ u"ph",u"Lagonoy",7324,13.7342,123.5207 ],
    [ u"ph",u"La Granja",5277,10.4082,122.9898 ],
    [ u"ph",u"Laguilayan",17764,6.6525,124.521111 ],
    [ u"ph",u"Laguindingan",3120,8.574722,124.442222 ],
    [ u"ph",u"Laguitas",2181,8.089167,125.130556 ],
    [ u"ph",u"Laguit",4533,15.9472,120.1904 ],
    [ u"ph",u"La Hacienda",3726,9.8815,124.3923 ],
    [ u"ph",u"Lais",2298,6.332778,125.646389 ],
    [ u"ph",u"Laiya",7504,13.675,121.390278 ],
    [ u"ph",u"Lajong",2253,12.833333,123.966667 ],
    [ u"ph",u"Lakewood",6540,7.8541,123.1598 ],
    [ u"ph",u"Lalab",2542,11.5749,122.4284 ],
    [ u"ph",u"Lalagsan",2941,10.2824,123.013 ],
    [ u"ph",u"Lalawigan",2025,11.589167,125.469722 ],
    [ u"ph",u"La Libertad",5632,10.0266,123.2335 ],
    [ u"ph",u"La Libertad",5324,7.480278,125.647222 ],
    [ u"ph",u"Lalig",14729,13.976389,121.3275 ],
    [ u"ph",u"Lallayug",2102,17.705209,121.439748 ],
    [ u"ph",u"Lamacan",11993,10.026,123.6008 ],
    [ u"ph",u"Lamak",2201,10.399722,124.738889 ],
    [ u"ph",u"Lambakin",9193,14.75,120.866667 ],
    [ u"ph",u"Lambakin",2995,15.3899,120.8364 ],
    [ u"ph",u"Lamba",6408,6.359722,124.812222 ],
    [ u"ph",u"Lambontong",4338,6.308333,124.810556 ],
    [ u"ph",u"Lamian",3936,6.309167,124.846389 ],
    [ u"ph",u"Lamidan",3241,6.087222,125.702222 ],
    [ u"ph",u"Laminusa",8113,5.5549,120.9136 ],
    [ u"ph",u"Lamisahan",2989,7.070833,122.158333 ],
    [ u"ph",u"Lampari",2383,6.3125,124.880278 ],
    [ u"ph",u"Lampitak",2266,6.432222,125.0525 ],
    [ u"ph",u"Lamut",4089,16.649073,121.22474 ],
    [ u"ph",u"Lanao",2875,11.2603,124.0373 ],
    [ u"ph",u"Lanas",2325,10.266667,123.733333 ],
    [ u"ph",u"Lanas",2499,12.049464,121.918511 ],
    [ u"ph",u"Lanat",2178,15.8,120.6 ],
    [ u"ph",u"Landang",3542,6.958333,122.254722 ],
    [ u"ph",u"Langatian",3518,8.5208,123.2324 ],
    [ u"ph",u"Langcangan",8706,8.4262,123.7554 ],
    [ u"ph",u"Langpas",2378,5.975,120.949 ],
    [ u"ph",u"Langtad",2502,9.891667,123.607778 ],
    [ u"ph",u"Langub",2861,10.5774,123.7309 ],
    [ u"ph",u"Lañgub",3039,10.833333,123.566667 ],
    [ u"ph",u"Lañgub",3039,10.797542,123.533803 ],
    [ u"ph",u"Languyan",8900,5.2618,120.0807 ],
    [ u"ph",u"Lanigay",2789,13.316667,123.5 ],
    [ u"ph",u"Lanipao",4114,7.955278,123.776667 ],
    [ u"ph",u"Lanna",3439,17.694,121.7006 ],
    [ u"ph",u"Lanot",6928,11.519167,122.757222 ],
    [ u"ph",u"Lantangan",2252,11.386,122.8887 ],
    [ u"ph",u"Lantapan",5021,7.997778,125.027778 ],
    [ u"ph",u"Lantawan",2766,6.6402,121.8395 ],
    [ u"ph",u"Lanuza",2033,9.234167,126.064444 ],
    [ u"ph",u"Laoag",102109,18.1978,120.5957 ],
    [ u"ph",u"Lao",2154,11.0181,124.5609 ],
    [ u"ph",u"Laparay",2140,7.403611,122.817222 ],
    [ u"ph",u"Lapasan",2573,8.1924,123.8632 ],
    [ u"ph",u"La Paz",3405,17.6746,120.6864 ],
    [ u"ph",u"La Paz",3618,8.270833,125.799722 ],
    [ u"ph",u"La Paz",4017,16.910754,121.668242 ],
    [ u"ph",u"La Paz",4146,10.8925,124.955833 ],
    [ u"ph",u"La Paz",2080,15.9,120.75 ],
    [ u"ph",u"La Paz",2314,8.983611,126.263889 ],
    [ u"ph",u"La Paz",2782,7.315833,125.733333 ],
    [ u"ph",u"La Paz",2024,10.4131,122.5162 ],
    [ u"ph",u"Lapi",2849,17.716005,121.897748 ],
    [ u"ph",u"Lapinigan",4328,8.420556,125.9825 ],
    [ u"ph",u"Lapinig",3473,7.9227,123.6883 ],
    [ u"ph",u"Lapinig",3684,12.3151,125.3032 ],
    [ u"ph",u"Lapog",3148,17.742222,120.458333 ],
    [ u"ph",u"Lapolapo",3621,13.8341,121.1379 ],
    [ u"ph",u"Lapuan",3825,6.144444,125.700833 ],
    [ u"ph",u"Lapu-Lapu",241391,10.310278,123.949444 ],
    [ u"ph",u"La Purisima",7396,13.4225,123.324722 ],
    [ u"ph",u"Lapuyan",5274,7.6379,123.1944 ],
    [ u"ph",u"Lapuz",2601,6.523333,124.63 ],
    [ u"ph",u"Larap",4329,14.299,122.6504 ],
    [ u"ph",u"Larap",4113,4.761389,119.4075 ],
    [ u"ph",u"Larion",3010,17.628611,121.760847 ],
    [ u"ph",u"La Roxas",2456,7.864167,124.886944 ],
    [ u"ph",u"Lasam",6352,18.065186,121.600651 ],
    [ u"ph",u"Lasang",8318,7.266944,125.665 ],
    [ u"ph",u"Las Navas",3415,12.3392,125.0313 ],
    [ u"ph",u"Latung",2964,5.5,120.883333 ],
    [ u"ph",u"Laug",3157,15.0471,120.7509 ],
    [ u"ph",u"La Union",4758,9.085556,125.535833 ],
    [ u"ph",u"La Union",5220,6.704128,126.087982 ],
    [ u"ph",u"Laurel",9720,14.055419,120.919316 ],
    [ u"ph",u"Lavezares",4082,12.5336,124.3305 ],
    [ u"ph",u"Lawang Kupang",2616,15.3489,120.8582 ],
    [ u"ph",u"Lawigan",2571,10.549,121.9856 ],
    [ u"ph",u"Lawigan",2571,10.487,122.0354 ],
    [ u"ph",u"Laya",3787,17.4726,121.4678 ],
    [ u"ph",u"Laylay",2718,13.4391,121.8202 ],
    [ u"ph",u"Layog",2588,7.076667,124.730556 ],
    [ u"ph",u"Lazi",3429,9.1287,123.6356 ],
    [ u"ph",u"Leganes",2463,10.787222,122.589167 ],
    [ u"ph",u"Legarda",4016,7.6333,123.3045 ],
    [ u"ph",u"Legaspi",3281,16.0418,120.7432 ],
    [ u"ph",u"Legaspi",142871,13.1387,123.7353 ],
    [ u"ph",u"Lemery",3240,11.2258,122.9275 ],
    [ u"ph",u"Lemon",2102,11.2837,124.5648 ],
    [ u"ph",u"Lennec",3142,15.6835,120.7338 ],
    [ u"ph",u"Leones",2713,16.3633,120.3919 ],
    [ u"ph",u"Leon",5172,10.780849,122.389404 ],
    [ u"ph",u"Lepa",8877,15.8826,120.4493 ],
    [ u"ph",u"Lepanto",2472,9.6845,123.4026 ],
    [ u"ph",u"Leuteboro",3802,13.061,121.374717 ],
    [ u"ph",u"Leyte",7223,11.3697,124.4873 ],
    [ u"ph",u"Lianga",13623,8.633611,126.094722 ],
    [ u"ph",u"Lian",7496,14.0381,120.6509 ],
    [ u"ph",u"Libacao",2897,11.480201,122.304207 ],
    [ u"ph",u"Libacao",4796,10.18,122.9137 ],
    [ u"ph",u"Libas",2056,10.9388,124.545 ],
    [ u"ph",u"Libas",2256,13.241667,121.955548 ],
    [ u"ph",u"Libas",3373,9.883333,125.983333 ],
    [ u"ph",u"Libas",2153,6.535556,124.778889 ],
    [ u"ph",u"Libas",3311,15.8779,120.3118 ],
    [ u"ph",u"Libato",3830,13.8,121.35 ],
    [ u"ph",u"Libertad",5800,8.1075,126.026389 ],
    [ u"ph",u"Libertad",2025,11.7694,121.919 ],
    [ u"ph",u"Libertad",3798,11.0304,124.0215 ],
    [ u"ph",u"Libertad",2537,11.035278,122.769444 ],
    [ u"ph",u"Libertad",4486,10.916667,124.45 ],
    [ u"ph",u"Libertad",2349,8.2755,123.8382 ],
    [ u"ph",u"Libertad",4516,8.561111,124.351389 ],
    [ u"ph",u"Libertad",2231,12.455556,122.009722 ],
    [ u"ph",u"Libertad",5210,8.25,124.233333 ],
    [ u"ph",u"Libertad",2383,11.0349,124.5691 ],
    [ u"ph",u"Liberty",2323,10.874167,125.0025 ],
    [ u"ph",u"Liberty",2172,6.455278,124.981944 ],
    [ u"ph",u"Liboganon",2338,7.3488,125.7782 ],
    [ u"ph",u"Libog",11690,13.2349,123.7778 ],
    [ u"ph",u"Libona",5713,8.338889,124.735278 ],
    [ u"ph",u"Liboran",2772,8.354722,124.648889 ],
    [ u"ph",u"Liboro",6028,13.8245,122.7295 ],
    [ u"ph",u"Libungan",5606,7.240833,124.52 ],
    [ u"ph",u"Licab",6783,15.5439,120.7634 ],
    [ u"ph",u"Liciada",3982,14.898056,120.932778 ],
    [ u"ph",u"Ligaya",8431,12.659929,120.892315 ],
    [ u"ph",u"Ligaya",5300,15.5091,121.2872 ],
    [ u"ph",u"Ligayan",2319,4.653333,119.470556 ],
    [ u"ph",u"Liliongan",3049,7.362778,124.792778 ],
    [ u"ph",u"Liliw",15246,14.1313,121.4362 ],
    [ u"ph",u"Liloan",3549,10.161389,125.130278 ],
    [ u"ph",u"Liloan",3521,11.0422,124.5502 ],
    [ u"ph",u"Liloy",4784,8.114444,122.659444 ],
    [ u"ph",u"Limao",2123,7.079167,125.673611 ],
    [ u"ph",u"Limaong",3321,7.360556,122.366389 ],
    [ u"ph",u"Limay",52823,14.561944,120.598333 ],
    [ u"ph",u"Limbo",4841,7.250833,124.265833 ],
    [ u"ph",u"Limbuhan",3190,11.883765,124.050107 ],
    [ u"ph",u"Liminangcong",4790,10.9893,119.3593 ],
    [ u"ph",u"Limon",2495,12.3,122.016667 ],
    [ u"ph",u"Limot",2221,7.040502,126.272683 ],
    [ u"ph",u"Limpapa",3751,7.120431,121.907634 ],
    [ u"ph",u"Limulan",3933,6.585279,124.061892 ],
    [ u"ph",u"Linabo",5849,8.054167,125.155 ],
    [ u"ph",u"Linabuan",3430,11.651111,122.345 ],
    [ u"ph",u"Linabuan Sur",2789,11.651111,122.345 ],
    [ u"ph",u"Linamon",6849,8.186032,124.162765 ],
    [ u"ph",u"Linan",3160,6.43,124.975556 ],
    [ u"ph",u"Linao",2571,7.0172,125.992 ],
    [ u"ph",u"Linao",4489,7.167778,124.9675 ],
    [ u"ph",u"Linaon",3669,9.9499,122.4483 ],
    [ u"ph",u"Linapacan",2972,11.4924,119.8703 ],
    [ u"ph",u"Linay",2657,8.5207,123.1309 ],
    [ u"ph",u"Lingasad",2421,8.4966,123.3997 ],
    [ u"ph",u"Lingating",3774,8.331667,124.628889 ],
    [ u"ph",u"Lingig",6400,8.038889,126.4125 ],
    [ u"ph",u"Lingion",4321,8.188056,124.609722 ],
    [ u"ph",u"Linmansangan",3872,15.8349,120.2836 ],
    [ u"ph",u"Linoan",2952,7.626,125.9741 ],
    [ u"ph",u"Lintangan",3211,7.215545,121.952 ],
    [ u"ph",u"Liozon",3245,15.3993,119.933 ],
    [ u"ph",u"Lipa",213525,13.9411,121.1631 ],
    [ u"ph",u"Lipay",2078,16.708056,120.409722 ],
    [ u"ph",u"Lipay",2717,15.4561,119.9208 ],
    [ u"ph",u"Litayen",5294,7.335833,124.034722 ],
    [ u"ph",u"Little Baguio",4926,7.893889,125.276389 ],
    [ u"ph",u"Liwan",5286,17.5191,121.632 ],
    [ u"ph",u"Llanera",5121,15.6635,121.0182 ],
    [ u"ph",u"Lloren",5800,16.3331,120.4329 ],
    [ u"ph",u"Llorente",7908,11.411944,125.545833 ],
    [ u"ph",u"Loacan",6371,16.55,120.666667 ],
    [ u"ph",u"Lobo",3052,13.6481,121.2112 ],
    [ u"ph",u"Lobong",3641,16.0815,120.4704 ],
    [ u"ph",u"Logon",3644,11.3303,124.1146 ],
    [ u"ph",u"Loma de Gato",21990,14.783333,121 ],
    [ u"ph",u"Lombog",2276,9.7788,124.4174 ],
    [ u"ph",u"Lomboy",3282,15.492548,120.717232 ],
    [ u"ph",u"Longos",15546,14.3394,121.4813 ],
    [ u"ph",u"Longos",2638,16.1066,120.3954 ],
    [ u"ph",u"Lonoy",3076,11.512222,122.553333 ],
    [ u"ph",u"Lonoy",2096,11.513611,122.729722 ],
    [ u"ph",u"Looc",3092,14.1648,120.6293 ],
    [ u"ph",u"Looc",2627,13.720363,120.249821 ],
    [ u"ph",u"Looc",2292,8.843333,124.791667 ],
    [ u"ph",u"Looc",3389,12.2605,121.9926 ],
    [ u"ph",u"Looc",2209,11.4788,124.5542 ],
    [ u"ph",u"Lookan",2758,5.037,120.1027 ],
    [ u"ph",u"Loon",9485,9.7998,123.7929 ],
    [ u"ph",u"Lope de Vega",2532,12.2983,124.6238 ],
    [ u"ph",u"Lopez Jaena",3575,8.5528,123.7615 ],
    [ u"ph",u"Lopez Jaena",5352,6.508889,124.6825 ],
    [ u"ph",u"Lopez Jaena",5573,10.8478,123.4141 ],
    [ u"ph",u"Loqueb",6141,15.9419,120.4478 ],
    [ u"ph",u"Loreto",5730,8.186944,125.853056 ],
    [ u"ph",u"Loreto",5397,10.3601,125.5763 ],
    [ u"ph",u"Los Angeles",4054,9.0125,125.608056 ],
    [ u"ph",u"Los Arcos",2234,8.632778,125.985556 ],
    [ u"ph",u"Los Baños",95752,14.1798,121.2234 ],
    [ u"ph",u"Lourdes",3791,13.3899,123.3735 ],
    [ u"ph",u"Lourdes",3198,8.525,124.432222 ],
    [ u"ph",u"Lourdes",2370,15.0193,120.8511 ],
    [ u"ph",u"Loyola",2673,8.335,126.334722 ],
    [ u"ph",u"Lubang",5750,13.858355,120.124022 ],
    [ u"ph",u"Lubigan",2444,13.742,122.9373 ],
    [ u"ph",u"Lubuagan",2893,17.3548,121.1747 ],
    [ u"ph",u"Lucap",4935,16.18891,120.003737 ],
    [ u"ph",u"Lucapon",5767,15.6998,119.932 ],
    [ u"ph",u"Lucatan",2557,7.009604,126.421182 ],
    [ u"ph",u"Lucban",30991,14.1148,121.5547 ],
    [ u"ph",u"Lucena",228738,13.9348,121.6127 ],
    [ u"ph",u"Lucero",2155,11.454202,122.464307 ],
    [ u"ph",u"Lucero",2990,16.4051,119.9124 ],
    [ u"ph",u"Lucmayan",2024,10.4726,122.519 ],
    [ u"ph",u"Lucsuhin",4240,13.881856,120.641306 ],
    [ u"ph",u"Lugait",7370,8.341111,124.259167 ],
    [ u"ph",u"Lugo",2372,10.816389,123.988889 ],
    [ u"ph",u"Lugui",2308,14.1131,122.7935 ],
    [ u"ph",u"Lugus",7167,5.703611,120.820278 ],
    [ u"ph",u"Luisiana",4554,14.185,121.5109 ],
    [ u"ph",u"Luklukan",4335,14.3254,122.7124 ],
    [ u"ph",u"Luksuhin",4614,14.096667,120.880833 ],
    [ u"ph",u"Lumangbayan",2227,13.3782,121.0882 ],
    [ u"ph",u"Lumasal",3876,5.885278,124.849444 ],
    [ u"ph",u"Lumatil",2172,5.874722,124.888333 ],
    [ u"ph",u"Lumbac",2448,7.724513,124.250832 ],
    [ u"ph",u"Lumbangan",7071,14.0245,120.7139 ],
    [ u"ph",u"Lumban",30269,14.2973,121.4598 ],
    [ u"ph",u"Lumbayao",3693,8.016667,125.166667 ],
    [ u"ph",u"Lumbayao",2557,6.947222,122.141111 ],
    [ u"ph",u"Lumbia",7863,8.399167,124.593611 ],
    [ u"ph",u"Lumbog",2128,7.5581,123.2014 ],
    [ u"ph",u"Lumil",2512,14.181683,121.013646 ],
    [ u"ph",u"Luna",2616,16.96975,121.729242 ],
    [ u"ph",u"Luna",2209,12.5492,123.7336 ],
    [ u"ph",u"Luna",2321,16.3311,119.8939 ],
    [ u"ph",u"Luna",11311,10.969,123.2419 ],
    [ u"ph",u"Luna",7799,9.737,125.4976 ],
    [ u"ph",u"Luna",4550,7.576389,125.667222 ],
    [ u"ph",u"Lunao",8995,8.850278,125.056389 ],
    [ u"ph",u"Lunas",5789,10.6402,123.7525 ],
    [ u"ph",u"Lunec",2317,15.9524,120.4912 ],
    [ u"ph",u"Lunen",2416,6.359167,124.904722 ],
    [ u"ph",u"Lungaog",3203,7.529444,125.687778 ],
    [ u"ph",u"Lungog",2097,17.4645,120.4784 ],
    [ u"ph",u"Lun",11541,6.035556,125.298056 ],
    [ u"ph",u"Luntal",2765,14.0292,120.7174 ],
    [ u"ph",u"Lupao",11000,15.8793,120.8983 ],
    [ u"ph",u"Lupi",2253,13.533333,123.15 ],
    [ u"ph",u"Lupo",2291,11.5076,122.4791 ],
    [ u"ph",u"Lusacan",14870,13.952778,121.346944 ],
    [ u"ph",u"Lutayan",13080,6.62,124.883056 ],
    [ u"ph",u"Lut-od",2418,10.257222,123.629444 ],
    [ u"ph",u"Luuk Datan",2567,4.811944,119.845278 ],
    [ u"ph",u"Luzong",2207,16.867,120.442 ],
    [ u"ph",u"Luzon",3211,6.519041,126.094082 ],
    [ u"ph",u"Maanas",3477,8.893889,125.030833 ],
    [ u"ph",u"Maan",3450,5.933889,124.735556 ],
    [ u"ph",u"Ma-ao",25837,10.520764,123.017002 ],
    [ u"ph",u"Maasim",3577,14.9958,121.0289 ],
    [ u"ph",u"Maasim",5847,5.8575,125.006111 ],
    [ u"ph",u"Maasin",3514,10.8923,122.4359 ],
    [ u"ph",u"Mababanaba",3733,15.497149,120.460532 ],
    [ u"ph",u"Mababanaba",3733,15.5036,120.5369 ],
    [ u"ph",u"Mabahin",2327,9.185556,126.170556 ],
    [ u"ph",u"Mabalacat",188057,15.2216,120.5736 ],
    [ u"ph",u"Mabalodbalod",2494,13.5888,123.4554 ],
    [ u"ph",u"Mabantao",3251,7.643333,125.674722 ],
    [ u"ph",u"Mabasa",2242,16.321,121.1262 ],
    [ u"ph",u"Mabay",3212,6.057723,124.466607 ],
    [ u"ph",u"Mabayo",2843,14.7318,120.2781 ],
    [ u"ph",u"Mabilang",2229,15.6752,120.4879 ],
    [ u"ph",u"Mabilao",2397,16.1543,120.4248 ],
    [ u"ph",u"Mabilbila",2408,17.51,120.444722 ],
    [ u"ph",u"Mabilog",2581,15.394854,120.665731 ],
    [ u"ph",u"Mabilo",2440,11.6784,122.4079 ],
    [ u"ph",u"Mabini",2767,13.753237,120.940487 ],
    [ u"ph",u"Mabini",5999,9.8649,124.5215 ],
    [ u"ph",u"Mabini",4458,17.096943,121.737243 ],
    [ u"ph",u"Mabini",7810,15.6,120.98333 ],
    [ u"ph",u"Mabini",2859,16.0699,119.9391 ],
    [ u"ph",u"Mabini",2130,11.416667,125.166667 ],
    [ u"ph",u"Mabini",2757,6.538889,124.9 ],
    [ u"ph",u"Mabini",7270,10.795942,123.484603 ],
    [ u"ph",u"Mabitac",12398,14.4259,121.429 ],
    [ u"ph",u"Mabiton",2202,12.8334,123.2612 ],
    [ u"ph",u"Mabua",2075,9.8039,125.4409 ],
    [ u"ph",u"Mabuhay",2848,7.417778,122.836667 ],
    [ u"ph",u"Mabusag",2249,17.9261,120.4976 ],
    [ u"ph",u"Mabuttal",2342,18.3762,121.5147 ],
    [ u"ph",u"Macaas",2703,10.698889,124.008611 ],
    [ u"ph",u"Macaboboni",2461,16.1909,119.7802 ],
    [ u"ph",u"Macabugos",2561,13.2362,123.3053 ],
    [ u"ph",u"Macalamcam",2931,13.85,121.316667 ],
    [ u"ph",u"Macalaya",3673,12.889444,123.771111 ],
    [ u"ph",u"Macalelon",6042,13.746944,122.138611 ],
    [ u"ph",u"Macalong",5802,16.0137,120.6586 ],
    [ u"ph",u"Macalva",2874,16.3485,120.3866 ],
    [ u"ph",u"Macapsing",2282,15.6783,121.1319 ],
    [ u"ph",u"Macarse",2311,15.4243,120.7781 ],
    [ u"ph",u"MacArthur",2668,10.834722,124.995278 ],
    [ u"ph",u"Macatbong",2727,15.5048,121.0791 ],
    [ u"ph",u"Macayug",2432,16.0896,120.405 ],
    [ u"ph",u"Macrohon",2826,10.079722,124.943056 ],
    [ u"ph",u"Madalag",2133,10.899438,122.982804 ],
    [ u"ph",u"Maddarulug",2186,17.6047,121.6792 ],
    [ u"ph",u"Maddela",9751,16.3414,121.6849 ],
    [ u"ph",u"Madridejos",3998,11.298,123.7339 ],
    [ u"ph",u"Madrid",3119,9.262114,125.964367 ],
    [ u"ph",u"Maduao",2143,7.294167,125.625833 ],
    [ u"ph",u"Madulao",3378,13.5684,122.3413 ],
    [ u"ph",u"Magalalag",2625,17.5754,121.7411 ],
    [ u"ph",u"Magallanes",6637,9.02,125.517222 ],
    [ u"ph",u"Magallanes",3396,14.188333,120.7575 ],
    [ u"ph",u"Magallanes",2487,16.0196,120.739 ],
    [ u"ph",u"Magallanes",2740,12.829167,123.836389 ],
    [ u"ph",u"Magallon Cadre",3622,10.2885,123.0922 ],
    [ u"ph",u"Magallon",14619,10.2716,123.0735 ],
    [ u"ph",u"Magapit",2624,18.107883,121.677051 ],
    [ u"ph",u"Magarao",15205,13.6604,123.1869 ],
    [ u"ph",u"Magatos",5770,7.555556,125.726667 ],
    [ u"ph",u"Magay",2281,10.4719,124.0132 ],
    [ u"ph",u"Magbay",3248,12.410144,121.089913 ],
    [ u"ph",u"Magdalena",2419,10.4236,121.9751 ],
    [ u"ph",u"Magdalena",2146,16.933333,121.766667 ],
    [ u"ph",u"Magdalena",3168,14.1999,121.429 ],
    [ u"ph",u"Magdiwang",2716,12.491032,122.513512 ],
    [ u"ph",u"Magdug",2343,6.547639,126.095082 ],
    [ u"ph",u"Magliman",2505,15.0337,120.6651 ],
    [ u"ph",u"Magnaga",7644,7.1694,125.8931 ],
    [ u"ph",u"Magpet",5414,7.111944,125.113333 ],
    [ u"ph",u"Magsalangi",2399,12.182747,123.566609 ],
    [ u"ph",u"Magsaysay",16592,6.766667,125.183333 ],
    [ u"ph",u"Magsaysay",9407,12.333333,121.15 ],
    [ u"ph",u"Magsaysay",4001,7.396667,125.635 ],
    [ u"ph",u"Magsingal",4571,17.685,120.424444 ],
    [ u"ph",u"Magtaking",5946,15.9854,120.1832 ],
    [ u"ph",u"Magtanggol",2204,15.758,120.9156 ],
    [ u"ph",u"Maguilling",2892,17.7582,121.4849 ],
    [ u"ph",u"Maguinao",2978,15.0239,120.9344 ],
    [ u"ph",u"Maguling",2361,6.095,124.403333 ],
    [ u"ph",u"Maguyam",5437,14.262766,121.004996 ],
    [ u"ph",u"Mahaba",3125,13.2676,123.5514 ],
    [ u"ph",u"Mahabang Parang",2791,13.983333,121.083333 ],
    [ u"ph",u"Mahala",2427,5.916667,121.133333 ],
    [ u"ph",u"Mahanub",3872,7.578333,126.504167 ],
    [ u"ph",u"Mahaplag",3866,10.5788,124.9753 ],
    [ u"ph",u"Mahayag",2353,9.9349,124.3164 ],
    [ u"ph",u"Mahayag",2814,7.216667,125.619444 ],
    [ u"ph",u"Mahayag",17146,8.1183,123.4455 ],
    [ u"ph",u"Mahinog",2780,9.157778,124.7875 ],
    [ u"ph",u"Maigo",7235,8.1613,123.9583 ],
    [ u"ph",u"Mailag",5388,7.970278,125.1375 ],
    [ u"ph",u"Maimbung",3779,5.927196,121.029353 ],
    [ u"ph",u"Maindang",3201,6.595556,124.845 ],
    [ u"ph",u"Mainit",2323,9.4335,123.3595 ],
    [ u"ph",u"Mainit",2304,8.8436,117.8183 ],
    [ u"ph",u"Mainit",2442,14.146944,121.979444 ],
    [ u"ph",u"Mainit",6148,7.5327,126.0173 ],
    [ u"ph",u"Mainit",5520,9.5372,125.5227 ],
    [ u"ph",u"Maitum",8478,6.041944,124.502778 ],
    [ u"ph",u"Majayjay",11412,14.1463,121.4729 ],
    [ u"ph",u"Makati",510383,14.566667,121.033333 ],
    [ u"ph",u"Makato",3035,11.712,122.2922 ],
    [ u"ph",u"Makiling",4441,10.780944,123.393803 ],
    [ u"ph",u"Makir",2371,7.030833,124.304167 ],
    [ u"ph",u"Makiwalo",4614,12.5101,124.706 ],
    [ u"ph",u"Malabag",7021,14.139381,120.967509 ],
    [ u"ph",u"Malabago",3618,15.9743,120.3547 ],
    [ u"ph",u"Malabanan",3731,14,121.133333 ],
    [ u"ph",u"Malabanban",19470,13.933333,121.466667 ],
    [ u"ph",u"Malabang",4354,7.590278,124.070278 ],
    [ u"ph",u"Malabog",3957,13.1738,123.6865 ],
    [ u"ph",u"Malabon",2640,15.6361,119.9379 ],
    [ u"ph",u"Malabor",2690,11.272916,122.046607 ],
    [ u"ph",u"Malabugas",4646,9.3692,122.7702 ],
    [ u"ph",u"Malabuyoc",2812,9.6525,123.3252 ],
    [ u"ph",u"Malacampa",4537,15.6483,120.4093 ],
    [ u"ph",u"Malaga",2156,12.236856,124.375287 ],
    [ u"ph",u"Malagos",4975,7.185,125.422222 ],
    [ u"ph",u"Malaiba",6888,10.333333,123.316667 ],
    [ u"ph",u"Malainen Luma",2813,14.270303,120.788398 ],
    [ u"ph",u"Malajog",2196,12.1102,124.4793 ],
    [ u"ph",u"Malaking Pulo",6182,14.137373,121.08961 ],
    [ u"ph",u"Malalag",6180,6.595833,125.399167 ],
    [ u"ph",u"Malamig",2824,12.95,121.366667 ],
    [ u"ph",u"Malamote",3098,7.072222,124.897222 ],
    [ u"ph",u"Malandag",12867,6.308889,125.251111 ],
    [ u"ph",u"Malanday",21901,14.7069,121.1306 ],
    [ u"ph",u"Malanday",21901,14.6463,121.095 ],
    [ u"ph",u"Malangas",8473,7.6192,123.0255 ],
    [ u"ph",u"Malapag",3306,7.133333,124.816667 ],
    [ u"ph",u"Malaruhatan",3169,14.0306,120.6804 ],
    [ u"ph",u"Malasila",5864,6.943889,125.129444 ],
    [ u"ph",u"Malasin",2379,16.80286,121.785741 ],
    [ u"ph",u"Malasin",3396,16.3045,121.1062 ],
    [ u"ph",u"Malasugui",2978,14.1439,122.8471 ],
    [ u"ph",u"Malatap",2157,14.1871,122.5119 ],
    [ u"ph",u"Malawag",3155,13.383333,123.283333 ],
    [ u"ph",u"Malawa",2102,15.9584,120.2783 ],
    [ u"ph",u"Malayal",2811,7.20801,121.94204 ],
    [ u"ph",u"Malaya",11442,14.3971,121.3385 ],
    [ u"ph",u"Malayu-an",2868,11.0979,123.0091 ],
    [ u"ph",u"Malbago",2614,9.7327,123.3402 ],
    [ u"ph",u"Malbang",2448,5.855556,125.045278 ],
    [ u"ph",u"Malbug",2292,12.0563,123.6461 ],
    [ u"ph",u"Malhiao",2678,9.878611,123.421944 ],
    [ u"ph",u"Malibago",3087,13.2783,122.0228 ],
    [ u"ph",u"Malibong",2313,15.8444,120.3199 ],
    [ u"ph",u"Malicboy",6224,13.9799,121.7907 ],
    [ u"ph",u"Malidong",2301,13.013329,123.459622 ],
    [ u"ph",u"Maligaya",4275,15.6747,120.8887 ],
    [ u"ph",u"Maliig",2837,13.845556,120.150322 ],
    [ u"ph",u"Malilipot",19450,13.3188,123.7385 ],
    [ u"ph",u"Malim",2356,7.452,123.4312 ],
    [ u"ph",u"Malinao",2308,6.659167,125.286667 ],
    [ u"ph",u"Malinao",3196,8.825,125.193056 ],
    [ u"ph",u"Malinao",4264,7.591667,124.688889 ],
    [ u"ph",u"Malinao",7528,14,121.833333 ],
    [ u"ph",u"Malingin",2650,11.05,123.983333 ],
    [ u"ph",u"Malinta",3374,12.301439,123.55811 ],
    [ u"ph",u"Malisbong",4452,6.12,124.354722 ],
    [ u"ph",u"Malitbog",3151,8.533889,124.883056 ],
    [ u"ph",u"Malitbog",3125,12.75212,121.465915 ],
    [ u"ph",u"Malitbog",2800,10.16,124.999167 ],
    [ u"ph",u"Malitubog",2241,7.315556,124.638056 ],
    [ u"ph",u"Mallig",3767,17.141111,121.683056 ],
    [ u"ph",u"Malocloc",3664,11.497,122.696 ],
    [ u"ph",u"Maloco",2511,11.7832,122.152 ],
    [ u"ph",u"Maloh",5105,9.056,122.9851 ],
    [ u"ph",u"Malolos",198763,14.841944,120.811667 ],
    [ u"ph",u"Maloma",4430,15.1135,120.0639 ],
    [ u"ph",u"Maltana",3361,6.4225,124.937222 ],
    [ u"ph",u"Maluanluan",3116,13.096697,121.423517 ],
    [ u"ph",u"Maluay",2878,9.1319,123.2203 ],
    [ u"ph",u"Maluid",2726,15.5493,120.6528 ],
    [ u"ph",u"Maluko",3278,8.375,124.953889 ],
    [ u"ph",u"Maluno",2493,16.998847,121.964342 ],
    [ u"ph",u"Malusac",2162,14.8587,120.6215 ],
    [ u"ph",u"Malusay",2473,10.1439,123.2717 ],
    [ u"ph",u"Maluso",31375,6.543,121.8753 ],
    [ u"ph",u"Malvar",29880,14.044722,121.158611 ],
    [ u"ph",u"Mamala",7418,14.016667,121.516667 ],
    [ u"ph",u"Mamali",2394,6.776667,124.645 ],
    [ u"ph",u"Mamatid",40271,14.235381,121.152601 ],
    [ u"ph",u"Mambago",2913,7.105556,125.694444 ],
    [ u"ph",u"Mambajao",10057,9.2504,124.7156 ],
    [ u"ph",u"Mambatangan",2922,8.433333,124.833333 ],
    [ u"ph",u"Mambatangan",2922,8.476944,124.805278 ],
    [ u"ph",u"Mambayaan",2781,8.782778,124.784167 ],
    [ u"ph",u"Mambog",3726,15.3137,120.0304 ],
    [ u"ph",u"Mambulo",6319,13.716667,123.05 ],
    [ u"ph",u"Mamburao",23892,13.2233,120.596 ],
    [ u"ph",u"Mamonit",2178,15.5859,120.3972 ],
    [ u"ph",u"Mampurog",2310,14.0458,122.8836 ],
    [ u"ph",u"Manacsac",2313,15.5952,120.7911 ],
    [ u"ph",u"Managa",3460,6.746111,125.268056 ],
    [ u"ph",u"Managok",6477,8.028889,125.188611 ],
    [ u"ph",u"Managpi",2683,13.3108,121.204 ],
    [ u"ph",u"Manalad",3151,10.0056,122.7769 ],
    [ u"ph",u"Manalongon",9321,9.2209,122.886 ],
    [ u"ph",u"Manambrag",2920,13.7351,124.1064 ],
    [ u"ph",u"Mananum",2185,8.833333,124.95 ],
    [ u"ph",u"Manaoag",59115,16.0438,120.4861 ],
    [ u"ph",u"Manapa",3919,8.977778,125.439444 ],
    [ u"ph",u"Manapla",34312,10.958033,123.123004 ],
    [ u"ph",u"Manaring",2114,17.172937,121.902544 ],
    [ u"ph",u"Manatal",2290,14.816667,120.9 ],
    [ u"ph",u"Manat",2679,7.5327,126.0173 ],
    [ u"ph",u"Manaulanan",2231,7.048056,124.619444 ],
    [ u"ph",u"Manaul",3011,12.453,121.4107 ],
    [ u"ph",u"Manay",20336,7.215,126.539722 ],
    [ u"ph",u"Manay",4610,7.341667,125.575 ],
    [ u"ph",u"Mandangoa",2740,8.772778,124.791111 ],
    [ u"ph",u"Mandaon",3539,12.225945,123.28421 ],
    [ u"ph",u"Mandaue",288898,10.323611,123.922222 ],
    [ u"ph",u"Mandih",3420,8.2087,123.0141 ],
    [ u"ph",u"Mandili",4532,15.1595,120.9171 ],
    [ u"ph",u"Mangalcal",3446,7.366111,125.660278 ],
    [ u"ph",u"Mangaldan",88828,16.07,120.4025 ],
    [ u"ph",u"Manga",2433,13.2719,123.4623 ],
    [ u"ph",u"Manga",2211,17.701106,121.862348 ],
    [ u"ph",u"Mangarin",3246,12.351148,121.098013 ],
    [ u"ph",u"Mangas",4911,14.117689,120.866605 ],
    [ u"ph",u"Manggahan",13825,14.294097,120.906867 ],
    [ u"ph",u"Mangga",2247,15.251,120.9089 ],
    [ u"ph",u"Mangile",3020,6.003333,125.683889 ],
    [ u"ph",u"Mangoso",2466,11.4175,122.6382 ],
    [ u"ph",u"Manguiring",3767,13.7341,123.269 ],
    [ u"ph",u"Mangusu",3710,7.323382,122.273978 ],
    [ u"ph",u"Manhoy",2172,11.3534,122.6663 ],
    [ u"ph",u"Manibaug",24618,15.1012,120.5604 ],
    [ u"ph",u"Manicahan",8338,7.018445,122.202219 ],
    [ u"ph",u"Manika",3074,11.388007,122.279307 ],
    [ u"ph",u"Manikling",2444,6.879074,126.060626 ],
    [ u"ph",u"Manila",10443877,14.6042,120.9822 ],
    [ u"ph",u"Maninihon",6150,9.3711,122.8405 ],
    [ u"ph",u"Manito",3008,13.1235,123.8693 ],
    [ u"ph",u"Mankayan",15886,16.8632,120.7829 ],
    [ u"ph",u"Manlilinao",2397,11.1084,124.4991 ],
    [ u"ph",u"Mansalay",23044,12.520435,121.438514 ],
    [ u"ph",u"Mantalongon",2274,10.126,123.5808 ],
    [ u"ph",u"Mantang",2081,11.87,125.428333 ],
    [ u"ph",u"Manticao",7956,8.404167,124.286667 ],
    [ u"ph",u"Mantiquil",2281,9.166667,123.05 ],
    [ u"ph",u"Manuañgan",4422,7.25,124.433333 ],
    [ u"ph",u"Manuangan",4422,7.276944,124.404444 ],
    [ u"ph",u"Manubul",4736,5.4732,120.7986 ],
    [ u"ph",u"Manuel Roxas",4482,6.445278,124.666667 ],
    [ u"ph",u"Manukan",11524,8.5184,123.0933 ],
    [ u"ph",u"Manuk Mangkaw",4981,4.8,119.85 ],
    [ u"ph",u"Maonon",2942,13.036432,123.370741 ],
    [ u"ph",u"Mapalacsiao",5419,15.428552,120.650832 ],
    [ u"ph",u"Mapalad",3353,15.433333,121.1 ],
    [ u"ph",u"Mapanas",3575,12.475018,125.256208 ],
    [ u"ph",u"Mapandan",11166,16.0248,120.4547 ],
    [ u"ph",u"Mapaniqui",4200,15.1043,120.922 ],
    [ u"ph",u"Mapili",2104,11.1081,122.7393 ],
    [ u"ph",u"Mapolopolo",2219,15.9,120.366667 ],
    [ u"ph",u"Mapulo",2828,13.7317,121.1842 ],
    [ u"ph",u"Mapulot",2668,14.033,122.5399 ],
    [ u"ph",u"Maputi",2304,8.449722,124.290556 ],
    [ u"ph",u"Maquiapo",2307,14.9852,120.5589 ],
    [ u"ph",u"Maragondon",22973,14.2733,120.7377 ],
    [ u"ph",u"Maramag",33844,7.763333,125.005278 ],
    [ u"ph",u"Maranding",13694,7.9248,123.7715 ],
    [ u"ph",u"Marantao",3572,7.95,124.233333 ],
    [ u"ph",u"Marao",2245,13.9166,121.8397 ],
    [ u"ph",u"Maravilla",2253,10.9011,123.8918 ],
    [ u"ph",u"Marawa",3812,15.4174,120.8386 ],
    [ u"ph",u"Marawi",143546,7.998611,124.292778 ],
    [ u"ph",u"Marbel",3399,7.115833,124.9125 ],
    [ u"ph",u"Margen",2813,11.017,124.5293 ],
    [ u"ph",u"Margosatubig",14606,7.5777,123.1658 ],
    [ u"ph",u"Maria Aurora",6807,15.7967,121.4737 ],
    [ u"ph",u"Maribojoc",2476,9.7417,123.8446 ],
    [ u"ph",u"Maribong",3308,11.1,122.533333 ],
    [ u"ph",u"Maricaban",2779,11.1516,123.7679 ],
    [ u"ph",u"Marihatag",3829,8.793611,126.296944 ],
    [ u"ph",u"Marintoc",2111,12.285539,123.72281 ],
    [ u"ph",u"Mariroc",4324,13.3449,123.702 ],
    [ u"ph",u"Mariveles",84569,14.4361,120.4857 ],
    [ u"ph",u"Marogong",3785,7.666667,124.15 ],
    [ u"ph",u"Marsada",2571,5.931389,121.106944 ],
    [ u"ph",u"Masaba",2456,10.533333,123.966667 ],
    [ u"ph",u"Masaguisi",2481,12.75452,121.448415 ],
    [ u"ph",u"Masaling",3829,9.9818,122.5369 ],
    [ u"ph",u"Masalipit",2532,15.1481,121.0373 ],
    [ u"ph",u"Masalukot",10667,13.983333,121.416667 ],
    [ u"ph",u"Masapang",4579,14.1843,121.3367 ],
    [ u"ph",u"Masarawag",3725,13.2268,123.6148 ],
    [ u"ph",u"Masarayao",2085,11.089722,124.6175 ],
    [ u"ph",u"Masaya",5524,16.5013,121.747 ],
    [ u"ph",u"Masaya",7587,14.1434,121.2733 ],
    [ u"ph",u"Masiga",2668,13.3607,121.8278 ],
    [ u"ph",u"Masinloc",28041,15.5363,119.9502 ],
    [ u"ph",u"Maslog",3641,13.1046,123.7713 ],
    [ u"ph",u"Masoli",2601,13.3593,123.3898 ],
    [ u"ph",u"Matabao",3570,8.957222,125.399444 ],
    [ u"ph",u"Matabungkay",3718,13.952255,120.619813 ],
    [ u"ph",u"Matacon",3976,13.3284,123.4356 ],
    [ u"ph",u"Matagbak",2893,14.130556,120.834722 ],
    [ u"ph",u"Matala",2597,13.8287,121.1549 ],
    [ u"ph",u"Matalom",4335,10.283056,124.787778 ],
    [ u"ph",u"Matangad",2825,8.576944,124.37 ],
    [ u"ph",u"Mataya",3136,7.471111,124.371944 ],
    [ u"ph",u"Matayumtayum",2730,15.5166,120.7098 ],
    [ u"ph",u"Mataywanac",2375,14.0311,120.7296 ],
    [ u"ph",u"Matiao",2814,7.0828,125.9362 ],
    [ u"ph",u"Maticmatic",3552,15.987,120.4544 ],
    [ u"ph",u"Mati",71832,6.955081,126.216552 ],
    [ u"ph",u"Matingain",4130,13.912901,120.880058 ],
    [ u"ph",u"Matiompong",2317,6.681667,124.576944 ],
    [ u"ph",u"Matlang",5840,10.8902,124.4554 ],
    [ u"ph",u"Matnog",2822,14.066667,122.933333 ],
    [ u"ph",u"Matnog",6720,12.5878,124.0875 ],
    [ u"ph",u"Matti",4796,6.770556,125.308611 ],
    [ u"ph",u"Maturanoc",4912,15.6571,120.7921 ],
    [ u"ph",u"Mauboh",2561,5.99,121.093611 ],
    [ u"ph",u"Maugat",2613,13.85,121.3 ],
    [ u"ph",u"Maujao",2310,12.290151,121.300712 ],
    [ u"ph",u"Maulawin",6822,14.2674,121.4564 ],
    [ u"ph",u"Mauraro",3753,13.1494,123.5953 ],
    [ u"ph",u"Mauswagon",3126,8.600833,124.411944 ],
    [ u"ph",u"Mawab",14446,7.5092,125.9189 ],
    [ u"ph",u"Maxingal",2323,18.214877,121.668152 ],
    [ u"ph",u"Mayabon",6521,9.0961,123.1738 ],
    [ u"ph",u"Maya",7572,11.2743,124.0579 ],
    [ u"ph",u"Mayana",2305,9.7427,124.3438 ],
    [ u"ph",u"Mayantoc",6250,15.6199,120.377 ],
    [ u"ph",u"Mayaposi",2538,9.6241,123.0188 ],
    [ u"ph",u"Maydolong",5492,11.499167,125.501111 ],
    [ u"ph",u"Maygatasan",4014,8.709444,125.718333 ],
    [ u"ph",u"Mayo",2829,7.002105,126.331983 ],
    [ u"ph",u"Mayorga",2721,10.9,125 ],
    [ u"ph",u"Maypangdan",2342,11.651944,125.450278 ],
    [ u"ph",u"Medellin",11741,11.1286,123.9622 ],
    [ u"ph",u"Medina",9201,8.912222,125.024444 ],
    [ u"ph",u"Mendez",22081,14.128611,120.905833 ],
    [ u"ph",u"Mercedes",16991,14.1093,123.0109 ],
    [ u"ph",u"Mercedes",2463,10.6686,124.4021 ],
    [ u"ph",u"Mercedes",8730,6.958611,122.148333 ],
    [ u"ph",u"Merida",3570,10.9098,124.5376 ],
    [ u"ph",u"Meycauayan",184838,14.7328,120.96 ],
    [ u"ph",u"Miaga",2149,12.2376,123.8167 ],
    [ u"ph",u"Mianay",3042,11.4716,122.7011 ],
    [ u"ph",u"Miaray",3190,7.574722,125.044444 ],
    [ u"ph",u"Midsalip",4069,8.0552,123.214 ],
    [ u"ph",u"Midsayap",32932,7.190833,124.530278 ],
    [ u"ph",u"Miglamin",2633,8.051944,125.261667 ],
    [ u"ph",u"Milagros",6009,12.218145,123.50951 ],
    [ u"ph",u"Milaor",8809,13.5961,123.1772 ],
    [ u"ph",u"Mileb",2758,6.898611,124.583889 ],
    [ u"ph",u"Minalabac",4724,13.5687,123.1838 ],
    [ u"ph",u"Minalin",13528,14.9676,120.6828 ],
    [ u"ph",u"Minallo",2490,16.986849,121.853942 ],
    [ u"ph",u"Mina",2665,10.9313,122.5745 ],
    [ u"ph",u"Minanga",2111,17.762603,121.727649 ],
    [ u"ph",u"Minanga",2191,17.451221,121.787246 ],
    [ u"ph",u"Minante",6697,16.898455,121.762842 ],
    [ u"ph",u"Minapan",3055,6.815,124.858611 ],
    [ u"ph",u"Minapasuk",6885,10.69885,123.349002 ],
    [ u"ph",u"Mindupok",3437,6.090556,124.423333 ],
    [ u"ph",u"Minglanilla",62058,10.24498,123.7964 ],
    [ u"ph",u"Minien",6111,15.9703,120.4786 ],
    [ u"ph",u"Minolos",2355,10.1019,123.4727 ],
    [ u"ph",u"Minoyan",7771,10.513664,123.104902 ],
    [ u"ph",u"Minuri",2546,16.4746,121.8394 ],
    [ u"ph",u"Miranda",8040,10.3047,122.8778 ],
    [ u"ph",u"Moalboal",6831,9.943333,123.399167 ],
    [ u"ph",u"Mobo",3750,12.3363,123.6574 ],
    [ u"ph",u"Mogpog",3192,13.474444,121.861389 ],
    [ u"ph",u"Molave",21089,8.0844,123.491 ],
    [ u"ph",u"Molugan",8042,8.5375,124.562222 ],
    [ u"ph",u"Monamon",5371,16.8833,120.8833 ],
    [ u"ph",u"Monbon",3408,12.7307,124.0189 ],
    [ u"ph",u"Monching",4393,7.737778,122.833889 ],
    [ u"ph",u"Mondragon",5198,12.5157,124.7523 ],
    [ u"ph",u"Monpon",2189,10.911944,122.637778 ],
    [ u"ph",u"Monreal",4759,12.644,123.6648 ],
    [ u"ph",u"Montalban",134436,14.7314,121.1417 ],
    [ u"ph",u"Montecillo",3289,13.889444,121.477778 ],
    [ u"ph",u"Montevista",10146,7.693333,125.988889 ],
    [ u"ph",u"Montilla",3558,10.2027,122.9261 ],
    [ u"ph",u"Moog",5197,8.601111,124.465833 ],
    [ u"ph",u"Morales",2600,11.5456,122.3764 ],
    [ u"ph",u"Moriones",2916,15.460751,120.466432 ],
    [ u"ph",u"Morobuan",2442,10.625658,122.554703 ],
    [ u"ph",u"Morong",16117,14.678889,120.266111 ],
    [ u"ph",u"Morong",49589,14.5115,121.2393 ],
    [ u"ph",u"Motiong",2507,11.78,124.999722 ],
    [ u"ph",u"Motrico",2947,15.413553,120.676532 ],
    [ u"ph",u"Mozzozzin",2559,17.45,121.75 ],
    [ u"ph",u"Muladbucad",3988,13.2389,123.6057 ],
    [ u"ph",u"Mulanay",7643,13.522222,122.404167 ],
    [ u"ph",u"Munai",2113,7.975833,124.063611 ],
    [ u"ph",u"Mungo",4591,17.721108,121.471248 ],
    [ u"ph",u"Muñoz",5198,17.15754,121.613544 ],
    [ u"ph",u"Murcia",5138,15.404254,120.609032 ],
    [ u"ph",u"Muti",2308,7.272669,122.283686 ],
    [ u"ph",u"Muzon",4301,13.852598,120.989345 ],
    [ u"ph",u"Naawan",3643,8.434444,124.288889 ],
    [ u"ph",u"Nabannagan",3596,18.071486,121.533751 ],
    [ u"ph",u"Nabulao",7059,9.6616,122.4577 ],
    [ u"ph",u"Naga",147115,13.6232,123.1841 ],
    [ u"ph",u"Naga",8461,7.770278,122.750833 ],
    [ u"ph",u"Nagas",2785,13.4357,123.6781 ],
    [ u"ph",u"Nagbacalan",2778,18.0892,120.6005 ],
    [ u"ph",u"Nagbalaye",5108,9.2492,122.8759 ],
    [ u"ph",u"Nagcarlan",24560,14.1364,121.4165 ],
    [ u"ph",u"Naghalin",2977,11.1456,124.5671 ],
    [ u"ph",u"Nagpandayan",3140,15.5997,120.766 ],
    [ u"ph",u"Nagsabaran",2533,16.666667,120.333333 ],
    [ u"ph",u"Nagsaing",7482,15.976,120.3419 ],
    [ u"ph",u"Nagtipunan",5682,16.216667,121.6 ],
    [ u"ph",u"Naguelguel",3124,16.0053,120.2635 ],
    [ u"ph",u"Naguilayan",3777,16.0023,120.2903 ],
    [ u"ph",u"Naguilayan",3777,15.9635,120.3234 ],
    [ u"ph",u"Naguilian",8560,17.023147,121.837043 ],
    [ u"ph",u"Naguilian",9691,16.533889,120.396667 ],
    [ u"ph",u"Nahawan",2226,9.9711,124.0484 ],
    [ u"ph",u"Naile",2221,11.7666,122.1765 ],
    [ u"ph",u"Nailon",5379,11.0537,124.0385 ],
    [ u"ph",u"Naisud",2499,11.8058,122.1939 ],
    [ u"ph",u"Nalsian",3157,15.8383,120.453 ],
    [ u"ph",u"Nalundan",9674,9.75,123.066667 ],
    [ u"ph",u"Nalus",3920,6.012222,124.585278 ],
    [ u"ph",u"Nalvo",2324,16.8459,120.3506 ],
    [ u"ph",u"Nama",2355,16.1412,120.5426 ],
    [ u"ph",u"Nambalan",2265,15.6008,120.4594 ],
    [ u"ph",u"Namboongan",2329,16.3033,120.3758 ],
    [ u"ph",u"Nampicuan",6058,15.7314,120.625 ],
    [ u"ph",u"Namuac",3037,18.610905,121.165699 ],
    [ u"ph",u"Nancalabasaan",2139,15.9342,120.8426 ],
    [ u"ph",u"Nancamarinan",3565,15.6752,120.5364 ],
    [ u"ph",u"Nanca",2666,10.85564,123.035904 ],
    [ u"ph",u"Nangalisan",2297,16.4,120.55 ],
    [ u"ph",u"Nangan",3362,6.472645,126.124382 ],
    [ u"ph",u"Nangka",4348,10.5324,123.7195 ],
    [ u"ph",u"Nangka",6580,10.55,123.966667 ],
    [ u"ph",u"Nangka",9708,9.4023,122.8244 ],
    [ u"ph",u"Nanyo",3236,7.325278,125.644444 ],
    [ u"ph",u"Napaliran",2284,8.775278,124.802222 ],
    [ u"ph",u"Napnapan",3258,10.708453,122.393004 ],
    [ u"ph",u"Napoles",5440,10.504,122.8979 ],
    [ u"ph",u"Napuro",2507,12.0273,124.7082 ],
    [ u"ph",u"Narauis",2233,10.2453,122.8869 ],
    [ u"ph",u"Naro",2977,11.896972,123.673922 ],
    [ u"ph",u"Narvacan",3019,17.4175,120.4753 ],
    [ u"ph",u"Nasipit",9407,8.969167,125.294722 ],
    [ u"ph",u"Nasunogan",2564,11.3686,122.6753 ],
    [ u"ph",u"Natappian",11867,17.6745,121.7066 ],
    [ u"ph",u"Natividad",5828,16.0443,120.7987 ],
    [ u"ph",u"Nato",5583,13.6105,123.5356 ],
    [ u"ph",u"Nato",3548,10.1492,122.8619 ],
    [ u"ph",u"Natubleng",2145,16.696474,120.780541 ],
    [ u"ph",u"Natulongan",3165,7.531667,125.023611 ],
    [ u"ph",u"Naval",12217,11.5612,124.3952 ],
    [ u"ph",u"Navatat",2493,15.8536,120.3804 ],
    [ u"ph",u"Navotas",3220,14.4167,121.2268 ],
    [ u"ph",u"Nena",2276,11.765833,125.417778 ],
    [ u"ph",u"Nenita",2551,12.491667,124.804444 ],
    [ u"ph",u"New Agutaya",2464,10.561389,119.307778 ],
    [ u"ph",u"New Baclayon",3804,6.584167,125.369444 ],
    [ u"ph",u"New Bohol",3749,7.5233,125.8363 ],
    [ u"ph",u"New Cebu",2895,7.095278,125.033611 ],
    [ u"ph",u"New Corella",20574,7.5866,125.8237 ],
    [ u"ph",u"New Guinlo",3676,10.8009,119.4383 ],
    [ u"ph",u"New Iloilo",3707,6.547778,124.789722 ],
    [ u"ph",u"New Lagao",2223,6.702778,124.641389 ],
    [ u"ph",u"New Leyte",2788,7.5,125.75 ],
    [ u"ph",u"New Lucena",3059,10.8794,122.5967 ],
    [ u"ph",u"New Panay",3151,6.758611,124.589167 ],
    [ u"ph",u"New Sibonga",2310,7.5609,125.9298 ],
    [ u"ph",u"New Visayas",14758,7.523333,125.623333 ],
    [ u"ph",u"New Washington",5731,11.6508,122.4322 ],
    [ u"ph",u"Nibaliw",13630,16.1275,120.4027 ],
    [ u"ph",u"Nieves",8617,15.3274,120.9485 ],
    [ u"ph",u"Nilombot",7605,16.0052,120.4202 ],
    [ u"ph",u"Niugan",4014,14.95,120.966667 ],
    [ u"ph",u"Norala",12750,6.5225,124.659167 ],
    [ u"ph",u"Novallas",5525,9.5117,123.1225 ],
    [ u"ph",u"Noveleta",37299,14.42922,120.87989 ],
    [ u"ph",u"Nueva Fuerza",2191,9.8464,124.167 ],
    [ u"ph",u"Nueva Valencia",2681,10.510767,122.531503 ],
    [ u"ph",u"Nueva Vida",3058,9.7846,124.1745 ],
    [ u"ph",u"Nuing",2610,5.632778,125.435278 ],
    [ u"ph",u"Nuling",2989,6.659845,124.099811 ],
    [ u"ph",u"Nunguan",2584,7.114167,124.686389 ],
    [ u"ph",u"Nuyo",2224,7.418056,124.410833 ],
    [ u"ph",u"Oaqui",2304,16.8512,120.4102 ],
    [ u"ph",u"Obando",59924,14.7098,120.9362 ],
    [ u"ph",u"Obong",5576,9.741,123.5098 ],
    [ u"ph",u"Ocampo",2841,13.5594,123.3761 ],
    [ u"ph",u"Ocaña",13898,10.0656,123.6244 ],
    [ u"ph",u"Ochando",2615,11.6139,122.4833 ],
    [ u"ph",u"Odicon",2439,13.53,123.0588 ],
    [ u"ph",u"Odiongan",4151,8.845833,125.166389 ],
    [ u"ph",u"Odiongan",6077,12.401667,121.991944 ],
    [ u"ph",u"Odiong",2873,11.5356,122.4666 ],
    [ u"ph",u"Odiong",3346,12.5931,121.5032 ],
    [ u"ph",u"Odiong",4668,10.2858,123.0526 ],
    [ u"ph",u"Ogod",2948,12.9009,123.617 ],
    [ u"ph",u"Okiot",3370,9.566667,123.166667 ],
    [ u"ph",u"Okoy",3099,11.1716,123.7948 ],
    [ u"ph",u"Olea",2434,15.866667,120.5 ],
    [ u"ph",u"Olingan",7806,8.5381,123.3216 ],
    [ u"ph",u"Olongapo",219999,14.8373,120.2868 ],
    [ u"ph",u"Olo",3468,15.766667,120.316667 ],
    [ u"ph",u"Olutanga",7133,7.310556,122.846389 ],
    [ u"ph",u"Omaganhan",2032,11.3292,124.377 ],
    [ u"ph",u"Ondoy",2041,11.819167,122.126111 ],
    [ u"ph",u"Opol",3468,8.521389,124.571111 ],
    [ u"ph",u"Oracon",2045,10.4782,122.5839 ],
    [ u"ph",u"Oras",9022,12.1406,125.4397 ],
    [ u"ph",u"Orion",46991,14.620556,120.581667 ],
    [ u"ph",u"Ormoc",92345,11.006389,124.6075 ],
    [ u"ph",u"Orong",6772,9.9373,122.829 ],
    [ u"ph",u"Oroquieta",39279,8.4859,123.8048 ],
    [ u"ph",u"Osiao",2737,13.0914,123.9811 ],
    [ u"ph",u"Osias",3225,7.6,124.816667 ],
    [ u"ph",u"Oslob",3724,9.5211,123.4315 ],
    [ u"ph",u"Osmeña",2915,12.7315,123.3318 ],
    [ u"ph",u"Osmeña",4866,10.520833,119.925833 ],
    [ u"ph",u"Otavi",2833,12.6417,123.9092 ],
    [ u"ph",u"Owak",3202,10.55,123.7 ],
    [ u"ph",u"Ozamiz",93083,8.1481,123.8405 ],
    [ u"ph",u"Paagahan",3621,14.4447,121.401 ],
    [ u"ph",u"Paatan",4526,7.075278,124.95 ],
    [ u"ph",u"Paclolo",2346,12.376746,121.173513 ],
    [ u"ph",u"Pacol",19839,10.4717,122.8323 ],
    [ u"ph",u"Padada",11439,6.641111,125.345 ],
    [ u"ph",u"Padang",2187,13.2196,123.7655 ],
    [ u"ph",u"Padapada",3016,15.5517,120.5163 ],
    [ u"ph",u"Paddaya",3228,18.307671,121.782953 ],
    [ u"ph",u"Padong",3361,18.052222,120.756667 ],
    [ u"ph",u"Padre Garcia",4304,13.8791,121.2139 ],
    [ u"ph",u"Padre Zamora",2271,10.066667,123.25 ],
    [ u"ph",u"Paete",26855,14.3647,121.4829 ],
    [ u"ph",u"Pagadian",132578,7.8257,123.437 ],
    [ u"ph",u"Pagalungan",2936,6.235278,125.041944 ],
    [ u"ph",u"Pagangan",2560,7.114444,124.595278 ],
    [ u"ph",u"Pag-asa",3507,7.575556,125.683889 ],
    [ u"ph",u"Pagatin",3079,6.973056,124.475278 ],
    [ u"ph",u"Pagsabangan",4284,7.481111,125.749444 ],
    [ u"ph",u"Pagsañgahan",13572,13.215833,122.543056 ],
    [ u"ph",u"Pagsanjan",4279,14.2732,121.4552 ],
    [ u"ph",u"Pagudpud",4945,18.5616,120.7868 ],
    [ u"ph",u"Paiisa",4275,13.925,121.356111 ],
    [ u"ph",u"Paitan",2586,15.833333,120.733333 ],
    [ u"ph",u"Paitan",2826,16.085316,120.031636 ],
    [ u"ph",u"Pajo",3051,11.2306,124.0138 ],
    [ u"ph",u"Pakiad",2689,10.7,122.466667 ],
    [ u"ph",u"Pakil",10693,14.3835,121.4786 ],
    [ u"ph",u"Palacpalac",2956,16.1312,120.5305 ],
    [ u"ph",u"Palagao",2953,18.043187,121.699051 ],
    [ u"ph",u"Palahanan",3404,13.833333,121.366667 ],
    [ u"ph",u"Palampas",9036,10.525062,123.420802 ],
    [ u"ph",u"Palanas",2690,12.1458,123.9216 ],
    [ u"ph",u"Palangue",9567,14.284167,120.811389 ],
    [ u"ph",u"Palanit",3358,12.32134,124.343413 ],
    [ u"ph",u"Palapag",8342,12.5458,125.1147 ],
    [ u"ph",u"Palarao",2409,11.4056,124.483 ],
    [ u"ph",u"Palauig",2944,15.435,119.9045 ],
    [ u"ph",u"Palayan",23742,15.5415,121.0848 ],
    [ u"ph",u"Paldit",3664,16.17,120.5276 ],
    [ u"ph",u"Palguyod",3230,16.1227,120.52 ],
    [ u"ph",u"Palhi",2185,10.6498,124.8062 ],
    [ u"ph",u"Palian",2861,6.373889,124.910556 ],
    [ u"ph",u"Palimbang",4858,6.210556,124.189444 ],
    [ u"ph",u"Palkan",3591,6.296389,125.031667 ],
    [ u"ph",u"Palma Gil",4894,7.642222,125.629167 ],
    [ u"ph",u"Palompon",12087,11.0508,124.3843 ],
    [ u"ph",u"Palo",17534,11.1575,124.990833 ],
    [ u"ph",u"Palsong",4566,13.4248,123.2963 ],
    [ u"ph",u"Paluan",4549,13.416,120.4623 ],
    [ u"ph",u"Palusapis",2443,15.6796,120.8614 ],
    [ u"ph",u"Pamantingan",2776,6.704444,124.458889 ],
    [ u"ph",u"Pamatawan",2849,14.927786,120.213628 ],
    [ u"ph",u"Pambisan",2844,13.013703,121.412816 ],
    [ u"ph",u"Pambuhan",2526,13.9736,123.0837 ],
    [ u"ph",u"Pambujan",10812,12.5642,124.9276 ],
    [ u"ph",u"Pamplona",4884,13.5916,123.0816 ],
    [ u"ph",u"Pamplona",11772,9.4724,123.1192 ],
    [ u"ph",u"Panabuan",2528,5.9616,120.9627 ],
    [ u"ph",u"Panacan",10526,9.246271,118.408198 ],
    [ u"ph",u"Panadtaban",2324,6.900833,124.642778 ],
    [ u"ph",u"Panalingaan",2973,8.784167,117.423056 ],
    [ u"ph",u"Panalipan",2679,10.648333,124.021667 ],
    [ u"ph",u"Panan",2294,15.2134,120.0272 ],
    [ u"ph",u"Panayakan",2298,11.7603,122.2236 ],
    [ u"ph",u"Panay",3048,11.557778,122.794167 ],
    [ u"ph",u"Pan-ay",2160,8.219167,123.840278 ],
    [ u"ph",u"Panay",4134,6.497778,124.638333 ],
    [ u"ph",u"Panaytayon",2574,9.95,123.983333 ],
    [ u"ph",u"Pance",4070,15.6885,120.6201 ],
    [ u"ph",u"Pancol",2261,10.8715,119.4157 ],
    [ u"ph",u"Pandacaqui",28603,15.1835,120.6455 ],
    [ u"ph",u"Pandakan",3161,5.988889,121.165833 ],
    [ u"ph",u"Pandan Niog",3192,6.2282,120.5631 ],
    [ u"ph",u"Pandanon",2201,10.556961,123.147502 ],
    [ u"ph",u"Pandan",2330,13.7421,123.0815 ],
    [ u"ph",u"Pandan",2332,9.2388,124.7278 ],
    [ u"ph",u"Pandan",5093,14.0453,124.1694 ],
    [ u"ph",u"Pandi",34928,14.865,120.957222 ],
    [ u"ph",u"Pando",2560,15.393954,120.684731 ],
    [ u"ph",u"Pangabuan",2098,8.056944,123.695833 ],
    [ u"ph",u"Pangal",2710,16.6176,121.6631 ],
    [ u"ph",u"Panganiban",2698,16.0075,120.7752 ],
    [ u"ph",u"Pangao",2314,13.9179,121.1246 ],
    [ u"ph",u"Pangapisan",2602,16.216,119.957 ],
    [ u"ph",u"Pangascasan",2644,16.116914,120.086637 ],
    [ u"ph",u"Pangdan",4063,10.230781,123.7379 ],
    [ u"ph",u"Pangdan",2597,11.744444,124.916667 ],
    [ u"ph",u"Panggulayan",2737,13.039801,121.447916 ],
    [ u"ph",u"Pangian",4001,6.462778,125.545278 ],
    [ u"ph",u"Pangil",19726,14.4008,121.4685 ],
    [ u"ph",u"Panglao",6853,9.578056,123.745833 ],
    [ u"ph",u"Pañgobilian",7178,8.801111,117.859444 ],
    [ u"ph",u"Pang",2563,5.94837,121.288297 ],
    [ u"ph",u"Pangpang",2021,12.5692,125.074 ],
    [ u"ph",u"Pangpang",2592,15.9395,120.3099 ],
    [ u"ph",u"Panguiranan",2744,12.069856,123.318509 ],
    [ u"ph",u"Pangyan",5261,5.700833,125.281111 ],
    [ u"ph",u"Panikian",2878,7.010705,126.024183 ],
    [ u"ph",u"Panikian",2103,9.329354,125.9338 ],
    [ u"ph",u"Panikihan",2424,13.9083,122.131 ],
    [ u"ph",u"Panique",4375,12.4532,123.3821 ],
    [ u"ph",u"Panique",2690,12.479722,122.015278 ],
    [ u"ph",u"Panitan",5156,11.466,122.7725 ],
    [ u"ph",u"Panitian",7258,9.0965,118.0864 ],
    [ u"ph",u"Panlaitan",2596,12.11907,119.848612 ],
    [ u"ph",u"Panlinlang",2539,15.166667,120.7 ],
    [ u"ph",u"Pansol",6380,13.8866,121.2432 ],
    [ u"ph",u"Pansoy",5728,13.181771,122.599889 ],
    [ u"ph",u"Pantabangan",5956,15.8113,121.1443 ],
    [ u"ph",u"Pantao",6864,13.1944,123.3271 ],
    [ u"ph",u"Pantay",5791,14.1175,121.121111 ],
    [ u"ph",u"Pantihan",5182,14.245556,120.794722 ],
    [ u"ph",u"Pantubig",39285,14.968056,120.954722 ],
    [ u"ph",u"Panubigan",2110,7.4281,123.3466 ],
    [ u"ph",u"Panugnawan",2154,11.1619,124.005 ],
    [ u"ph",u"Panukulan",2836,14.933711,121.816847 ],
    [ u"ph",u"Paoay",3284,18.0616,120.5221 ],
    [ u"ph",u"Paolbo",3447,13.7136,123.2496 ],
    [ u"ph",u"Paombong",41384,14.831111,120.789167 ],
    [ u"ph",u"Papaya",32874,15.350755,121.047731 ],
    [ u"ph",u"Paracale",8290,14.2804,122.7881 ],
    [ u"ph",u"Paracelis",4232,17.266667,121.466667 ],
    [ u"ph",u"Paradahan",8977,14.32335,120.86046 ],
    [ u"ph",u"Paraiso",4152,6.473611,124.810833 ],
    [ u"ph",u"Paraiso",30494,10.8849,123.3627 ],
    [ u"ph",u"Parangan",2432,5.083889,119.938333 ],
    [ u"ph",u"Parang",2728,14.6331,120.4493 ],
    [ u"ph",u"Parang",44930,7.370351,124.269733 ],
    [ u"ph",u"Parang",9681,5.9137,120.9056 ],
    [ u"ph",u"Parang",3491,9.281491,125.942075 ],
    [ u"ph",u"Parian Dakula",4005,5.556667,120.771944 ],
    [ u"ph",u"Parian",2889,11.4526,122.687 ],
    [ u"ph",u"Paringao",6570,16.571667,120.324167 ],
    [ u"ph",u"Parioc",2718,17.166667,120.466667 ],
    [ u"ph",u"Parista",3515,15.8536,120.9282 ],
    [ u"ph",u"Parubcan",4491,13.7088,123.745 ],
    [ u"ph",u"Pasacao",10531,13.5118,123.0426 ],
    [ u"ph",u"Pasian",4291,7.928056,126.067222 ],
    [ u"ph",u"Pasibi",3201,15.8456,120.3684 ],
    [ u"ph",u"Pasil",10109,17.3881,121.1492 ],
    [ u"ph",u"Pasong Kawayan",7031,14.347449,120.870513 ],
    [ u"ph",u"Pastrana",2730,11.136667,124.885556 ],
    [ u"ph",u"Pasuquin",5768,18.3328,120.6177 ],
    [ u"ph",u"Patabog",3149,13.4432,122.4557 ],
    [ u"ph",u"Patac",2553,16.2783,120.4011 ],
    [ u"ph",u"Patao",5997,11.2202,123.6925 ],
    [ u"ph",u"Pata",2224,17.7152,121.5018 ],
    [ u"ph",u"Patawag",2279,8.106389,122.620833 ],
    [ u"ph",u"Patayac",2497,15.963,120.4318 ],
    [ u"ph",u"Paticui",2742,10.237,122.8993 ],
    [ u"ph",u"Patin-ay",7263,8.550556,125.937222 ],
    [ u"ph",u"Patindeguen",2112,7.219722,124.498333 ],
    [ u"ph",u"Patnanungan",6901,14.783333,122.183333 ],
    [ u"ph",u"Patnongon",5810,10.9132,121.9937 ],
    [ u"ph",u"Pato-o",2949,12.430556,122.064722 ],
    [ u"ph",u"Patpata",2567,17.183333,120.433333 ],
    [ u"ph",u"Patria",2463,11.7403,122.0171 ],
    [ u"ph",u"Pattao",3222,18.249274,121.815952 ],
    [ u"ph",u"Patun-an",2509,10.568158,123.472302 ],
    [ u"ph",u"Paulba",2468,13.178754,123.462518 ],
    [ u"ph",u"Pau",2428,15.0279,120.7243 ],
    [ u"ph",u"Pavia",5928,10.776111,122.545556 ],
    [ u"ph",u"Pawak",2555,8.006944,124.244444 ],
    [ u"ph",u"Pawa",2123,13.1335,123.8915 ],
    [ u"ph",u"Pawa",2138,11.565833,122.849167 ],
    [ u"ph",u"Pawican",3159,12.0741,123.9706 ],
    [ u"ph",u"Pawili",2247,13.516667,123.283333 ],
    [ u"ph",u"Pawing",3316,11.18,125.002778 ],
    [ u"ph",u"Payao",9137,10.1769,122.9451 ],
    [ u"ph",u"Payao",9137,10.1785,122.9236 ],
    [ u"ph",u"Payao",4674,7.586667,122.802778 ],
    [ u"ph",u"Payas",3108,15.964,120.4218 ],
    [ u"ph",u"Payo",3839,13.9076,124.3003 ],
    [ u"ph",u"Paypay",2758,11.2152,123.9762 ],
    [ u"ph",u"Payuhan",4519,5.941667,120.901111 ],
    [ u"ph",u"Pedtad",2278,7.160556,124.814444 ],
    [ u"ph",u"Peñablanca",2983,17.624211,121.786647 ],
    [ u"ph",u"Peña",2537,12.089,123.9384 ],
    [ u"ph",u"Peñaranda",27465,15.351155,121.003931 ],
    [ u"ph",u"Perez",4788,14.193151,121.925918 ],
    [ u"ph",u"Perrelos",10971,10.1169,123.6738 ],
    [ u"ph",u"Piape",2543,10.7288,121.9724 ],
    [ u"ph",u"Pias",3788,15.345255,121.074731 ],
    [ u"ph",u"Pias",2853,15.0198,120.5599 ],
    [ u"ph",u"Piat",5958,17.7905,121.478 ],
    [ u"ph",u"Piddig",3508,18.1655,120.7175 ],
    [ u"ph",u"Pidigan",2734,17.57,120.5903 ],
    [ u"ph",u"Pidsandawan",2481,6.932222,124.590833 ],
    [ u"ph",u"Pigkelegan",6083,7.231271,124.324722 ],
    [ u"ph",u"Pila",34383,14.2325,121.3648 ],
    [ u"ph",u"Pilar",17831,14.66,120.565278 ],
    [ u"ph",u"Pilar",2812,9.829,124.3273 ],
    [ u"ph",u"Pilar",9957,11.487,122.9963 ],
    [ u"ph",u"Pilar",2392,9.865,126.099444 ],
    [ u"ph",u"Pilig",2336,17.342778,121.773889 ],
    [ u"ph",u"Pililla",30408,14.4854,121.3062 ],
    [ u"ph",u"Pili",23178,13.5572,123.2735 ],
    [ u"ph",u"Pili",2695,11.1196,123.0147 ],
    [ u"ph",u"Pili",3421,13.066399,121.520317 ],
    [ u"ph",u"Pimbalayan",2143,6.869167,124.6725 ],
    [ u"ph",u"Pinagsibaan",2671,13.838056,121.318889 ],
    [ u"ph",u"Piñahan",3005,15.6266,121.0621 ],
    [ u"ph",u"Pinambaran",3378,15.1704,120.9903 ],
    [ u"ph",u"Pinamopoan",2770,11.314722,124.573889 ],
    [ u"ph",u"Pinamungahan",23068,10.2708,123.5839 ],
    [ u"ph",u"Piñan",4512,8.4815,123.4462 ],
    [ u"ph",u"Piña",2054,10.639557,122.638203 ],
    [ u"ph",u"Pinaring",2247,7.228889,124.310556 ],
    [ u"ph",u"Pinayagan",4498,9.933333,123.933333 ],
    [ u"ph",u"Pindangan",4101,15.860556,120.551389 ],
    [ u"ph",u"Pindasan",5254,7.2838,125.8535 ],
    [ u"ph",u"Pines",3019,8.451,123.8038 ],
    [ u"ph",u"Pinili",2310,17.9517,120.5278 ],
    [ u"ph",u"Pinocawan",4489,10.341175,123.293901 ],
    [ u"ph",u"Pinoma",3305,16.874956,121.713342 ],
    [ u"ph",u"Pinugay",5666,14.5299,121.2561 ],
    [ u"ph",u"Pio Duran",13249,13.029283,123.444956 ],
    [ u"ph",u"Pio",24345,15.0466,120.5181 ],
    [ u"ph",u"Pitogo",2403,10.1214,124.5533 ],
    [ u"ph",u"Pitogo",2643,12.507438,121.090414 ],
    [ u"ph",u"Pitogo",3493,5.888234,121.312154 ],
    [ u"ph",u"Pitogo",7817,13.7838,122.0902 ],
    [ u"ph",u"Pitogo",5973,7.4546,123.3111 ],
    [ u"ph",u"Placer",5969,11.8687,123.9184 ],
    [ u"ph",u"Placer",10443,9.6563,125.6019 ],
    [ u"ph",u"Plaridel",3904,10.5667,124.7645 ],
    [ u"ph",u"Plaridel",2972,8.6214,123.7101 ],
    [ u"ph",u"Plaridel",2842,15.65,121 ],
    [ u"ph",u"Plaridel",2789,9.378604,118.501737 ],
    [ u"ph",u"Plaridel",4216,13.866667,122.016667 ],
    [ u"ph",u"Plaridel",5110,10.8974,123.4894 ],
    [ u"ph",u"Poctol",2237,13.816667,121.433333 ],
    [ u"ph",u"Pogonsili",2214,15.8189,120.2581 ],
    [ u"ph",u"Polahongon",2730,10.5288,124.9694 ],
    [ u"ph",u"Polanco",3817,8.5329,123.3617 ],
    [ u"ph",u"Polangi",2647,12.396667,124.631111 ],
    [ u"ph",u"Polillo",5502,14.716417,121.938103 ],
    [ u"ph",u"Polloc",3140,7.355278,124.220833 ],
    [ u"ph",u"Polomolok",64849,6.221666,125.063982 ],
    [ u"ph",u"Polong",2834,15.9771,120.2009 ],
    [ u"ph",u"Polo",2121,11.5844,122.3122 ],
    [ u"ph",u"Polo",2631,6.264722,125.1125 ],
    [ u"ph",u"Polo",2343,16.1963,119.9491 ],
    [ u"ph",u"Polo",4046,9.4816,123.1802 ],
    [ u"ph",u"Pongol",3421,8.278611,124.748333 ],
    [ u"ph",u"Pongpong",2927,6.4975,125.463333 ],
    [ u"ph",u"Ponong",2513,11.0829,122.6261 ],
    [ u"ph",u"Ponong",2513,11.1185,122.6405 ],
    [ u"ph",u"Ponot",6624,8.452,123.0222 ],
    [ u"ph",u"Ponso",4574,13.291,123.5171 ],
    [ u"ph",u"Pontevedra",3120,11.4812,122.8325 ],
    [ u"ph",u"Pontevedra",7865,10.3746,122.8682 ],
    [ u"ph",u"Pooc",2220,11.152,123.7931 ],
    [ u"ph",u"Porac",2305,15.252,120.0169 ],
    [ u"ph",u"Porais",3075,15.7551,121.0427 ],
    [ u"ph",u"Poro",2621,10.6292,124.4087 ],
    [ u"ph",u"Port Barton",4832,10.475556,119.247222 ],
    [ u"ph",u"Potong",2498,12.336428,125.285207 ],
    [ u"ph",u"Potot",2529,12.203446,123.43191 ],
    [ u"ph",u"Prado",3590,14.866667,120.516667 ],
    [ u"ph",u"Prado",3590,14.8814,120.5176 ],
    [ u"ph",u"Prenza",3731,13.996791,120.654086 ],
    [ u"ph",u"President Roxas",10879,7.154444,125.055833 ],
    [ u"ph",u"Prinza",2907,14.19607,121.136958 ],
    [ u"ph",u"Progreso",3097,13.9083,122.0906 ],
    [ u"ph",u"Prosperidad",4470,10.515963,123.308502 ],
    [ u"ph",u"Pualas",2100,8.017222,123.848056 ],
    [ u"ph",u"Pudoc",2455,17.606667,120.370278 ],
    [ u"ph",u"Puelay",6854,15.885,120.574167 ],
    [ u"ph",u"Puerto Bello",2887,10.9733,124.5351 ],
    [ u"ph",u"Puerto Galera",3274,13.5006,120.9548 ],
    [ u"ph",u"Puerto Princesa",154816,9.739167,118.735278 ],
    [ u"ph",u"Pugo",2354,16.3221,120.467 ],
    [ u"ph",u"Pulangbato",2320,13.7475,121.398611 ],
    [ u"ph",u"Pulilan",77187,14.901667,120.849167 ],
    [ u"ph",u"Pulong Gubat",4697,14.866667,120.9 ],
    [ u"ph",u"Pulong Sampalok",2335,14.9611,121.0609 ],
    [ u"ph",u"Pulong Santol",5591,15.0456,120.5605 ],
    [ u"ph",u"Pulo",3152,14.9136,121.0734 ],
    [ u"ph",u"Pulo",2267,14.714625,121.632929 ],
    [ u"ph",u"Pulungmasle",9278,15.0102,120.5429 ],
    [ u"ph",u"Pulupandan",27361,10.5203,122.8017 ],
    [ u"ph",u"Punang",2533,9.0169,118.0495 ],
    [ u"ph",u"Punao",5997,10.532961,123.434002 ],
    [ u"ph",u"Punay",6099,5.961389,121.198056 ],
    [ u"ph",u"Puncan",4047,15.9071,120.9907 ],
    [ u"ph",u"Pundaguitan",2143,6.361153,126.177781 ],
    [ u"ph",u"Punol",2468,7.05,124.583333 ],
    [ u"ph",u"Punta",3909,8.989722,125.34 ],
    [ u"ph",u"Punta",4435,18.31837,121.755053 ],
    [ u"ph",u"Punta",2577,14.2914,121.3074 ],
    [ u"ph",u"Punta",2934,12.2441,122.0097 ],
    [ u"ph",u"Punta Silum",3613,8.381667,124.269444 ],
    [ u"ph",u"Puntian",2312,8.281111,124.900278 ],
    [ u"ph",u"Pura",6929,15.6248,120.648 ],
    [ u"ph",u"Purikay",2537,6.686143,124.06957 ],
    [ u"ph",u"Puro",4035,17.680833,120.357222 ],
    [ u"ph",u"Puro",5442,12.4713,123.3898 ],
    [ u"ph",u"Putat",3874,10.7858,123.8469 ],
    [ u"ph",u"Putiao",2303,13.0195,123.7148 ],
    [ u"ph",u"Putingkahoy",2577,13.819167,121.307222 ],
    [ u"ph",u"Puting Kahoy",4046,14.2157,121.031 ],
    [ u"ph",u"Putlod",3481,15.3706,120.8675 ],
    [ u"ph",u"Putol",5387,13.9564,120.7507 ],
    [ u"ph",u"Quezon",9485,17.313031,121.606545 ],
    [ u"ph",u"Quezon",18451,15.5512,120.8147 ],
    [ u"ph",u"Quezon",5080,16.5,121.266667 ],
    [ u"ph",u"Quezon",7860,9.241111,118.031389 ],
    [ u"ph",u"Quezon",2198,12.6,123.95 ],
    [ u"ph",u"Quezon",11681,10.436169,123.260401 ],
    [ u"ph",u"Quezon",6805,14.0057,122.1838 ],
    [ u"ph",u"Quibal",2376,17.715905,121.811348 ],
    [ u"ph",u"Quiling",3570,18.068333,120.543889 ],
    [ u"ph",u"Quilo-quilo",7126,13.8638,121.2209 ],
    [ u"ph",u"Quinabigan",2575,12.993604,121.478116 ],
    [ u"ph",u"Quinagaringan",2153,11.1222,122.5875 ],
    [ u"ph",u"Quinapondan",3471,11.158333,125.521944 ],
    [ u"ph",u"Quinarayan",2558,17.4441,120.4722 ],
    [ u"ph",u"Quiniput",3509,7.181876,122.219043 ],
    [ u"ph",u"Quintong",3162,15.9577,120.3113 ],
    [ u"ph",u"Quipot",2764,13.7775,121.396111 ],
    [ u"ph",u"Quipot",2883,11.283333,123 ],
    [ u"ph",u"Quipot",3616,13.931667,121.315833 ],
    [ u"ph",u"Quisao",10989,14.4347,121.3344 ],
    [ u"ph",u"Quitang",2055,13.5513,123.0529 ],
    [ u"ph",u"Ragandang",2216,6.663862,124.120635 ],
    [ u"ph",u"Ragay",9000,13.8183,122.7923 ],
    [ u"ph",u"Rajal",10281,15.4377,120.8712 ],
    [ u"ph",u"Ramon",36307,16.784163,121.535041 ],
    [ u"ph",u"Ramos",15066,15.6653,120.6406 ],
    [ u"ph",u"Ramos",3042,16.6984,121.6136 ],
    [ u"ph",u"Ranao",2112,16.2076,119.8155 ],
    [ u"ph",u"Ransang",3548,8.960278,117.582778 ],
    [ u"ph",u"Rapu-Rapu",4647,13.1866,124.1256 ],
    [ u"ph",u"Rawis",4551,13.3263,123.4177 ],
    [ u"ph",u"Real",2256,15.8085,120.3468 ],
    [ u"ph",u"Real",9163,14.663971,121.604123 ],
    [ u"ph",u"Rebe",4413,7.9076,123.8155 ],
    [ u"ph",u"Rebokon",2494,7.7535,123.4187 ],
    [ u"ph",u"Recodo",2160,11.949144,123.736954 ],
    [ u"ph",u"Recodo",42790,6.952563,121.959541 ],
    [ u"ph",u"Refugio",2289,10.521662,123.444502 ],
    [ u"ph",u"Reina Mercedes",6228,16.985449,121.826642 ],
    [ u"ph",u"Rimos",6670,16.8764,120.3966 ],
    [ u"ph",u"Rio Tuba",8943,8.506126,117.431694 ],
    [ u"ph",u"Rissing",2117,16.8554,120.4142 ],
    [ u"ph",u"Rizal",2836,8.929167,125.398611 ],
    [ u"ph",u"Rizal",2178,11.438,122.8413 ],
    [ u"ph",u"Rizal",2428,10.671389,122.597222 ],
    [ u"ph",u"Rizal",2815,16.7462,121.638 ],
    [ u"ph",u"Rizal",4959,14.1095,121.3913 ],
    [ u"ph",u"Rizal",26200,15.7118,121.1061 ],
    [ u"ph",u"Rizal",2764,12.8864,124.1343 ],
    [ u"ph",u"Rizal",2796,13.8765,121.159 ],
    [ u"ph",u"Rizal",3835,11.176389,124.579444 ],
    [ u"ph",u"Rizal",2428,10.663656,122.590103 ],
    [ u"ph",u"Rizal",3823,10.8807,123.4178 ],
    [ u"ph",u"Rizal",2815,16.7235,121.556 ],
    [ u"ph",u"Rogongon",5530,8.268333,124.338333 ],
    [ u"ph",u"Romblon",15316,12.575127,122.270813 ],
    [ u"ph",u"Rominimbang",2485,7.5,124.3 ],
    [ u"ph",u"Rosario",8180,8.386944,126.003333 ],
    [ u"ph",u"Rosario",2318,11.5832,122.3019 ],
    [ u"ph",u"Rosario",6560,16.2304,120.4863 ],
    [ u"ph",u"Rosario",8965,16.095,120.5627 ],
    [ u"ph",u"Rosario",5563,13.8635,122.2731 ],
    [ u"ph",u"Roxas",14335,12.5835,121.5176 ],
    [ u"ph",u"Roxas",102688,11.585278,122.751111 ],
    [ u"ph",u"Saavedra",2190,9.973889,123.380278 ],
    [ u"ph",u"Sabang",5144,14.6951,120.2507 ],
    [ u"ph",u"Sabang",2563,14.0614,120.708 ],
    [ u"ph",u"Sabang",2803,14.2194,122.9151 ],
    [ u"ph",u"Sabang",2281,13.7218,123.5781 ],
    [ u"ph",u"Sabang",3470,14.305556,120.803611 ],
    [ u"ph",u"Sabang",3212,13.5092,120.9737 ],
    [ u"ph",u"Sabang",4916,12.733333,123.933333 ],
    [ u"ph",u"Sabang",3522,12.0746,124.5414 ],
    [ u"ph",u"Sablan",2456,16.493,120.4954 ],
    [ u"ph",u"Sablig",2482,16.2643,119.9901 ],
    [ u"ph",u"Sadsadan",2842,16.9333,120.8667 ],
    [ u"ph",u"Sadsalan",2276,6.904167,124.607222 ],
    [ u"ph",u"Sadsalan",2276,6.823056,124.622222 ],
    [ u"ph",u"Sagacad",2073,7.686111,123.340556 ],
    [ u"ph",u"Sagada",2830,17.084,120.8996 ],
    [ u"ph",u"Sagana",2298,12.722521,121.486715 ],
    [ u"ph",u"Sagana",2496,15.5689,121.1522 ],
    [ u"ph",u"Sagasa",3952,10.468,122.8939 ],
    [ u"ph",u"Sagay",3256,9.1059,124.7243 ],
    [ u"ph",u"Sagay",71589,10.9427,123.4239 ],
    [ u"ph",u"Sagbayan",4934,9.9144,124.0919 ],
    [ u"ph",u"Sagpon",6849,13.15,123.733333 ],
    [ u"ph",u"Saguday",7464,16.5428,121.5638 ],
    [ u"ph",u"Saguing",5073,6.980278,125.078056 ],
    [ u"ph",u"Sagunto",2082,16.2007,120.5149 ],
    [ u"ph",u"Sagurong",2243,13.7805,122.9594 ],
    [ u"ph",u"Salamanca",4994,10.746546,123.530002 ],
    [ u"ph",u"Salapungan",5928,15.1337,120.929 ],
    [ u"ph",u"Salawagan",6508,7.705278,125.115 ],
    [ u"ph",u"Salay",6427,8.859167,124.789167 ],
    [ u"ph",u"Salaza",4599,15.4541,119.9553 ],
    [ u"ph",u"Salcedo",3603,11.146944,125.665 ],
    [ u"ph",u"Salcedo",4618,12.810516,121.467415 ],
    [ u"ph",u"Salcedo",2182,15.857222,120.6 ],
    [ u"ph",u"Salimbalan",2746,8.274167,124.721944 ],
    [ u"ph",u"Salinas",2506,16.3695,121.0188 ],
    [ u"ph",u"Salingogon",2338,13.4333,123.1923 ],
    [ u"ph",u"Salinungan",8110,16.869057,121.614542 ],
    [ u"ph",u"Salogon",2239,13.6586,123.5225 ],
    [ u"ph",u"Salomague",4238,15.9091,120.229 ],
    [ u"ph",u"Salug",6775,8.114722,122.783333 ],
    [ u"ph",u"Salunayan",2758,7.154444,124.4975 ],
    [ u"ph",u"Salvacion",4904,8.6775,125.699167 ],
    [ u"ph",u"Salvacion",2835,13.066667,123.616667 ],
    [ u"ph",u"Salvacion",2101,13.4633,123.3765 ],
    [ u"ph",u"Salvacion",5565,10.683333,122.616667 ],
    [ u"ph",u"Salvacion",3721,15.8396,120.9159 ],
    [ u"ph",u"Salvacion",2361,12.132869,119.932812 ],
    [ u"ph",u"Salvacion",2835,13.016667,123.6 ],
    [ u"ph",u"Salvacion",2087,8.712778,126.208056 ],
    [ u"ph",u"Salvacion",2519,12.6151,125.039 ],
    [ u"ph",u"Salvacion",6090,7.983333,126.133333 ],
    [ u"ph",u"Salvacion",2554,10.4441,122.5332 ],
    [ u"ph",u"Salvador",4285,7.9042,123.8399 ],
    [ u"ph",u"Samal",43525,7.074444,125.708333 ],
    [ u"ph",u"Samal",29729,14.7683,120.5418 ],
    [ u"ph",u"Samboan",3646,9.4628,123.3001 ],
    [ u"ph",u"Sambulawan",2679,6.883333,124.7 ],
    [ u"ph",u"Sambulawan",4585,6.703889,124.737222 ],
    [ u"ph",u"Samon",2112,15.939722,120.655278 ],
    [ u"ph",u"Sampagar",2207,7.513889,124.955278 ],
    [ u"ph",u"Sampaloc",3023,14.087759,120.970977 ],
    [ u"ph",u"Sampaloc",20157,14.5402,121.3602 ],
    [ u"ph",u"Sampao",5259,6.876667,124.595556 ],
    [ u"ph",u"Sampao",8648,7.593889,125.661111 ],
    [ u"ph",u"Sampiro",2465,13.784167,121.384167 ],
    [ u"ph",u"San Agustin",3982,9.633333,123.783333 ],
    [ u"ph",u"San Agustin",2236,13.574,123.2641 ],
    [ u"ph",u"San Agustin",4808,12.419844,120.989313 ],
    [ u"ph",u"San Agustin",3097,13.277286,121.304818 ],
    [ u"ph",u"San Agustin",3289,14.9724,120.6372 ],
    [ u"ph",u"San Agustin",4258,12.568889,122.131389 ],
    [ u"ph",u"San Agustin",3912,14.933333,120.15 ],
    [ u"ph",u"San Alejandro",3064,15.5497,120.8601 ],
    [ u"ph",u"San Alfonso",3386,7.780278,126.420278 ],
    [ u"ph",u"San Andres",2249,13.2614,123.7795 ],
    [ u"ph",u"San Andres",5527,14.05,121.216667 ],
    [ u"ph",u"San Andres",3329,15.7222,120.778 ],
    [ u"ph",u"San Andres",5527,14.003527,121.151371 ],
    [ u"ph",u"San Andres",5192,13.3227,122.6779 ],
    [ u"ph",u"San Antonio",4374,13.3,123.433333 ],
    [ u"ph",u"San Antonio",2646,10.8,122.45 ],
    [ u"ph",u"San Antonio",2810,17.273232,121.792645 ],
    [ u"ph",u"San Antonio",2929,14.2,121.5 ],
    [ u"ph",u"San Antonio",7250,8.689167,124.741667 ],
    [ u"ph",u"San Antonio",2489,9.3377,123.2372 ],
    [ u"ph",u"San Antonio",26247,15.2462,120.8496 ],
    [ u"ph",u"San Antonio",2488,16.3278,121.1145 ],
    [ u"ph",u"San Antonio",2332,15.1511,120.6886 ],
    [ u"ph",u"San Antonio",3655,16.0846,120.7639 ],
    [ u"ph",u"San Antonio",2325,11.277778,125.010833 ],
    [ u"ph",u"San Antonio",2567,15.286361,120.671631 ],
    [ u"ph",u"San Antonio",2693,12.4129,124.2791 ],
    [ u"ph",u"San Antonio",4374,13.371,123.4202 ],
    [ u"ph",u"San Antonio",2260,13.888889,121.284722 ],
    [ u"ph",u"San Antonio",2355,7.12,125.739722 ],
    [ u"ph",u"San Anton",4911,15.3457,120.9197 ],
    [ u"ph",u"San Aquilino",3151,12.59743,121.486714 ],
    [ u"ph",u"San Basilio",8125,15.0335,120.5837 ],
    [ u"ph",u"San Benito",2549,14.850833,120.4275 ],
    [ u"ph",u"San Benito",2334,9.957778,126.006944 ],
    [ u"ph",u"San Bernardo",2366,17.403824,121.753846 ],
    [ u"ph",u"San Carlos",4644,13.8422,121.2416 ],
    [ u"ph",u"San Carlos",3186,7.959722,125.0775 ],
    [ u"ph",u"San Carlos",2536,15.5448,120.8931 ],
    [ u"ph",u"San Carlos",2623,15.0389,120.7627 ],
    [ u"ph",u"San Carlos",59673,10.484,123.4203 ],
    [ u"ph",u"San Carlos",91673,15.9273,120.347 ],
    [ u"ph",u"San Casimiro",2833,15.55306,120.78083 ],
    [ u"ph",u"San Celestino",2222,13.9258,121.2349 ],
    [ u"ph",u"San Clemente",3019,15.7124,120.359 ],
    [ u"ph",u"San Cristobal",3201,15.56667,120.76667 ],
    [ u"ph",u"Sandayong",3389,10.495833,123.998889 ],
    [ u"ph",u"Sandiat",4910,17.074045,121.665843 ],
    [ u"ph",u"San Diego",3451,14.0422,120.6255 ],
    [ u"ph",u"San Diego",2488,14.1872,121.4867 ],
    [ u"ph",u"San Dionisio",3134,11.271,123.0964 ],
    [ u"ph",u"Sandulot",3641,9.104722,123.019444 ],
    [ u"ph",u"San Eduardo",2164,12.1679,125.4503 ],
    [ u"ph",u"San Enrique",2620,11.0712,122.656 ],
    [ u"ph",u"San Enrique",9818,10.4161,122.8504 ],
    [ u"ph",u"San Eugenio",3719,16.3598,120.357 ],
    [ u"ph",u"San Fabian",2335,15.601,120.9062 ],
    [ u"ph",u"San Felipe",3090,14.0184,122.9295 ],
    [ u"ph",u"San Felipe",3707,15.5014,120.9078 ],
    [ u"ph",u"San Felipe",3801,16.0575,120.6271 ],
    [ u"ph",u"San Felipe",2570,15.816667,120.6 ],
    [ u"ph",u"San Felipe",14981,15.0624,120.0702 ],
    [ u"ph",u"San Fernando",6345,13.5656,123.1453 ],
    [ u"ph",u"San Fernando",23706,10.1624,123.7076 ],
    [ u"ph",u"San Fernando",2136,11.4585,123.2499 ],
    [ u"ph",u"San Fernando",83961,16.618611,120.319444 ],
    [ u"ph",u"San Fernando",6211,12.4833,123.7622 ],
    [ u"ph",u"San Fernando",2084,16.3892,121.1324 ],
    [ u"ph",u"San Fernando",251157,15.0286,120.6898 ],
    [ u"ph",u"San Fernando",3165,10.709,123.0695 ],
    [ u"ph",u"San Francisco",2154,13.316667,123.75 ],
    [ u"ph",u"San Francisco",2901,11.319613,122.050507 ],
    [ u"ph",u"San Francisco",5047,10.16018,124.310984 ],
    [ u"ph",u"San Francisco",8989,10.6461,124.3816 ],
    [ u"ph",u"San Francisco",19570,15.3525,120.8327 ],
    [ u"ph",u"San Francisco",3960,14.956762,120.555161 ],
    [ u"ph",u"San Francisco",2541,12.724722,123.906389 ],
    [ u"ph",u"San Francisco",2676,10.06,125.160556 ],
    [ u"ph",u"San Francisco",2180,15.6287,120.4368 ],
    [ u"ph",u"San Francisco",2903,13.0367,123.7832 ],
    [ u"ph",u"San Francisco",2535,13.898,121.2461 ],
    [ u"ph",u"San Francisco",3016,13.7911,122.2876 ],
    [ u"ph",u"San Francisco",2279,9.528056,125.485556 ],
    [ u"ph",u"San Gabriel",5065,13.566667,123.1 ],
    [ u"ph",u"San Gabriel",4716,16.675556,120.403056 ],
    [ u"ph",u"San Gabriel",2992,15.7634,120.4644 ],
    [ u"ph",u"Sangali",14728,7.067795,122.20231 ],
    [ u"ph",u"Sangat",4608,10.136,123.6896 ],
    [ u"ph",u"Sanghan",2508,9.085556,125.572778 ],
    [ u"ph",u"San Gregorio",3068,14.0297,121.2639 ],
    [ u"ph",u"San Gregorio",3068,14.0486,121.3291 ],
    [ u"ph",u"San Guillermo",3927,16.7254,121.8098 ],
    [ u"ph",u"San Ignacio",6300,7.118896,126.488382 ],
    [ u"ph",u"San Ildefonso",6436,15.1508,120.6724 ],
    [ u"ph",u"San Isidro",2670,8.486389,125.971667 ],
    [ u"ph",u"San Isidro",2363,13.824688,120.944678 ],
    [ u"ph",u"San Isidro",2184,9.916667,123.883333 ],
    [ u"ph",u"San Isidro",4270,8.258333,124.593056 ],
    [ u"ph",u"San Isidro",2563,13.3766,123.513 ],
    [ u"ph",u"San Isidro",2440,10.5508,123.7335 ],
    [ u"ph",u"San Isidro",2199,7.233889,126.5575 ],
    [ u"ph",u"San Isidro",3205,14.1675,121.450833 ],
    [ u"ph",u"San Isidro",2735,10.9629,124.4304 ],
    [ u"ph",u"San Isidro",2307,13.5,120.9025 ],
    [ u"ph",u"San Isidro",4070,15.8346,120.9442 ],
    [ u"ph",u"San Isidro",4061,15.166667,120.65 ],
    [ u"ph",u"San Isidro",3054,12.974167,123.857222 ],
    [ u"ph",u"San Isidro",4061,15.283333,120.683333 ],
    [ u"ph",u"San Isidro",3490,6.462778,124.860833 ],
    [ u"ph",u"San Isidro",3469,13.6325,122.2428 ],
    [ u"ph",u"San Isidro",3404,10.54996,123.471202 ],
    [ u"ph",u"San Isidro",3122,9.5591,125.6768 ],
    [ u"ph",u"San Isidro",3006,8.1098,123.4781 ],
    [ u"ph",u"San Jacinto",7637,12.5677,123.7337 ],
    [ u"ph",u"San Jacinto",10529,16.0726,120.4383 ],
    [ u"ph",u"San Jacinto",2771,15.5446,120.6664 ],
    [ u"ph",u"San Joaquin",3498,14.04695,121.218642 ],
    [ u"ph",u"San Joaquin",4893,10.588,122.1397 ],
    [ u"ph",u"San Joaquin",4497,12.166972,124.430028 ],
    [ u"ph",u"San Jose de Buan",2811,12.0529,125.0251 ],
    [ u"ph",u"San Jose Malino",4979,15.1257,120.6727 ],
    [ u"ph",u"San Jose",2792,13.246291,123.371364 ],
    [ u"ph",u"San Jose",22784,10.745,121.9415 ],
    [ u"ph",u"San Jose",2311,13.85209,120.949507 ],
    [ u"ph",u"San Jose",4847,10.141546,124.307503 ],
    [ u"ph",u"San Jose",6345,7.736667,125.070278 ],
    [ u"ph",u"San Jose",7461,14.983889,120.7775 ],
    [ u"ph",u"San Jose",4533,17.892694,121.87125 ],
    [ u"ph",u"San Jose",7322,13.6993,123.5178 ],
    [ u"ph",u"San Jose",2456,6.1575,125.7075 ],
    [ u"ph",u"San Jose",3771,10.770278,122.533889 ],
    [ u"ph",u"San Jose",5905,17.15,121.6 ],
    [ u"ph",u"San Jose",2258,16.4245,120.3913 ],
    [ u"ph",u"San Jose",3744,10.988889,125.035278 ],
    [ u"ph",u"San Jose",49149,12.455842,121.045913 ],
    [ u"ph",u"San Jose",2335,13.279285,121.356118 ],
    [ u"ph",u"San Jose",2738,8.86,125.051944 ],
    [ u"ph",u"San Jose",7461,15.0169,120.865 ],
    [ u"ph",u"San Jose",2637,8.133611,126.293889 ],
    [ u"ph",u"San Jose",3813,12.5296,124.4875 ],
    [ u"ph",u"San Jose",2844,6.553611,124.639167 ],
    [ u"ph",u"San Jose",6907,6.069816,125.059128 ],
    [ u"ph",u"San Jose",6079,9.7956,118.7483 ],
    [ u"ph",u"San Jose",98670,15.7923,120.9894 ],
    [ u"ph",u"San Jose",3681,10.756345,123.483603 ],
    [ u"ph",u"San Jose",7461,15.0373,120.6946 ],
    [ u"ph",u"San Jose",10607,9.757222,125.666667 ],
    [ u"ph",u"San Jose",2085,7.692222,123.053333 ],
    [ u"ph",u"San Juan de Mata",3131,15.5177,120.566 ],
    [ u"ph",u"San Juan",15416,13.830278,121.400833 ],
    [ u"ph",u"San Juan",2126,13.327,123.3167 ],
    [ u"ph",u"San Juan",2517,17.345556,121.695556 ],
    [ u"ph",u"San Juan",3212,14.05715,121.229309 ],
    [ u"ph",u"San Juan",2096,8.706944,124.867222 ],
    [ u"ph",u"San Juan",3514,14.966667,120.633333 ],
    [ u"ph",u"San Juan",2558,16.0461,120.67 ],
    [ u"ph",u"San Juan",4373,10.266944,125.175556 ],
    [ u"ph",u"San Juan",5034,15.2897,120.0648 ],
    [ u"ph",u"San Juan",2317,12.3568,124.3364 ],
    [ u"ph",u"San Juan",2374,13.4237,123.4261 ],
    [ u"ph",u"San Juan",2056,10.9992,124.5395 ],
    [ u"ph",u"San Juan",2808,10.4524,123.4273 ],
    [ u"ph",u"San Juan",3212,14.0927,121.3003 ],
    [ u"ph",u"San Juan",2642,13.5232,122.5813 ],
    [ u"ph",u"San Juan",2894,10.3865,122.8651 ],
    [ u"ph",u"San Julian",3069,11.753611,125.455833 ],
    [ u"ph",u"Sankanan",3055,8.315556,124.858056 ],
    [ u"ph",u"Sanlibo",2609,15.916667,120.55 ],
    [ u"ph",u"San Lorenzo",2177,18.1323,120.6305 ],
    [ u"ph",u"San Lorenzo",2498,15.4862,119.9622 ],
    [ u"ph",u"San Lucas",2268,13.7062,123.2032 ],
    [ u"ph",u"San Luis",7109,8.478056,125.743889 ],
    [ u"ph",u"San Luis",6357,8.483333,125 ],
    [ u"ph",u"San Luis",2181,7.441389,126.551111 ],
    [ u"ph",u"San Luis",4235,8.878333,125.038889 ],
    [ u"ph",u"San Luis",33467,15.0401,120.7883 ],
    [ u"ph",u"San Luis",2176,16.96455,121.827842 ],
    [ u"ph",u"San Manuel",9865,17.023748,121.635743 ],
    [ u"ph",u"San Manuel",5995,15.491248,120.663932 ],
    [ u"ph",u"San Marcelino",18721,14.974184,120.157329 ],
    [ u"ph",u"San Mariano",12441,16.982648,122.014042 ],
    [ u"ph",u"San Mariano",4781,12.641427,121.437914 ],
    [ u"ph",u"San Martin",3434,8.561111,124.771389 ],
    [ u"ph",u"San Mateo",2090,17.13754,121.745344 ],
    [ u"ph",u"San Mateo",4984,15.2062,120.7983 ],
    [ u"ph",u"San Mateo",134515,14.6982,121.1236 ],
    [ u"ph",u"San Mateo",3791,7.149444,124.583056 ],
    [ u"ph",u"San Miguel",2997,13.874,121.1983 ],
    [ u"ph",u"San Miguel",2375,9.9869,124.3411 ],
    [ u"ph",u"San Miguel",5054,8.03,124.753889 ],
    [ u"ph",u"San Miguel",65661,15.1454,120.9789 ],
    [ u"ph",u"San Miguel",3149,13.3476,123.3848 ],
    [ u"ph",u"San Miguel",2099,11.2146,122.5425 ],
    [ u"ph",u"San Miguel",8438,10.78,122.465556 ],
    [ u"ph",u"San Miguel",2599,14.2013,121.3732 ],
    [ u"ph",u"San Miguel",3401,11.267222,124.8325 ],
    [ u"ph",u"San Miguel",2769,9.2239,123.2853 ],
    [ u"ph",u"San Miguel",2983,8.968889,125.945 ],
    [ u"ph",u"San Miguel",4345,6.489444,124.695278 ],
    [ u"ph",u"San Miguel",2171,10.538562,123.083002 ],
    [ u"ph",u"San Miguel",6061,16.0247,120.3524 ],
    [ u"ph",u"San Miguel",3149,13.4196,123.4082 ],
    [ u"ph",u"San Miguel",3783,10.4154,123.0214 ],
    [ u"ph",u"San Miguel",2875,7.485,125.676389 ],
    [ u"ph",u"San Miguel",4455,10.59606,122.589903 ],
    [ u"ph",u"San Miguel",18582,15.439752,120.597632 ],
    [ u"ph",u"San Miguel",2657,7.648333,123.2675 ],
    [ u"ph",u"San Narciso",15635,15.0143,120.0803 ],
    [ u"ph",u"San Narciso",11118,13.5677,122.5667 ],
    [ u"ph",u"San Nicolas",2340,13.928252,120.951001 ],
    [ u"ph",u"San Nicolas",11155,14.983333,120.633333 ],
    [ u"ph",u"San Nicolas",2364,11.3213,122.5184 ],
    [ u"ph",u"San Nicolas",19898,18.15,120.633333 ],
    [ u"ph",u"San Nicolas",2396,10.684444,122.495556 ],
    [ u"ph",u"San Nicolas",11155,14.8915,120.7062 ],
    [ u"ph",u"San Nicolas",3514,16.0703,120.7624 ],
    [ u"ph",u"San Nicolas",9526,15.5841,120.6765 ],
    [ u"ph",u"San Nicolas",2844,14.949086,120.077029 ],
    [ u"ph",u"San Nicolas",11155,15.0168,120.7017 ],
    [ u"ph",u"San Pablo",2169,14.9696,120.6197 ],
    [ u"ph",u"San Pablo",207572,14.0683,121.3256 ],
    [ u"ph",u"San Pablo",8046,10.893937,123.144304 ],
    [ u"ph",u"San Pablo",3346,7.656389,123.460833 ],
    [ u"ph",u"San Pascual",39395,13.7975,121.034167 ],
    [ u"ph",u"San Pascual",3351,9.9538,124.4287 ],
    [ u"ph",u"San Pascual",5939,13.129722,122.979167 ],
    [ u"ph",u"San Pascual",2467,15.509167,120.668056 ],
    [ u"ph",u"San Patricio",3647,15.0953,120.7295 ],
    [ u"ph",u"San Pedro Apartado",3331,15.835278,120.566111 ],
    [ u"ph",u"San Pedro",5026,10.8018,121.9499 ],
    [ u"ph",u"San Pedro",4010,14.053407,121.145358 ],
    [ u"ph",u"San Pedro",4079,7.341944,126.5175 ],
    [ u"ph",u"San Pedro",3027,17.2,121.883333 ],
    [ u"ph",u"San Pedro",270223,14.3595,121.0473 ],
    [ u"ph",u"San Pedro",3603,10.961,124.8197 ],
    [ u"ph",u"San Pedro",2318,12.016667,124 ],
    [ u"ph",u"San Pedro",2698,12.460841,121.010413 ],
    [ u"ph",u"San Pedro",3445,15.883333,120.65 ],
    [ u"ph",u"San Policarpio",5616,12.0686,124.5695 ],
    [ u"ph",u"San Policarpo",3581,12.1791,125.5072 ],
    [ u"ph",u"San Rafael",3846,13.216667,123.6 ],
    [ u"ph",u"San Rafael",2126,7.763889,126.455833 ],
    [ u"ph",u"San Rafael",3492,11.1781,122.8273 ],
    [ u"ph",u"San Rafael",3792,14.1284,121.4147 ],
    [ u"ph",u"San Rafael",3036,13.094167,122.96 ],
    [ u"ph",u"San Rafael",2777,14.9056,120.6945 ],
    [ u"ph",u"San Rafael",2574,16.0725,120.741 ],
    [ u"ph",u"San Rafael",2720,12.8905,123.6823 ],
    [ u"ph",u"San Ramon",4054,17.4135,120.7076 ],
    [ u"ph",u"San Ramon",2149,13.6181,123.0383 ],
    [ u"ph",u"San Remigio",3806,11.0809,123.9381 ],
    [ u"ph",u"San Remigio",2147,6.923056,125.775833 ],
    [ u"ph",u"San Ricardo",2501,15.5959,120.9727 ],
    [ u"ph",u"San Roque Dau",9621,14.9784,120.5741 ],
    [ u"ph",u"San Roque",2094,9.422222,125.558611 ],
    [ u"ph",u"San Roque",4698,13.2474,123.769 ],
    [ u"ph",u"San Roque",2580,10.091903,124.322621 ],
    [ u"ph",u"San Roque",6026,14.3219,122.5459 ],
    [ u"ph",u"San Roque",2154,10.6043,123.7441 ],
    [ u"ph",u"San Roque",2811,11.009722,125.0375 ],
    [ u"ph",u"San Roque",6038,15.2419,120.853 ],
    [ u"ph",u"San Roque",2195,15.261463,120.651831 ],
    [ u"ph",u"San Roque",4605,16.0529,120.7576 ],
    [ u"ph",u"San Roque",2213,12.7393,124.0839 ],
    [ u"ph",u"San Roque",2195,15.275962,120.566331 ],
    [ u"ph",u"San Roque",8637,12.533333,124.866667 ],
    [ u"ph",u"San Roque",2549,6.156389,124.266667 ],
    [ u"ph",u"San Roque",4509,13.1494,123.7539 ],
    [ u"ph",u"San Roque",6038,15.2372,120.9558 ],
    [ u"ph",u"San Salvador",2807,11.002778,122.835278 ],
    [ u"ph",u"San Sebastian",2101,13.7283,123.5939 ],
    [ u"ph",u"San Sebastian",2795,17.625833,120.363611 ],
    [ u"ph",u"San Sebastian",2018,11.71,125.018056 ],
    [ u"ph",u"San Simon",29049,14.9996,120.7808 ],
    [ u"ph",u"Santa Ana",2452,9.192778,125.564444 ],
    [ u"ph",u"Santa Ana",5770,8.536944,124.801944 ],
    [ u"ph",u"Santa Ana",6315,18.457659,122.143154 ],
    [ u"ph",u"Santa Ana",5770,8.516667,124.783333 ],
    [ u"ph",u"Santa Ana",47158,15.0955,120.767 ],
    [ u"ph",u"Santa Barbara",8629,10.823056,122.534444 ],
    [ u"ph",u"Santa Barbara",6525,15.3859,120.7969 ],
    [ u"ph",u"Santa Brigida",2541,12.567832,121.489014 ],
    [ u"ph",u"Santa Catalina Norte",5448,13.870833,121.3575 ],
    [ u"ph",u"Santa Catalina",26457,9.3337,122.8637 ],
    [ u"ph",u"Santa Catalina",2727,16.0835,120.6116 ],
    [ u"ph",u"Santa Catalina",2278,14.1213,121.3419 ],
    [ u"ph",u"Santa Catalina Sur",6195,13.871667,121.433056 ],
    [ u"ph",u"Santa Cecilia",4229,14.1054,122.2016 ],
    [ u"ph",u"Santa Clara",4430,13.753611,121.060556 ],
    [ u"ph",u"Santa Clara",4306,6.6782,122.06 ],
    [ u"ph",u"Santa Cruz Nuevo",4731,9.5352,123.1054 ],
    [ u"ph",u"Santa Cruz",2639,13.865,121.1887 ],
    [ u"ph",u"Santa Cruz",2295,18.51646,121.310525 ],
    [ u"ph",u"Santa Cruz",2501,10.0068,123.414 ],
    [ u"ph",u"Santa Cruz",2826,17.085556,120.452222 ],
    [ u"ph",u"Santa Cruz",108135,14.2814,121.4161 ],
    [ u"ph",u"Santa Cruz",9863,13.4758,122.0275 ],
    [ u"ph",u"Santa Cruz",9825,13.0736,120.7226 ],
    [ u"ph",u"Santa Cruz",9347,8.603611,124.911944 ],
    [ u"ph",u"Santa Cruz",3394,15.3079,120.8517 ],
    [ u"ph",u"Santa Cruz",15408,14.9132,120.5626 ],
    [ u"ph",u"Santa Cruz",2070,12.8763,124.0566 ],
    [ u"ph",u"Santa Cruz",26429,15.7654,119.9092 ],
    [ u"ph",u"Santa Cruz",2919,10.633756,123.082103 ],
    [ u"ph",u"Santa Elena",14641,14.170227,122.382464 ],
    [ u"ph",u"Santa Fe",3380,8.3425,124.780833 ],
    [ u"ph",u"Santa Fe",2405,11.1544,123.8058 ],
    [ u"ph",u"Santa Fe",2204,10.2375,124.771944 ],
    [ u"ph",u"Santa Fe",2358,12.156557,121.994111 ],
    [ u"ph",u"Santa Fe",2231,15.0103,120.2102 ],
    [ u"ph",u"Santa Filomena",2932,9.7402,123.3407 ],
    [ u"ph",u"Santa Ignacia",11477,15.6169,120.4358 ],
    [ u"ph",u"Santa Ines",5821,15.564,120.4656 ],
    [ u"ph",u"Santa Josefa",4164,7.991111,126.03 ],
    [ u"ph",u"Santa Juliana",2962,15.32826,120.428631 ],
    [ u"ph",u"Santa Justina",5712,13.3967,123.4731 ],
    [ u"ph",u"Santa Lucia",2748,15.1654,120.996 ],
    [ u"ph",u"Santa Lucia",2651,17.1175,120.453056 ],
    [ u"ph",u"Santa Lucia",4090,15.4598,120.7996 ],
    [ u"ph",u"Santa Lucia",8642,15.368057,120.486431 ],
    [ u"ph",u"Santa Lucia",4224,14.0349,121.4312 ],
    [ u"ph",u"Santa Magdalena",3913,12.648,124.1093 ],
    [ u"ph",u"Santa Margarita",4825,12.037778,124.657778 ],
    [ u"ph",u"Santa Maria Norte",2458,16.0721,120.5885 ],
    [ u"ph",u"Santa Maria",2554,8.033333,126.1625 ],
    [ u"ph",u"Santa Maria",2623,18.149481,121.661252 ],
    [ u"ph",u"Santa Maria",16759,6.553611,125.470833 ],
    [ u"ph",u"Santa Maria",3651,17.3665,120.4808 ],
    [ u"ph",u"Santa Maria",3736,17.466389,121.752222 ],
    [ u"ph",u"Santa Maria",6604,14.4719,121.4286 ],
    [ u"ph",u"Santa Maria",2947,12.578831,121.460414 ],
    [ u"ph",u"Santa Maria",3753,15.5232,120.7925 ],
    [ u"ph",u"Santa Maria",2420,15.0801,120.7743 ],
    [ u"ph",u"Santa Maria",2599,16.0284,120.468 ],
    [ u"ph",u"Santa Maria",2354,7.991667,126.445 ],
    [ u"ph",u"Santa Maria",2420,15.6379,120.4282 ],
    [ u"ph",u"Santa Monica",2581,10.736389,122.453333 ],
    [ u"ph",u"Santa Monica",5475,15.357856,120.717531 ],
    [ u"ph",u"Santander",2541,9.4156,123.3291 ],
    [ u"ph",u"Santa Paz",2046,10.266667,124.783333 ],
    [ u"ph",u"Santa Rita",3211,15.6036,120.823 ],
    [ u"ph",u"Santa Rita",19936,14.9974,120.6183 ],
    [ u"ph",u"Santa Rita",4338,11.4502,124.9425 ],
    [ u"ph",u"Santa Rosa",2552,14.426116,120.879311 ],
    [ u"ph",u"Santa Rosa",11683,15.4238,120.9378 ],
    [ u"ph",u"Santa Rosa",3843,13.5402,122.3912 ],
    [ u"ph",u"Santa Rosa",3794,10.57226,123.101202 ],
    [ u"ph",u"Santa Rosa",216650,14.305579,121.110739 ],
    [ u"ph",u"Santa Rosa Sur",2295,14.259,122.7233 ],
    [ u"ph",u"Santa",2283,17.486,120.4348 ],
    [ u"ph",u"Santa Teresa",3177,12.251855,121.112512 ],
    [ u"ph",u"Santa Teresa",4881,14.9253,120.557 ],
    [ u"ph",u"Santa Teresa",4000,10.585461,122.560403 ],
    [ u"ph",u"Santa Teresita",2849,13.866389,120.981389 ],
    [ u"ph",u"Santa Teresita",2576,18.2472,121.9127 ],
    [ u"ph",u"Santa Teresita",2281,13.4786,123.4191 ],
    [ u"ph",u"San Teodoro",4827,13.4375,121.0193 ],
    [ u"ph",u"Santiago",2337,10.5897,124.3066 ],
    [ u"ph",u"Santiago",2631,7.288889,126.573333 ],
    [ u"ph",u"Santiago",2022,11.058056,122.911667 ],
    [ u"ph",u"Santiago",5971,14.8995,120.5201 ],
    [ u"ph",u"Santiago",4939,14.0211,121.2792 ],
    [ u"ph",u"Santiago",108427,16.6928,121.557 ],
    [ u"ph",u"Santisimo Rosario",4190,13.995,121.308056 ],
    [ u"ph",u"Santo Angel",2344,11.3068,122.6408 ],
    [ u"ph",u"Santo Cristo",8664,15.281,120.9477 ],
    [ u"ph",u"Santo Cristo",4326,15.330558,120.673231 ],
    [ u"ph",u"Santo Cristo",8664,15.2567,120.952 ],
    [ u"ph",u"Santo Domingo",3481,14.1338,122.8883 ],
    [ u"ph",u"Santo Domingo",2666,13.5961,123.1772 ],
    [ u"ph",u"Santo Domingo",2640,17.158239,121.753344 ],
    [ u"ph",u"Santo Domingo",2247,15.0736,120.7619 ],
    [ u"ph",u"Santo Domingo",7029,16.0605,120.6405 ],
    [ u"ph",u"Santo Domingo",5031,13.42,123.4486 ],
    [ u"ph",u"Santol",6435,10.1725,122.9947 ],
    [ u"ph",u"Santo Niño",3054,13.8489,121.1328 ],
    [ u"ph",u"Santo Niño",2339,10.689,123.7884 ],
    [ u"ph",u"Santo Niño",2390,15.228056,120.703056 ],
    [ u"ph",u"Santo Niño",2864,11.9263,124.4492 ],
    [ u"ph",u"Santo Niño",2040,13.1043,123.9682 ],
    [ u"ph",u"Santo Nino",2966,15.340358,120.636431 ],
    [ u"ph",u"Santo Niño",9662,6.435,124.6975 ],
    [ u"ph",u"Santo Niño",2247,13.7018,121.0949 ],
    [ u"ph",u"Santo Niño",2012,11.062,124.5608 ],
    [ u"ph",u"Santo Niño",3787,7.327778,125.705278 ],
    [ u"ph",u"Santo Rosario",6005,15.434,120.8913 ],
    [ u"ph",u"Santo Rosario",6005,15.45,120.783333 ],
    [ u"ph",u"Santor",3448,14.095491,121.108745 ],
    [ u"ph",u"Santo Tomas",3055,8.185833,125.803889 ],
    [ u"ph",u"Santo Tomas",2772,17.399724,121.764546 ],
    [ u"ph",u"Santo Tomas",2446,14.183333,121.5 ],
    [ u"ph",u"Santo Tomas",23988,14.9923,120.7057 ],
    [ u"ph",u"Santo Tomas",2490,16.0826,120.7359 ],
    [ u"ph",u"Santo Tomas",5138,15.754,120.9517 ],
    [ u"ph",u"San Vicente",2355,13.231359,123.487576 ],
    [ u"ph",u"San Vicente",2718,13.4068,121.175 ],
    [ u"ph",u"San Vicente",3269,18.507456,122.150354 ],
    [ u"ph",u"San Vicente",4523,14.1061,122.8733 ],
    [ u"ph",u"San Vicente",2705,13.7,123.2 ],
    [ u"ph",u"San Vicente",2081,11.1183,124.5657 ],
    [ u"ph",u"San Vicente",6835,15.2124,120.8189 ],
    [ u"ph",u"San Vicente",4576,10.55,119.266667 ],
    [ u"ph",u"San Vicente",6449,14.9038,120.7377 ],
    [ u"ph",u"San Vicente",3143,15.84,120.498611 ],
    [ u"ph",u"San Vicente",2038,12.978056,123.822222 ],
    [ u"ph",u"San Vicente",2126,8.536944,126.094167 ],
    [ u"ph",u"San Vicente",16115,15.295461,120.646531 ],
    [ u"ph",u"San Vicente",2478,12.271111,124.1 ],
    [ u"ph",u"San Vicente",3247,6.449722,124.794722 ],
    [ u"ph",u"San Vicente",4297,13.4081,123.4188 ],
    [ u"ph",u"San Vicente",3159,13.8203,122.222 ],
    [ u"ph",u"San Vicente",3843,16.1411,119.9927 ],
    [ u"ph",u"Sapad",4376,7.483333,124.25 ],
    [ u"ph",u"Sapang Buho",3339,15.5921,121.122 ],
    [ u"ph",u"Sapang Dalaga",2742,8.5399,123.5624 ],
    [ u"ph",u"Sapang",2078,15.9925,120.4052 ],
    [ u"ph",u"Sapang",11372,15.7032,120.5245 ],
    [ u"ph",u"Sapao",2284,10.02,126.038333 ],
    [ u"ph",u"Sapa",2572,5.1544,120.3241 ],
    [ u"ph",u"Sapul",2840,13.365,121.1893 ],
    [ u"ph",u"Sapu",9788,5.917222,125.266944 ],
    [ u"ph",u"Sapu",9788,5.92,125.275278 ],
    [ u"ph",u"Sarangani",7506,5.403333,125.463611 ],
    [ u"ph",u"Sara",4062,11.2579,123.0138 ],
    [ u"ph",u"Saraza",2533,8.735556,117.78 ],
    [ u"ph",u"Sarrat",5822,18.1574,120.647 ],
    [ u"ph",u"Sasmuan",21124,14.9438,120.6229 ],
    [ u"ph",u"Satan",4068,6.863056,124.408611 ],
    [ u"ph",u"Saug",11693,7.5413,125.7553 ],
    [ u"ph",u"Saysain",2683,14.561111,120.3925 ],
    [ u"ph",u"Sebaste",3711,11.5901,122.0945 ],
    [ u"ph",u"Sebaste",2106,10.4963,122.657 ],
    [ u"ph",u"Sebu",21767,6.22,124.693611 ],
    [ u"ph",u"Seguinon",2211,10.9423,124.6806 ],
    [ u"ph",u"Seit",14552,5.994904,121.212267 ],
    [ u"ph",u"Semirara",5470,12.069666,121.398611 ],
    [ u"ph",u"Semut",3423,6.663611,122.218889 ],
    [ u"ph",u"Sergio Osmeña Sr",4954,8.166667,123.5 ],
    [ u"ph",u"Siare",3531,8.3245,122.9881 ],
    [ u"ph",u"Siayan",4906,8.266667,123.1 ],
    [ u"ph",u"Siay",2351,7.696111,122.863056 ],
    [ u"ph",u"Sibagat",4865,8.8225,125.6975 ],
    [ u"ph",u"Sibaguan",2174,11.557778,122.713889 ],
    [ u"ph",u"Sibucao",2829,10.4179,122.887 ],
    [ u"ph",u"Sibuco",3327,7.291111,122.065556 ],
    [ u"ph",u"Sibulan",9021,6.933611,125.462222 ],
    [ u"ph",u"Sibulan",28079,9.3584,123.285 ],
    [ u"ph",u"Sibulan",3633,14.75,121.933333 ],
    [ u"ph",u"Sibulao",2939,7.324545,122.241799 ],
    [ u"ph",u"Sibul",8225,15.169,121.0616 ],
    [ u"ph",u"Sibul",2368,15.8,121 ],
    [ u"ph",u"Sibutad",3395,8.5916,123.4859 ],
    [ u"ph",u"Siclong",2700,15.5808,121.2239 ],
    [ u"ph",u"Siempre Viva",3904,17.228736,121.632944 ],
    [ u"ph",u"Sierra Bullones",2978,9.8081,124.2921 ],
    [ u"ph",u"Sigma",3222,11.4214,122.6662 ],
    [ u"ph",u"Silab",3296,9.4383,123.1792 ],
    [ u"ph",u"Silae",2214,8.158889,125.2825 ],
    [ u"ph",u"Silago",2276,10.5291,125.1618 ],
    [ u"ph",u"Silanga",2350,11.818056,124.843056 ],
    [ u"ph",u"Silawit",3084,16.873156,121.759242 ],
    [ u"ph",u"Silay",84131,10.8003,122.9763 ],
    [ u"ph",u"Sillon",4042,11.199,123.7675 ],
    [ u"ph",u"Silvino Lobos",2720,12.3,124.833333 ],
    [ u"ph",u"Silway",7893,6.177109,125.120676 ],
    [ u"ph",u"Simala",2569,9.970833,123.616389 ],
    [ u"ph",u"Simbahan",4712,6.3032,120.5836 ],
    [ u"ph",u"Simimbaan",2854,17.115743,121.582444 ],
    [ u"ph",u"Simuay",4666,7.277222,124.307222 ],
    [ u"ph",u"Sinacaban",2372,8.2864,123.8399 ],
    [ u"ph",u"Sinait",3123,17.8664,120.4583 ],
    [ u"ph",u"Sinait",2268,15.5367,120.5851 ],
    [ u"ph",u"Sinala",2802,13.805696,120.97463 ],
    [ u"ph",u"Sinamar",6012,16.9,121.566667 ],
    [ u"ph",u"Sinawilan",4017,6.754444,125.246389 ],
    [ u"ph",u"Sinayawan",4930,6.7125,125.309444 ],
    [ u"ph",u"Sindon",2418,17.060343,122.015143 ],
    [ u"ph",u"Sinilian",5040,15.6952,120.4594 ],
    [ u"ph",u"Sinisian",3703,13.915599,120.844008 ],
    [ u"ph",u"Sinobong",3335,8.0684,125.9308 ],
    [ u"ph",u"Sinolon",2838,6.243889,124.814444 ],
    [ u"ph",u"Sinonoc",2648,8.3096,123.8461 ],
    [ u"ph",u"Sinubung",2173,7.027504,121.924428 ],
    [ u"ph",u"Sinuknipan",2533,13.8894,122.6375 ],
    [ u"ph",u"Siocon",5071,7.706111,122.135278 ],
    [ u"ph",u"Sionogan",2730,6.005278,120.948611 ],
    [ u"ph",u"Siquijor",10259,9.2142,123.515 ],
    [ u"ph",u"Sirawai",4126,7.585278,122.139722 ],
    [ u"ph",u"Sirib",5008,7.133333,125.407222 ],
    [ u"ph",u"Sison",9256,16.173,120.51 ],
    [ u"ph",u"Sison",3171,9.6588,125.5272 ],
    [ u"ph",u"Sitangkai",17200,4.662778,119.392778 ],
    [ u"ph",u"Socorro",5543,13.058333,121.411667 ],
    [ u"ph",u"Socorro",9742,9.621389,125.966667 ],
    [ u"ph",u"Sogod",2960,13.833333,123.316667 ],
    [ u"ph",u"Sogod",2968,10.750833,123.994722 ],
    [ u"ph",u"Sogod",8303,10.3847,124.9814 ],
    [ u"ph",u"Solana",2984,8.623056,124.770556 ],
    [ u"ph",u"Solano",36208,16.519182,121.181239 ],
    [ u"ph",u"Soledad",4728,15.4282,120.9839 ],
    [ u"ph",u"Solo",3065,13.746914,120.901189 ],
    [ u"ph",u"Solsona",3725,18.093333,120.769722 ],
    [ u"ph",u"Songculan",3335,9.634722,123.819722 ],
    [ u"ph",u"Sonquil",2347,15.9883,120.3898 ],
    [ u"ph",u"Sorsogon",81419,12.9708,124.0053 ],
    [ u"ph",u"Soyung",5418,16.7001,121.6655 ],
    [ u"ph",u"Sual",5290,16.066817,120.094136 ],
    [ u"ph",u"Sua-on",2936,7.662778,125.638333 ],
    [ u"ph",u"Subaan",2527,13.130495,121.368717 ],
    [ u"ph",u"Suba",2965,10.8438,121.0102 ],
    [ u"ph",u"Subic",8882,13.948587,120.940131 ],
    [ u"ph",u"Subusub",6887,16.227,120.4947 ],
    [ u"ph",u"Suclayin",5734,15.7574,121.5503 ],
    [ u"ph",u"Sugal",2759,5.662222,125.461667 ],
    [ u"ph",u"Sugbongcogon",2494,8.956944,124.791111 ],
    [ u"ph",u"Sugcad",3000,13.366667,123.7 ],
    [ u"ph",u"Sugod",2221,12.380438,122.684312 ],
    [ u"ph",u"Sugod",2080,12.987,124.0805 ],
    [ u"ph",u"Sulangan",4582,11.1373,123.7228 ],
    [ u"ph",u"Sulangan",3034,10.936,125.8264 ],
    [ u"ph",u"Sulangan",2262,10.811,122.664 ],
    [ u"ph",u"Sula",3431,15.457252,120.395532 ],
    [ u"ph",u"Sulat",4684,11.810278,125.454444 ],
    [ u"ph",u"Sulit",5019,6.236111,125.020556 ],
    [ u"ph",u"Sulop",6582,6.598611,125.343611 ],
    [ u"ph",u"Sulucan",5703,14.8,120.933333 ],
    [ u"ph",u"Sumabnit",4296,16.0303,120.5832 ],
    [ u"ph",u"Sumagui",3495,12.795317,121.474015 ],
    [ u"ph",u"Sumalig",3118,7.9986,123.6627 ],
    [ u"ph",u"Sumilao",5339,8.287222,124.945556 ],
    [ u"ph",u"Sumisip",3735,6.419722,121.971389 ],
    [ u"ph",u"Sumpong",7399,8.163333,125.118333 ],
    [ u"ph",u"Sungay",2094,8.451389,124.402778 ],
    [ u"ph",u"Surigao",88581,9.789,125.495 ],
    [ u"ph",u"Surop",2119,6.390351,126.145581 ],
    [ u"ph",u"Suso",2280,17.3594,120.4611 ],
    [ u"ph",u"Suyan",7229,6.060278,125.385278 ],
    [ u"ph",u"Suyo",3493,16.9657,120.5417 ],
    [ u"ph",u"Taal",39761,13.879923,120.923114 ],
    [ u"ph",u"Tabaan",2653,16.3,120.516667 ],
    [ u"ph",u"Tabacao",3465,15.6414,120.9349 ],
    [ u"ph",u"Tabalong",2294,9.621944,123.835278 ],
    [ u"ph",u"Tabango",5806,11.3077,124.373 ],
    [ u"ph",u"Tabialan",2312,6.028059,121.893546 ],
    [ u"ph",u"Tabid",3152,8.1085,123.7801 ],
    [ u"ph",u"Tabina",5074,7.4669,123.4081 ],
    [ u"ph",u"Tabinay",2522,13.4871,120.9566 ],
    [ u"ph",u"Tabing",2345,11.4,124.35 ],
    [ u"ph",u"Tabio",3543,16.85,120.8 ],
    [ u"ph",u"Tablac",2903,17.216667,120.483333 ],
    [ u"ph",u"Tablas",2336,6.629167,122.174722 ],
    [ u"ph",u"Taboc",2546,16.686667,120.341111 ],
    [ u"ph",u"Taboc",2107,8.878333,124.7975 ],
    [ u"ph",u"Tabon",3270,9.7578,123.4436 ],
    [ u"ph",u"Tabon",2878,10.3019,123.326 ],
    [ u"ph",u"Tabon",2537,15.2746,120.9128 ],
    [ u"ph",u"Tabon",3801,9.238773,117.994598 ],
    [ u"ph",u"Tabontabon",2557,11.040833,124.961111 ],
    [ u"ph",u"Tabo-o",2965,8.334,123.8547 ],
    [ u"ph",u"Tabuan",5390,9.515556,122.850556 ],
    [ u"ph",u"Tabuating",4120,15.3891,120.9386 ],
    [ u"ph",u"Tabuc",5275,11.4694,122.775 ],
    [ u"ph",u"Tabuelan",3985,10.8209,123.8689 ],
    [ u"ph",u"Tabug",3281,18.0343,120.5488 ],
    [ u"ph",u"Tabuk",27048,17.4189,121.4443 ],
    [ u"ph",u"Tabunok",2822,10.8512,123.8766 ],
    [ u"ph",u"Tabunok",2670,10.35,124.8 ],
    [ u"ph",u"Taburi",2501,8.675315,117.339895 ],
    [ u"ph",u"Tabu",6143,9.8923,122.7098 ],
    [ u"ph",u"Tacadang",2402,16.7264,120.6405 ],
    [ u"ph",u"Tacligan",2593,13.3975,121.0626 ],
    [ u"ph",u"Tacloban",189087,11.243333,125.004722 ],
    [ u"ph",u"Taclobo",4782,12.307443,122.586011 ],
    [ u"ph",u"Tacub",2391,6.856389,125.4225 ],
    [ u"ph",u"Tacub",3137,8.1875,124.108056 ],
    [ u"ph",u"Tadian",2803,16.9956,120.8203 ],
    [ u"ph",u"Taft",4421,11.901111,125.418889 ],
    [ u"ph",u"Tagabas",2228,13.6222,122.2814 ],
    [ u"ph",u"Tagakpan",4019,7.112778,125.429167 ],
    [ u"ph",u"Tagana-an",4386,9.697222,125.585556 ],
    [ u"ph",u"Taganak",2638,6.083333,118.3 ],
    [ u"ph",u"Tagasilay",3192,7.301782,122.257913 ],
    [ u"ph",u"Tagas",15292,13.166667,123.716667 ],
    [ u"ph",u"Taga",4898,17.575117,121.368847 ],
    [ u"ph",u"Tagaytay",52883,14.095321,120.93355 ],
    [ u"ph",u"Tagbacan",4840,13.6028,122.3687 ],
    [ u"ph",u"Tagbac",4143,13.841656,120.088722 ],
    [ u"ph",u"Tagbilaran",86421,9.6475,123.855556 ],
    [ u"ph",u"Tagbina",10673,8.451944,126.171389 ],
    [ u"ph",u"Tagbubunga",2489,11.1257,124.4028 ],
    [ u"ph",u"Tagburos",4149,9.8279,118.743 ],
    [ u"ph",u"Tagcatong",2907,9.002222,125.256944 ],
    [ u"ph",u"Tagdangua",4116,7.2043,125.8841 ],
    [ u"ph",u"Tagkawayan",7684,13.9664,122.5383 ],
    [ u"ph",u"Tagnanan",4171,7.2648,125.8584 ],
    [ u"ph",u"Tagoloan",30390,8.538889,124.756944 ],
    [ u"ph",u"Tago",6300,9.021111,126.231667 ],
    [ u"ph",u"Tagoytoy",2106,13.4158,123.678 ],
    [ u"ph",u"Tagpañgi",2980,8.371944,124.559444 ],
    [ u"ph",u"Tagudin",3884,16.9355,120.4442 ],
    [ u"ph",u"Tagudin",3052,16.0806,119.9539 ],
    [ u"ph",u"Taguing",2081,17.944692,121.75885 ],
    [ u"ph",u"Taguisa",3147,6.698333,124.035833 ],
    [ u"ph",u"Tagum",2559,10.06536,124.383022 ],
    [ u"ph",u"Tagum",171656,7.4475,125.8046 ],
    [ u"ph",u"Tagusao",2961,9.192377,117.814097 ],
    [ u"ph",u"Tajao",5394,10.3148,123.5835 ],
    [ u"ph",u"Talabaan",3553,6.941111,122.172222 ],
    [ u"ph",u"Talaban",6003,10.1254,122.8671 ],
    [ u"ph",u"Talacogon",15581,8.456111,125.784167 ],
    [ u"ph",u"Talaga",3231,13.736459,120.936175 ],
    [ u"ph",u"Talaga",4655,15.385055,120.585731 ],
    [ u"ph",u"Talahiban",3385,13.806944,121.388056 ],
    [ u"ph",u"Talahib",3117,13.6396,121.1436 ],
    [ u"ph",u"Talaibon",2820,13.8378,121.1398 ],
    [ u"ph",u"Talakag",7861,8.233611,124.600278 ],
    [ u"ph",u"Talalora",2186,11.5293,124.8362 ],
    [ u"ph",u"Talangnan",3276,9.634,123.3344 ],
    [ u"ph",u"Talang",2497,15.0143,120.9047 ],
    [ u"ph",u"Tala",4270,13.2742,122.5859 ],
    [ u"ph",u"Talibon",11209,10.149167,124.325 ],
    [ u"ph",u"Taligaman",7430,8.904444,125.655833 ],
    [ u"ph",u"Talipan",4473,13.933333,121.683333 ],
    [ u"ph",u"Talisayan",2332,10.95,124.7 ],
    [ u"ph",u"Talisayan",4616,8.996389,124.884167 ],
    [ u"ph",u"Talisayan",5445,6.988036,121.927347 ],
    [ u"ph",u"Talisay",2356,13.914842,120.623262 ],
    [ u"ph",u"Talisay",7544,14.1343,122.9226 ],
    [ u"ph",u"Talisay",4117,11.2434,124.0619 ],
    [ u"ph",u"Talisay",2583,6.719726,126.099982 ],
    [ u"ph",u"Talisay",5141,13.180556,122.623611 ],
    [ u"ph",u"Talisay",2200,9.818889,125.615556 ],
    [ u"ph",u"Talisay",133189,10.244379,123.8473 ],
    [ u"ph",u"Talisay",66356,10.7375,122.9666 ],
    [ u"ph",u"Talitay",3983,6.996667,124.705278 ],
    [ u"ph",u"Talobatib",3459,14.1825,122.7853 ],
    [ u"ph",u"Taloc",20409,10.5746,122.8954 ],
    [ u"ph",u"Talomo",3857,7.528611,125.722778 ],
    [ u"ph",u"Talon",2311,11.56,122.681111 ],
    [ u"ph",u"Talospatang",3057,15.9179,120.4496 ],
    [ u"ph",u"Taloy",3485,16.333333,120.5 ],
    [ u"ph",u"Taloy",2352,15.9241,120.3847 ],
    [ u"ph",u"Taltal",5370,15.5878,119.9455 ],
    [ u"ph",u"Talugtug",6306,15.7778,120.8111 ],
    [ u"ph",u"Taluksangay",7343,6.954167,122.183889 ],
    [ u"ph",u"Talusan",5783,7.426667,122.810278 ],
    [ u"ph",u"Taluya",4903,5.811667,125.172778 ],
    [ u"ph",u"Tamayong",5717,7.133056,125.379722 ],
    [ u"ph",u"Tamayo",5767,15.8774,120.2853 ],
    [ u"ph",u"Tambak",2690,11.6705,122.4112 ],
    [ u"ph",u"Tambak",2258,6.726389,124.626389 ],
    [ u"ph",u"Tambaliza",2950,11.2698,123.165 ],
    [ u"ph",u"Tambilil",4740,5.962222,124.669722 ],
    [ u"ph",u"Tambongon",2643,10.9677,123.9244 ],
    [ u"ph",u"Tambongon",3243,7.0792,125.9486 ],
    [ u"ph",u"Tambong",2510,12.963906,121.484616 ],
    [ u"ph",u"Tambo",2989,13.4676,123.4939 ],
    [ u"ph",u"Tambo",3196,9.895,123.0556 ],
    [ u"ph",u"Tambo",2378,7.156944,125.699167 ],
    [ u"ph",u"Tambulan",2162,9.9085,123.0896 ],
    [ u"ph",u"Tambulig",7488,8.0702,123.5348 ],
    [ u"ph",u"Tamisan",2866,6.843717,126.298382 ],
    [ u"ph",u"Tamisu",2904,9.6314,123.0873 ],
    [ u"ph",u"Tamlang",2275,10.816667,123.433333 ],
    [ u"ph",u"Tamlang",2275,10.825441,123.454103 ],
    [ u"ph",u"Tamnag",6302,6.567778,124.850556 ],
    [ u"ph",u"Tamorong",2442,17.333333,120.433333 ],
    [ u"ph",u"Tampakan",9048,6.444167,124.926389 ],
    [ u"ph",u"Tampakan",8306,4.922778,119.793889 ],
    [ u"ph",u"Tamparan",2396,7.879167,124.333056 ],
    [ u"ph",u"Tampayan",2839,12.479432,122.523112 ],
    [ u"ph",u"Tampilisan",3578,7.9835,122.7054 ],
    [ u"ph",u"Tampocon",3768,9.85,123.133333 ],
    [ u"ph",u"Tamugan",8291,7.230833,125.376389 ],
    [ u"ph",u"Tanauan",16567,11.109444,125.015556 ],
    [ u"ph",u"Tanay",59898,14.4968,121.2846 ],
    [ u"ph",u"Tandag",29010,9.078333,126.198611 ],
    [ u"ph",u"Tandayag",3532,9.4547,123.2299 ],
    [ u"ph",u"Tandoc",3191,15.9605,120.328 ],
    [ u"ph",u"Tanglad",2184,6.602222,125.445 ],
    [ u"ph",u"Tangnan",2870,9.6125,123.783056 ],
    [ u"ph",u"Tangub",29721,8.0618,123.7477 ],
    [ u"ph",u"Tanolong",2779,15.816667,120.4 ],
    [ u"ph",u"Tantangan",10337,6.615,124.748889 ],
    [ u"ph",u"Tanza",2584,11.5825,122.783611 ],
    [ u"ph",u"Tanza",3844,10.834842,123.011004 ],
    [ u"ph",u"Tanza",105537,14.6753,120.9389 ],
    [ u"ph",u"Tapayan",3240,7.294444,124.266111 ],
    [ u"ph",u"Tapaz",2340,11.2613,122.5364 ],
    [ u"ph",u"Tapel",2548,18.28907,122.029153 ],
    [ u"ph",u"Tapia",2720,7.754167,126.011944 ],
    [ u"ph",u"Tapikan",2232,6.844444,124.340833 ],
    [ u"ph",u"Tapilon",7786,11.2774,124.0306 ],
    [ u"ph",u"Tapon",5245,10.0631,123.4453 ],
    [ u"ph",u"Tarangnan",2762,11.9009,124.7459 ],
    [ u"ph",u"Tara",2077,13.816667,122.983333 ],
    [ u"ph",u"Tariji",2332,15.5211,120.6124 ],
    [ u"ph",u"Tarlac",182413,15.489449,120.591932 ],
    [ u"ph",u"Tarong",2376,11.5314,123.132 ],
    [ u"ph",u"Tarragona",3777,7.049101,126.447082 ],
    [ u"ph",u"Tartaro",5231,15.1664,121.0397 ],
    [ u"ph",u"Tarusan",3107,8.654615,117.510395 ],
    [ u"ph",u"Taviran",2851,7.123333,124.319722 ],
    [ u"ph",u"Tawagan",2810,7.8434,123.4729 ],
    [ u"ph",u"Tawala",2695,9.559167,123.783056 ],
    [ u"ph",u"Tayabo",4406,15.8345,121.0309 ],
    [ u"ph",u"Taysan",5296,13.8697,121.0971 ],
    [ u"ph",u"Taytayan",3654,10.8787,123.9771 ],
    [ u"ph",u"Taytayan",6894,7.733889,126.501944 ],
    [ u"ph",u"Taytay",2670,14.1122,121.4157 ],
    [ u"ph",u"Taytay",2821,8.541111,124.539722 ],
    [ u"ph",u"Taytay",7717,10.825259,119.516905 ],
    [ u"ph",u"Taytay",231475,14.5678,121.1394 ],
    [ u"ph",u"Tayud",7788,10.366667,123.966667 ],
    [ u"ph",u"Tayug",11611,16.0274,120.7434 ],
    [ u"ph",u"Tayuman",5276,13.4164,122.5164 ],
    [ u"ph",u"Tayum",2530,17.6172,120.6542 ],
    [ u"ph",u"Taywanak",3093,14.157589,120.846545 ],
    [ u"ph",u"Tebag",2779,15.9678,120.466 ],
    [ u"ph",u"Telabastagan",25935,15.1204,120.6017 ],
    [ u"ph",u"Telafas",2306,6.635278,124.975 ],
    [ u"ph",u"Telbang",2795,16.17241,120.060737 ],
    [ u"ph",u"Teneguiban",3267,11.3574,119.5049 ],
    [ u"ph",u"Teresa",34715,14.5612,121.2195 ],
    [ u"ph",u"Teresita",2609,6.413611,124.707222 ],
    [ u"ph",u"Ternate",20050,14.2897,120.7168 ],
    [ u"ph",u"Tiaong",5044,13.953611,121.316111 ],
    [ u"ph",u"Tibagon",3905,7.2327,125.8628 ],
    [ u"ph",u"Tibanban",7838,6.631533,126.105482 ],
    [ u"ph",u"Tibiao",3723,11.291515,122.035407 ],
    [ u"ph",u"Tiblawan",2843,6.478344,126.108282 ],
    [ u"ph",u"Tidman",3154,8.298611,126.338889 ],
    [ u"ph",u"Tiep",2178,16.2382,119.8609 ],
    [ u"ph",u"Tigaon",12509,13.6331,123.4968 ],
    [ u"ph",u"Tigao",2077,9.208889,126.176111 ],
    [ u"ph",u"Tigbao",2294,12.5546,123.3389 ],
    [ u"ph",u"Tigbao",2207,7.423597,122.327007 ],
    [ u"ph",u"Tigbinan",2805,14.186479,122.469226 ],
    [ u"ph",u"Tiglawigan",6848,10.9527,123.3575 ],
    [ u"ph",u"Tignapoloan",4098,8.272778,124.575556 ],
    [ u"ph",u"Tignoan",4164,14.565223,121.617862 ],
    [ u"ph",u"Tigpalay",5480,7.494789,122.34496 ],
    [ u"ph",u"Tigtabon",3546,6.895556,122.166944 ],
    [ u"ph",u"Tiguha",2142,7.704444,123.211389 ],
    [ u"ph",u"Tiguib",2573,9.8008,123.1352 ],
    [ u"ph",u"Tiguion",3018,13.3347,121.861 ],
    [ u"ph",u"Tiguisan",2486,12.839414,121.460515 ],
    [ u"ph",u"Tigum",2168,10.783333,122.566667 ],
    [ u"ph",u"Tigwi",2543,13.2681,122.0415 ],
    [ u"ph",u"Tikalaan",3389,8.035278,124.620833 ],
    [ u"ph",u"Tilik",2350,13.814357,120.200221 ],
    [ u"ph",u"Tiling",3332,9.9736,122.6544 ],
    [ u"ph",u"Timbangan",2230,6.005468,120.994055 ],
    [ u"ph",u"Timpas",3551,11.479,122.7324 ],
    [ u"ph",u"Tinaan",5959,11.266667,123.75 ],
    [ u"ph",u"Tinagacan",4808,6.209851,125.239032 ],
    [ u"ph",u"Tinago",4491,13.183333,123.65 ],
    [ u"ph",u"Tinalmud",2217,13.5941,122.878 ],
    [ u"ph",u"Tinambacan",4555,12.0943,124.5025 ],
    [ u"ph",u"Tinampo",2590,13.2274,123.5101 ],
    [ u"ph",u"Tinang",4217,15.376256,120.653431 ],
    [ u"ph",u"Tinaogan",2360,9.7791,123.1503 ],
    [ u"ph",u"Tinawagan",2632,13.65,123.483333 ],
    [ u"ph",u"Tindog",3306,11.1247,124.0118 ],
    [ u"ph",u"Tingloy",2646,13.660908,120.871097 ],
    [ u"ph",u"Tinogboc",2208,12.00737,121.412211 ],
    [ u"ph",u"Tinongan",4440,10.215,123.035278 ],
    [ u"ph",u"Tinoto",3725,5.886667,125.070556 ],
    [ u"ph",u"Tinubdan",2146,11.186,124.0078 ],
    [ u"ph",u"Tiparak",2898,8.0341,123.5288 ],
    [ u"ph",u"Tipolo",2361,10.0196,124.5144 ],
    [ u"ph",u"Tiring",2232,10.8527,122.511 ],
    [ u"ph",u"Titay",11469,7.8125,122.534444 ],
    [ u"ph",u"Tiwi",16826,13.4585,123.6805 ],
    [ u"ph",u"Tiwi",2269,10.929722,122.734167 ],
    [ u"ph",u"Toboso",13006,10.714348,123.516202 ],
    [ u"ph",u"Toboy",3082,16.0271,120.6369 ],
    [ u"ph",u"Tobuan",2772,16.055617,120.110236 ],
    [ u"ph",u"Tococ",2266,15.833333,120.416667 ],
    [ u"ph",u"Tocok",3067,15.75,120.3 ],
    [ u"ph",u"Tokawal",3435,6.223333,125.251944 ],
    [ u"ph",u"Tokawal",3435,6.160379,125.249316 ],
    [ u"ph",u"Toledo",156915,10.3773,123.6386 ],
    [ u"ph",u"Tolosa",2686,7.032813,122.160749 ],
    [ u"ph",u"Tomado",2610,7.1925,124.608056 ],
    [ u"ph",u"Tomas Oppus",2446,10.250556,124.983056 ],
    [ u"ph",u"Tombod",2063,15.95,120.55 ],
    [ u"ph",u"Tominjao",3644,11.2277,124.0432 ],
    [ u"ph",u"Tondod",3182,15.7182,120.968 ],
    [ u"ph",u"Tondol",2680,16.3104,120.0131 ],
    [ u"ph",u"Toong",2684,14.070632,120.763331 ],
    [ u"ph",u"Topdac",2289,16.5454,120.7196 ],
    [ u"ph",u"Toritori",2076,16.2405,119.987 ],
    [ u"ph",u"Torres",2489,16.0012,120.4557 ],
    [ u"ph",u"Torrijos",3002,13.3238,122.0841 ],
    [ u"ph",u"Tortosa",7048,10.932935,123.090004 ],
    [ u"ph",u"Totolan",4030,9.628611,123.851389 ],
    [ u"ph",u"Tranca",2445,14.118146,121.057413 ],
    [ u"ph",u"Tran",2167,6.720278,124.055 ],
    [ u"ph",u"Trapiche",11539,10.684167,122.432222 ],
    [ u"ph",u"Trento",15916,8.045833,126.063611 ],
    [ u"ph",u"Trinidad",3225,10.079549,124.343244 ],
    [ u"ph",u"Tuao",2200,17.736407,121.456349 ],
    [ u"ph",u"Tubajon",2906,10.331667,125.561944 ],
    [ u"ph",u"Tubalan",4164,6.495,125.566111 ],
    [ u"ph",u"Tuban",5194,6.822778,125.386944 ],
    [ u"ph",u"Tuban",2402,12.8122,120.8323 ],
    [ u"ph",u"Tuba",24482,16.389722,120.560833 ],
    [ u"ph",u"Tubay",7946,9.166944,125.523889 ],
    [ u"ph",u"Tubigagmanok",3866,10.6282,123.7489 ],
    [ u"ph",u"Tubigan",2629,8.532222,124.312222 ],
    [ u"ph",u"Tubig Indangan",4671,4.898333,119.849444 ],
    [ u"ph",u"Tubigon",11262,9.9518,123.9622 ],
    [ u"ph",u"Tublay",3706,16.5431,120.6096 ],
    [ u"ph",u"Tubli",2452,13.9318,124.1478 ],
    [ u"ph",u"Tubod",2310,9.983333,123.583333 ],
    [ u"ph",u"Tubod",10975,8.0555,123.7904 ],
    [ u"ph",u"Tubod",7871,7.371667,125.644722 ],
    [ u"ph",u"Tuburan",8205,6.643889,122.273611 ],
    [ u"ph",u"Tuburan",3954,13.2379,123.5511 ],
    [ u"ph",u"Tucdao",2424,11.7011,124.4719 ],
    [ u"ph",u"Tudela",3137,8.2472,123.8424 ],
    [ u"ph",u"Tuding",7491,16.410278,120.644167 ],
    [ u"ph",u"Tuganay",4054,7.368889,125.723056 ],
    [ u"ph",u"Tugaya",2501,7.882773,124.174003 ],
    [ u"ph",u"Tugbong",2636,11.016667,124.6 ],
    [ u"ph",u"Tugdan",2373,12.3134,122.0853 ],
    [ u"ph",u"Tugos",3818,14.266667,122.75 ],
    [ u"ph",u"Tuguegarao",116665,17.6125,121.7281 ],
    [ u"ph",u"Tuhian",2646,13.6222,122.2178 ],
    [ u"ph",u"Tuka",4003,6.52,124.585 ],
    [ u"ph",u"Tukuran",13149,7.8524,123.5743 ],
    [ u"ph",u"Tulay",3294,14.269687,120.769247 ],
    [ u"ph",u"Tulay",7808,10.2463,123.5805 ],
    [ u"ph",u"Tuli",3643,7.233333,125.416667 ],
    [ u"ph",u"Tulunan",9584,6.834444,124.876944 ],
    [ u"ph",u"Tumalaytay",2340,12.275842,123.23201 ],
    [ u"ph",u"Tumalim",3692,14.0801,120.7231 ],
    [ u"ph",u"Tumarbong",3261,10.376589,119.457903 ],
    [ u"ph",u"Tumauini",3573,17.276631,121.808545 ],
    [ u"ph",u"Tumbagaan",2261,5.3656,120.3139 ],
    [ u"ph",u"Tumcon",5067,10.916667,122.666667 ],
    [ u"ph",u"Tungao",8910,8.777222,125.571944 ],
    [ u"ph",u"Tunga",2932,11.245556,124.751667 ],
    [ u"ph",u"Tungawan",3603,7.513429,122.36489 ],
    [ u"ph",u"Tunggol",3976,7.080833,124.753056 ],
    [ u"ph",u"Tunggol",3013,5.844583,121.154357 ],
    [ u"ph",u"Tupang",2213,17.921594,121.64165 ],
    [ u"ph",u"Tupsan",2370,9.199167,124.776944 ],
    [ u"ph",u"Tutubigan",2030,11.839722,125.061389 ],
    [ u"ph",u"Tuyan",4239,6,125.283333 ],
    [ u"ph",u"Tuyom",11117,9.9769,122.5582 ],
    [ u"ph",u"Tuy",8603,14.0183,120.7296 ],
    [ u"ph",u"Uacon",3377,15.6787,119.9403 ],
    [ u"ph",u"Ubay",3799,10.056001,124.472935 ],
    [ u"ph",u"Udalo",3047,13.4776,120.8223 ],
    [ u"ph",u"Uddiawan",3112,16.558879,121.15124 ],
    [ u"ph",u"Udtongan",2201,10.773344,123.520003 ],
    [ u"ph",u"Ugac",2208,17.6103,121.7172 ],
    [ u"ph",u"Ugad",2166,17.293731,121.799845 ],
    [ u"ph",u"Ula",2689,7.132222,125.492222 ],
    [ u"ph",u"Umabay",3480,12.309538,123.67961 ],
    [ u"ph",u"Umanday",4701,15.938,120.2153 ],
    [ u"ph",u"Umiray",5096,15.2206,121.4111 ],
    [ u"ph",u"Ungka",5598,10.75,122.55 ],
    [ u"ph",u"Unidad",3344,8.535,126.230556 ],
    [ u"ph",u"Unidos",2103,11.906773,122.00051 ],
    [ u"ph",u"Unidos",2111,8.5942,123.668 ],
    [ u"ph",u"Union",2284,11.7612,121.8963 ],
    [ u"ph",u"Union",2270,10.0475,124.5151 ],
    [ u"ph",u"Union",4580,10.6695,124.3252 ],
    [ u"ph",u"Union",2368,9.756667,126.110278 ],
    [ u"ph",u"Unisan",4764,13.8403,121.9762 ],
    [ u"ph",u"Unzad",3570,15.918889,120.539167 ],
    [ u"ph",u"Upig",2262,15.0248,120.9932 ],
    [ u"ph",u"Upi",5647,17.080443,121.836443 ],
    [ u"ph",u"Upper Klinan",3768,6.227222,125.120833 ],
    [ u"ph",u"Urbiztondo",12734,15.8227,120.3295 ],
    [ u"ph",u"Urdaneta",102827,15.976111,120.571111 ],
    [ u"ph",u"Usab",2404,12.329737,123.58091 ],
    [ u"ph",u"Uson",4395,12.2253,123.7834 ],
    [ u"ph",u"Uyaan",2601,7.863056,124.041111 ],
    [ u"ph",u"Uyong",2728,16.050017,120.120736 ],
    [ u"ph",u"Valderrama",4276,11.405907,122.083707 ],
    [ u"ph",u"Valencia",2429,9.6097,124.208 ],
    [ u"ph",u"Valencia",3471,9.7504,123.3922 ],
    [ u"ph",u"Valencia",3771,11.108889,124.5725 ],
    [ u"ph",u"Vallehermoso",10179,10.3349,123.3259 ],
    [ u"ph",u"Vargas",2777,15.5928,120.4867 ],
    [ u"ph",u"Veruela",18114,8.0731,125.9558 ],
    [ u"ph",u"Victorias",86507,10.901537,123.070504 ],
    [ u"ph",u"Victoria",24455,14.2277,121.3292 ],
    [ u"ph",u"Victoria",10088,13.177222,121.278056 ],
    [ u"ph",u"Victoria",2718,12.447222,124.311111 ],
    [ u"ph",u"Vigan",37521,17.574722,120.386944 ],
    [ u"ph",u"Viga",4089,13.8719,124.3091 ],
    [ u"ph",u"Vigo",2482,13.826657,120.179221 ],
    [ u"ph",u"Vigo",2024,12.5162,125.0528 ],
    [ u"ph",u"Villa Aglipay",4800,15.466051,120.452732 ],
    [ u"ph",u"Villaba",3266,11.2135,124.3921 ],
    [ u"ph",u"Villahermosa",2428,13.0458,123.7133 ],
    [ u"ph",u"Villa Isla",2256,15.7703,120.8666 ],
    [ u"ph",u"Villamor",2409,6.704722,124.518611 ],
    [ u"ph",u"Villanueva",7415,8.588889,124.775556 ],
    [ u"ph",u"Villanueva",2592,15.783333,120.55 ],
    [ u"ph",u"Villareal",3765,11.5659,124.9281 ],
    [ u"ph",u"Vintar",5263,18.2284,120.6475 ],
    [ u"ph",u"Vinzons",13617,14.1737,122.9066 ],
    [ u"ph",u"Vista Alegre",2709,9.9984,122.7663 ],
    [ u"ph",u"Vitali",9653,7.371658,122.28924 ],
    [ u"ph",u"Vito",6141,10.9031,123.5154 ],
    [ u"ph",u"Vizal San Pablo",2322,15.0379,120.8649 ],
    [ u"ph",u"Vizal Santo Niño",2529,15.0381,120.8803 ],
    [ u"ph",u"Wañgan",7621,7.159722,125.445278 ],
    [ u"ph",u"Wao",17845,7.683333,124.666667 ],
    [ u"ph",u"Wawa",2873,14.3019,121.4595 ],
    [ u"ph",u"Wawa",4881,13.4632,120.7441 ],
    [ u"ph",u"Wawa",4416,13.7401,121.0529 ],
    [ u"ph",u"Wines",2907,7.193889,125.389167 ],
    [ u"ph",u"Yeban",3557,17.005547,121.948042 ],
    [ u"ph",u"Yook",2820,13.226083,121.964003 ],
    [ u"ph",u"Yubo",2374,10.3896,123.069 ],
    [ u"ph",u"Yumbing",4930,9.2393,124.6578 ],
    [ u"ph",u"Yuni",5714,13.4124,122.4846 ],
    [ u"ph",u"Zamboanga",460879,6.910255,122.071715 ],
    [ u"ph",u"Zamboanguita",6164,9.1025,123.1996 ],
    [ u"ph",u"Zaragoza",7391,16.3871,119.9443 ],
    [ u"ph",u"Zarraga",3253,10.819722,122.608056 ],
    [ u"pk",u"Adilpur",8248,27.936974,69.318685 ],
    [ u"pk",u"Ahmadpur East",116613,29.143092,71.259757 ],
    [ u"pk",u"Ahmadpur Sial",24888,30.67539,71.748284 ],
    [ u"pk",u"Akora",23289,34.003611,72.126111 ],
    [ u"pk",u"Alipur",33599,29.384645,70.911572 ],
    [ u"pk",u"Alipur Chatha",49144,32.267345,73.815336 ],
    [ u"pk",u"Alizai",3334,33.538327,70.346156 ],
    [ u"pk",u"Amangarh",25725,34.005833,71.93 ],
    [ u"pk",u"Arifwala",87386,30.293988,73.073535 ],
    [ u"pk",u"Attock",85504,33.892813,72.240741 ],
    [ u"pk",u"Badah",38856,27.333333,68.016667 ],
    [ u"pk",u"Baddomalhi",18434,31.992826,74.668335 ],
    [ u"pk",u"Badin",73572,24.655994,68.838412 ],
    [ u"pk",u"Baffa",14048,34.290686,72.887248 ],
    [ u"pk",u"Bagarji",8005,27.755986,68.752355 ],
    [ u"pk",u"Bahawalnagar",126654,29.998659,73.253604 ],
    [ u"pk",u"Bahawalpur",552765,29.4,71.683333 ],
    [ u"pk",u"Bandhi",8609,26.586128,68.300585 ],
    [ u"pk",u"Bannu",49028,32.985414,70.602701 ],
    [ u"pk",u"Barkhan",8761,29.897696,69.52555 ],
    [ u"pk",u"Basirpur",41630,30.583185,73.828996 ],
    [ u"pk",u"Bat Khela",46082,34.616667,71.971389 ],
    [ u"pk",u"Begowala",9258,32.437594,74.26824 ],
    [ u"pk",u"Bela",20121,26.2271,66.3111 ],
    [ u"pk",u"Berani",9976,25.785005,68.806856 ],
    [ u"pk",u"Bhag",14556,29.0415,67.8239 ],
    [ u"pk",u"Bhakkar",81974,31.625247,71.06574 ],
    [ u"pk",u"Bhalwal",74765,32.270079,72.876494 ],
    [ u"pk",u"Bhan",16962,26.558311,67.721386 ],
    [ u"pk",u"Bhawana",16217,31.56918,72.648992 ],
    [ u"pk",u"Bhera",31790,32.483177,72.909699 ],
    [ u"pk",u"Bhit Shah",19326,25.804372,68.49265 ],
    [ u"pk",u"Bhopalwala",17340,32.428884,74.363301 ],
    [ u"pk",u"Bozdar",9175,27.182752,68.636042 ],
    [ u"pk",u"Bulri",4997,24.866667,68.333333 ],
    [ u"pk",u"Burewala",183969,30.161423,72.681512 ],
    [ u"pk",u"Chak Azam Sahu",38214,30.75,73.033333 ],
    [ u"pk",u"Chak",14276,27.857545,68.832916 ],
    [ u"pk",u"Chak Jhumra",37212,31.567809,73.183468 ],
    [ u"pk",u"Chakwal",101230,32.933376,72.858531 ],
    [ u"pk",u"Chaman",88606,30.923604,66.451161 ],
    [ u"pk",u"Chambar",12747,25.293133,68.812007 ],
    [ u"pk",u"Charsadda",95358,34.143453,71.731731 ],
    [ u"pk",u"Chawinda",23598,32.34692,74.706123 ],
    [ u"pk",u"Cherat",2986,33.823284,71.891527 ],
    [ u"pk",u"Chichawatni",82787,30.533333,72.7 ],
    [ u"pk",u"Chiniot",201840,31.72,72.978889 ],
    [ u"pk",u"Chishtian Mandi",122235,29.8,72.866667 ],
    [ u"pk",u"Chitral",36097,35.846227,71.785801 ],
    [ u"pk",u"Choa Saidan Shah",15343,32.720056,72.984861 ],
    [ u"pk",u"Chor",16302,25.516667,69.766667 ],
    [ u"pk",u"Chuhar Kana",69341,31.505,73.585556 ],
    [ u"pk",u"Chunian",57329,30.963967,73.980293 ],
    [ u"pk",u"Dadu",139836,26.732865,67.776306 ],
    [ u"pk",u"Dajal",17629,29.557673,70.376146 ],
    [ u"pk",u"Dalbandin",14623,28.894702,64.410094 ],
    [ u"pk",u"Daro",10870,24.794626,68.180523 ],
    [ u"pk",u"Darya Khan",15047,31.791232,71.103941 ],
    [ u"pk",u"Darya Khan Mari",8974,26.677475,68.285902 ],
    [ u"pk",u"Daska",126961,32.324262,74.349741 ],
    [ u"pk",u"Daud Khel",26394,32.874984,71.570125 ],
    [ u"pk",u"Daulatpur",14575,26.501541,67.970605 ],
    [ u"pk",u"Daultala",11813,33.192529,73.141284 ],
    [ u"pk",u"Daur",17578,26.458343,68.319153 ],
    [ u"pk",u"Dera Bugti",18122,29.03069,69.150992 ],
    [ u"pk",u"Dera Din Panah",14877,30.6766,70.730522 ],
    [ u"pk",u"Dera Ghazi Khan",236162,30.056142,70.634766 ],
    [ u"pk",u"Dera Ismail Khan",101658,31.832691,70.902398 ],
    [ u"pk",u"Dhadar",15091,29.475268,67.651346 ],
    [ u"pk",u"Digri",31844,25.15579,69.111294 ],
    [ u"pk",u"Dijkot",27468,31.216667,72.983333 ],
    [ u"pk",u"Dina",46305,28.230603,68.643012 ],
    [ u"pk",u"Dinga",39796,32.639764,73.722015 ],
    [ u"pk",u"Dipalpur",74662,30.670912,73.652921 ],
    [ u"pk",u"Diplo",11576,24.466667,69.584007 ],
    [ u"pk",u"Dir",29871,35.205833,71.875556 ],
    [ u"pk",u"Doaba",8894,33.424444,70.736389 ],
    [ u"pk",u"Dokri",14800,27.374269,68.096729 ],
    [ u"pk",u"Duki",6385,30.154145,68.572798 ],
    [ u"pk",u"Dullewala",48680,31.835867,71.436252 ],
    [ u"pk",u"Dunga Bunga",25891,29.749307,73.243236 ],
    [ u"pk",u"Dunyapur",34043,29.799502,71.719581 ],
    [ u"pk",u"Eminabad",22677,32.042188,74.259435 ],
    [ u"pk",u"Faisalabad",2507302,31.416667,73.083333 ],
    [ u"pk",u"Faqirwali",25185,29.466307,73.034034 ],
    [ u"pk",u"Faruka",21746,31.887224,72.414398 ],
    [ u"pk",u"Fatehpur",18125,31.179592,71.209457 ],
    [ u"pk",u"Fazalpur",28212,32.183333,75.066667 ],
    [ u"pk",u"Fort Abbas",40624,29.1925,72.853611 ],
    [ u"pk",u"Gambat",34007,27.351453,68.52051 ],
    [ u"pk",u"Garhi Khairo",13666,28.060584,67.980274 ],
    [ u"pk",u"Garhi Yasin",14811,27.906895,68.510961 ],
    [ u"pk",u"Garh Maharaja",29151,30.833877,71.905293 ],
    [ u"pk",u"Gharo",19525,24.742407,67.585651 ],
    [ u"pk",u"Ghauspur",29769,28.139065,69.083053 ],
    [ u"pk",u"Ghotki",64319,28.00604,69.316077 ],
    [ u"pk",u"Gilgit",9891,35.918685,74.312451 ],
    [ u"pk",u"Gojra",139767,31.148744,72.686556 ],
    [ u"pk",u"Gujar Khan",69394,33.255786,73.302546 ],
    [ u"pk",u"Gujranwala",1384869,32.161667,74.188309 ],
    [ u"pk",u"Gujrat",301595,32.572842,74.078969 ],
    [ u"pk",u"Gwadar",51907,25.12163,62.325411 ],
    [ u"pk",u"Hafizabad",153701,32.067857,73.685449 ],
    [ u"pk",u"Hala",47918,25.813083,68.422733 ],
    [ u"pk",u"Hangu",36152,33.531085,71.05934 ],
    [ u"pk",u"Haripur",56981,33.999967,72.934093 ],
    [ u"pk",u"Harnai",11067,30.100474,67.937414 ],
    [ u"pk",u"Harnoli",15669,32.279167,71.553889 ],
    [ u"pk",u"Harunabad",72453,29.613333,73.138889 ],
    [ u"pk",u"Hasan Abdal",45678,30.433333,72.7 ],
    [ u"pk",u"Hasilpur",88056,29.712222,72.555278 ],
    [ u"pk",u"Havelian",40497,34.053605,73.165711 ],
    [ u"pk",u"Haveli",65308,30.450157,73.698878 ],
    [ u"pk",u"Hazro",26308,33.909137,72.492116 ],
    [ u"pk",u"Hingorja",22264,27.210882,68.415977 ],
    [ u"pk",u"Hunza",15606,36.318987,74.664273 ],
    [ u"pk",u"Hyderabad",1386840,25.39242,68.373656 ],
    [ u"pk",u"Isa Khel",17588,32.674722,71.281111 ],
    [ u"pk",u"Islamabad",756105,33.69,73.0551 ],
    [ u"pk",u"Islamkot",12426,24.6997,70.177 ],
    [ u"pk",u"Jacobabad",170653,28.281004,68.438759 ],
    [ u"pk",u"Jalalpur Jattan",93910,32.637443,74.218286 ],
    [ u"pk",u"Jalalpur Pirwala",37391,29.506872,71.219172 ],
    [ u"pk",u"Jampur",63810,29.644138,70.595436 ],
    [ u"pk",u"Jam Sahib",6870,26.296729,68.629418 ],
    [ u"pk",u"Jand",18169,33.429853,72.019285 ],
    [ u"pk",u"Jaranwala",119820,31.333333,73.433333 ],
    [ u"pk",u"Jati",9152,24.353901,68.267064 ],
    [ u"pk",u"Jatoi",47158,29.510493,70.846764 ],
    [ u"pk",u"Jauharabad",46542,32.2898,72.281295 ],
    [ u"pk",u"Jhang",341311,31.306773,72.32814 ],
    [ u"pk",u"Jhawarian",27892,32.361389,72.622778 ],
    [ u"pk",u"Jhelum",164128,32.933132,73.726367 ],
    [ u"pk",u"Jhol",16068,25.955068,68.888212 ],
    [ u"pk",u"Jhudo",25909,24.957833,69.312161 ],
    [ u"pk",u"Jiwani",16324,25.04992,61.746805 ],
    [ u"pk",u"Johi",16311,26.692062,67.613305 ],
    [ u"pk",u"Kabirwala",60799,30.406766,71.8667 ],
    [ u"pk",u"Kadhan",6854,24.481025,68.9859 ],
    [ u"pk",u"Kahna Nau",45885,31.369167,74.365278 ],
    [ u"pk",u"Kahuta",22550,33.591303,73.38676 ],
    [ u"pk",u"Kalabagh",15975,32.964999,71.556973 ],
    [ u"pk",u"Kalaswala",12575,32.200932,74.649138 ],
    [ u"pk",u"Kalat",26704,29.022515,66.591604 ],
    [ u"pk",u"Kalur Kot",25573,32.156389,71.259444 ],
    [ u"pk",u"Kamalia",112459,30.733333,72.65 ],
    [ u"pk",u"Kambar",77510,27.586755,68.001026 ],
    [ u"pk",u"Kamir",24052,30.433333,73.05 ],
    [ u"pk",u"Kamoke",199589,31.974444,74.224444 ],
    [ u"pk",u"Kamra",43776,33.747336,73.511066 ],
    [ u"pk",u"Kandiari",6861,26.91558,68.521595 ],
    [ u"pk",u"Kandiaro",26808,27.060114,68.209088 ],
    [ u"pk",u"Kanganpur",21787,30.766286,74.123107 ],
    [ u"pk",u"Karachi",11627378,24.9056,67.0822 ],
    [ u"pk",u"Karak",32587,30.328056,66.898611 ],
    [ u"pk",u"Kashmor",33734,28.433333,69.583333 ],
    [ u"pk",u"Kasur",290728,31.115556,74.446667 ],
    [ u"pk",u"Keti Bandar",2934,24.144722,67.449722 ],
    [ u"pk",u"Khadro",9997,26.147227,68.71764 ],
    [ u"pk",u"Khairpur",124650,27.529483,68.761698 ],
    [ u"pk",u"Khairpur Nathan Shah",30287,27.09359,67.733662 ],
    [ u"pk",u"Khalabat",39164,34.06,72.889444 ],
    [ u"pk",u"Khanewal",154407,30.3,71.933333 ],
    [ u"pk",u"Khangah Dogran",30312,31.831667,73.623056 ],
    [ u"pk",u"Khangarh",19697,29.917305,71.16184 ],
    [ u"pk",u"Khanpur",142468,28.645338,70.656702 ],
    [ u"pk",u"Khanpur",22274,27.843579,69.413732 ],
    [ u"pk",u"Kharan",30845,28.583333,65.416667 ],
    [ u"pk",u"Kharian",81459,32.780556,74.275 ],
    [ u"pk",u"Khewra",32619,32.647931,73.010582 ],
    [ u"pk",u"Khipro",28731,25.828471,69.377194 ],
    [ u"pk",u"Khurianwala",35290,31.500556,73.266667 ],
    [ u"pk",u"Khushab",102823,32.296667,72.3525 ],
    [ u"pk",u"Khuzdar",141286,27.738385,66.643365 ],
    [ u"pk",u"Kohat",151488,33.581958,71.449291 ],
    [ u"pk",u"Kohlu",11090,29.896151,69.251988 ],
    [ u"pk",u"Kot Addu",104247,30.469197,70.967141 ],
    [ u"pk",u"Kot Diji",25617,27.342724,68.708343 ],
    [ u"pk",u"Kotli Loharan",21462,32.588303,74.493208 ],
    [ u"pk",u"Kot Radha Kishan",45951,31.1725,74.099722 ],
    [ u"pk",u"Kotri",72700,25.366004,68.312155 ],
    [ u"pk",u"Kot Samaba",22952,28.552205,70.468374 ],
    [ u"pk",u"Kulachi",22378,31.928611,70.459167 ],
    [ u"pk",u"Kundian",35417,32.458722,71.47754 ],
    [ u"pk",u"Kunjah",28102,32.528482,73.97368 ],
    [ u"pk",u"Kunri",26774,25.178471,69.569132 ],
    [ u"pk",u"Lachi",18538,33.383253,71.338576 ],
    [ u"pk",u"Lahore",6312576,31.549722,74.343611 ],
    [ u"pk",u"Lakhi",13600,27.849583,68.699356 ],
    [ u"pk",u"Lakki Marwat",36394,32.607953,70.911416 ],
    [ u"pk",u"Lalian",31364,31.82414,72.799713 ],
    [ u"pk",u"Larkana",364168,27.555082,68.214137 ],
    [ u"pk",u"Liaqatabad",26374,32.286441,71.357976 ],
    [ u"pk",u"Liliani",12211,32.206513,72.953724 ],
    [ u"pk",u"Lodhran",97276,29.256944,71.55 ],
    [ u"pk",u"Loralai",37791,30.370531,68.597981 ],
    [ u"pk",u"Mach",16932,29.86371,67.329785 ],
    [ u"pk",u"Madeji",14803,27.754434,68.452556 ],
    [ u"pk",u"Mailsi",64564,29.800278,72.175833 ],
    [ u"pk",u"Malakwal",34599,32.55362,73.212339 ],
    [ u"pk",u"Mamu Kanjan",31912,30.833333,72.8 ],
    [ u"pk",u"Mandi Bahauddin",129770,32.583387,73.484315 ],
    [ u"pk",u"Mangla",16263,31.893056,72.381667 ],
    [ u"pk",u"Mankera",10818,31.386555,71.440668 ],
    [ u"pk",u"Mansehra",66513,34.333333,73.2 ],
    [ u"pk",u"Mardan",300545,34.201946,72.052539 ],
    [ u"pk",u"Mastung",29086,29.799358,66.845053 ],
    [ u"pk",u"Matiari",18930,25.596092,68.446665 ],
    [ u"pk",u"Matli",50401,25.043115,68.655677 ],
    [ u"pk",u"Mehar",30430,27.180668,67.822883 ],
    [ u"pk",u"Mehrabpur",35264,28.108495,68.025399 ],
    [ u"pk",u"Mian Channun",76248,30.440042,72.354314 ],
    [ u"pk",u"Mianwali",89596,32.574095,71.526386 ],
    [ u"pk",u"Minchinabad",29251,30.163001,73.568542 ],
    [ u"pk",u"Mingaora",227423,34.77584,72.36249 ],
    [ u"pk",u"Miram Shah",3334,33.008611,70.069722 ],
    [ u"pk",u"Miro Khan",10590,27.759913,68.092124 ],
    [ u"pk",u"Mirpur Bathoro",8867,24.728613,68.260256 ],
    [ u"pk",u"Mirpur Khas",215739,25.5251,69.0159 ],
    [ u"pk",u"Mirpur Mathelo",49313,28.022713,69.548858 ],
    [ u"pk",u"Mirpur Sakro",8371,24.547425,67.627713 ],
    [ u"pk",u"Mirwah",12140,25.309281,69.05211 ],
    [ u"pk",u"Mitha Tiwana",26430,32.248611,72.110833 ],
    [ u"pk",u"Mithi",23432,24.731826,69.798113 ],
    [ u"pk",u"Moro",76794,26.664586,68.00156 ],
    [ u"pk",u"Multan",1437644,30.195556,71.475278 ],
    [ u"pk",u"Muridke",164292,31.760027,73.835687 ],
    [ u"pk",u"Murree",25245,33.907268,73.392946 ],
    [ u"pk",u"Mustafabad",45809,30.776217,73.698165 ],
    [ u"pk",u"Muzaffarabad",19748,34.37002,73.47082 ],
    [ u"pk",u"Muzaffargarh",165240,30.07537,71.192129 ],
    [ u"pk",u"Nabisar",6256,25.068535,69.641861 ],
    [ u"pk",u"Nankana Sahib",56383,31.4475,73.697222 ],
    [ u"pk",u"Narang",34776,31.913197,74.517556 ],
    [ u"pk",u"Narowal",68311,32.1,74.883333 ],
    [ u"pk",u"Nasirabad",27810,27.380909,67.916775 ],
    [ u"pk",u"Naudero",33457,27.66477,68.362174 ],
    [ u"pk",u"Naukot",22082,24.858689,69.402381 ],
    [ u"pk",u"Naushahro Firoz",17632,26.842382,68.122984 ],
    [ u"pk",u"Nawabshah",229590,26.248334,68.409554 ],
    [ u"pk",u"Nowshera",96806,34.005823,71.997727 ],
    [ u"pk",u"Nushki",27683,29.554232,66.021479 ],
    [ u"pk",u"Okara",223714,30.808056,73.445833 ],
    [ u"pk",u"Ormara",13027,25.2088,64.6357 ],
    [ u"pk",u"Pabbi",37310,34.010556,71.798889 ],
    [ u"pk",u"Paharpur",17295,32.103844,70.97235 ],
    [ u"pk",u"Pakpattan",126743,30.341044,73.386642 ],
    [ u"pk",u"Pano Aqil",72885,27.856848,69.111564 ],
    [ u"pk",u"Pasni",33114,25.263113,63.471033 ],
    [ u"pk",u"Pasrur",53379,32.264133,74.663425 ],
    [ u"pk",u"Pattoki",70457,31.016667,73.85 ],
    [ u"pk",u"Peshawar",1219248,34.008,71.578488 ],
    [ u"pk",u"Phalia",24788,32.429733,73.577454 ],
    [ u"pk",u"Phulji",7878,26.882513,67.680695 ],
    [ u"pk",u"Pind Dadan Khan",22000,32.587887,73.045638 ],
    [ u"pk",u"Pindi Bhattian",35086,31.89781,73.273019 ],
    [ u"pk",u"Pindi Gheb",34311,33.240235,72.266094 ],
    [ u"pk",u"Pishin",24242,30.580278,66.996111 ],
    [ u"pk",u"Pithoro",6440,25.516667,69.383333 ],
    [ u"pk",u"Qadirpur Ran",20406,30.292385,71.671167 ],
    [ u"pk",u"Quetta",733970,30.199004,67.009708 ],
    [ u"pk",u"Rabwah",50207,31.755833,72.919722 ],
    [ u"pk",u"Radhan",16787,27.183333,67.95 ],
    [ u"pk",u"Raiwind",31590,31.254444,74.217778 ],
    [ u"pk",u"Raja Jang",24406,31.220833,74.251944 ],
    [ u"pk",u"Rajanpur",50679,29.103513,70.325038 ],
    [ u"pk",u"Rajo Khanani",7683,24.984051,68.853573 ],
    [ u"pk",u"Ranipur",22496,27.28792,68.505046 ],
    [ u"pk",u"Rasulnagar",14392,32.328532,73.781357 ],
    [ u"pk",u"Ratodero",47822,27.802955,68.287078 ],
    [ u"pk",u"Rawalpindi",1743599,33.6007,73.0679 ],
    [ u"pk",u"Renala Khurd",37109,30.883333,73.6 ],
    [ u"pk",u"Risalpur",37099,34.061865,71.991655 ],
    [ u"pk",u"Rohri",50668,27.692233,68.895062 ],
    [ u"pk",u"Rojhan",13030,28.686768,69.953426 ],
    [ u"pk",u"Rustam",9048,27.968967,68.804809 ],
    [ u"pk",u"Sadiqabad",189931,28.30623,70.130646 ],
    [ u"pk",u"Sahiwal",235765,30.666667,73.1 ],
    [ u"pk",u"Sakrand",31631,26.138393,68.273609 ],
    [ u"pk",u"Samaro",8784,25.281473,69.396541 ],
    [ u"pk",u"Sambrial",62892,32.474553,74.35209 ],
    [ u"pk",u"Sanghar",62057,26.046558,68.9481 ],
    [ u"pk",u"Sanjwal",10657,33.760833,72.433611 ],
    [ u"pk",u"Sann",8834,26.041841,68.137772 ],
    [ u"pk",u"Sarai Alamgir",44133,32.901221,73.755907 ],
    [ u"pk",u"Sarai Naurang",19695,32.825906,70.781358 ],
    [ u"pk",u"Sarai Sidhu",15631,30.594889,71.969766 ],
    [ u"pk",u"Sargodha",542761,32.083611,72.671111 ],
    [ u"pk",u"Sarhari",11434,26.095895,68.478148 ],
    [ u"pk",u"Sehwan",41152,26.427943,67.863004 ],
    [ u"pk",u"Setharja",32653,27.200684,68.478572 ],
    [ u"pk",u"Shabqadar",66568,34.213903,71.555226 ],
    [ u"pk",u"Shahdadkot",75439,27.847709,67.905497 ],
    [ u"pk",u"Shahdadpur",67275,25.924059,68.619991 ],
    [ u"pk",u"Shahpur Chakar",21447,26.154968,68.650934 ],
    [ u"pk",u"Shahpur City",14152,32.287021,72.430825 ],
    [ u"pk",u"Sharqpur",31853,31.463333,74.1 ],
    [ u"pk",u"Shekhupura",361408,31.713056,73.978333 ],
    [ u"pk",u"Shikarpur",156961,27.957057,68.637886 ],
    [ u"pk",u"Shinpokh",1111,34.329204,71.178206 ],
    [ u"pk",u"Shorkot",67467,31.909907,70.877409 ],
    [ u"pk",u"Shujaabad",65972,29.879668,71.29313 ],
    [ u"pk",u"Sialkot",477537,32.510103,74.54313 ],
    [ u"pk",u"Sibi",64096,29.5448,67.8764 ],
    [ u"pk",u"Sillanwali",27022,31.826106,72.539843 ],
    [ u"pk",u"Sinjhoro",15971,26.030307,68.808979 ],
    [ u"pk",u"Sita Road",27588,27.033333,67.85 ],
    [ u"pk",u"Sodhra",15976,32.461622,74.182339 ],
    [ u"pk",u"Sohbatpur",8941,28.520173,68.543437 ],
    [ u"pk",u"Sujawal",27599,24.602968,68.078902 ],
    [ u"pk",u"Sukheke",32834,31.880703,73.472447 ],
    [ u"pk",u"Sukkur",417923,27.705164,68.857383 ],
    [ u"pk",u"Surab",13105,28.491389,66.2585 ],
    [ u"pk",u"Swabi",97402,34.119881,72.469871 ],
    [ u"pk",u"Talagang",44974,32.929731,72.415829 ],
    [ u"pk",u"Talhar",21155,24.883333,68.816667 ],
    [ u"pk",u"Tandlianwala",38296,31.033333,73.133333 ],
    [ u"pk",u"Tando Adam",125646,25.763736,68.660982 ],
    [ u"pk",u"Tando Ghulam Ali",16299,25.124332,68.890127 ],
    [ u"pk",u"Tando Jam",31613,25.427178,68.536192 ],
    [ u"pk",u"Tando Muhammad Khan",72687,25.123007,68.535773 ],
    [ u"pk",u"Tangi",29447,34.300556,71.653611 ],
    [ u"pk",u"Tangwani",9256,28.278699,68.997185 ],
    [ u"pk",u"Tank",38504,32.221683,70.379282 ],
    [ u"pk",u"Taunsa",44867,30.458744,70.746929 ],
    [ u"pk",u"Thano Bula Khan",14739,25.41113,67.785188 ],
    [ u"pk",u"Thatta",44304,24.747449,67.923528 ],
    [ u"pk",u"Thul",34473,28.240345,68.775878 ],
    [ u"pk",u"Toba Tek Singh",69084,30.974326,72.482694 ],
    [ u"pk",u"Topi",36343,34.070408,72.623577 ],
    [ u"pk",u"Turbat",75727,26.002284,63.043994 ],
    [ u"pk",u"Ubauro",23463,28.165241,69.728898 ],
    [ u"pk",u"Uch",23992,29.235621,71.049889 ],
    [ u"pk",u"Umarkot",42077,25.36157,69.736241 ],
    [ u"pk",u"Usta Muhammad",43988,28.179429,68.044538 ],
    [ u"pk",u"Uthal",16485,25.807222,66.621944 ],
    [ u"pk",u"Utmanzai",29425,33.940337,71.545547 ],
    [ u"pk",u"Vihari",112873,30.033333,72.35 ],
    [ u"pk",u"Wah",237584,33.797995,72.695703 ],
    [ u"pk",u"Wana",2223,32.298889,69.5725 ],
    [ u"pk",u"Warah",18725,27.448082,67.797761 ],
    [ u"pk",u"Warburton",24294,31.55,73.833333 ],
    [ u"pk",u"Wazirabad",102474,32.445831,74.115944 ],
    [ u"pk",u"Yazman",24579,29.121218,71.744587 ],
    [ u"pk",u"Zafarwal",23077,32.34631,74.899873 ],
    [ u"pk",u"Zahir Pir",34119,28.812386,70.524047 ],
    [ u"pk",u"Zaida",26789,34.060278,72.467778 ],
    [ u"pk",u"Zhob",50559,31.341111,69.448056 ],
    [ u"pk",u"Ziarat",733,30.343651,67.741324 ],
    [ u"pl",u"Aleksandrow Kujawski",12285,52.877639,18.703163 ],
    [ u"pl",u"Aleksandrow Lodzki",20292,51.81773,19.300709 ],
    [ u"pl",u"Andrychow",21954,49.854141,19.338582 ],
    [ u"pl",u"Augustow",29752,53.844711,22.980133 ],
    [ u"pl",u"Barlinek",14385,52.987733,15.204479 ],
    [ u"pl",u"Bartoszyce",25660,54.250693,20.814911 ],
    [ u"pl",u"Bedzin",58236,50.319705,19.145249 ],
    [ u"pl",u"Belchatow",62896,51.366503,19.374485 ],
    [ u"pl",u"Biala Podlaska",57541,52.03129,23.121418 ],
    [ u"pl",u"Bialogard",24265,54.00937,15.986562 ],
    [ u"pl",u"Bialystok",291855,53.133333,23.15 ],
    [ u"pl",u"Bielawa",30824,50.686712,16.621677 ],
    [ u"pl",u"Bielsko-Biala",176515,49.822449,19.046863 ],
    [ u"pl",u"Bielsk Podlaski",26745,52.770017,23.190889 ],
    [ u"pl",u"Bierun",19659,50.088872,19.093498 ],
    [ u"pl",u"Bilgoraj",26987,50.53583,22.727577 ],
    [ u"pl",u"Biskupiec",10340,53.864674,20.956922 ],
    [ u"pl",u"Blonie",12195,52.194994,20.616058 ],
    [ u"pl",u"Bochnia",29184,49.97215,20.426816 ],
    [ u"pl",u"Bogatynia",19221,50.905611,14.959402 ],
    [ u"pl",u"Boguszow-Gorce",16726,50.755135,16.204937 ],
    [ u"pl",u"Boleslawiec",40682,51.264183,15.569703 ],
    [ u"pl",u"Braniewo",18356,54.379722,19.82 ],
    [ u"pl",u"Brodnica",27341,53.25,19.4 ],
    [ u"pl",u"Brwinow",11669,52.142784,20.71795 ],
    [ u"pl",u"Brzeg",38259,50.857495,17.46976 ],
    [ u"pl",u"Brzeg Dolny",12707,51.267976,16.721664 ],
    [ u"pl",u"Brzesko",16866,49.970044,20.607661 ],
    [ u"pl",u"Brzeszcze",11787,49.984333,19.142123 ],
    [ u"pl",u"Brzeziny",12319,51.800545,19.749864 ],
    [ u"pl",u"Bukowno",10874,50.262676,19.467277 ],
    [ u"pl",u"Busko-Zdroj",17095,50.466667,20.716667 ],
    [ u"pl",u"Bydgoszcz",366452,53.127062,18.019987 ],
    [ u"pl",u"Bystrzyca Klodzka",10589,50.298252,16.653029 ],
    [ u"pl",u"Bytom",189186,50.348017,18.932822 ],
    [ u"pl",u"Bytow",16724,54.176362,17.487638 ],
    [ u"pl",u"Chelmek",9059,50.101628,19.248013 ],
    [ u"pl",u"Chelmno",20576,53.35,18.433333 ],
    [ u"pl",u"Chelmza",15403,53.18596,18.605931 ],
    [ u"pl",u"Chodziez",19776,52.993089,16.91405 ],
    [ u"pl",u"Chojnice",39407,53.695062,17.566093 ],
    [ u"pl",u"Chojnow",14209,51.273155,15.935862 ],
    [ u"pl",u"Chorzow",113430,50.305817,18.974203 ],
    [ u"pl",u"Choszczno",15733,53.169051,15.420537 ],
    [ u"pl",u"Chrzanow",39973,50.139468,19.40626 ],
    [ u"pl",u"Ciechanow",46438,52.878352,20.618754 ],
    [ u"pl",u"Ciechocinek",10832,52.877244,18.792883 ],
    [ u"pl",u"Cieszyn",35586,49.74634,18.636093 ],
    [ u"pl",u"Cracow",755050,50.083333,19.916667 ],
    [ u"pl",u"Czarnkow",11562,52.902144,16.564126 ],
    [ u"pl",u"Czechowice-Dziedzice",34703,49.913416,19.004789 ],
    [ u"pl",u"Czeladz",34308,50.315417,19.078245 ],
    [ u"pl",u"Czersk",9390,53.796296,17.972567 ],
    [ u"pl",u"Czestochowa",248125,50.796455,19.124088 ],
    [ u"pl",u"Czluchow",14759,53.672639,17.361185 ],
    [ u"pl",u"Dabrowa Gornicza",130601,50.326206,19.224381 ],
    [ u"pl",u"Dabrowa Tarnowska",11291,50.174915,20.990776 ],
    [ u"pl",u"Darlowo",14398,54.421168,16.409652 ],
    [ u"pl",u"Debica",47366,50.052379,21.414763 ],
    [ u"pl",u"Deblin",19561,51.560755,21.857117 ],
    [ u"pl",u"Debno",13804,52.735427,14.703947 ],
    [ u"pl",u"Dobre Miasto",10514,53.987652,20.390809 ],
    [ u"pl",u"Drawsko Pomorskie",11275,53.529754,15.80987 ],
    [ u"pl",u"Drezdenko",10541,52.83831,15.830785 ],
    [ u"pl",u"Dzialdowo",21127,53.239581,20.170041 ],
    [ u"pl",u"Dzierzoniow",34888,50.732045,16.648718 ],
    [ u"pl",u"Elblag",127558,54.1522,19.408841 ],
    [ u"pl",u"Elk",55769,53.826478,22.365416 ],
    [ u"pl",u"Garwolin",15912,51.897384,21.614392 ],
    [ u"pl",u"Gdansk",461865,54.36085,18.658291 ],
    [ u"pl",u"Gdynia",253730,54.5,18.55 ],
    [ u"pl",u"Gizycko",29972,54.03811,21.764411 ],
    [ u"pl",u"Gliwice",198835,50.297612,18.676583 ],
    [ u"pl",u"Glogow",68530,51.663026,16.075688 ],
    [ u"pl",u"Glowno",15103,51.966926,19.726598 ],
    [ u"pl",u"Glubczyce",13697,50.202034,17.829379 ],
    [ u"pl",u"Glucholazy",15120,50.316769,17.388328 ],
    [ u"pl",u"Gniezno",70269,52.53944,17.611262 ],
    [ u"pl",u"Goldap",13769,54.309055,22.303898 ],
    [ u"pl",u"Goleniow",22505,53.563753,14.830032 ],
    [ u"pl",u"Golub-Dobrzyn",12937,53.109425,19.054212 ],
    [ u"pl",u"Gora",12668,51.668392,16.538039 ],
    [ u"pl",u"Gora Kalwaria",10777,51.981529,21.215053 ],
    [ u"pl",u"Gorlice",28609,49.658084,21.159693 ],
    [ u"pl",u"Gorzow Wielkopolski",124430,52.73679,15.228775 ],
    [ u"pl",u"Gostyn",20771,51.882468,17.012255 ],
    [ u"pl",u"Grajewo",22803,53.648062,22.459669 ],
    [ u"pl",u"Grodkow",8654,50.698662,17.384761 ],
    [ u"pl",u"Grodzisk Mazowiecki",26684,52.106384,20.623141 ],
    [ u"pl",u"Grodzisk Wielkopolski",13826,52.227622,16.365335 ],
    [ u"pl",u"Grojec",14880,51.862518,20.867569 ],
    [ u"pl",u"Grudziadz",99486,53.483333,18.774123 ],
    [ u"pl",u"Gryfice",16720,53.91624,15.198219 ],
    [ u"pl",u"Gryfino",21270,53.253865,14.490097 ],
    [ u"pl",u"Gubin",16629,51.949629,14.727588 ],
    [ u"pl",u"Hajnowka",22157,52.743281,23.581223 ],
    [ u"pl",u"Hrubieszow",18605,50.805019,23.892508 ],
    [ u"pl",u"Ilawa",32557,53.586851,19.560983 ],
    [ u"pl",u"Inowroclaw",77597,52.798858,18.263875 ],
    [ u"pl",u"Janikowo",8942,52.440681,17.028924 ],
    [ u"pl",u"Janow Lubelski",11811,50.706673,22.412479 ],
    [ u"pl",u"Jarocin",25665,51.97076,17.498773 ],
    [ u"pl",u"Jaroslaw",40134,50.016381,22.677813 ],
    [ u"pl",u"Jaslo",37851,49.743718,21.47095 ],
    [ u"pl",u"Jawor",24269,51.051317,16.193471 ],
    [ u"pl",u"Jaworzno",96541,50.206025,19.270062 ],
    [ u"pl",u"Jedrzejow",16792,50.640023,20.305868 ],
    [ u"pl",u"Jelenia Gora",87310,50.89828,15.729929 ],
    [ u"pl",u"Jozefow",17910,51.806452,21.220953 ],
    [ u"pl",u"Kalety",8670,50.562701,18.892596 ],
    [ u"pl",u"Kalisz",108759,51.76109,18.091018 ],
    [ u"pl",u"Kamienna Gora",21743,50.783136,16.030371 ],
    [ u"pl",u"Kamien Pomorski",9036,53.968946,14.772834 ],
    [ u"pl",u"Karczew",10319,52.078202,21.250481 ],
    [ u"pl",u"Kartuzy",15002,54.333333,18.2 ],
    [ u"pl",u"Katowice",317316,50.258415,19.027545 ],
    [ u"pl",u"Kedzierzyn-Kozle",65636,50.35,18.2 ],
    [ u"pl",u"Kepno",14813,51.278425,17.985831 ],
    [ u"pl",u"Ketrzyn",28172,54.079293,21.370583 ],
    [ u"pl",u"Kety",19249,49.87982,19.218778 ],
    [ u"pl",u"Kholm",68043,51.135831,23.482511 ],
    [ u"pl",u"Kielce",208598,50.833333,20.666667 ],
    [ u"pl",u"Klobuck",13190,50.90298,18.937036 ],
    [ u"pl",u"Klodzko",28627,50.436362,16.653612 ],
    [ u"pl",u"Kluczbork",25978,50.97429,18.213765 ],
    [ u"pl",u"Knurow",39744,50.219708,18.65067 ],
    [ u"pl",u"Kobylka",17659,52.329545,21.191248 ],
    [ u"pl",u"Kolno",10659,53.409314,21.932665 ],
    [ u"pl",u"Kolobrzeg",44377,54.175112,15.591352 ],
    [ u"pl",u"Kolo",23493,52.207244,18.631954 ],
    [ u"pl",u"Koluszki",13343,51.766667,19.8 ],
    [ u"pl",u"Konin",81258,52.208577,18.254103 ],
    [ u"pl",u"Konskie",20756,51.191432,20.408217 ],
    [ u"pl",u"Konstancin-Jeziorna",16548,52.093277,21.118037 ],
    [ u"pl",u"Konstantynow Lodzki",17415,51.747873,19.332181 ],
    [ u"pl",u"Koronowo",10965,53.31048,17.945527 ],
    [ u"pl",u"Koscian",24096,52.088293,16.648657 ],
    [ u"pl",u"Koscierzyna",23361,54.124787,17.972062 ],
    [ u"pl",u"Kostrzyn",18099,52.590891,14.651163 ],
    [ u"pl",u"Koszalin",107450,54.193589,16.184916 ],
    [ u"pl",u"Kowary",11834,50.795493,15.833476 ],
    [ u"pl",u"Kozienice",18677,51.583602,21.549937 ],
    [ u"pl",u"Kozuchow",9679,51.745394,15.594384 ],
    [ u"pl",u"Krapkowice",18275,50.474689,17.965447 ],
    [ u"pl",u"Krasnik",35834,50.922758,22.22648 ],
    [ u"pl",u"Krasnystaw",19532,50.985028,23.172715 ],
    [ u"pl",u"Krosno",47784,49.688663,21.770579 ],
    [ u"pl",u"Krosno Odrzanskie",12178,52.052902,15.100955 ],
    [ u"pl",u"Krotoszyn",29231,51.698677,17.437383 ],
    [ u"pl",u"Kruszwica",9494,52.675624,18.331314 ],
    [ u"pl",u"Krzeszowice",9978,50.13446,19.636713 ],
    [ u"pl",u"Kudowa-Zdroj",10176,50.45,16.25 ],
    [ u"pl",u"Kutno",48323,52.228954,19.361672 ],
    [ u"pl",u"Kwidzyn",37601,53.724949,18.931137 ],
    [ u"pl",u"Lancut",18266,50.06819,22.228955 ],
    [ u"pl",u"Lapy",16434,52.991104,22.884219 ],
    [ u"pl",u"Lask",18577,51.588037,19.125084 ],
    [ u"pl",u"Laziska Gorne",21972,50.14643,18.839423 ],
    [ u"pl",u"Lebork",35161,54.539214,17.750121 ],
    [ u"pl",u"Leczna",21719,51.304588,22.883235 ],
    [ u"pl",u"Leczyca",15528,52.059352,19.20184 ],
    [ u"pl",u"Ledziny",15928,50.129707,19.10729 ],
    [ u"pl",u"Legionowo",50786,52.401488,20.926636 ],
    [ u"pl",u"Legnica",106033,51.210062,16.161898 ],
    [ u"pl",u"Leszno",63565,51.848268,16.57022 ],
    [ u"pl",u"Lezajsk",13958,50.260132,22.421242 ],
    [ u"pl",u"Libiaz",17834,50.100376,19.322176 ],
    [ u"pl",u"Lidzbark Warminski",16540,54.128687,20.57807 ],
    [ u"pl",u"Limanowa",14714,49.704128,20.42245 ],
    [ u"pl",u"Lipno",14821,52.845174,19.182561 ],
    [ u"pl",u"Lobez",10609,53.638794,15.62231 ],
    [ u"pl",u"Lomianki",15315,52.343844,20.882817 ],
    [ u"pl",u"Lomza",63723,53.173552,22.06538 ],
    [ u"pl",u"Lowicz",30397,52.113739,19.948742 ],
    [ u"pl",u"Lubaczow",12595,50.159707,23.122425 ],
    [ u"pl",u"Luban",22245,51.120143,15.287678 ],
    [ u"pl",u"Lubartow",22839,51.462888,22.607754 ],
    [ u"pl",u"Lubawa",9302,53.504283,19.749657 ],
    [ u"pl",u"Lubin",77532,51.400825,16.203381 ],
    [ u"pl",u"Lubliniec",24133,50.672289,18.68672 ],
    [ u"pl",u"Lublin",360044,51.25,22.566667 ],
    [ u"pl",u"Lubon",26431,52.347049,16.892671 ],
    [ u"pl",u"Lubsko",14994,51.785269,14.975639 ],
    [ u"pl",u"Lukow",30551,51.928998,22.379556 ],
    [ u"pl",u"Lwowek Slaski",9657,51.108956,15.582667 ],
    [ u"pl",u"Makow Mazowiecki",9978,52.866667,21.1 ],
    [ u"pl",u"Malbork",38655,54.03596,19.03452 ],
    [ u"pl",u"Marki",23177,52.321267,21.102666 ],
    [ u"pl",u"Miastko",10954,53.999114,16.972278 ],
    [ u"pl",u"Miechow",11735,50.356529,20.030126 ],
    [ u"pl",u"Miedzychod",10994,52.599017,15.890664 ],
    [ u"pl",u"Miedzyrzec Podlaski",17158,51.986397,22.782482 ],
    [ u"pl",u"Miedzyrzecz",18669,52.447891,15.581652 ],
    [ u"pl",u"Mielec",60993,50.286188,21.432657 ],
    [ u"pl",u"Mikolow",38650,50.17103,18.904098 ],
    [ u"pl",u"Milanowek",15451,52.130695,20.662227 ],
    [ u"pl",u"Milicz",12169,51.526373,17.276928 ],
    [ u"pl",u"Minsk Mazowiecki",37027,52.181875,21.565981 ],
    [ u"pl",u"Mlawa",29398,53.116667,20.383333 ],
    [ u"pl",u"Mogilno",12465,52.660492,17.956662 ],
    [ u"pl",u"Monki",10577,53.404957,22.79791 ],
    [ u"pl",u"Morag",14745,53.91711,19.926025 ],
    [ u"pl",u"Mosina",12097,52.244194,16.851333 ],
    [ u"pl",u"Mragowo",21965,53.866667,21.3 ],
    [ u"pl",u"Murowana Goslina",9989,52.575213,17.010543 ],
    [ u"pl",u"Myslenice",17686,49.831956,19.9441 ],
    [ u"pl",u"Mysliborz",12092,52.92174,14.863315 ],
    [ u"pl",u"Myslowice",75281,50.236209,19.141123 ],
    [ u"pl",u"Myszkow",33273,50.575202,19.324607 ],
    [ u"pl",u"Naklo nad Notecia",19565,53.141874,17.602976 ],
    [ u"pl",u"Namyslow",16376,51.075035,17.714347 ],
    [ u"pl",u"Nidzica",14720,53.360936,20.426476 ],
    [ u"pl",u"Nisko",15573,50.518509,22.144659 ],
    [ u"pl",u"Nowa Deba",11489,50.427778,21.750328 ],
    [ u"pl",u"Nowa Ruda",24753,50.579022,16.502913 ],
    [ u"pl",u"Nowa Sol",40354,51.803937,15.715998 ],
    [ u"pl",u"Nowe Miasto Lubawskie",10997,53.422694,19.592512 ],
    [ u"pl",u"Nowogard",16703,53.668859,15.123372 ],
    [ u"pl",u"Nowy Dwor Gdanski",9822,54.21305,19.117714 ],
    [ u"pl",u"Nowy Dwor Mazowiecki",27633,52.430356,20.715855 ],
    [ u"pl",u"Nowy Sacz",84376,49.621766,20.697053 ],
    [ u"pl",u"Nowy Targ",33763,49.477579,20.029205 ],
    [ u"pl",u"Nowy Tomysl",15179,52.316477,16.133629 ],
    [ u"pl",u"Nysa",47954,50.47226,17.33618 ],
    [ u"pl",u"Oborniki",17915,52.647394,16.814061 ],
    [ u"pl",u"Olawa",31036,50.942078,17.299643 ],
    [ u"pl",u"Olecko",15923,54.036431,22.508387 ],
    [ u"pl",u"Olesnica",36956,51.207733,17.386545 ],
    [ u"pl",u"Olesno",10236,50.876976,18.420937 ],
    [ u"pl",u"Olkusz",37744,50.27916,19.563162 ],
    [ u"pl",u"Olsztyn",171803,53.779949,20.494162 ],
    [ u"pl",u"Opalenica",8991,52.307043,16.413346 ],
    [ u"pl",u"Opoczno",22592,51.375821,20.286737 ],
    [ u"pl",u"Opole Lubelskie",8780,51.148001,21.969903 ],
    [ u"pl",u"Opole",127676,50.666667,17.95 ],
    [ u"pl",u"Orneta",9412,54.114827,20.133277 ],
    [ u"pl",u"Orzesze",18438,50.155949,18.779235 ],
    [ u"pl",u"Ostroda",33524,53.699585,19.962986 ],
    [ u"pl",u"Ostroleka",53740,53.086206,21.575663 ],
    [ u"pl",u"Ostrowiec Swietokrzyski",73989,50.939932,21.387944 ],
    [ u"pl",u"Ostrow Mazowiecka",22653,52.803342,21.895544 ],
    [ u"pl",u"Ostrow Wielkopolski",72898,51.649762,17.808934 ],
    [ u"pl",u"Ostrzeszow",14447,51.425661,17.930084 ],
    [ u"pl",u"Oswiecim",41143,50.036838,19.230829 ],
    [ u"pl",u"Otwock",42776,52.118856,21.308008 ],
    [ u"pl",u"Ozimek",9963,50.678897,18.215928 ],
    [ u"pl",u"Ozorkow",20608,51.962778,19.295112 ],
    [ u"pl",u"Pabianice",70542,51.655351,19.345602 ],
    [ u"pl",u"Parczew",10249,51.642884,22.908449 ],
    [ u"pl",u"Paslek",12267,54.061599,19.659322 ],
    [ u"pl",u"Piaseczno",36279,51.822171,21.195831 ],
    [ u"pl",u"Piastow",23250,52.187959,20.840462 ],
    [ u"pl",u"Piekary Slaskie",59757,50.384664,18.944183 ],
    [ u"pl",u"Pieszyce",9406,50.718531,16.587301 ],
    [ u"pl",u"Pila",75532,53.154997,16.746074 ],
    [ u"pl",u"Pinczow",11806,50.520961,20.526694 ],
    [ u"pl",u"Pionki",19966,51.476614,21.450739 ],
    [ u"pl",u"Piotrkow Trybunalski",80128,51.410445,19.694952 ],
    [ u"pl",u"Pisz",19232,53.627444,21.812528 ],
    [ u"pl",u"Pleszew",17640,51.895386,17.782928 ],
    [ u"pl",u"Plock",127474,52.55,19.7 ],
    [ u"pl",u"Plonsk",22217,52.622238,20.37532 ],
    [ u"pl",u"Polaniec",8158,50.427146,21.282381 ],
    [ u"pl",u"Polczyn-Zdroj",8682,53.766932,16.096622 ],
    [ u"pl",u"Police",34350,53.542062,14.555212 ],
    [ u"pl",u"Polkowice",21565,51.50618,16.072623 ],
    [ u"pl",u"Poniatowa",10056,51.180192,22.128574 ],
    [ u"pl",u"Poreba",8718,50.488837,19.348249 ],
    [ u"pl",u"Poznan",570352,52.416667,16.966667 ],
    [ u"pl",u"Prudnik",23343,50.323175,17.576214 ],
    [ u"pl",u"Pruszkow",54851,52.162608,20.812948 ],
    [ u"pl",u"Przasnysz",16718,53.020284,20.882391 ],
    [ u"pl",u"Przeworsk",15805,50.059053,22.49486 ],
    [ u"pl",u"Pszczyna",25288,49.976483,18.947323 ],
    [ u"pl",u"Pszow",14028,50.03783,18.401537 ],
    [ u"pl",u"Puck",11415,54.718542,18.41085 ],
    [ u"pl",u"Pulawy",49759,51.416667,21.966667 ],
    [ u"pl",u"Pultusk",19039,52.704141,21.083007 ],
    [ u"pl",u"Pyrzyce",12893,53.145647,14.892897 ],
    [ u"pl",u"Pyskowice",19018,50.4,18.633333 ],
    [ u"pl",u"Raciborz",58464,50.090569,18.207455 ],
    [ u"pl",u"Radlin",17479,50.027632,18.447699 ],
    [ u"pl",u"Radom",226794,51.400963,21.15809 ],
    [ u"pl",u"Radomsko",49175,51.066749,19.454424 ],
    [ u"pl",u"Radzionkow",17167,50.416667,18.916667 ],
    [ u"pl",u"Radzyn Podlaski",16071,51.783333,22.616667 ],
    [ u"pl",u"Rawa Mazowiecka",17770,51.764368,20.254933 ],
    [ u"pl",u"Rawicz",21380,51.611313,16.861194 ],
    [ u"pl",u"Reda",18116,54.601882,18.354363 ],
    [ u"pl",u"Rogozno",10859,52.75226,16.990493 ],
    [ u"pl",u"Ropczyce",15254,50.05257,21.609053 ],
    [ u"pl",u"Ruda Slaska",146189,50.307941,18.855156 ],
    [ u"pl",u"Rumia",44791,54.570608,18.410544 ],
    [ u"pl",u"Rybnik",142510,50.092076,18.547479 ],
    [ u"pl",u"Rydultowy",21887,50.060637,18.425658 ],
    [ u"pl",u"Ryki",9619,51.623966,21.933517 ],
    [ u"pl",u"Rypin",16589,53.067489,19.415666 ],
    [ u"pl",u"Rzeszow",158382,50.037246,22.004949 ],
    [ u"pl",u"Sandomierz",25087,50.685808,21.738864 ],
    [ u"pl",u"Sanok",39684,49.558958,22.202951 ],
    [ u"pl",u"Sepolno Krajenskie",9223,53.452046,17.539826 ],
    [ u"pl",u"Siedlce",76772,52.168215,22.277296 ],
    [ u"pl",u"Siemianowice Slaskie",73121,50.304126,19.035834 ],
    [ u"pl",u"Siemiatycze",15421,52.42719,22.862311 ],
    [ u"pl",u"Sieradz",44436,51.6,18.75 ],
    [ u"pl",u"Sierpc",18866,52.852857,19.668927 ],
    [ u"pl",u"Skarzysko-Kamienna",49410,51.117238,20.895717 ],
    [ u"pl",u"Skawina",23647,49.976489,19.823317 ],
    [ u"pl",u"Skierniewice",49042,51.966667,20.15 ],
    [ u"pl",u"Skoczow",14810,49.800892,18.787705 ],
    [ u"pl",u"Skwierzyna",10051,52.593923,15.502619 ],
    [ u"pl",u"Slawno",13415,54.361546,16.67801 ],
    [ u"pl",u"Slubice",17567,52.355255,14.564826 ],
    [ u"pl",u"Slupca",14476,52.290352,17.873101 ],
    [ u"pl",u"Slupsk",98608,54.467761,17.027457 ],
    [ u"pl",u"Sochaczew",38267,52.233333,20.25 ],
    [ u"pl",u"Sokolka",19080,53.407154,23.502278 ],
    [ u"pl",u"Sokolow Podlaski",18241,52.407477,22.251923 ],
    [ u"pl",u"Solec Kujawski",15125,53.079814,18.220852 ],
    [ u"pl",u"Sopot",40142,54.434676,18.57076 ],
    [ u"pl",u"Sosnowiec",227295,50.272243,19.155039 ],
    [ u"pl",u"Srem",30404,52.088712,17.0173 ],
    [ u"pl",u"Sroda Wielkopolska",21757,52.227622,17.279907 ],
    [ u"pl",u"Stalowa Wola",66495,50.551635,22.051089 ],
    [ u"pl",u"Starachowice",53738,51.051914,21.088273 ],
    [ u"pl",u"Stargard Szczecinski",71224,53.341761,15.052135 ],
    [ u"pl",u"Starogard Gdanski",48202,53.968898,18.535355 ],
    [ u"pl",u"Stary Sacz",8959,49.563247,20.63461 ],
    [ u"pl",u"Staszow",15553,50.56342,21.168666 ],
    [ u"pl",u"Strzegom",17004,50.959294,16.347235 ],
    [ u"pl",u"Strzelce Krajenskie",9978,52.876306,15.5326 ],
    [ u"pl",u"Strzelce Opolskie",20241,50.513404,18.305401 ],
    [ u"pl",u"Strzelin",12394,50.783958,17.066399 ],
    [ u"pl",u"Sucha Beskidzka",9801,49.733333,19.6 ],
    [ u"pl",u"Suchedniow",9184,51.040683,20.829716 ],
    [ u"pl",u"Sulechow",18055,52.085595,15.618175 ],
    [ u"pl",u"Sulecin",10090,52.443562,15.118347 ],
    [ u"pl",u"Sulejowek",18630,52.246122,21.280447 ],
    [ u"pl",u"Suwalki",69222,54.099444,22.933056 ],
    [ u"pl",u"Swarzedz",29010,52.414169,17.089639 ],
    [ u"pl",u"Swidnica",60351,50.841705,16.479066 ],
    [ u"pl",u"Swidnik",40061,51.22057,22.700337 ],
    [ u"pl",u"Swidwin",16076,53.776279,15.775524 ],
    [ u"pl",u"Swiebodzice",23228,50.859755,16.328198 ],
    [ u"pl",u"Swiecie",25843,53.409527,18.44512 ],
    [ u"pl",u"Swietochlowice",55600,50.292455,18.914684 ],
    [ u"pl",u"Swinoujscie",40919,53.909148,14.240035 ],
    [ u"pl",u"Sycow",10809,51.308209,17.720236 ],
    [ u"pl",u"Szamotuly",18588,52.61267,16.581905 ],
    [ u"pl",u"Szczecinek",38496,53.707908,16.699373 ],
    [ u"pl",u"Szczecin",413658,53.439531,14.593891 ],
    [ u"pl",u"Szczytno",26044,53.562589,20.987474 ],
    [ u"pl",u"Szprotawa",12786,51.565553,15.536082 ],
    [ u"pl",u"Sztum",10081,53.920268,19.031101 ],
    [ u"pl",u"Szubin",9206,53.009925,17.738652 ],
    [ u"pl",u"Szydlowiec",12128,51.224862,20.858566 ],
    [ u"pl",u"Tarnobrzeg",50459,50.572007,21.684761 ],
    [ u"pl",u"Tarnowskie Gory",60938,50.448546,18.851463 ],
    [ u"pl",u"Tarnow",117799,50.006105,20.95527 ],
    [ u"pl",u"Tczew",60133,54.092291,18.79467 ],
    [ u"pl",u"Tomaszow Lubelski",20006,50.453239,23.414238 ],
    [ u"pl",u"Tomaszow Mazowiecki",67197,51.538614,20.017606 ],
    [ u"pl",u"Torun",208717,53.035831,18.604844 ],
    [ u"pl",u"Trzcianka",16914,53.040627,16.456285 ],
    [ u"pl",u"Trzebiatow",10322,54.059404,15.279377 ],
    [ u"pl",u"Trzebinia",18828,50.164789,19.458169 ],
    [ u"pl",u"Trzebnica",12212,51.309886,17.062849 ],
    [ u"pl",u"Tuchola",13686,53.586661,17.86059 ],
    [ u"pl",u"Turek",29533,52.017722,18.50559 ],
    [ u"pl",u"Tychy",131696,50.137167,18.96641 ],
    [ u"pl",u"Ustka",16250,54.582862,16.863289 ],
    [ u"pl",u"Ustron",15637,49.721526,18.801983 ],
    [ u"pl",u"Ustrzyki Dolne",9610,49.430858,22.584761 ],
    [ u"pl",u"Wabrzezno",13911,53.280183,18.948288 ],
    [ u"pl",u"Wadowice",19238,49.884086,19.491489 ],
    [ u"pl",u"Wagrowiec",24428,52.811659,17.207376 ],
    [ u"pl",u"Walbrzych",127431,50.771407,16.28432 ],
    [ u"pl",u"Walcz",25971,53.277869,16.471218 ],
    [ u"pl",u"Warka",11048,51.785362,21.186876 ],
    [ u"pl",u"Warsaw",1651676,52.25,21 ],
    [ u"pl",u"Wegorzewo",11864,54.215669,21.737202 ],
    [ u"pl",u"Wegrow",12512,52.401958,22.016667 ],
    [ u"pl",u"Wejherowo",44083,54.605211,18.235514 ],
    [ u"pl",u"Wieliczka",18677,49.984057,20.062219 ],
    [ u"pl",u"Wielun",24384,51.221009,18.566548 ],
    [ u"pl",u"Wisla",11379,49.656294,18.859105 ],
    [ u"pl",u"Wladyslawowo",14889,54.791759,18.403942 ],
    [ u"pl",u"Wloclawek",120339,52.651435,19.072755 ],
    [ u"pl",u"Wlodawa",13142,51.55,23.55 ],
    [ u"pl",u"Wloszczowa",10661,50.852583,19.966843 ],
    [ u"pl",u"Wodzislaw Slaski",49521,50.010983,18.455074 ],
    [ u"pl",u"Wojkowice",9602,50.370433,19.061742 ],
    [ u"pl",u"Wolbrom",9146,50.378801,19.765041 ],
    [ u"pl",u"Wolomin",36592,52.346753,21.239244 ],
    [ u"pl",u"Wolow",12276,51.339044,16.646788 ],
    [ u"pl",u"Wolsztyn",13689,52.112706,16.12361 ],
    [ u"pl",u"Wroclaw",634893,51.1,17.033333 ],
    [ u"pl",u"Wronki",11611,52.706768,16.384391 ],
    [ u"pl",u"Wrzesnia",28703,52.323234,17.569913 ],
    [ u"pl",u"Wschowa",14458,51.805426,16.317381 ],
    [ u"pl",u"Wysokie Mazowieckie",9203,52.917069,22.511442 ],
    [ u"pl",u"Wyszkow",26628,52.596407,21.457539 ],
    [ u"pl",u"Zabki",23473,52.292714,21.105392 ],
    [ u"pl",u"Zabkowice Slaskie",16321,50.591954,16.818407 ],
    [ u"pl",u"Zabrze",192177,50.306355,18.783333 ],
    [ u"pl",u"Zagan",26251,51.615804,15.314769 ],
    [ u"pl",u"Zakopane",27581,49.296247,19.956785 ],
    [ u"pl",u"Zambrow",22857,52.985607,22.242249 ],
    [ u"pl",u"Zamosc",66034,50.724679,23.260629 ],
    [ u"pl",u"Zary",38779,51.638165,15.141717 ],
    [ u"pl",u"Zawadzkie",8439,50.609916,18.477694 ],
    [ u"pl",u"Zawiercie",53159,50.488242,19.431832 ],
    [ u"pl",u"Zdunska Wola",44515,51.59741,18.931347 ],
    [ u"pl",u"Zdzieszowice",13401,50.424206,18.123756 ],
    [ u"pl",u"Zgierz",58036,51.84469,19.408752 ],
    [ u"pl",u"Zgorzelec",33247,51.153659,15.008839 ],
    [ u"pl",u"Ziebice",9328,50.600714,17.040233 ],
    [ u"pl",u"Zielona Gora",118433,51.939345,15.505772 ],
    [ u"pl",u"Zielonka",17518,52.303157,21.158459 ],
    [ u"pl",u"Zlocieniec",13337,53.532862,16.011321 ],
    [ u"pl",u"Zlotoryja",16612,51.123612,15.915771 ],
    [ u"pl",u"Zlotow",18395,53.361739,17.045241 ],
    [ u"pl",u"Znin",14008,52.853617,17.716677 ],
    [ u"pl",u"Zory",63174,50.044976,18.694315 ],
    [ u"pl",u"Zychlin",8844,52.244244,19.62637 ],
    [ u"pl",u"Zyrardow",41179,52.055392,20.441451 ],
    [ u"pm",u"Miquelon",1141,47.0975,-56.3813889 ],
    [ u"pm",u"Saint-Pierre",6200,46.7666667,-56.1833333 ],
    [ u"pt",u"Abrantes",13646,39.466667,-8.2 ],
    [ u"pt",u"Abraveses",9319,40.681372,-7.921024 ],
    [ u"pt",u"Adaúfe",3850,41.58732,-8.398173 ],
    [ u"pt",u"A dos Cunhados",6594,39.15237,-9.297199 ],
    [ u"pt",u"Aguada de Cima",4388,40.522909,-8.427 ],
    [ u"pt",u"Águas Santas",27686,41.210607,-8.586599 ],
    [ u"pt",u"Aguçadoura",4520,41.431759,-8.780377 ],
    [ u"pt",u"Águeda",11940,40.577205,-8.444418 ],
    [ u"pt",u"Albufeira",15851,37.090205,-8.25079 ],
    [ u"pt",u"Alcabideche",33315,38.73366,-9.409278 ],
    [ u"pt",u"Alcácer do Sal",9198,38.373258,-8.514436 ],
    [ u"pt",u"Alcains",5029,39.916415,-7.456551 ],
    [ u"pt",u"Alcanede",5020,39.41501,-8.821886 ],
    [ u"pt",u"Alcanena",4408,39.459005,-8.668924 ],
    [ u"pt",u"Alcobaça",5051,39.552233,-8.977495 ],
    [ u"pt",u"Alcochete",9705,38.755335,-8.960861 ],
    [ u"pt",u"Alcoentre",3923,39.208573,-8.959531 ],
    [ u"pt",u"Aldeia de Paio Pires",12179,38.616667,-9.083333 ],
    [ u"pt",u"Alenquer",9626,39.053151,-9.009282 ],
    [ u"pt",u"Alfena",14455,41.236709,-8.524538 ],
    [ u"pt",u"Alferrarede",3654,39.483333,-8.166667 ],
    [ u"pt",u"Algés",19326,38.702452,-9.22936 ],
    [ u"pt",u"Alhadas",3767,40.186072,-8.790568 ],
    [ u"pt",u"Alhandra",7226,38.92732,-9.00864 ],
    [ u"pt",u"Alhos Vedros",13384,38.654864,-9.023682 ],
    [ u"pt",u"Aljezur",4122,37.319152,-8.803305 ],
    [ u"pt",u"Aljubarrota",6146,39.567155,-8.929254 ],
    [ u"pt",u"Aljustrel",5334,37.877594,-8.165159 ],
    [ u"pt",u"Almada",34007,38.679018,-9.156904 ],
    [ u"pt",u"Almancil",9898,37.086858,-8.030738 ],
    [ u"pt",u"Almargem do Bispo",8271,38.844851,-9.273155 ],
    [ u"pt",u"Almeirim",11556,39.209028,-8.616426 ],
    [ u"pt",u"Alpiarça",7946,39.257116,-8.581866 ],
    [ u"pt",u"Alvor",5272,37.129333,-8.593104 ],
    [ u"pt",u"Amadora",178856,38.759711,-9.239708 ],
    [ u"pt",u"Amarante",6782,41.272711,-8.082455 ],
    [ u"pt",u"Amora",52577,38.629613,-9.115569 ],
    [ u"pt",u"Amor",4870,39.804039,-8.859845 ],
    [ u"pt",u"Angra",12045,38.65,-27.216667 ],
    [ u"pt",u"Anta",10951,41.266336,-8.628442 ],
    [ u"pt",u"Antas",5569,41.736444,-8.308882 ],
    [ u"pt",u"Apelação",7181,38.813872,-9.132254 ],
    [ u"pt",u"Apúlia",4394,41.485125,-8.764133 ],
    [ u"pt",u"Aradas",7294,40.62084,-8.641953 ],
    [ u"pt",u"Arazede",5906,40.286268,-8.649989 ],
    [ u"pt",u"Arcos",6725,40.447787,-8.44171 ],
    [ u"pt",u"Arcozelo",13495,41.053275,-8.643261 ],
    [ u"pt",u"Areosa",4626,41.717788,-8.857073 ],
    [ u"pt",u"Arganil",4330,40.218261,-8.054029 ],
    [ u"pt",u"Argoncilhe",8743,41.025406,-8.538849 ],
    [ u"pt",u"Armação de Pêra",4030,37.102565,-8.356954 ],
    [ u"pt",u"Arões",4855,41.455533,-8.214186 ],
    [ u"pt",u"Arrentela",30156,38.616667,-9.1 ],
    [ u"pt",u"Arrifana",6927,40.915653,-8.496569 ],
    [ u"pt",u"Arrifes",6981,37.766667,-25.7 ],
    [ u"pt",u"Arruda dos Vinhos",6170,38.984106,-9.077463 ],
    [ u"pt",u"Árvore",4553,41.339217,-8.718059 ],
    [ u"pt",u"Atouguia da Baleia",8313,39.338145,-9.326302 ],
    [ u"pt",u"Avanca",6539,40.807707,-8.5722 ],
    [ u"pt",u"Aveiras de Cima",4615,39.137957,-8.899323 ],
    [ u"pt",u"Aveiro",54161,40.644269,-8.645535 ],
    [ u"pt",u"Aves",8506,41.370339,-8.410104 ],
    [ u"pt",u"Avintes",11577,41.117471,-8.549862 ],
    [ u"pt",u"Azambuja",7179,39.07029,-8.86822 ],
    [ u"pt",u"Baguim do Monte",15850,41.193919,-8.541327 ],
    [ u"pt",u"Baltar",4929,41.185115,-8.373437 ],
    [ u"pt",u"Barcarena",11968,38.73245,-9.279998 ],
    [ u"pt",u"Barcelos",19084,41.538763,-8.615053 ],
    [ u"pt",u"Barreiro",51279,38.663137,-9.072395 ],
    [ u"pt",u"Barrosas",5573,41.330802,-8.267735 ],
    [ u"pt",u"Batalha",7910,39.660252,-8.824751 ],
    [ u"pt",u"Beduido",8201,40.764271,-8.561096 ],
    [ u"pt",u"Beja",23906,38.015064,-7.863227 ],
    [ u"pt",u"Belas",21018,38.777212,-9.260782 ],
    [ u"pt",u"Benavente",8932,38.979192,-8.807591 ],
    [ u"pt",u"Benedita",8556,39.424704,-8.969961 ],
    [ u"pt",u"Bobadela",8399,38.811436,-9.094115 ],
    [ u"pt",u"Boliqueime",4470,37.137184,-8.1582 ],
    [ u"pt",u"Bombarral",5852,39.267231,-9.157952 ],
    [ u"pt",u"Borba",4586,38.80553,-7.45465 ],
    [ u"pt",u"Bougado",21680,41.339792,-8.551798 ],
    [ u"pt",u"Braga",121393,41.550323,-8.420052 ],
    [ u"pt",u"Bragança",21468,41.805817,-6.757189 ],
    [ u"pt",u"Branca",5632,40.766533,-8.482616 ],
    [ u"pt",u"Brito",5051,41.458208,-8.361033 ],
    [ u"pt",u"Buarcos",7865,40.166039,-8.876801 ],
    [ u"pt",u"Bucelas",4614,38.901929,-9.118848 ],
    [ u"pt",u"Cacilhas",6494,38.687726,-9.146626 ],
    [ u"pt",u"Caldas da Rainha",26647,39.403255,-9.138387 ],
    [ u"pt",u"Caldas de Vizela",10239,41.382118,-8.308902 ],
    [ u"pt",u"Caldelas",5724,41.671009,-8.381475 ],
    [ u"pt",u"Calendário",11357,41.403607,-8.529671 ],
    [ u"pt",u"Camacha",8635,33.083333,-16.333333 ],
    [ u"pt",u"Câmara de Lobos",32209,32.633333,-16.966667 ],
    [ u"pt",u"Camarate",20176,38.80358,-9.128085 ],
    [ u"pt",u"Campanário",3987,32.65,-17.033333 ],
    [ u"pt",u"Campo",8916,41.185162,-8.464927 ],
    [ u"pt",u"Campo",4551,40.710857,-7.91445 ],
    [ u"pt",u"Campo Maior",8235,39.017742,-7.064967 ],
    [ u"pt",u"Candoso",3893,41.422053,-8.332138 ],
    [ u"pt",u"Caneças",10977,38.813209,-9.226794 ],
    [ u"pt",u"Canedo",6159,40.790835,-8.619333 ],
    [ u"pt",u"Canelas",14247,41.083333,-8.6 ],
    [ u"pt",u"Caniço",11996,32.633333,-16.85 ],
    [ u"pt",u"Canidelo",26430,41.124018,-8.651038 ],
    [ u"pt",u"Cantanhede",7347,40.346708,-8.594195 ],
    [ u"pt",u"Caparica",21167,38.666667,-9.2 ],
    [ u"pt",u"Caranguejeira",5247,39.746193,-8.707398 ],
    [ u"pt",u"Carcavelos",20366,38.691049,-9.322151 ],
    [ u"pt",u"Carnaxide",23697,38.727064,-9.246714 ],
    [ u"pt",u"Carregado",10473,39.023619,-8.976916 ],
    [ u"pt",u"Cartaxo",10502,39.160221,-8.787408 ],
    [ u"pt",u"Carvalhosa",4502,41.30057,-8.360803 ],
    [ u"pt",u"Cascais",36436,38.69745,-9.423141 ],
    [ u"pt",u"Castanheira de Pêra",3331,40.007169,-8.210484 ],
    [ u"pt",u"Castanheira do Ribatejo",7651,38.992978,-8.973462 ],
    [ u"pt",u"Castelo Branco",33479,39.822191,-7.490869 ],
    [ u"pt",u"Castelões de Cepeda",8322,41.202648,-8.335161 ],
    [ u"pt",u"Castro Daire",4744,40.898399,-7.933805 ],
    [ u"pt",u"Castro Marim",5089,37.220683,-7.4435 ],
    [ u"pt",u"Castro Verde",4857,37.698282,-8.085812 ],
    [ u"pt",u"Cercal",3772,37.806009,-8.671531 ],
    [ u"pt",u"Charneca de Caparica",23712,38.62059,-9.191492 ],
    [ u"pt",u"Chaves",13066,41.740186,-7.468789 ],
    [ u"pt",u"Coimbra",106580,40.205642,-8.419551 ],
    [ u"pt",u"Colares",7905,38.799215,-9.44691 ],
    [ u"pt",u"Coronado",8697,41.285444,-8.563196 ],
    [ u"pt",u"Corroios",52517,38.645023,-9.148431 ],
    [ u"pt",u"Cortegaça",4139,40.948833,-8.6213 ],
    [ u"pt",u"Coruche",8775,38.959546,-8.525235 ],
    [ u"pt",u"Cova da Piedade",19472,38.666667,-9.15 ],
    [ u"pt",u"Covilhã",17610,40.286011,-7.503961 ],
    [ u"pt",u"Custoias",19406,41.1053,-7.320971 ],
    [ u"pt",u"Darque",8092,41.683333,-8.766667 ],
    [ u"pt",u"Eixo",5978,40.627582,-8.569224 ],
    [ u"pt",u"Elvas",9904,38.881502,-7.162817 ],
    [ u"pt",u"Entroncamento",19887,39.466667,-8.466667 ],
    [ u"pt",u"Ericeira",7538,38.964721,-9.416724 ],
    [ u"pt",u"Esmoriz",11393,40.959231,-8.626488 ],
    [ u"pt",u"Espinho",9566,41.007628,-8.641251 ],
    [ u"pt",u"Estômbar",8590,37.145741,-8.485586 ],
    [ u"pt",u"Estoril",23375,38.716086,-9.392349 ],
    [ u"pt",u"Estremoz",9349,38.844316,-7.585854 ],
    [ u"pt",u"Évora",45851,38.566667,-7.9 ],
    [ u"pt",u"Fafe",16868,41.454227,-8.167998 ],
    [ u"pt",u"Fajã de Baixo",4915,37.75,-25.65 ],
    [ u"pt",u"Famões",9435,38.788041,-9.210332 ],
    [ u"pt",u"Fânzeres",23916,41.170866,-8.525701 ],
    [ u"pt",u"Faro",41355,37.019367,-7.932229 ],
    [ u"pt",u"Fátima",11798,39.62071,-8.652367 ],
    [ u"pt",u"Fazendas de Almeirim",6634,39.175527,-8.569273 ],
    [ u"pt",u"Feira",16376,40.925348,-8.542769 ],
    [ u"pt",u"Ferreira do Alentejo",4689,38.05,-8.033333 ],
    [ u"pt",u"Ferreira",4205,41.267182,-8.344339 ],
    [ u"pt",u"Ferreiras",5157,37.129265,-8.237592 ],
    [ u"pt",u"Ferreiros",7870,41.35,-8.55 ],
    [ u"pt",u"Fiães",8708,40.994459,-8.52537 ],
    [ u"pt",u"Figueira da Foz",12050,40.150852,-8.861786 ],
    [ u"pt",u"Figueiró",4579,41.299224,-8.167793 ],
    [ u"pt",u"Foz do Sousa",6315,41.09668,-8.501838 ],
    [ u"pt",u"Frazão",4314,41.258657,-8.400142 ],
    [ u"pt",u"Freamunde",7982,41.288348,-8.335334 ],
    [ u"pt",u"Funchal",98041,32.633333,-16.9 ],
    [ u"pt",u"Fundão",9725,40.140247,-7.501348 ],
    [ u"pt",u"Gafanha da Encarnação",4914,40.618058,-8.733026 ],
    [ u"pt",u"Gafanha da Nazaré",14840,40.636212,-8.713377 ],
    [ u"pt",u"Galegos",5403,41.562679,-8.57204 ],
    [ u"pt",u"Gandra",6034,41.201156,-8.433757 ],
    [ u"pt",u"Gemunde",5284,41.267661,-8.645151 ],
    [ u"pt",u"Godim",4919,41.171037,-7.803033 ],
    [ u"pt",u"Golegã",3830,39.40474,-8.48625 ],
    [ u"pt",u"Gondomar",27690,41.144536,-8.532229 ],
    [ u"pt",u"Grândola",10737,38.177181,-8.566746 ],
    [ u"pt",u"Grijó",10907,41.02836,-8.580167 ],
    [ u"pt",u"Guarda",28502,40.537328,-7.265749 ],
    [ u"pt",u"Guia",4173,37.129586,-8.299625 ],
    [ u"pt",u"Guifões",9231,41.200391,-8.667194 ],
    [ u"pt",u"Guimarães",40603,41.444435,-8.296189 ],
    [ u"pt",u"Gulpilhares",10660,41.082916,-8.626794 ],
    [ u"pt",u"Horta",6572,38.533333,-28.633333 ],
    [ u"pt",u"Ílhavo",17236,40.599896,-8.667325 ],
    [ u"pt",u"Joane",7869,41.439063,-8.40846 ],
    [ u"pt",u"Jovim",7067,41.111022,-8.51903 ],
    [ u"pt",u"Lagoa",6301,37.135349,-8.453188 ],
    [ u"pt",u"Lagoa",9239,39.05,-27.983333 ],
    [ u"pt",u"Lagos",18831,37.101782,-8.674242 ],
    [ u"pt",u"Lamego",10928,41.097407,-7.809907 ],
    [ u"pt",u"Laranjeiro",20472,37.06831,-7.793697 ],
    [ u"pt",u"Lavos",4164,40.093628,-8.828263 ],
    [ u"pt",u"Lavra",9633,41.259355,-8.718489 ],
    [ u"pt",u"Leça da Palmeira",17995,41.190998,-8.700268 ],
    [ u"pt",u"Leça do Bailio",16103,41.214567,-8.613484 ],
    [ u"pt",u"Leiria",45111,39.747724,-8.804995 ],
    [ u"pt",u"Linda-a-Velha",20895,38.71446,-9.242202 ],
    [ u"pt",u"Lisbon",517798,38.716667,-9.133333 ],
    [ u"pt",u"Lobão",6049,40.986643,-8.485659 ],
    [ u"pt",u"Lordelo",4560,41.374108,-8.380164 ],
    [ u"pt",u"Lordelo",10034,41.234507,-8.402969 ],
    [ u"pt",u"Lorvão",4158,40.259384,-8.316835 ],
    [ u"pt",u"Loulé",23109,37.137722,-8.019684 ],
    [ u"pt",u"Loures",66230,38.829082,-9.168106 ],
    [ u"pt",u"Louriçal",5085,40.003898,-8.737363 ],
    [ u"pt",u"Lourinhã",9196,39.233333,-9.316667 ],
    [ u"pt",u"Lourosa",9619,40.984202,-8.55142 ],
    [ u"pt",u"Lousã",11444,40.111911,-8.24703 ],
    [ u"pt",u"Lustosa",4686,41.340815,-8.317153 ],
    [ u"pt",u"Luz",3627,37.095266,-7.703808 ],
    [ u"pt",u"Macedo de Cavaleiros",6566,41.538161,-6.9611 ],
    [ u"pt",u"Maceira",9831,39.688529,-8.894232 ],
    [ u"pt",u"Machico",12567,32.7,-16.766667 ],
    [ u"pt",u"Macieira de Cambra",4909,40.859387,-8.373383 ],
    [ u"pt",u"Madalena",9617,41.216165,-8.334509 ],
    [ u"pt",u"Mafra",12259,38.937933,-9.327565 ],
    [ u"pt",u"Maia",36425,41.235739,-8.619897 ],
    [ u"pt",u"Malveira",4747,38.93213,-9.257785 ],
    [ u"pt",u"Mangualde",8894,40.604248,-7.76115 ],
    [ u"pt",u"Margaride",10652,41.368292,-8.200716 ],
    [ u"pt",u"Marinha Grande",28915,39.747691,-8.932284 ],
    [ u"pt",u"Marinhais",5788,39.047297,-8.702358 ],
    [ u"pt",u"Marinhas",6052,41.559059,-8.782972 ],
    [ u"pt",u"Matosinhos",28069,41.18207,-8.689076 ],
    [ u"pt",u"Meadela",9981,41.706541,-8.796279 ],
    [ u"pt",u"Mealhada",4443,40.378063,-8.449912 ],
    [ u"pt",u"Meinedo",4416,41.248271,-8.258068 ],
    [ u"pt",u"Milharado",5935,38.947316,-9.199136 ],
    [ u"pt",u"Milheirós de Poiares",4339,40.921628,-8.467883 ],
    [ u"pt",u"Milheirós",4342,41.214778,-8.588372 ],
    [ u"pt",u"Mira",7682,40.428924,-8.737462 ],
    [ u"pt",u"Miranda do Corvo",7857,40.09318,-8.332608 ],
    [ u"pt",u"Mirandela",12504,41.487385,-7.186949 ],
    [ u"pt",u"Mogadouro",3935,41.335282,-6.650396 ],
    [ u"pt",u"Moita",17795,38.650779,-8.990383 ],
    [ u"pt",u"Moncarapacho",8545,37.088631,-7.787223 ],
    [ u"pt",u"Monchique",5421,37.317748,-8.555294 ],
    [ u"pt",u"Monte Gordo",4282,37.181923,-7.452252 ],
    [ u"pt",u"Montemor-o-Novo",12854,38.648117,-8.214549 ],
    [ u"pt",u"Monte Redondo",4463,39.899297,-8.831712 ],
    [ u"pt",u"Montijo",30010,38.706747,-8.973885 ],
    [ u"pt",u"Moreira de Conegos",5607,41.386797,-8.339399 ],
    [ u"pt",u"Moreira",11336,41.056004,-8.389392 ],
    [ u"pt",u"Moscavide",11488,38.779288,-9.102223 ],
    [ u"pt",u"Moura",9360,38.140095,-7.44856 ],
    [ u"pt",u"Mozelos",7229,41.866667,-8.4 ],
    [ u"pt",u"Nazaré",8993,39.602891,-9.068355 ],
    [ u"pt",u"Negrelos",6664,41.344222,-8.350132 ],
    [ u"pt",u"Nelas",4190,40.532157,-7.851525 ],
    [ u"pt",u"Nogueira da Regedoura",5328,41.005301,-8.591953 ],
    [ u"pt",u"Nogueira",4855,41.242456,-8.586848 ],
    [ u"pt",u"Odemira",5830,37.598106,-8.638886 ],
    [ u"pt",u"Odivelas",54623,38.795234,-9.187387 ],
    [ u"pt",u"Oiã",7118,40.542641,-8.538562 ],
    [ u"pt",u"Olhão",29238,37.0286,-7.841101 ],
    [ u"pt",u"Olival",5715,41.050244,-8.544163 ],
    [ u"pt",u"Oliveira de Azemeis",11771,40.84101,-8.475554 ],
    [ u"pt",u"Oliveira do Bairro",6239,40.514596,-8.493858 ],
    [ u"pt",u"Oliveira do Douro",24406,41.124664,-8.584626 ],
    [ u"pt",u"Oliveira do Hospital",4704,40.361796,-7.86014 ],
    [ u"pt",u"Oliveira",6222,41.406479,-8.402734 ],
    [ u"pt",u"Oliveirinha",4971,40.607146,-8.591978 ],
    [ u"pt",u"Ourém",12729,39.641675,-8.591899 ],
    [ u"pt",u"Ovar",18452,40.861753,-8.626014 ],
    [ u"pt",u"Paço de Arcos",25974,38.69543,-9.294057 ],
    [ u"pt",u"Paços de Brandão",4637,40.975411,-8.583504 ],
    [ u"pt",u"Paços de Ferreira",6782,41.276571,-8.376174 ],
    [ u"pt",u"Palmela",16934,38.569021,-8.901255 ],
    [ u"pt",u"Pampilhosa",4512,40.335801,-8.427381 ],
    [ u"pt",u"Pardilhó",4169,40.799247,-8.625982 ],
    [ u"pt",u"Parede",17212,38.692815,-9.35412 ],
    [ u"pt",u"Pataias",5510,39.669776,-8.995797 ],
    [ u"pt",u"Pedroso",18962,41.41103,-8.748974 ],
    [ u"pt",u"Pedrouços",12553,41.193149,-8.581672 ],
    [ u"pt",u"Penafiel",8065,41.208348,-8.282847 ],
    [ u"pt",u"Peniche",15661,39.357486,-9.380439 ],
    [ u"pt",u"Perafita",12538,41.182517,-8.254503 ],
    [ u"pt",u"Pero Pinheiro",4792,38.857832,-9.323519 ],
    [ u"pt",u"Perozinho",6259,41.065128,-8.585315 ],
    [ u"pt",u"Peso da Régua",5048,41.164912,-7.787034 ],
    [ u"pt",u"Pinhal Novo",23508,38.631057,-8.913764 ],
    [ u"pt",u"Poceirão",4225,38.830946,-8.793648 ],
    [ u"pt",u"Poiares",5514,40.210256,-8.257464 ],
    [ u"pt",u"Pombal",17355,39.916738,-8.628474 ],
    [ u"pt",u"Ponta Delgada",20056,37.733333,-25.666667 ],
    [ u"pt",u"Ponta do Sol",4236,32.666667,-17.1 ],
    [ u"pt",u"Ponte de Sor",11062,39.249642,-8.010086 ],
    [ u"pt",u"Ponte",7040,41.470566,-8.329895 ],
    [ u"pt",u"Pontével",4435,39.14945,-8.838799 ],
    [ u"pt",u"Pontinha",23249,38.767713,-9.199346 ],
    [ u"pt",u"Portalegre",15581,39.297178,-7.430151 ],
    [ u"pt",u"Portimão",38486,37.136636,-8.539796 ],
    [ u"pt",u"Porto de Mós",6032,39.601911,-8.818389 ],
    [ u"pt",u"Porto",249630,41.149606,-8.610993 ],
    [ u"pt",u"Porto Salvo",13867,38.717452,-9.298333 ],
    [ u"pt",u"Porto Santo",4348,33.05,-16.333333 ],
    [ u"pt",u"Póvoa de Lanhoso",5008,41.577713,-8.268468 ],
    [ u"pt",u"Póvoa de Santa Iria",28900,38.861009,-9.064528 ],
    [ u"pt",u"Póvoa de Santo Adrião",14897,38.8,-9.166667 ],
    [ u"pt",u"Póvoa de Varzim",29044,41.38344,-8.763637 ],
    [ u"pt",u"Pragal",7701,38.674592,-9.169806 ],
    [ u"pt",u"Praia da Vitória",6061,38.733333,-27.066667 ],
    [ u"pt",u"Quarteira",18782,37.069458,-8.10064 ],
    [ u"pt",u"Queijas",8828,38.722356,-9.265932 ],
    [ u"pt",u"Queluz",103398,38.756572,-9.254512 ],
    [ u"pt",u"Quinta do Anjo",9124,38.56753,-8.942277 ],
    [ u"pt",u"Rabo de Peixe",7681,37.8,-25.583333 ],
    [ u"pt",u"Ramada",17535,38.802354,-9.192161 ],
    [ u"pt",u"Real",5827,41.638822,-8.180976 ],
    [ u"pt",u"Rebordosa",11490,41.224052,-8.406689 ],
    [ u"pt",u"Recarei",4856,41.153559,-8.411779 ],
    [ u"pt",u"Redondo",5845,38.648716,-7.547082 ],
    [ u"pt",u"Refojos de Basto",5037,41.513178,-7.995172 ],
    [ u"pt",u"Reguengos de Monsaraz",7217,38.425293,-7.534945 ],
    [ u"pt",u"Riachos",5463,39.444725,-8.5142 ],
    [ u"pt",u"Ribeira Brava",5933,32.65,-17.066667 ],
    [ u"pt",u"Ribeira Grande",5198,38.516667,-28.7 ],
    [ u"pt",u"Ribeirão",8735,41.360807,-8.567738 ],
    [ u"pt",u"Rio de Loba",9529,40.665962,-7.877814 ],
    [ u"pt",u"Rio de Mouro",54695,38.774567,-9.327595 ],
    [ u"pt",u"Rio Maior",12064,39.337325,-8.939063 ],
    [ u"pt",u"Rio Meão",4802,40.957752,-8.578176 ],
    [ u"pt",u"Rio Tinto",49966,41.182592,-8.558109 ],
    [ u"pt",u"Ronfe",4888,41.441457,-8.384116 ],
    [ u"pt",u"Rosto do Cão",7880,37.75,-25.65 ],
    [ u"pt",u"Sacavém",17718,38.793795,-9.104577 ],
    [ u"pt",u"Salreu",4140,40.739709,-8.557195 ],
    [ u"pt",u"Salvaterra de Magos",5165,39.027881,-8.793502 ],
    [ u"pt",u"Samora Correia",14154,38.937093,-8.871779 ],
    [ u"pt",u"Sande",7789,41.7019,-8.392465 ],
    [ u"pt",u"Sandim",6449,41.035081,-8.507 ],
    [ u"pt",u"Sangalhos",4516,40.486781,-8.469679 ],
    [ u"pt",u"Santa Bárbara de Nexe",4087,37.106191,-7.966481 ],
    [ u"pt",u"Santa Catarina da Serra",4405,39.679604,-8.68679 ],
    [ u"pt",u"Santa Cruz do Bispo",6230,41.225498,-8.683605 ],
    [ u"pt",u"Santa Cruz",6010,32.683333,-16.8 ],
    [ u"pt",u"Santa Iria de Azoia",18573,38.846288,-9.087485 ],
    [ u"pt",u"Santarém",29385,39.233333,-8.683333 ],
    [ u"pt",u"Santiago do Cacém",7797,38.016935,-8.69475 ],
    [ u"pt",u"Santo André",11213,39.055316,-8.244139 ],
    [ u"pt",u"Santo André",10601,38.054445,-8.752115 ],
    [ u"pt",u"Santo Antão do Tojal",4156,38.85151,-9.13975 ],
    [ u"pt",u"Santo António da Charneca",11143,38.625612,-9.03043 ],
    [ u"pt",u"Santo Tirso",14021,41.342567,-8.477456 ],
    [ u"pt",u"São Bartolomeu de Messines",8381,37.260243,-8.2867 ],
    [ u"pt",u"São Brás de Alportel",11153,37.1531,-7.887515 ],
    [ u"pt",u"São Domingos de Rana",46717,38.701226,-9.327595 ],
    [ u"pt",u"São Félix da Marinha",11685,41.035548,-8.622585 ],
    [ u"pt",u"São João da Madeira",22079,40.900956,-8.499744 ],
    [ u"pt",u"São João da Talha",18924,38.821833,-9.090787 ],
    [ u"pt",u"São João de Ver",9568,40.95527,-8.551171 ],
    [ u"pt",u"São João dos Montes",4772,38.939444,-9.018923 ],
    [ u"pt",u"São João",6762,40.868016,-8.606716 ],
    [ u"pt",u"São Mamede de Infesta",25939,41.200424,-8.602509 ],
    [ u"pt",u"São Pedro da Cadeira",4452,39.069826,-9.371743 ],
    [ u"pt",u"São Pedro da Cova",17011,41.155081,-8.504124 ],
    [ u"pt",u"São Pedro do Sul",4080,40.75537,-8.072646 ],
    [ u"pt",u"São Roque",5575,40.872159,-8.471487 ],
    [ u"pt",u"São Teotónio",4936,37.512825,-8.707085 ],
    [ u"pt",u"Sátão",4034,40.741775,-7.732855 ],
    [ u"pt",u"Seia",7082,40.415099,-7.708586 ],
    [ u"pt",u"Selho",10223,41.419382,-8.345989 ],
    [ u"pt",u"Senhora da Hora",28929,41.186405,-8.651721 ],
    [ u"pt",u"Seroa",4040,41.265112,-8.428923 ],
    [ u"pt",u"Serpa",6586,37.945811,-7.597537 ],
    [ u"pt",u"Sertã",5636,39.808461,-8.098829 ],
    [ u"pt",u"Serzedelo",4019,41.401277,-8.368883 ],
    [ u"pt",u"Serzedo",8000,41.405022,-8.229264 ],
    [ u"pt",u"Sesimbra",41133,38.444513,-9.101236 ],
    [ u"pt",u"Setúbal",117109,38.533333,-8.9 ],
    [ u"pt",u"Silvalde",7188,40.993969,-8.626079 ],
    [ u"pt",u"Silveira",6942,39.111197,-9.364298 ],
    [ u"pt",u"Silves",10917,37.189213,-8.438217 ],
    [ u"pt",u"Sines",12791,37.956215,-8.869788 ],
    [ u"pt",u"Sintra",26193,38.800971,-9.378257 ],
    [ u"pt",u"Sobrado",6703,41.210406,-8.45488 ],
    [ u"pt",u"Sobralinho",4453,38.917031,-9.026562 ],
    [ u"pt",u"Sobreda",11145,38.649608,-9.189766 ],
    [ u"pt",u"Sobreira",4219,41.523707,-7.802344 ],
    [ u"pt",u"Soure",8416,40.05989,-8.626053 ],
    [ u"pt",u"Souto da Carpalhosa",4130,39.845686,-8.823322 ],
    [ u"pt",u"Souto",4922,40.986747,-8.622304 ],
    [ u"pt",u"Tavarede",8586,40.170791,-8.845663 ],
    [ u"pt",u"Tavira",13871,37.127338,-7.648609 ],
    [ u"pt",u"Teixoso",4703,40.31448,-7.457594 ],
    [ u"pt",u"Telões",4675,41.310544,-8.111006 ],
    [ u"pt",u"Terrugem",4693,38.706474,-9.286929 ],
    [ u"pt",u"Tomar",19168,39.601987,-8.409242 ],
    [ u"pt",u"Tondela",4393,40.516815,-8.080866 ],
    [ u"pt",u"Torres Novas",14526,39.481143,-8.539493 ],
    [ u"pt",u"Torres Vedras",24443,39.091089,-9.258602 ],
    [ u"pt",u"Trafaria",5603,38.672225,-9.232679 ],
    [ u"pt",u"Tramagal",3821,39.45,-8.25 ],
    [ u"pt",u"Turquel",4434,39.464115,-8.977427 ],
    [ u"pt",u"Unhos",10711,38.825887,-9.122307 ],
    [ u"pt",u"Vagos",4529,40.555998,-8.68175 ],
    [ u"pt",u"Valadares",9255,41.147368,-7.981202 ],
    [ u"pt",u"Valbom",14443,41.132471,-8.564145 ],
    [ u"pt",u"Vale da Amoreira",10828,39.069687,-7.69849 ],
    [ u"pt",u"Válega",7005,40.836287,-8.580608 ],
    [ u"pt",u"Vale",5058,41.426739,-8.481212 ],
    [ u"pt",u"Valongo",21327,41.195007,-8.51027 ],
    [ u"pt",u"Valpaços",4572,41.607461,-7.310876 ],
    [ u"pt",u"Venda do Pinheiro",4950,38.92365,-9.231776 ],
    [ u"pt",u"Vendas Novas",11248,38.677056,-8.457924 ],
    [ u"pt",u"Ventosa",5215,39.12696,-9.084235 ],
    [ u"pt",u"Vialonga",16087,38.870945,-9.068234 ],
    [ u"pt",u"Viana do Castelo",15555,41.693234,-8.832869 ],
    [ u"pt",u"Vieira de Leiria",5807,39.869451,-8.932378 ],
    [ u"pt",u"Vila Chã",4295,40.866667,-8.466667 ],
    [ u"pt",u"Vila do Conde",27642,41.354811,-8.743397 ],
    [ u"pt",u"Vila Franca de Xira",18354,38.955249,-8.98966 ],
    [ u"pt",u"Vila Franca do Campo",5035,37.716667,-25.433333 ],
    [ u"pt",u"Vila Frescainha",4018,41.52779,-8.646102 ],
    [ u"pt",u"Vila Nova da Telha",5848,41.071697,-8.641456 ],
    [ u"pt",u"Vila Nova de Famalicão",9496,41.407967,-8.51978 ],
    [ u"pt",u"Vila Nova de Gaia",70810,41.133633,-8.617421 ],
    [ u"pt",u"Vila Nova de Milfontes",4393,37.723766,-8.782775 ],
    [ u"pt",u"Vila Praia de Âncora",4987,41.810976,-8.852548 ],
    [ u"pt",u"Vilar de Andorinho",18944,41.107508,-8.596321 ],
    [ u"pt",u"Vilar do Paraíso",14727,41.08974,-8.621095 ],
    [ u"pt",u"Vila Real de Santo António",11560,37.194999,-7.417658 ],
    [ u"pt",u"Vila Real",17001,41.30062,-7.744129 ],
    [ u"pt",u"Vilarinho",4177,41.359553,-8.331228 ],
    [ u"pt",u"Vila Verde",4389,41.647294,-8.43715 ],
    [ u"pt",u"Vila Viçosa",5484,38.777696,-7.417927 ],
    [ u"pt",u"Vilela",5540,41.225112,-7.603378 ],
    [ u"pt",u"Viseu",26364,40.661014,-7.909714 ],
    [ u"pt",u"Vizela",4066,41.390962,-8.263888 ],
    [ u"pt",u"Vizela",4066,41.365906,-8.283761 ],
    [ u"pw",u"Airai",960,7.3575,134.5577778 ],
    [ u"pw",u"Imeong",132,7.5275,134.5255556 ],
    [ u"pw",u"Kloulklubed",531,7.0394444,134.2525 ],
    [ u"pw",u"Koror",11357,7.3333333,134.4833333 ],
    [ u"pw",u"Melekeok",217,7.4933333,134.6341667 ],
    [ u"pw",u"Meyungs",1275,7.3519444,134.4544444 ],
    [ u"pw",u"Ngaramash",135,6.9013889,134.1294444 ],
    [ u"pw",u"Ngermechau",287,7.5513889,134.6330556 ],
    [ u"pw",u"Ngetkip",62,7.3619444,134.5122222 ],
    [ u"pw",u"Ollei",109,7.7172222,134.6122222 ],
    [ u"pw",u"Ulimang",130,7.6216667,134.6388889 ],
    [ u"py",u"Abaí",3024,-26.033333,-55.933333 ],
    [ u"py",u"Acahay",3205,-25.916667,-57.15 ],
    [ u"py",u"Alberdi",6518,-26.166667,-58.15 ],
    [ u"py",u"Altos",4763,-25.233333,-57.25 ],
    [ u"py",u"Alto Verá",642,-26.583333,-55.633333 ],
    [ u"py",u"Antequera",2701,-24.133333,-57.083333 ],
    [ u"py",u"Areguá",11224,-25.3,-57.416667 ],
    [ u"py",u"Arroyos y Esteros",2455,-25.066667,-57.1 ],
    [ u"py",u"Asunción",508797,-25.266667,-57.666667 ],
    [ u"py",u"Atyrá",4769,-25.25,-57.166667 ],
    [ u"py",u"Ayolas",12064,-27.4,-56.9 ],
    [ u"py",u"Belén",1621,-23.466111,-57.261944 ],
    [ u"py",u"Bella Vista",5654,-22.133333,-56.516667 ],
    [ u"py",u"Bella Vista",2334,-27.05,-55.55 ],
    [ u"py",u"Benjamín Aceval",7751,-24.966667,-57.566667 ],
    [ u"py",u"Borja",325,-25.95,-56.483333 ],
    [ u"py",u"Buena Vista",1580,-26.183333,-56.083333 ],
    [ u"py",u"Caacupé",21697,-25.383333,-57.15 ],
    [ u"py",u"Caaguazú",54814,-25.45,-56.016667 ],
    [ u"py",u"Caapucú",2284,-26.216667,-57.2 ],
    [ u"py",u"Caazapá",6790,-26.15,-56.4 ],
    [ u"py",u"Cambyretá",822,-27.35,-55.783333 ],
    [ u"py",u"Capiatá",198801,-25.35,-57.416667 ],
    [ u"py",u"Capiíbary",3537,-24.8,-56.033333 ],
    [ u"py",u"Capitán Bado",9115,-23.266667,-55.533333 ],
    [ u"py",u"Capitán Meza",963,-27.016667,-55.566667 ],
    [ u"py",u"Capitán Miranda",2498,-27.2,-55.8 ],
    [ u"py",u"Caraguatay",1637,-25.233333,-56.816667 ],
    [ u"py",u"Carapeguá",5784,-25.8,-57.233333 ],
    [ u"py",u"Carayaó",2473,-25.183333,-56.4 ],
    [ u"py",u"Carlos Antonio López",1497,-26.4,-54.766667 ],
    [ u"py",u"Carmen del Paraná",4196,-27.233333,-56.216667 ],
    [ u"py",u"Cerrito",1036,-27.316667,-57.666667 ],
    [ u"py",u"Chore",2193,-24.2,-56.566667 ],
    [ u"py",u"Concepción",48127,-23.406389,-57.434444 ],
    [ u"py",u"Coronel Bogado",9831,-27.183333,-56.3 ],
    [ u"py",u"Coronel Martínez",1359,-25.75,-56.616667 ],
    [ u"py",u"Coronel Oviedo",51291,-25.416667,-56.45 ],
    [ u"py",u"Corpus Christi",1387,-24.033333,-54.833333 ],
    [ u"py",u"Curuguaty",11096,-24.516667,-55.7 ],
    [ u"py",u"Desmochados",240,-27.116667,-58.1 ],
    [ u"py",u"Doctor Botrell",246,-25.583333,-56.316667 ],
    [ u"py",u"Doctor Cecilio Báez",1978,-25.05,-56.316667 ],
    [ u"py",u"Doctor Juan León Mallorquín",7489,-25.4,-55.266667 ],
    [ u"py",u"Doctor Juan Manuel Frutos",4798,-25.366667,-55.8 ],
    [ u"py",u"Doctor Pedro P. Peña",5043,-22.45,-62.35 ],
    [ u"py",u"Edelira",1699,-26.75,-55.266667 ],
    [ u"py",u"Emboscada",5911,-25.15,-57.35 ],
    [ u"py",u"Encarnación",74991,-27.333333,-55.9 ],
    [ u"py",u"Escobar",234,-25.65,-57.016667 ],
    [ u"py",u"Eusebio Ayala",8253,-25.4,-56.966667 ],
    [ u"py",u"Félix Pérez Cardozo",536,-25.733333,-56.516667 ],
    [ u"py",u"Fernando de la Mora",120180,-25.316667,-57.6 ],
    [ u"py",u"Filadelfia",8049,-22.35,-60.033333 ],
    [ u"py",u"Fram",3916,-26.983333,-55.883333 ],
    [ u"py",u"Fuerte Olimpo",2478,-21.033333,-57.9 ],
    [ u"py",u"General Artigas",4073,-26.933333,-56.216667 ],
    [ u"py",u"General Delgado",1544,-27.166667,-56.516667 ],
    [ u"py",u"General Elizardo Aquino",2983,-24.433333,-56.7 ],
    [ u"py",u"General Higinio Morínigo",1399,-25.95,-55.916667 ],
    [ u"py",u"General José Eduvigis Díaz",1345,-27.166667,-58.416667 ],
    [ u"py",u"Guarambaré",9066,-25.483333,-57.466667 ],
    [ u"py",u"Hohenau",5307,-27.083333,-55.75 ],
    [ u"py",u"Horqueta",10533,-23.342778,-57.059722 ],
    [ u"py",u"Humaitá",1519,-27.05,-58.55 ],
    [ u"py",u"Independencia",1575,-25.716667,-56.25 ],
    [ u"py",u"Isla Pucú",1529,-25.3,-56.9 ],
    [ u"py",u"Isla Umbú",340,-27,-58.3 ],
    [ u"py",u"Itacurubí de la Cordillera",3576,-25.45,-56.85 ],
    [ u"py",u"Itacurubí del Rosario",3888,-24.5,-56.683333 ],
    [ u"py",u"Itá",18461,-25.483333,-57.35 ],
    [ u"py",u"Itanara",316,-23.816667,-55.783333 ],
    [ u"py",u"Itapé",1641,-25.85,-56.616667 ],
    [ u"py",u"Itapúa Poty",646,-26.583333,-55.566667 ],
    [ u"py",u"Itaquyry",3038,-24.933333,-55.216667 ],
    [ u"py",u"Itauguá",65035,-25.383333,-57.333333 ],
    [ u"py",u"Iturbe",4476,-26.05,-56.483333 ],
    [ u"py",u"Jesús",2530,-27.05,-55.783333 ],
    [ u"py",u"Juan de Mena",480,-24.916667,-56.733333 ],
    [ u"py",u"La Colmena",2551,-25.883333,-56.816667 ],
    [ u"py",u"Lambaré",126391,-25.35,-57.65 ],
    [ u"py",u"La Paz",340,-27.016667,-55.85 ],
    [ u"py",u"Laureles",708,-27.25,-57.466667 ],
    [ u"py",u"Leandro Oviedo",309,-26.716667,-56.233333 ],
    [ u"py",u"Lima",2358,-23.9,-56.333333 ],
    [ u"py",u"Limpio",96238,-25.183333,-57.533333 ],
    [ u"py",u"Loma Grande",364,-25.166667,-57.216667 ],
    [ u"py",u"Los Cedrales",2755,-25.65,-54.7 ],
    [ u"py",u"Luque",209836,-25.266667,-57.566667 ],
    [ u"py",u"Maciel",503,-26.166667,-56.466667 ],
    [ u"py",u"Mariano Roque Alonso",72023,-25.166667,-57.55 ],
    [ u"py",u"Mayor Pablo Lagerenza",1205,-19.916667,-60.783333 ],
    [ u"py",u"Mbocayaty",2296,-25.7,-56.4 ],
    [ u"py",u"Mbutuy",1466,-24.966667,-56.3 ],
    [ u"py",u"Mbuyapey",2201,-26.2,-56.75 ],
    [ u"py",u"Ñacunday",912,-26.016667,-54.766667 ],
    [ u"py",u"Naranjal",2155,-25.966667,-55.183333 ],
    [ u"py",u"Natalicio Talavera",1809,-25.633333,-56.3 ],
    [ u"py",u"Natalio",2253,-26.716667,-55.083333 ],
    [ u"py",u"Nemby",94767,-25.366667,-57.6 ],
    [ u"py",u"Nueva Alborada",290,-27.25,-55.616667 ],
    [ u"py",u"Nueva Colombia",683,-25.183333,-57.35 ],
    [ u"py",u"Nueva Germania",1206,-23.9,-56.566667 ],
    [ u"py",u"Nueva Italia",2841,-25.616667,-57.5 ],
    [ u"py",u"Nueva Londres",813,-25.416667,-56.533333 ],
    [ u"py",u"Ñumí",864,-25.95,-56.316667 ],
    [ u"py",u"Obligado",6350,-27.033333,-55.633333 ],
    [ u"py",u"Paraguarí",10079,-25.633333,-57.15 ],
    [ u"py",u"Paso de Patria",853,-27.216667,-58.583333 ],
    [ u"py",u"Pedro Juan Caballero",67432,-22.566667,-55.616667 ],
    [ u"py",u"Pilar",25542,-26.866667,-58.383333 ],
    [ u"py",u"Pirapo",1757,-26.85,-55.533333 ],
    [ u"py",u"Pirayú",4000,-25.483333,-57.233333 ],
    [ u"py",u"Piribebuy",10337,-25.483333,-57.05 ],
    [ u"py",u"Pozo Colorado",1850,-23.466667,-58.966667 ],
    [ u"py",u"Presidente Franco",54303,-25.533333,-54.616667 ],
    [ u"py",u"Primero de Marzo",837,-25.15,-56.916667 ],
    [ u"py",u"Puerto Pinasco",892,-22.716667,-57.833333 ],
    [ u"py",u"Quiindy",5137,-25.966667,-57.266667 ],
    [ u"py",u"Quyquyhó",757,-26.233333,-56.983333 ],
    [ u"py",u"Repatriación",7091,-25.533333,-55.95 ],
    [ u"py",u"Salto del Guairá",7387,-24.05,-54.35 ],
    [ u"py",u"San Alberto",4990,-24.966667,-54.9 ],
    [ u"py",u"San Antonio",55759,-25.383333,-57.633333 ],
    [ u"py",u"San Bernardino",4651,-25.266667,-57.316667 ],
    [ u"py",u"San Carlos",706,-22.266667,-57.333333 ],
    [ u"py",u"San Cosme y Damián",2224,-27.316667,-56.35 ],
    [ u"py",u"San Cristóbal",478,-25.916667,-55.45 ],
    [ u"py",u"San Estanislao",14751,-24.65,-56.433333 ],
    [ u"py",u"San Joaquín",1745,-24.95,-56.116667 ],
    [ u"py",u"San José de los Arroyos",5118,-25.533333,-56.733333 ],
    [ u"py",u"San José Obrero",459,-25.25,-56.866667 ],
    [ u"py",u"San Juan Bautista de Ñeembucú",330,-26.65,-57.933333 ],
    [ u"py",u"San Juan Bautista",10935,-26.633333,-57.166667 ],
    [ u"py",u"San Juan del Paraná",1494,-27.3,-55.966667 ],
    [ u"py",u"San Juan Nepomuceno",7894,-26.1,-55.966667 ],
    [ u"py",u"San Lázaro",708,-22.166667,-57.916667 ],
    [ u"py",u"San Lorenzo",227898,-25.333333,-57.533333 ],
    [ u"py",u"San Miguel",1210,-26.5,-57.05 ],
    [ u"py",u"San Patricio",1525,-26.966667,-56.816667 ],
    [ u"py",u"San Pedro del Paraná",5723,-26.833333,-56.2 ],
    [ u"py",u"San Pedro de Ycuamandiyú",9361,-24.1,-57.083333 ],
    [ u"py",u"San Rafael del Parana",460,-26.65,-54.933333 ],
    [ u"py",u"San Salvador",723,-25.9,-56.483333 ],
    [ u"py",u"Santa Elena",1138,-25.4,-56.8 ],
    [ u"py",u"Santa María",2095,-26.783333,-56.933333 ],
    [ u"py",u"Santa Rita",11850,-25.783333,-55.066667 ],
    [ u"py",u"Santa Rosa",7257,-26.866667,-56.85 ],
    [ u"py",u"Santiago",2144,-27.15,-56.783333 ],
    [ u"py",u"Sapucaí",1932,-25.666667,-56.916667 ],
    [ u"py",u"Tacuaras",280,-26.816667,-58.1 ],
    [ u"py",u"Tacuatí",2406,-23.45,-56.583333 ],
    [ u"py",u"Tavai",722,-26.483333,-56.35 ],
    [ u"py",u"Tobatí",9953,-25.25,-57.066667 ],
    [ u"py",u"Trinidad",2837,-27.116667,-55.783333 ],
    [ u"py",u"Unión",1653,-24.8,-56.55 ],
    [ u"py",u"Valenzuela",587,-25.583333,-56.866667 ],
    [ u"py",u"Veinticinco de Diciembre",766,-24.7,-56.55 ],
    [ u"py",u"Villa Elisa",64138,-25.366667,-57.616667 ],
    [ u"py",u"Villa Florida",2305,-26.383333,-57.15 ],
    [ u"py",u"Villa Franca",459,-26.283333,-58.2 ],
    [ u"py",u"Villa Hayes",16726,-25.1,-57.566667 ],
    [ u"py",u"Villalbin",375,-27.15,-57.916667 ],
    [ u"py",u"Villa Oliva",772,-26.016667,-57.883333 ],
    [ u"py",u"Villarrica",41160,-25.75,-56.433333 ],
    [ u"py",u"Villeta",11031,-25.466667,-57.6 ],
    [ u"py",u"Yabebyry",217,-27.4,-57.183333 ],
    [ u"py",u"Yaguarón",7182,-25.6,-57.3 ],
    [ u"py",u"Yataity del Norte",1392,-24.833333,-56.35 ],
    [ u"py",u"Yataity",1874,-26.366667,-56.066667 ],
    [ u"py",u"Ybycuí",4629,-26.016667,-57.05 ],
    [ u"py",u"Ybytimí",526,-25.766667,-56.783333 ],
    [ u"py",u"Yegros",1140,-26.45,-56.4 ],
    [ u"py",u"Ygatimí",2810,-24.083333,-55.5 ],
    [ u"py",u"Yhú",2092,-25.05,-55.916667 ],
    [ u"py",u"Ypacarai",9656,-25.383333,-57.266667 ],
    [ u"py",u"Ypane",6659,-25.45,-57.533333 ],
    [ u"py",u"Yuty",4774,-26.6,-56.25 ],
    [ u"qa",u"Abu Samrah",938,24.748333,50.84 ],
    [ u"qa",u"Doha",344939,25.286667,51.533333 ],
    [ u"qa",u"Khor",18923,25.683889,51.505833 ],
    [ u"qa",u"Umm Bab",2500,25.214167,50.807222 ],
    [ u"re",u"Bras-Panon",10445,-20.9833333,55.6833333 ],
    [ u"re",u"Cilaos",6225,-21.1166667,55.4666667 ],
    [ u"re",u"Entre-Deux",5788,-21.2333333,55.4666667 ],
    [ u"re",u"La Possession",26867,-20.9166667,55.3333333 ],
    [ u"re",u"Le Port",40774,-20.9166667,55.3 ],
    [ u"re",u"Les Trois-Bassins",7114,-21.1,55.3 ],
    [ u"re",u"Le Tampon",69989,-21.2666667,55.5166667 ],
    [ u"re",u"Saint-André",48675,-20.95,55.65 ],
    [ u"re",u"Saint-Benoît",35312,-21.0333333,55.7166667 ],
    [ u"re",u"Saint-Denis",137198,-20.8666667,55.4666667 ],
    [ u"re",u"Sainte-Marie",31638,-20.8833333,55.55 ],
    [ u"re",u"Sainte-Rose",7036,-21.1,55.7833333 ],
    [ u"re",u"Sainte-Suzanne",20531,-20.9,55.6166667 ],
    [ u"re",u"Saint-Joseph",33696,-21.3666667,55.6166667 ],
    [ u"re",u"Saint-Leu",28280,-21.15,55.2833333 ],
    [ u"re",u"Saint-Louis",47884,-21.2666667,55.4166667 ],
    [ u"re",u"Saint-Paul",99309,-21.0,55.2666667 ],
    [ u"re",u"Saint-Philippe",5441,-21.35,55.7666667 ],
    [ u"re",u"Saint-Pierre",76657,-21.3166667,55.4833333 ],
    [ u"re",u"Salazie",7696,-21.0166667,55.55 ],
    [ u"ro",u"Abram",3291,47.316667,22.383333 ],
    [ u"ro",u"Abramut",2962,47.316667,22.25 ],
    [ u"ro",u"Abrud",6122,46.266667,23.066667 ],
    [ u"ro",u"Acas",2819,47.533333,22.783333 ],
    [ u"ro",u"Acatari",4719,46.483333,24.633333 ],
    [ u"ro",u"Adamclisi",2247,44.083333,27.95 ],
    [ u"ro",u"Adamus",5905,46.3,24.233333 ],
    [ u"ro",u"Adancata",7779,47.733333,26.3 ],
    [ u"ro",u"Adancata",3083,44.766667,26.433333 ],
    [ u"ro",u"Adjud",17299,46.1,27.166667 ],
    [ u"ro",u"Adunati",2239,45.133333,25.616667 ],
    [ u"ro",u"Adunatii-Copaceni",6584,44.253333,26.0475 ],
    [ u"ro",u"Afumati",3247,44,23.466667 ],
    [ u"ro",u"Afumati",6696,44.516667,26.266667 ],
    [ u"ro",u"Agapia",4517,47.166667,26.283333 ],
    [ u"ro",u"Agas",6619,46.483333,26.216667 ],
    [ u"ro",u"Aghiresu",7071,46.883333,23.25 ],
    [ u"ro",u"Agigea",5405,44.083333,28.616667 ],
    [ u"ro",u"Agnita",10505,45.966667,24.616667 ],
    [ u"ro",u"Agrij",1374,47.066667,23.133333 ],
    [ u"ro",u"Aita Mare",1750,45.966667,25.55 ],
    [ u"ro",u"Aiton",1331,46.683333,23.733333 ],
    [ u"ro",u"Aiud",28341,46.3,23.716667 ],
    [ u"ro",u"Albac",2168,46.45,22.966667 ],
    [ u"ro",u"Alba Iulia",66085,46.066667,23.583333 ],
    [ u"ro",u"Albeni",2820,45.033333,23.6 ],
    [ u"ro",u"Albesti",6578,47.7,27.066667 ],
    [ u"ro",u"Albesti",3459,43.8,28.416667 ],
    [ u"ro",u"Albesti",5382,46.233333,24.85 ],
    [ u"ro",u"Albesti",2702,44.533333,27.133333 ],
    [ u"ro",u"Albesti",3279,46.5,27.866667 ],
    [ u"ro",u"Albesti",4503,45.316667,25 ],
    [ u"ro",u"Albestii-Pamanteni",5815,45.216667,24.666667 ],
    [ u"ro",u"Albesti-Paleologu",5695,44.95,26.216667 ],
    [ u"ro",u"Alesd",10264,47.066667,22.416667 ],
    [ u"ro",u"Alexandria",49346,43.983333,25.333333 ],
    [ u"ro",u"Alexandru Ioan Cuza",2951,47.133333,26.85 ],
    [ u"ro",u"Alexandru Odobescu",3062,44.266667,27.083333 ],
    [ u"ro",u"Alexandru Vlahuta",3139,46.416667,27.633333 ],
    [ u"ro",u"Alexeni",2478,44.683333,26.7 ],
    [ u"ro",u"Aliman",3015,44.183333,27.85 ],
    [ u"ro",u"Alimpesti",2232,45.083333,23.8 ],
    [ u"ro",u"Almajiu",4108,44.45,23.716667 ],
    [ u"ro",u"Almas",2957,46.083333,22.433333 ],
    [ u"ro",u"Almasu",2801,46.95,23.133333 ],
    [ u"ro",u"Almasu Mare",1649,46.1,23.133333 ],
    [ u"ro",u"Altina",1587,45.933333,24.466667 ],
    [ u"ro",u"Alunis",1370,47.033333,23.75 ],
    [ u"ro",u"Alunis",3258,46.9,24.816667 ],
    [ u"ro",u"Alunis",3677,45.2,25.866667 ],
    [ u"ro",u"Alunu",4495,45.016667,23.816667 ],
    [ u"ro",u"Amara",7557,44.616667,27.316667 ],
    [ u"ro",u"Amarasti",2109,44.766667,24.15 ],
    [ u"ro",u"Amarastii de Jos",5870,43.95,24.166667 ],
    [ u"ro",u"Amarastii de Sus",3879,43.983333,24.15 ],
    [ u"ro",u"Amaru",2749,44.933333,26.583333 ],
    [ u"ro",u"Amzacea",2647,43.95,28.4 ],
    [ u"ro",u"Andrasesti",2272,44.566667,27.133333 ],
    [ u"ro",u"Andreiasu de Jos",2000,45.75,26.833333 ],
    [ u"ro",u"Andrid",2627,47.516667,22.35 ],
    [ u"ro",u"Andrieseni",4501,47.533333,27.283333 ],
    [ u"ro",u"Anina",8689,45.079444,21.856944 ],
    [ u"ro",u"Aninoasa",5907,44.966667,25.433333 ],
    [ u"ro",u"Aninoasa",4999,45.4,23.333333 ],
    [ u"ro",u"Aninoasa",4288,44.75,23.483333 ],
    [ u"ro",u"Aninoasa",3334,45.183333,24.933333 ],
    [ u"ro",u"Apa",2842,47.766667,23.2 ],
    [ u"ro",u"Apahida",8658,46.816667,23.75 ],
    [ u"ro",u"Apata",2929,45.95,25.516667 ],
    [ u"ro",u"Apateu",3622,46.616667,21.783333 ],
    [ u"ro",u"Apele Vii",2462,44.066667,24.066667 ],
    [ u"ro",u"Apold",2698,46.116667,24.816667 ],
    [ u"ro",u"Apoldu de Jos",1506,45.866667,23.85 ],
    [ u"ro",u"Apostolache",2311,45.133333,26.266667 ],
    [ u"ro",u"Arad",169067,46.183333,21.316667 ],
    [ u"ro",u"Arbore",6736,47.733333,25.933333 ],
    [ u"ro",u"Arcani",1424,45.083333,23.133333 ],
    [ u"ro",u"Ardeoani",2532,46.533333,26.6 ],
    [ u"ro",u"Ardud",6357,47.633333,22.883333 ],
    [ u"ro",u"Ardusat",2513,47.65,23.366667 ],
    [ u"ro",u"Arefu",2750,45.333333,24.6 ],
    [ u"ro",u"Argetoaia",4862,44.516667,23.366667 ],
    [ u"ro",u"Aricestii-Rahtivani",8764,44.95,25.833333 ],
    [ u"ro",u"Aricestii-Zeletin",1376,45.216667,26.166667 ],
    [ u"ro",u"Arieseni",1876,46.483333,22.766667 ],
    [ u"ro",u"Arinis",1192,47.5,23.233333 ],
    [ u"ro",u"Armasesti",7243,44.75,26.583333 ],
    [ u"ro",u"Armenis",2613,45.2,22.316667 ],
    [ u"ro",u"Aroneanu",2916,47.2,27.6 ],
    [ u"ro",u"Arpasu de Jos",2733,45.783333,24.616667 ],
    [ u"ro",u"Arsura",1984,46.813333,28.022222 ],
    [ u"ro",u"Asau",7438,46.433333,26.4 ],
    [ u"ro",u"Astileu",3728,47.033333,22.383333 ],
    [ u"ro",u"Asuaju de Sus",1585,47.566667,23.183333 ],
    [ u"ro",u"Atel",3576,46.15,24.466667 ],
    [ u"ro",u"Atid",2797,46.45,25.05 ],
    [ u"ro",u"Atintis",1606,46.433333,24.1 ],
    [ u"ro",u"Auseu",2978,47.033333,22.5 ],
    [ u"ro",u"Avrameni",5490,48.016667,26.95 ],
    [ u"ro",u"Avramesti",2481,46.333333,25.016667 ],
    [ u"ro",u"Avram Iancu",1806,46.383333,22.783333 ],
    [ u"ro",u"Avrig",14032,45.716667,24.383333 ],
    [ u"ro",u"Axente Sever",3960,46.1,24.216667 ],
    [ u"ro",u"Axintele",2912,44.6,26.783333 ],
    [ u"ro",u"Azuga",4961,45.45,25.55 ],
    [ u"ro",u"Baba Ana",4234,44.966667,26.45 ],
    [ u"ro",u"Babadag",10101,44.9,28.716667 ],
    [ u"ro",u"Babaita",6276,44.166667,25.383333 ],
    [ u"ro",u"Babana",2809,44.9,24.7 ],
    [ u"ro",u"Babeni",2011,47.3,23.4 ],
    [ u"ro",u"Babeni",9350,44.966667,24.233333 ],
    [ u"ro",u"Babiciu",2337,44.033333,24.566667 ],
    [ u"ro",u"Bacani",2748,46.333333,27.666667 ],
    [ u"ro",u"Bacau",171397,46.566667,26.9 ],
    [ u"ro",u"Bacesti",4017,46.85,27.233333 ],
    [ u"ro",u"Bacia",1772,45.8,23.016667 ],
    [ u"ro",u"Baciu",8046,46.8,23.516667 ],
    [ u"ro",u"Baclesu",2730,44.483333,23.133333 ],
    [ u"ro",u"Bagaciu",2549,46.266667,24.366667 ],
    [ u"ro",u"Bahna",3713,46.783333,26.783333 ],
    [ u"ro",u"Bahnea",3754,46.366667,24.483333 ],
    [ u"ro",u"Baia",4938,44.716667,28.666667 ],
    [ u"ro",u"Baia",6762,47.416667,26.216667 ],
    [ u"ro",u"Baia de Arama",5624,45,22.806667 ],
    [ u"ro",u"Baia de Aries",4566,46.383333,23.283333 ],
    [ u"ro",u"Baia de Cris",2987,46.166667,22.716667 ],
    [ u"ro",u"Baia de Fier",4328,45.166667,23.766667 ],
    [ u"ro",u"Baia Mare",136554,47.666667,23.583333 ],
    [ u"ro",u"Baia-Sprie",16746,47.666667,23.7 ],
    [ u"ro",u"Baicoi",19869,45.033333,25.85 ],
    [ u"ro",u"Baiculesti",6207,45.066667,24.7 ],
    [ u"ro",u"Baile Govora",2862,45.083333,24.183333 ],
    [ u"ro",u"Baile Herculane",6022,44.879722,22.4125 ],
    [ u"ro",u"Baile Olanesti",4562,45.2,24.233333 ],
    [ u"ro",u"Bailesti",19599,44.016667,23.35 ],
    [ u"ro",u"Baile Tusnad",1675,46.15,25.85 ],
    [ u"ro",u"Baisoara",2319,46.583333,23.466667 ],
    [ u"ro",u"Baita",4183,46.033333,22.9 ],
    [ u"ro",u"Baita de sub Codru",1910,47.533333,23.15 ],
    [ u"ro",u"Baiut",2652,47.616667,24 ],
    [ u"ro",u"Bala",4580,44.883889,22.833333 ],
    [ u"ro",u"Bala",889,46.716667,24.5 ],
    [ u"ro",u"Balabanesti",3976,46.1,27.716667 ],
    [ u"ro",u"Balaceanu",1773,45.266667,27.15 ],
    [ u"ro",u"Balaci",2485,44.35,24.916667 ],
    [ u"ro",u"Balacita",3471,44.383333,23.133333 ],
    [ u"ro",u"Balaciu",3371,44.633333,26.883333 ],
    [ u"ro",u"Balan",7275,46.65,25.816667 ],
    [ u"ro",u"Balan",4050,47.15,23.333333 ],
    [ u"ro",u"Balanesti",2434,45.066667,23.4 ],
    [ u"ro",u"Balasesti",2534,46.1,27.666667 ],
    [ u"ro",u"Balauseri",4968,46.4,24.683333 ],
    [ u"ro",u"Balcani",7958,46.633333,26.55 ],
    [ u"ro",u"Balcauti",3384,47.9,26.083333 ],
    [ u"ro",u"Balc",3512,47.283333,22.533333 ],
    [ u"ro",u"Balcesti",5683,44.616667,23.95 ],
    [ u"ro",u"Baldovinesti",3380,44.383333,24.05 ],
    [ u"ro",u"Baleni",2696,45.816667,27.833333 ],
    [ u"ro",u"Balesti",7333,45.016667,23.216667 ],
    [ u"ro",u"Balesti",2215,45.433333,27.233333 ],
    [ u"ro",u"Balilesti",4362,45.066667,24.933333 ],
    [ u"ro",u"Balint",1736,45.8125,21.853611 ],
    [ u"ro",u"Balotesti",6795,44.616667,26.116667 ],
    [ u"ro",u"Balsa",1200,46.033333,23.116667 ],
    [ u"ro",u"Bals",20627,44.35,24.1 ],
    [ u"ro",u"Balta Alba",3080,45.316667,27.283333 ],
    [ u"ro",u"Balta",1391,44.886944,22.636944 ],
    [ u"ro",u"Balta Doamnei",2719,44.75,26.166667 ],
    [ u"ro",u"Baltatesti",6635,47.116667,26.3 ],
    [ u"ro",u"Baltati",5061,47.216667,27.15 ],
    [ u"ro",u"Balteni",7895,44.866667,23.283333 ],
    [ u"ro",u"Balteni",1612,46.666667,27.616667 ],
    [ u"ro",u"Baltesti",3543,45.1,26.133333 ],
    [ u"ro",u"Baluseni",5017,47.666667,26.8 ],
    [ u"ro",u"Balvanesti",1131,44.7975,22.680278 ],
    [ u"ro",u"Banca",5600,46.3,27.8 ],
    [ u"ro",u"Band",7599,46.583333,24.383333 ],
    [ u"ro",u"Baneasa",2184,45.933333,27.933333 ],
    [ u"ro",u"Baneasa",5280,44.066667,27.7 ],
    [ u"ro",u"Baneasa",5582,44.046111,26.064167 ],
    [ u"ro",u"Banesti",5636,45.1,25.766667 ],
    [ u"ro",u"Bania",1939,44.895833,22.044722 ],
    [ u"ro",u"Banisor",2385,47.116667,22.85 ],
    [ u"ro",u"Banita",1352,45.45,23.266667 ],
    [ u"ro",u"Banloc",4497,45.383611,21.138056 ],
    [ u"ro",u"Bara",374,45.894722,21.871944 ],
    [ u"ro",u"Bara",4436,47.033333,27.05 ],
    [ u"ro",u"Bara",374,45.816667,21.9 ],
    [ u"ro",u"Baraganul",3561,44.8,27.516667 ],
    [ u"ro",u"Baraolt",9429,46.083333,25.6 ],
    [ u"ro",u"Barasti",2156,44.616667,24.683333 ],
    [ u"ro",u"Barbatesti",1886,44.866667,23.5 ],
    [ u"ro",u"Barbatesti",3805,45.183333,24.116667 ],
    [ u"ro",u"Barbuletu",6777,45.133333,25.3 ],
    [ u"ro",u"Barca",4403,43.966667,23.616667 ],
    [ u"ro",u"Barcanesti",9225,44.883333,26.05 ],
    [ u"ro",u"Barcanesti",3936,44.633333,26.65 ],
    [ u"ro",u"Barcani",3792,45.7,26.083333 ],
    [ u"ro",u"Barcea",5985,45.75,27.466667 ],
    [ u"ro",u"Bargaoani",4203,46.983333,26.633333 ],
    [ u"ro",u"Barghis",2116,45.983333,24.533333 ],
    [ u"ro",u"Barla",5795,44.433333,24.766667 ],
    [ u"ro",u"Barlad",67819,46.233333,27.666667 ],
    [ u"ro",u"Barna",1531,45.716667,22.05 ],
    [ u"ro",u"Barnova",3925,47.066667,27.616667 ],
    [ u"ro",u"Barsana",6266,47.816667,24.066667 ],
    [ u"ro",u"Barsanesti",5038,46.333333,26.7 ],
    [ u"ro",u"Barsesti",3263,45.916667,26.733333 ],
    [ u"ro",u"Baru",3014,45.466667,23.166667 ],
    [ u"ro",u"Barza",2677,44.333333,24.783333 ],
    [ u"ro",u"Basarabi",10906,44.183333,28.416667 ],
    [ u"ro",u"Bascov",8759,44.9,24.816667 ],
    [ u"ro",u"Basesti",1586,47.483333,23.15 ],
    [ u"ro",u"Batar",5143,46.7,21.816667 ],
    [ u"ro",u"Batarci",3681,48.033333,23.166667 ],
    [ u"ro",u"Batos",4107,46.883333,24.666667 ],
    [ u"ro",u"Batrana",172,45.783333,22.583333 ],
    [ u"ro",u"Bautar",2731,45.516667,22.566667 ],
    [ u"ro",u"Bazna",3824,46.2,24.283333 ],
    [ u"ro",u"Beba",1586,46.133333,20.316667 ],
    [ u"ro",u"Beceni",4992,45.383333,26.783333 ],
    [ u"ro",u"Bechet",3824,43.766667,23.95 ],
    [ u"ro",u"Becicherecu Mic",4765,45.829167,21.051389 ],
    [ u"ro",u"Beclean",10909,47.183333,24.183333 ],
    [ u"ro",u"Beclean",1511,45.833333,24.916667 ],
    [ u"ro",u"Beica de Jos",2207,46.733333,24.8 ],
    [ u"ro",u"Beidaud",1793,44.716667,28.566667 ],
    [ u"ro",u"Belcesti",11335,47.3,27.083333 ],
    [ u"ro",u"Belciugatele",2322,44.483333,26.433333 ],
    [ u"ro",u"Belin",2612,45.933333,25.566667 ],
    [ u"ro",u"Belint",3023,45.755,21.760278 ],
    [ u"ro",u"Belis",1377,46.65,23.033333 ],
    [ u"ro",u"Beliu",3274,46.483333,21.983333 ],
    [ u"ro",u"Beltiug",3233,47.55,22.85 ],
    [ u"ro",u"Benesat",1737,47.416667,23.3 ],
    [ u"ro",u"Bengesti",3504,45.066667,23.6 ],
    [ u"ro",u"Berbesti",5606,44.983333,23.883333 ],
    [ u"ro",u"Berca",9479,45.283333,26.683333 ],
    [ u"ro",u"Berceni",5976,44.933333,26.116667 ],
    [ u"ro",u"Berceni",4154,44.314167,26.185556 ],
    [ u"ro",u"Beresti",3518,46.1,27.883333 ],
    [ u"ro",u"Beresti-Bistrita",3377,46.716667,26.833333 ],
    [ u"ro",u"Beresti-Sat",4352,46.1,27.883333 ],
    [ u"ro",u"Beresti-Tazlau",5661,46.466667,26.666667 ],
    [ u"ro",u"Berevoesti",3385,45.233333,24.916667 ],
    [ u"ro",u"Berezeni",5590,46.376111,28.147778 ],
    [ u"ro",u"Berghin",2125,46.066667,23.733333 ],
    [ u"ro",u"Berislavesti",3032,45.25,24.416667 ],
    [ u"ro",u"Beriu",3309,45.783333,23.183333 ],
    [ u"ro",u"Berlesti",2367,44.916667,23.666667 ],
    [ u"ro",u"Berliste",1326,44.986667,21.463056 ],
    [ u"ro",u"Bertea",3328,45.233333,25.866667 ],
    [ u"ro",u"Bertestii de Jos",3256,44.833333,27.75 ],
    [ u"ro",u"Berthelot",1006,45.616667,22.883333 ],
    [ u"ro",u"Berveni",3536,47.75,22.466667 ],
    [ u"ro",u"Berzasca",3014,44.699167,21.954722 ],
    [ u"ro",u"Berzovia",4031,45.426111,21.628056 ],
    [ u"ro",u"Berzunti",5285,46.4,26.633333 ],
    [ u"ro",u"Bethausen",3012,45.833056,21.952778 ],
    [ u"ro",u"Bezdead",5067,45.15,25.516667 ],
    [ u"ro",u"Bicaz",8340,46.916667,26.066667 ],
    [ u"ro",u"Bicaz",1272,47.466667,23.033333 ],
    [ u"ro",u"Bicaz Chei",4618,46.816667,25.883333 ],
    [ u"ro",u"Bicazu Ardelean",4212,46.85,25.933333 ],
    [ u"ro",u"Bichis",1023,46.366667,24.1 ],
    [ u"ro",u"Biertan",2939,46.133333,24.516667 ],
    [ u"ro",u"Biharia",5769,47.15,21.916667 ],
    [ u"ro",u"Bilbor",2820,47.05,25.516667 ],
    [ u"ro",u"Bilca",3460,47.916667,25.75 ],
    [ u"ro",u"Bilciuresti",1824,44.733333,25.8 ],
    [ u"ro",u"Biled",6230,45.886389,20.958889 ],
    [ u"ro",u"Birchis",2009,45.966667,22.166667 ],
    [ u"ro",u"Bisoca",2915,45.533333,26.7 ],
    [ u"ro",u"Bistra",4942,46.383333,23.1 ],
    [ u"ro",u"Bistra",4330,47.866667,24.2 ],
    [ u"ro",u"Bistret",4570,43.9,23.5 ],
    [ u"ro",u"Bistrita",81319,47.133333,24.483333 ],
    [ u"ro",u"Bivolari",4530,47.533333,27.433333 ],
    [ u"ro",u"Bixad",7369,47.933333,23.4 ],
    [ u"ro",u"Blagesti",7165,46.683333,26.65 ],
    [ u"ro",u"Blagesti",1844,46.137222,28.013056 ],
    [ u"ro",u"Blajani",1248,45.316667,26.816667 ],
    [ u"ro",u"Blaj",20371,46.183333,23.916667 ],
    [ u"ro",u"Blajel",2419,46.216667,24.316667 ],
    [ u"ro",u"Blajeni",1516,46.233333,22.9 ],
    [ u"ro",u"Blandiana",1157,45.966667,23.383333 ],
    [ u"ro",u"Blejesti",4149,44.3,25.466667 ],
    [ u"ro",u"Blejoi",7646,45,26.016667 ],
    [ u"ro",u"Bobicesti",3468,44.383333,24.15 ],
    [ u"ro",u"Bobota",3950,47.383333,22.766667 ],
    [ u"ro",u"Bocicoiu Mare",4400,47.966667,24 ],
    [ u"ro",u"Bocsa",16349,45.373333,21.709167 ],
    [ u"ro",u"Bocsa",3394,47.3,22.916667 ],
    [ u"ro",u"Bocsig",3493,46.416667,21.95 ],
    [ u"ro",u"Bod",3839,45.766667,25.65 ],
    [ u"ro",u"Bodesti",5122,47.033333,26.416667 ],
    [ u"ro",u"Bodoc",2466,45.95,25.85 ],
    [ u"ro",u"Bogata",1915,46.45,24.066667 ],
    [ u"ro",u"Bogati",4936,44.866667,25.133333 ],
    [ u"ro",u"Bogda",465,45.978333,21.5725 ],
    [ u"ro",u"Bogdana",2970,43.933333,25.083333 ],
    [ u"ro",u"Bogdana",1856,46.533333,27.616667 ],
    [ u"ro",u"Bogdand",3179,47.416667,22.933333 ],
    [ u"ro",u"Bogdanesti",3981,47.366667,26.283333 ],
    [ u"ro",u"Bogdanesti",2740,46.216667,26.683333 ],
    [ u"ro",u"Bogdanita",1573,46.45,27.683333 ],
    [ u"ro",u"Bogdan Voda",3377,47.7,24.266667 ],
    [ u"ro",u"Boghesti",1832,46.166667,27.4 ],
    [ u"ro",u"Boianu Mare",1403,47.383333,22.533333 ],
    [ u"ro",u"Boisoara",1653,45.433333,24.383333 ],
    [ u"ro",u"Boiu Mare",1254,47.4,23.583333 ],
    [ u"ro",u"Bolbosi",3286,44.75,23.216667 ],
    [ u"ro",u"Boldesti",1952,44.866667,26.533333 ],
    [ u"ro",u"Boldesti-Scaeni",11460,45.033333,26.033333 ],
    [ u"ro",u"Boldu",2518,45.333333,27.233333 ],
    [ u"ro",u"Boldur",2542,45.694167,21.776667 ],
    [ u"ro",u"Bolintin Deal",6139,44.459167,25.821111 ],
    [ u"ro",u"Bolintinu-din-Vale",11700,44.448889,25.757778 ],
    [ u"ro",u"Bolotesti",4578,45.833333,27.066667 ],
    [ u"ro",u"Bolvasnita",1525,45.35,22.3 ],
    [ u"ro",u"Borascu",3641,44.7,23.283333 ],
    [ u"ro",u"Borca",6556,47.183333,25.766667 ],
    [ u"ro",u"Borcea",9546,44.333333,27.75 ],
    [ u"ro",u"Bordei Verde",3016,45.083333,27.566667 ],
    [ u"ro",u"Bordesti",1806,45.55,27.05 ],
    [ u"ro",u"Bordusani",5285,44.483333,27.9 ],
    [ u"ro",u"Borlesti",8965,46.766667,26.483333 ],
    [ u"ro",u"Boroaia",4737,47.35,26.333333 ],
    [ u"ro",u"Borod",4076,46.983333,22.633333 ],
    [ u"ro",u"Borosneu Mare",3063,45.816667,26 ],
    [ u"ro",u"Borsa",26966,47.65,24.666667 ],
    [ u"ro",u"Borsa",1841,46.933333,23.666667 ],
    [ u"ro",u"Bors",3346,47.116667,21.816667 ],
    [ u"ro",u"Borsec",2815,46.95,25.566667 ],
    [ u"ro",u"Bosanci",6270,47.583333,26.316667 ],
    [ u"ro",u"Bosorod",2224,45.683333,23.083333 ],
    [ u"ro",u"Boteni",2733,45.183333,25.116667 ],
    [ u"ro",u"Botesti",6343,47.05,26.733333 ],
    [ u"ro",u"Botesti",2292,46.8,27.883333 ],
    [ u"ro",u"Botesti",1330,45.016667,25.133333 ],
    [ u"ro",u"Botiza",2949,47.666667,24.15 ],
    [ u"ro",u"Botiz",4779,47.833333,22.95 ],
    [ u"ro",u"Botoroaga",6488,44.148333,25.544722 ],
    [ u"ro",u"Botosana",4881,47.683333,25.95 ],
    [ u"ro",u"Botosani",114784,47.75,26.666667 ],
    [ u"ro",u"Botosesti-Paia",994,44.4,23.266667 ],
    [ u"ro",u"Bozieni",3057,46.833333,27.15 ],
    [ u"ro",u"Bozioru",1267,45.383333,26.483333 ],
    [ u"ro",u"Bozovici",3187,44.938889,22.001667 ],
    [ u"ro",u"Brabova",1791,44.366667,23.433333 ],
    [ u"ro",u"Brad",15988,46.133333,22.783333 ],
    [ u"ro",u"Bradeanu",2864,44.933333,26.85 ],
    [ u"ro",u"Bradeni",1470,46.083333,24.833333 ],
    [ u"ro",u"Bradesti",3510,46.35,25.35 ],
    [ u"ro",u"Bradesti",4625,44.483333,23.633333 ],
    [ u"ro",u"Bradu",5091,44.783333,24.9 ],
    [ u"ro",u"Bradulet",2130,45.283333,24.766667 ],
    [ u"ro",u"Bradut",4616,46.133333,25.616667 ],
    [ u"ro",u"Braesti",2222,47.866667,26.45 ],
    [ u"ro",u"Braesti",3289,47.15,27.1 ],
    [ u"ro",u"Braesti",2502,45.433333,26.5 ],
    [ u"ro",u"Bragadiru",4498,43.766667,25.516667 ],
    [ u"ro",u"Bragadiru",8274,44.371111,25.9775 ],
    [ u"ro",u"Brahasesti",8214,46.05,27.35 ],
    [ u"ro",u"Braila",213570,45.266667,27.983333 ],
    [ u"ro",u"Bralostita",3840,44.5,23.516667 ],
    [ u"ro",u"Bran",5177,45.516667,25.35 ],
    [ u"ro",u"Branceni",3057,43.883333,25.4 ],
    [ u"ro",u"Brancovenesti",4444,46.866667,24.766667 ],
    [ u"ro",u"Brancoveni",3321,44.316667,24.3 ],
    [ u"ro",u"Branesti",9094,45.033333,25.416667 ],
    [ u"ro",u"Branesti",2516,44.65,23.466667 ],
    [ u"ro",u"Branesti",8645,44.45,26.333333 ],
    [ u"ro",u"Branisca",1808,45.916667,22.783333 ],
    [ u"ro",u"Branistea",3347,47.166667,24.066667 ],
    [ u"ro",u"Branistea",4052,45.45,27.85 ],
    [ u"ro",u"Branistea",4430,44.683333,25.583333 ],
    [ u"ro",u"Brasov",276089,45.633333,25.583333 ],
    [ u"ro",u"Brastavatu",5189,43.916667,24.4 ],
    [ u"ro",u"Bratca",5462,46.933333,22.616667 ],
    [ u"ro",u"Brateiu",3126,46.166667,24.416667 ],
    [ u"ro",u"Brates",1525,45.833333,26.066667 ],
    [ u"ro",u"Brazi",8406,44.866667,26.016667 ],
    [ u"ro",u"Brazii",3473,44.766667,26.35 ],
    [ u"ro",u"Breasta",3867,44.333333,23.683333 ],
    [ u"ro",u"Breaza",1686,47.616667,25.333333 ],
    [ u"ro",u"Breaza",3127,45.1,26.533333 ],
    [ u"ro",u"Breaza",2492,46.766667,24.633333 ],
    [ u"ro",u"Breaza",17949,45.183333,25.666667 ],
    [ u"ro",u"Brebeni",2904,44.366667,24.45 ],
    [ u"ro",u"Brebu",1292,45.420278,21.9925 ],
    [ u"ro",u"Brebu",7591,45.183333,25.766667 ],
    [ u"ro",u"Brebu Nou",86,45.233333,22.133333 ],
    [ u"ro",u"Brestovat",812,45.872222,21.675556 ],
    [ u"ro",u"Bretcu",3866,46.05,26.3 ],
    [ u"ro",u"Breznita-Motru",1760,44.566667,23.216667 ],
    [ u"ro",u"Breznita Ocol",4002,44.666667,22.618333 ],
    [ u"ro",u"Brezoaiele",4100,44.583333,25.733333 ],
    [ u"ro",u"Brezoi",6668,45.35,24.25 ],
    [ u"ro",u"Brodina",3654,47.883333,25.416667 ],
    [ u"ro",u"Broscauti",3430,47.95,26.45 ],
    [ u"ro",u"Brosteni",3017,44.760833,22.979444 ],
    [ u"ro",u"Brosteni",6578,47.233333,25.7 ],
    [ u"ro",u"Brosteni",2152,45.75,27.033333 ],
    [ u"ro",u"Bruiu",782,45.866667,24.7 ],
    [ u"ro",u"Brusturi",4295,47.15,22.25 ],
    [ u"ro",u"Brusturoasa",3479,46.516667,26.2 ],
    [ u"ro",u"Bucecea",5143,47.766667,26.433333 ],
    [ u"ro",u"Buces",2355,46.183333,22.933333 ],
    [ u"ro",u"Bucharest",1877155,44.433333,26.1 ],
    [ u"ro",u"Buchin",2073,45.366667,22.25 ],
    [ u"ro",u"Bucinisu",2306,43.95,24.25 ],
    [ u"ro",u"Bucium",1747,46.233333,23.216667 ],
    [ u"ro",u"Buciumeni",4604,45.15,25.45 ],
    [ u"ro",u"Buciumeni",2658,46,27.3 ],
    [ u"ro",u"Buciumi",2776,47.033333,23.066667 ],
    [ u"ro",u"Bucosnita",3025,45.3,22.266667 ],
    [ u"ro",u"Bucovat",4175,44.3,23.75 ],
    [ u"ro",u"Bucov",10279,44.966667,26.083333 ],
    [ u"ro",u"Bucsani",3959,44.376111,25.655278 ],
    [ u"ro",u"Bucu",5232,44.6,27.5 ],
    [ u"ro",u"Bucuresci",1906,46.133333,22.9 ],
    [ u"ro",u"Buda",3257,45.5,26.9 ],
    [ u"ro",u"Budacu de Jos",2866,47.083333,24.516667 ],
    [ u"ro",u"Budeasa",3789,45.016667,24.85 ],
    [ u"ro",u"Budesti",2050,46.883333,24.25 ],
    [ u"ro",u"Budesti",3437,47.733333,23.95 ],
    [ u"ro",u"Budesti",5362,45.05,24.383333 ],
    [ u"ro",u"Budesti",9598,44.234722,26.465833 ],
    [ u"ro",u"Budila",3405,45.666667,25.8 ],
    [ u"ro",u"Budureasa",2622,46.666667,22.5 ],
    [ u"ro",u"Buduslau",1926,47.4,22.266667 ],
    [ u"ro",u"Buftea",20691,44.561389,25.948889 ],
    [ u"ro",u"Bughea de Jos",2988,45.266667,25 ],
    [ u"ro",u"Buhoci",4736,46.566667,27.016667 ],
    [ u"ro",u"Buhusi",18395,46.716667,26.7 ],
    [ u"ro",u"Bujoreni",3830,45.133333,24.35 ],
    [ u"ro",u"Bujoru",2018,43.716667,25.566667 ],
    [ u"ro",u"Bulbucata",1682,44.283333,25.803333 ],
    [ u"ro",u"Bulz",2352,46.916667,22.683333 ],
    [ u"ro",u"Bulzesti",400,46.266667,22.733333 ],
    [ u"ro",u"Bulzesti",1944,44.533333,23.883333 ],
    [ u"ro",u"Bumbesti-Jiu",10445,45.166667,23.4 ],
    [ u"ro",u"Bunesti",2435,46.1,25.05 ],
    [ u"ro",u"Bunesti",3070,46.833333,27.966667 ],
    [ u"ro",u"Bunesti",2684,47.516667,26.283333 ],
    [ u"ro",u"Bunesti",2620,45.116667,24.183333 ],
    [ u"ro",u"Bunila",455,45.7,22.666667 ],
    [ u"ro",u"Burila Mare",2656,44.452778,22.573611 ],
    [ u"ro",u"Burjuc",997,45.95,22.483333 ],
    [ u"ro",u"Busteni",9907,45.4,25.533333 ],
    [ u"ro",u"Bustuchin",3660,44.966667,23.733333 ],
    [ u"ro",u"Butea",3893,47.066667,26.916667 ],
    [ u"ro",u"Butimanu",2335,44.683333,25.9 ],
    [ u"ro",u"Butoiesti",3438,44.583333,23.366667 ],
    [ u"ro",u"Buturugeni",4078,44.365278,25.835278 ],
    [ u"ro",u"Buza",1374,46.9,24.15 ],
    [ u"ro",u"Buzau",130955,45.15,26.833333 ],
    [ u"ro",u"Buzescu",4243,44.016667,25.233333 ],
    [ u"ro",u"Buzias",7625,45.649167,21.603611 ],
    [ u"ro",u"Buzoesti",6281,44.583333,24.916667 ],
    [ u"ro",u"Cabesti",2043,46.766667,22.366667 ],
    [ u"ro",u"Cacica",4438,47.633333,25.9 ],
    [ u"ro",u"Caianu",2536,46.783333,23.916667 ],
    [ u"ro",u"Caianu Mic",5340,47.233333,24.15 ],
    [ u"ro",u"Caineni",2731,45.483333,24.3 ],
    [ u"ro",u"Caiuti",5357,46.183333,26.933333 ],
    [ u"ro",u"Cajvana",7236,47.7,25.966667 ],
    [ u"ro",u"Calafat",18643,43.991111,22.932778 ],
    [ u"ro",u"Calafindesti",5764,47.85,26.116667 ],
    [ u"ro",u"Calan",12782,45.733333,22.983333 ],
    [ u"ro",u"Calarasi",2544,46.483333,23.866667 ],
    [ u"ro",u"Calarasi",3962,47.616667,27.266667 ],
    [ u"ro",u"Calarasi",6632,43.8,24.05 ],
    [ u"ro",u"Calarasi",69167,44.2,27.333333 ],
    [ u"ro",u"Calatele",2689,46.766667,23.016667 ],
    [ u"ro",u"Caldararu",2975,44.45,24.95 ],
    [ u"ro",u"Calimanesti",8486,45.233333,24.333333 ],
    [ u"ro",u"Calinesti",10419,44.816667,25.05 ],
    [ u"ro",u"Calinesti",3354,47.783333,23.983333 ],
    [ u"ro",u"Calinesti",3964,44.083333,25.233333 ],
    [ u"ro",u"Calinesti-Oas",4654,47.9,23.3 ],
    [ u"ro",u"Calmatuiu",2747,43.966667,24.866667 ],
    [ u"ro",u"Calnic",2959,45.883333,23.666667 ],
    [ u"ro",u"Calugareni",1425,45.083333,26.383333 ],
    [ u"ro",u"Calvini",4315,45.25,26.3 ],
    [ u"ro",u"Camarasu",2768,46.783333,24.133333 ],
    [ u"ro",u"Camar",1855,47.3,22.616667 ],
    [ u"ro",u"Camarzana",2591,48,23.316667 ],
    [ u"ro",u"Campeni",7932,46.366667,23.05 ],
    [ u"ro",u"Campia Turzii",26457,46.55,23.883333 ],
    [ u"ro",u"Campina",38302,45.133333,25.733333 ],
    [ u"ro",u"Campineanca",3158,45.7,27.133333 ],
    [ u"ro",u"Campulung",37280,45.266667,25.05 ],
    [ u"ro",u"Campulung Moldovenesc",19765,47.533333,25.566667 ],
    [ u"ro",u"Candesti",4105,46.716667,26.583333 ],
    [ u"ro",u"Candesti",3137,45.083333,25.216667 ],
    [ u"ro",u"Canesti",1090,45.4,26.6 ],
    [ u"ro",u"Capalna",1975,46.733333,22.1 ],
    [ u"ro",u"Capalnita",1954,46.366667,25.516667 ],
    [ u"ro",u"Capleni",4424,47.716667,22.5 ],
    [ u"ro",u"Capreni",2435,44.75,23.616667 ],
    [ u"ro",u"Capusu Mare",3645,46.783333,23.3 ],
    [ u"ro",u"Caracal",33761,44.116667,24.35 ],
    [ u"ro",u"Caransebes",27521,45.416667,22.216667 ],
    [ u"ro",u"Carasova",3153,45.198611,21.87 ],
    [ u"ro",u"Carastelec",1133,47.3,22.7 ],
    [ u"ro",u"Caraula",2628,44.183333,23.25 ],
    [ u"ro",u"Carbunari",1236,44.834444,21.744167 ],
    [ u"ro",u"Carbunesti",1889,45.233333,26.2 ],
    [ u"ro",u"Carcaliu",3422,45.183333,28.15 ],
    [ u"ro",u"Carei",22583,47.683333,22.466667 ],
    [ u"ro",u"Carjiti",787,45.85,22.833333 ],
    [ u"ro",u"Carlibaba",1965,47.583333,25.133333 ],
    [ u"ro",u"Carligele",2949,45.683333,27.1 ],
    [ u"ro",u"Carlogani",2854,44.516667,24.15 ],
    [ u"ro",u"Carpen",2978,44.333333,23.25 ],
    [ u"ro",u"Carpinis",7071,45.787222,20.904167 ],
    [ u"ro",u"Carta",5407,46.533333,25.75 ],
    [ u"ro",u"Carta",928,45.783333,24.566667 ],
    [ u"ro",u"Cascioarele",2132,44.126111,26.469722 ],
    [ u"ro",u"Caseiu",4791,47.183333,23.866667 ],
    [ u"ro",u"Casimcea",3363,44.733333,28.366667 ],
    [ u"ro",u"Casin",3713,46.2,26.75 ],
    [ u"ro",u"Castelu",7816,44.25,28.333333 ],
    [ u"ro",u"Castra-Nova",3601,44.116667,24.016667 ],
    [ u"ro",u"Cata",2510,46.083333,25.266667 ],
    [ u"ro",u"Catalina",3497,45.966667,26.15 ],
    [ u"ro",u"Catcau",2451,47.2,23.783333 ],
    [ u"ro",u"Cateasca",3713,44.766667,25.083333 ],
    [ u"ro",u"Catina",2177,46.85,24.183333 ],
    [ u"ro",u"Catina",2695,45.3,26.25 ],
    [ u"ro",u"Catunele",2604,44.864167,22.906944 ],
    [ u"ro",u"Cauas",2497,47.566667,22.55 ],
    [ u"ro",u"Cavadinesti",3547,46.066667,28.016944 ],
    [ u"ro",u"Cavnic",5072,47.666667,23.866667 ],
    [ u"ro",u"Cazanesti",2726,44.723333,22.890556 ],
    [ u"ro",u"Cazanesti",3604,44.616667,27.016667 ],
    [ u"ro",u"Ceahlau",2458,47.05,25.966667 ],
    [ u"ro",u"Ceamurlia de Jos",2596,44.733333,28.716667 ],
    [ u"ro",u"Ceanu Mare",4247,46.666667,23.95 ],
    [ u"ro",u"Ceatalchioi",744,45.283333,28.783333 ],
    [ u"ro",u"Cefa",6206,46.916667,21.733333 ],
    [ u"ro",u"Cehal",1976,47.383333,22.6 ],
    [ u"ro",u"Cehu Silvaniei",7832,47.416667,23.183333 ],
    [ u"ro",u"Ceica",4028,46.85,22.183333 ],
    [ u"ro",u"Celaru",5326,44.05,24.133333 ],
    [ u"ro",u"Cenad",4218,46.133333,20.583333 ],
    [ u"ro",u"Cenade",994,46.05,24.016667 ],
    [ u"ro",u"Cenei",4754,45.715833,20.903889 ],
    [ u"ro",u"Cepari",2452,45.216667,24.566667 ],
    [ u"ro",u"Ceplenita",4533,47.383333,27.016667 ],
    [ u"ro",u"Cerasu",5105,45.316667,26.033333 ],
    [ u"ro",u"Ceratu",3851,44.066667,23.666667 ],
    [ u"ro",u"Cerbal",655,45.783333,22.716667 ],
    [ u"ro",u"Cerchezu",1548,43.816667,28.1 ],
    [ u"ro",u"Cermei",2811,46.55,21.85 ],
    [ u"ro",u"Cerna",4279,45.083333,28.316667 ],
    [ u"ro",u"Cernat",3963,45.95,26.033333 ],
    [ u"ro",u"Cernatesti",3982,45.266667,26.766667 ],
    [ u"ro",u"Cernatesti",2203,44.45,23.433333 ],
    [ u"ro",u"Cernavoda",18502,44.366667,28.016667 ],
    [ u"ro",u"Cernesti",3760,47.516667,23.75 ],
    [ u"ro",u"Cernica",9530,44.416667,26.283333 ],
    [ u"ro",u"Cernisoara",3948,45.033333,23.983333 ],
    [ u"ro",u"Certeju de Sus",3422,45.966667,22.966667 ],
    [ u"ro",u"Certesti",2506,46.016667,27.616667 ],
    [ u"ro",u"Certeze",5330,47.9,23.466667 ],
    [ u"ro",u"Ceru-Bacainti",367,45.983333,23.25 ],
    [ u"ro",u"Cervenia",3360,43.833333,25.466667 ],
    [ u"ro",u"Cetariu",3819,47.133333,22.016667 ],
    [ u"ro",u"Cetatea de Balta",3161,46.25,24.166667 ],
    [ u"ro",u"Cetate",5908,44.1,23.05 ],
    [ u"ro",u"Cetateni",3032,45.2,25.183333 ],
    [ u"ro",u"Ceuasul-de Campie",5332,46.633333,24.516667 ],
    [ u"ro",u"Cezieni",2187,44.183333,24.266667 ],
    [ u"ro",u"Cherechiu",2437,47.383333,22.133333 ],
    [ u"ro",u"Chetani",2844,46.466667,24.033333 ],
    [ u"ro",u"Cheveresu Mare",1938,45.666944,21.490833 ],
    [ u"ro",u"Chiajna",8105,44.46,25.973333 ],
    [ u"ro",u"Chichis",1676,45.783333,25.8 ],
    [ u"ro",u"Chiesd",2577,47.383333,22.883333 ],
    [ u"ro",u"Chiheru de Jos",1720,46.683333,24.883333 ],
    [ u"ro",u"Chilia Veche",3599,45.416667,29.283333 ],
    [ u"ro",u"Chiliile",774,45.45,26.583333 ],
    [ u"ro",u"Chinteni",2746,46.866667,23.533333 ],
    [ u"ro",u"Chiochis",3520,46.983333,24.183333 ],
    [ u"ro",u"Chiojdeanca",1788,45.166667,26.266667 ],
    [ u"ro",u"Chiojdeni",2449,45.55,26.866667 ],
    [ u"ro",u"Chiojdu",3791,45.35,26.2 ],
    [ u"ro",u"Chirnogeni",3533,43.9,28.233333 ],
    [ u"ro",u"Chirnogi",8022,44.116667,26.566667 ],
    [ u"ro",u"Chirpar",1448,45.9,24.6 ],
    [ u"ro",u"Chiscani",5294,45.183333,27.933333 ],
    [ u"ro",u"Chiselet",3535,44.183333,26.85 ],
    [ u"ro",u"Chisindia",1550,46.283333,22.1 ],
    [ u"ro",u"Chisineu Cris",8171,46.533333,21.516667 ],
    [ u"ro",u"Chislaz",3386,47.283333,22.233333 ],
    [ u"ro",u"Chitila",12788,44.508056,25.982222 ],
    [ u"ro",u"Chiuiesti",2720,47.3,23.883333 ],
    [ u"ro",u"Chiuza",2210,47.233333,24.25 ],
    [ u"ro",u"Ciacova",7205,45.508056,21.128611 ],
    [ u"ro",u"Cicanesti",2265,45.25,24.633333 ],
    [ u"ro",u"Cicarlau",3951,47.7,23.4 ],
    [ u"ro",u"Ciceu-Giurgesti",4285,47.25,24.016667 ],
    [ u"ro",u"Cilibia",1909,45.066667,27.016667 ],
    [ u"ro",u"Cilieni",3556,43.9,24.616667 ],
    [ u"ro",u"Cincu",1762,45.916667,24.8 ],
    [ u"ro",u"Ciobanu",3477,44.733333,27.966667 ],
    [ u"ro",u"Ciocanesti",5354,44.6,25.85 ],
    [ u"ro",u"Ciocanesti",4931,44.2,27.066667 ],
    [ u"ro",u"Ciocarlia",881,44.8,26.666667 ],
    [ u"ro",u"Ciochina",3573,44.583333,27.066667 ],
    [ u"ro",u"Ciocile",3101,44.816667,27.233333 ],
    [ u"ro",u"Ciofrangeni",2643,45.083333,24.533333 ],
    [ u"ro",u"Ciolpani",4523,44.733333,26.083333 ],
    [ u"ro",u"Ciomagesti",1362,44.833333,24.45 ],
    [ u"ro",u"Ciorasti",3861,45.433333,27.3 ],
    [ u"ro",u"Ciorogarla",4968,44.4425,25.883333 ],
    [ u"ro",u"Cioroiasiu",1977,44.083333,23.45 ],
    [ u"ro",u"Ciortesti",4378,46.9,27.833333 ],
    [ u"ro",u"Ciprian Porumbescu",6405,47.566667,26.066667 ],
    [ u"ro",u"Ciresu",813,44.823333,22.538056 ],
    [ u"ro",u"Ciresu",3523,44.95,27.35 ],
    [ u"ro",u"Cislau",4961,45.25,26.366667 ],
    [ u"ro",u"Cisnadie",15042,45.716667,24.15 ],
    [ u"ro",u"Ciucea",4393,46.95,22.816667 ],
    [ u"ro",u"Ciuchici",1222,44.941389,21.61 ],
    [ u"ro",u"Ciucsangeorgiu",4821,46.316667,25.95 ],
    [ u"ro",u"Ciucurova",2328,44.933333,28.483333 ],
    [ u"ro",u"Ciudanovita",752,45.144722,21.797778 ],
    [ u"ro",u"Ciugud",2613,46.05,23.616667 ],
    [ u"ro",u"Ciuhoiu",2249,47.233333,22.116667 ],
    [ u"ro",u"Ciulnita",2529,44.533333,27.35 ],
    [ u"ro",u"Ciumani",4428,46.683333,25.516667 ],
    [ u"ro",u"Ciumeghiu",4419,46.733333,21.583333 ],
    [ u"ro",u"Ciuperceni",1735,44.933333,23.016667 ],
    [ u"ro",u"Ciuperceni",1865,43.766667,24.95 ],
    [ u"ro",u"Ciupercenii Noi",5949,43.909722,22.948333 ],
    [ u"ro",u"Ciurea",10110,47.05,27.566667 ],
    [ u"ro",u"Ciurila",1506,46.65,23.55 ],
    [ u"ro",u"Ciuruleasa",1333,46.25,23.033333 ],
    [ u"ro",u"Cizer",2420,47.066667,22.883333 ],
    [ u"ro",u"Cleja",6816,46.416667,26.9 ],
    [ u"ro",u"Clejani",3414,44.319722,25.699444 ],
    [ u"ro",u"Clinceni",4995,44.373333,25.954722 ],
    [ u"ro",u"Cluj-Napoca",316749,46.766667,23.6 ],
    [ u"ro",u"Coarnele Caprei",3156,47.383333,27.1 ],
    [ u"ro",u"Cobadin",8979,44.083333,28.216667 ],
    [ u"ro",u"Cochirleanca",5712,45.216667,27.033333 ],
    [ u"ro",u"Cociuba Mare",3173,46.733333,22 ],
    [ u"ro",u"Cocora",3726,44.733333,27.05 ],
    [ u"ro",u"Cocorastii-Misli",3416,45.083333,25.933333 ],
    [ u"ro",u"Cocu",2662,44.866667,24.65 ],
    [ u"ro",u"Codaesti",4785,46.866667,27.75 ],
    [ u"ro",u"Codlea",24188,45.7,25.45 ],
    [ u"ro",u"Cogealac",7046,44.55,28.566667 ],
    [ u"ro",u"Cojasca",7205,44.716667,25.85 ],
    [ u"ro",u"Cojocna",4336,46.75,23.833333 ],
    [ u"ro",u"Colceag",5473,44.95,26.35 ],
    [ u"ro",u"Colibasi",3823,44.202222,26.194722 ],
    [ u"ro",u"Colonesti",2186,44.65,24.666667 ],
    [ u"ro",u"Colonesti",2162,46.566667,27.3 ],
    [ u"ro",u"Colti",1313,45.383333,26.383333 ],
    [ u"ro",u"Comana",1850,43.9,28.316667 ],
    [ u"ro",u"Comana",7717,44.170556,26.145 ],
    [ u"ro",u"Comandau",1034,45.766667,26.266667 ],
    [ u"ro",u"Comanesti",23730,46.416667,26.433333 ],
    [ u"ro",u"Comarna",4551,47.05,27.783333 ],
    [ u"ro",u"Comarnic",13255,45.25,25.633333 ],
    [ u"ro",u"Comisani",5401,44.883333,25.583333 ],
    [ u"ro",u"Comlosu Mare",4745,45.890556,20.627222 ],
    [ u"ro",u"Concesti",2049,48.166667,26.55 ],
    [ u"ro",u"Conop",2296,46.1,21.883333 ],
    [ u"ro",u"Constanta",303401,44.183333,28.65 ],
    [ u"ro",u"Constantin Daicoviciu",2854,45.55,22.15 ],
    [ u"ro",u"Contesti",3754,43.8,25.483333 ],
    [ u"ro",u"Copacel",2427,46.983333,22.166667 ],
    [ u"ro",u"Copacele",1309,45.5,22.1 ],
    [ u"ro",u"Copaceni",3013,45,23.966667 ],
    [ u"ro",u"Copalau",7086,47.616667,26.833333 ],
    [ u"ro",u"Copalnic Manastur",5747,47.5,23.683333 ],
    [ u"ro",u"Copsa Mica",5350,46.116667,24.25 ],
    [ u"ro",u"Corabia",20047,43.783333,24.5 ],
    [ u"ro",u"Corbasca",5328,46.283333,27.166667 ],
    [ u"ro",u"Corbeanca",3786,44.6,26.05 ],
    [ u"ro",u"Corbeni",5613,45.3,24.65 ],
    [ u"ro",u"Corbi",4381,45.283333,24.8 ],
    [ u"ro",u"Corbii Mari",8257,44.55,25.5 ],
    [ u"ro",u"Corbita",2091,46.15,27.3 ],
    [ u"ro",u"Corbu",5180,44.383333,28.65 ],
    [ u"ro",u"Corbu",1579,46.983333,25.7 ],
    [ u"ro",u"Corbu",2586,44.483333,24.716667 ],
    [ u"ro",u"Corcova",5946,44.7,23.05 ],
    [ u"ro",u"Cordareni",2172,47.983333,26.583333 ],
    [ u"ro",u"Cordun",7124,46.95,26.866667 ],
    [ u"ro",u"Corlatel",1552,44.398611,22.933056 ],
    [ u"ro",u"Corlateni",4127,47.933333,26.55 ],
    [ u"ro",u"Cornatelu",1751,44.75,25.666667 ],
    [ u"ro",u"Cornea",2098,45.033333,22.316667 ],
    [ u"ro",u"Cornereva",3291,45.066667,22.416667 ],
    [ u"ro",u"Cornesti",1797,47.033333,23.683333 ],
    [ u"ro",u"Cornesti",7616,44.783333,25.866667 ],
    [ u"ro",u"Cornetu",5063,44.341667,25.940833 ],
    [ u"ro",u"Corni",6521,47.65,26.583333 ],
    [ u"ro",u"Corni",2481,45.85,27.766667 ],
    [ u"ro",u"Cornu Luncii",7288,47.466667,26.15 ],
    [ u"ro",u"Corod",7855,45.9,27.616667 ],
    [ u"ro",u"Coroieni",2308,47.366667,23.766667 ],
    [ u"ro",u"Coroiesti",2318,46.25,27.483333 ],
    [ u"ro",u"Coroisanmartin",1464,46.4,24.6 ],
    [ u"ro",u"Coronini",1810,44.725833,21.687222 ],
    [ u"ro",u"Corund",6091,46.466667,25.183333 ],
    [ u"ro",u"Cosambesti",3482,44.566667,27.433333 ],
    [ u"ro",u"Cosbuc",2972,47.366667,24.4 ],
    [ u"ro",u"Coseiu",1298,47.316667,22.983333 ],
    [ u"ro",u"Cosereni",6957,44.683333,26.566667 ],
    [ u"ro",u"Cosesti",5416,45.066667,24.866667 ],
    [ u"ro",u"Cosmesti",2735,44.3,25.383333 ],
    [ u"ro",u"Cosmesti",6526,45.883333,27.3 ],
    [ u"ro",u"Cosoveni",5024,44.25,23.933333 ],
    [ u"ro",u"Costache Negri",2582,45.7,27.716667 ],
    [ u"ro",u"Costeiu",3805,45.741111,21.849167 ],
    [ u"ro",u"Costesti",10654,44.666667,24.883333 ],
    [ u"ro",u"Costesti",4704,45.05,26.766667 ],
    [ u"ro",u"Costesti",3192,46.5,27.75 ],
    [ u"ro",u"Costesti",3616,45.15,24.066667 ],
    [ u"ro",u"Costestii din Vale",3417,44.65,25.483333 ],
    [ u"ro",u"Costinesti",2500,43.95,28.633333 ],
    [ u"ro",u"Costisa",3540,46.75,26.65 ],
    [ u"ro",u"Costuleni",4911,47.033333,27.85 ],
    [ u"ro",u"Coteana",2960,44.3,24.466667 ],
    [ u"ro",u"Cotesti",4780,45.65,27.05 ],
    [ u"ro",u"Cotmeana",2230,44.966667,24.616667 ],
    [ u"ro",u"Cotnari",7985,47.35,26.983333 ],
    [ u"ro",u"Cotofanesti",3279,46.15,26.983333 ],
    [ u"ro",u"Cotofenii din Dos",2594,44.433333,23.616667 ],
    [ u"ro",u"Cotusca",5333,48.133333,26.85 ],
    [ u"ro",u"Covasint",2613,46.2,21.6 ],
    [ u"ro",u"Covasna",10979,45.85,26.183333 ],
    [ u"ro",u"Cozieni",2425,45.333333,26.483333 ],
    [ u"ro",u"Cozma",632,46.816667,24.533333 ],
    [ u"ro",u"Cozmesti",3192,46.883333,27.983333 ],
    [ u"ro",u"Cracaoani",4490,47.016667,26.383333 ],
    [ u"ro",u"Craciunelu de Jos",4297,46.183333,23.833333 ],
    [ u"ro",u"Craciunesti",4283,46.483333,24.583333 ],
    [ u"ro",u"Craidorolt",2151,47.616667,22.7 ],
    [ u"ro",u"Craiesti",1011,46.3,24.183333 ],
    [ u"ro",u"Craiova",304144,44.316667,23.8 ],
    [ u"ro",u"Crampoaia",3769,44.316667,24.733333 ],
    [ u"ro",u"Crangeni",3529,44.033333,24.783333 ],
    [ u"ro",u"Crangurile de Sus",3428,44.766667,25.233333 ],
    [ u"ro",u"Crasna",5466,45.166667,23.5 ],
    [ u"ro",u"Crasna",6233,47.166667,22.9 ],
    [ u"ro",u"Creaca",2987,47.2,23.25 ],
    [ u"ro",u"Creteni",2602,44.683333,24.183333 ],
    [ u"ro",u"Crevedia",6674,44.6,25.933333 ],
    [ u"ro",u"Crevedia Mare",4927,44.429167,25.625556 ],
    [ u"ro",u"Crevenicu",1693,44.240833,25.588611 ],
    [ u"ro",u"Cricau",2052,46.183333,23.566667 ],
    [ u"ro",u"Criciova",1698,45.633333,22.066667 ],
    [ u"ro",u"Crisan",1392,44.966667,29.466667 ],
    [ u"ro",u"Criscior",4232,46.116667,22.866667 ],
    [ u"ro",u"Criseni",2390,47.233333,23.05 ],
    [ u"ro",u"Cristesti",4745,47.633333,26.733333 ],
    [ u"ro",u"Cristesti",4273,47.266667,26.566667 ],
    [ u"ro",u"Cristesti",5507,46.5,24.483333 ],
    [ u"ro",u"Cristian",3849,45.616667,25.466667 ],
    [ u"ro",u"Cristian",3437,45.783333,24.033333 ],
    [ u"ro",u"Cristinesti",3866,48.1,26.383333 ],
    [ u"ro",u"Cristolt",1516,47.2,23.433333 ],
    [ u"ro",u"Cristuru Secuiesc",9554,46.283333,25.033333 ],
    [ u"ro",u"Crucea",3413,44.533333,28.233333 ],
    [ u"ro",u"Crucea",2279,47.35,25.616667 ],
    [ u"ro",u"Crucisor",2471,47.683333,23.25 ],
    [ u"ro",u"Crusetu",3895,44.633333,23.666667 ],
    [ u"ro",u"Cuca",2580,45.733333,27.883333 ],
    [ u"ro",u"Cuca",2315,44.95,24.516667 ],
    [ u"ro",u"Cucerdea",1680,46.4,24.266667 ],
    [ u"ro",u"Cuci",2171,46.466667,24.15 ],
    [ u"ro",u"Cucuteni",1454,47.283333,26.933333 ],
    [ u"ro",u"Cudalbi",8055,45.783333,27.7 ],
    [ u"ro",u"Cugir",24734,45.833333,23.366667 ],
    [ u"ro",u"Cujmir",3733,44.206667,22.926667 ],
    [ u"ro",u"Cumpana",9731,44.116667,28.566667 ],
    [ u"ro",u"Cungrea",2542,44.666667,24.383333 ],
    [ u"ro",u"Cupseni",3727,47.55,23.933333 ],
    [ u"ro",u"Curatele",2670,46.7,22.416667 ],
    [ u"ro",u"Curcani",5167,44.2,26.583333 ],
    [ u"ro",u"Curtea",1310,45.816667,22.3 ],
    [ u"ro",u"Curtea de Arges",32179,45.133333,24.683333 ],
    [ u"ro",u"Curtesti",4331,47.716667,26.65 ],
    [ u"ro",u"Curtici",9615,46.35,21.3 ],
    [ u"ro",u"Curtisoara",4583,44.5,24.333333 ],
    [ u"ro",u"Curtuiseni",3720,47.55,22.2 ],
    [ u"ro",u"Cuzaplac",1999,46.966667,23.2 ],
    [ u"ro",u"Cuza Voda",4296,44.266667,27.266667 ],
    [ u"ro",u"Cuzdrioara",2944,47.166667,23.916667 ],
    [ u"ro",u"Dabaca",1798,46.983333,23.666667 ],
    [ u"ro",u"Dabuleni",13641,43.8,24.083333 ],
    [ u"ro",u"Daeni",2506,44.833333,28.116667 ],
    [ u"ro",u"Daesti",2787,44.966667,24.133333 ],
    [ u"ro",u"Dagata",4861,46.933333,27.183333 ],
    [ u"ro",u"Daia",3090,44,25.983333 ],
    [ u"ro",u"Dalboset",1857,44.922778,21.9825 ],
    [ u"ro",u"Dambovicioara",1043,45.45,25.233333 ],
    [ u"ro",u"Damienesti",1896,46.733333,26.983333 ],
    [ u"ro",u"Damuc",3084,46.8,25.9 ],
    [ u"ro",u"Danciulesti",2756,44.733333,23.75 ],
    [ u"ro",u"Daneasa",3816,44.15,24.566667 ],
    [ u"ro",u"Danes",4759,46.216667,24.7 ],
    [ u"ro",u"Danesti",3879,44.966667,23.333333 ],
    [ u"ro",u"Danesti",4455,46.516667,25.75 ],
    [ u"ro",u"Danesti",2420,46.85,27.666667 ],
    [ u"ro",u"Daneti",7110,43.983333,24.05 ],
    [ u"ro",u"Dangeni",3094,47.85,26.966667 ],
    [ u"ro",u"Danicei",2459,44.9,24.383333 ],
    [ u"ro",u"Darabani",11890,48.183333,26.583333 ],
    [ u"ro",u"Darasti-Ilfov",2972,44.308889,26.018333 ],
    [ u"ro",u"Darjiu",1160,46.2,25.2 ],
    [ u"ro",u"Darlos",3212,46.183333,24.4 ],
    [ u"ro",u"Darmanesti",3676,45.016667,24.9 ],
    [ u"ro",u"Darmanesti",14290,46.366667,26.483333 ],
    [ u"ro",u"Darmanesti",5817,47.733333,26.15 ],
    [ u"ro",u"Darmanesti",7919,44.916667,25.783333 ],
    [ u"ro",u"Darova",3028,45.640278,21.765278 ],
    [ u"ro",u"Darvari",2990,44.2,23.05 ],
    [ u"ro",u"Dascalu",2594,44.6,26.233333 ],
    [ u"ro",u"Davidesti",2816,45.016667,25.033333 ],
    [ u"ro",u"Dealu",3850,46.4,25.3 ],
    [ u"ro",u"Dealu Morii",2970,46.316667,27.233333 ],
    [ u"ro",u"Deda",4263,46.933333,24.9 ],
    [ u"ro",u"Dej",38033,47.15,23.866667 ],
    [ u"ro",u"Deleni",2492,44.1,28.016667 ],
    [ u"ro",u"Deleni",10484,47.466667,26.883333 ],
    [ u"ro",u"Deleni",2627,46.55,27.75 ],
    [ u"ro",u"Delesti",5122,46.7,27.55 ],
    [ u"ro",u"Densus",1756,45.583333,22.8 ],
    [ u"ro",u"Denta",3152,45.353889,21.249167 ],
    [ u"ro",u"Derna",2963,47.2,22.3 ],
    [ u"ro",u"Dersca",5105,47.983333,26.2 ],
    [ u"ro",u"Desa",4981,43.866667,23.033333 ],
    [ u"ro",u"Desesti",2580,47.766667,23.85 ],
    [ u"ro",u"Deta",6253,45.388889,21.224444 ],
    [ u"ro",u"Deva",67802,45.883333,22.9 ],
    [ u"ro",u"Devesel",3529,44.468889,22.667222 ],
    [ u"ro",u"Dichiseni",1836,44.233333,27.533333 ],
    [ u"ro",u"Dimitrie Cantemir",3040,46.507778,28.054722 ],
    [ u"ro",u"Diosig",9455,47.3,22 ],
    [ u"ro",u"Diosti",3366,44.116667,24.183333 ],
    [ u"ro",u"Ditrau",5858,46.816667,25.516667 ],
    [ u"ro",u"Doba",2727,47.733333,22.716667 ],
    [ u"ro",u"Dobarceni",2897,47.816667,27.066667 ],
    [ u"ro",u"Dobarlau",2301,45.733333,25.883333 ],
    [ u"ro",u"Dobra",3459,45.916667,22.566667 ],
    [ u"ro",u"Dobra",3806,44.783333,25.716667 ],
    [ u"ro",u"Dobreni",3641,46.983333,26.416667 ],
    [ u"ro",u"Dobresti",1820,44.966667,25.133333 ],
    [ u"ro",u"Dobresti",5573,46.85,22.3 ],
    [ u"ro",u"Dobresti",2799,43.966667,23.95 ],
    [ u"ro",u"Dobretu",1502,44.5,23.95 ],
    [ u"ro",u"Dobrin",1736,47.283333,23.133333 ],
    [ u"ro",u"Dobroesti",6599,44.45,26.183333 ],
    [ u"ro",u"Dobromir",2597,44.016667,27.783333 ],
    [ u"ro",u"Dobrosloveni",3821,44.183333,24.366667 ],
    [ u"ro",u"Dobroteasa",2121,44.783333,24.383333 ],
    [ u"ro",u"Dobrotesti",5096,44.283333,24.883333 ],
    [ u"ro",u"Dobrovat",2644,46.95,27.7 ],
    [ u"ro",u"Dobrun",3419,44.266667,24.216667 ],
    [ u"ro",u"Doclin",1979,45.296944,21.653889 ],
    [ u"ro",u"Doftana",6777,45.15,25.8 ],
    [ u"ro",u"Dofteana",10785,46.316667,26.516667 ],
    [ u"ro",u"Dognecea",1982,45.274167,21.756944 ],
    [ u"ro",u"Doicesti",4727,44.983333,25.4 ],
    [ u"ro",u"Dolhasca",11025,47.433333,26.6 ],
    [ u"ro",u"Dolhesti",2821,46.866667,27.9 ],
    [ u"ro",u"Dolhesti",4046,47.45,26.516667 ],
    [ u"ro",u"Doljesti",7359,47.033333,26.983333 ],
    [ u"ro",u"Domasnea",1446,45.083333,22.316667 ],
    [ u"ro",u"Domnesti",3182,45.2,24.833333 ],
    [ u"ro",u"Domnesti",6393,44.399444,25.919722 ],
    [ u"ro",u"Dorgos",1368,46.016667,21.8 ],
    [ u"ro",u"Dor Marunt",6806,44.45,26.916667 ],
    [ u"ro",u"Dorna",3089,47.35,25.433333 ],
    [ u"ro",u"Dornesti",4371,47.866667,26.016667 ],
    [ u"ro",u"Dorobantu",1769,44.95,28.266667 ],
    [ u"ro",u"Dorobantu",3433,44.216667,26.95 ],
    [ u"ro",u"Dorohoi",30776,47.95,26.4 ],
    [ u"ro",u"Dorolt",3426,47.85,22.816667 ],
    [ u"ro",u"Dostat",1049,45.966667,23.85 ],
    [ u"ro",u"Douazeci si Trei August",5214,43.916667,28.583333 ],
    [ u"ro",u"Dracsenei",3616,44.216667,24.983333 ],
    [ u"ro",u"Dragalina",8642,44.433333,27.316667 ],
    [ u"ro",u"Draganesti de Vede",2237,44.133333,25.05 ],
    [ u"ro",u"Draganesti",5874,45.783333,27.466667 ],
    [ u"ro",u"Draganesti",5156,44.816667,26.3 ],
    [ u"ro",u"Draganesti-Olt",12057,44.166667,24.533333 ],
    [ u"ro",u"Draganesti-Vlasca",4740,44.101389,25.598056 ],
    [ u"ro",u"Dragasani",20630,44.65,24.266667 ],
    [ u"ro",u"Dragesti",2521,46.883333,22.133333 ],
    [ u"ro",u"Draghiceni",1885,44.133333,24.25 ],
    [ u"ro",u"Dragodana",6918,44.733333,25.35 ],
    [ u"ro",u"Dragoesti",5288,47.55,26.083333 ],
    [ u"ro",u"Dragoesti",2362,44.816667,24.3 ],
    [ u"ro",u"Dragoesti",1141,44.583333,26.566667 ],
    [ u"ro",u"Dragomiresti",8194,44.916667,25.333333 ],
    [ u"ro",u"Dragomiresti",3116,47.683333,24.3 ],
    [ u"ro",u"Dragomiresti",2418,47.016667,26.533333 ],
    [ u"ro",u"Dragomiresti",4868,46.633333,27.35 ],
    [ u"ro",u"Dragomiresti-Vale",4330,44.475,25.935 ],
    [ u"ro",u"Dragotesti",2530,44.25,24.1 ],
    [ u"ro",u"Dragotesti",2685,44.8,23.166667 ],
    [ u"ro",u"Dragu",1545,47.016667,23.4 ],
    [ u"ro",u"Draguseni",2762,48.016667,26.816667 ],
    [ u"ro",u"Draguseni",5297,45.966667,27.75 ],
    [ u"ro",u"Draguseni",2665,47.283333,26.483333 ],
    [ u"ro",u"Dragutesti",5126,44.966667,23.233333 ],
    [ u"ro",u"Drajna",5660,45.216667,26.05 ],
    [ u"ro",u"Dranceni Sat",4719,46.813611,28.100833 ],
    [ u"ro",u"Dranic",3032,44.05,23.85 ],
    [ u"ro",u"Dridu",5111,44.7,26.45 ],
    [ u"ro",u"Drobeta-Turnu Severin",102347,44.631944,22.656111 ],
    [ u"ro",u"Dubova",1073,44.616667,22.266667 ],
    [ u"ro",u"Duda",5037,46.7525,28.037222 ],
    [ u"ro",u"Dudesti",4061,44.9,27.433333 ],
    [ u"ro",u"Dudestii Vechi",5746,46.05,20.483333 ],
    [ u"ro",u"Dulcesti",4856,46.966667,26.766667 ],
    [ u"ro",u"Dumbrava",2820,45.816667,22.116667 ],
    [ u"ro",u"Dumbrava",4394,44.883333,26.183333 ],
    [ u"ro",u"Dumbrava Rosie",7104,46.883333,26.433333 ],
    [ u"ro",u"Dumbraveni",605,43.933333,27.983333 ],
    [ u"ro",u"Dumbraveni",8167,46.233333,24.566667 ],
    [ u"ro",u"Dumbraveni",8110,47.65,26.416667 ],
    [ u"ro",u"Dumbraveni",4156,45.533333,27.116667 ],
    [ u"ro",u"Dumbravesti",3664,45.083333,26 ],
    [ u"ro",u"Dumbravita",4435,45.766667,25.433333 ],
    [ u"ro",u"Dumbravita",4420,47.6,23.65 ],
    [ u"ro",u"Dumbravita",2644,45.796944,21.2425 ],
    [ u"ro",u"Dumesti",4732,47.183333,27.35 ],
    [ u"ro",u"Dumesti",3625,46.85,27.283333 ],
    [ u"ro",u"Dumitra",4482,47.216667,24.483333 ],
    [ u"ro",u"Dumitresti",5292,45.55,26.916667 ],
    [ u"ro",u"Durnesti",4144,47.766667,27.1 ],
    [ u"ro",u"Edera de Jos",3925,45.033333,25.633333 ],
    [ u"ro",u"Eforie",9499,44.066667,28.633333 ],
    [ u"ro",u"Eftimie Murgu",1761,44.900278,22.092778 ],
    [ u"ro",u"Epureni",3241,46.25,27.9 ],
    [ u"ro",u"Erbiceni",5655,47.266667,27.233333 ],
    [ u"ro",u"Eremitu",3818,46.666667,24.933333 ],
    [ u"ro",u"Ernei",5141,46.6,24.65 ],
    [ u"ro",u"Eselnita",2994,44.699167,22.362222 ],
    [ u"ro",u"Ezeris",1362,45.410833,21.885833 ],
    [ u"ro",u"Facaeni",5893,44.566667,27.9 ],
    [ u"ro",u"Fagaras",34034,45.85,24.966667 ],
    [ u"ro",u"Fagetelu",1427,44.783333,24.533333 ],
    [ u"ro",u"Faget",7125,45.85,22.183333 ],
    [ u"ro",u"Falciu",6178,46.296111,28.140833 ],
    [ u"ro",u"Falcoiu",4283,44.233333,24.366667 ],
    [ u"ro",u"Falticeni",29576,47.45,26.3 ],
    [ u"ro",u"Fantanele",5597,46.116667,21.4 ],
    [ u"ro",u"Fantanele",4981,46.416667,24.75 ],
    [ u"ro",u"Fantanele",4913,47.516667,26.316667 ],
    [ u"ro",u"Fantanele",4053,44.716667,25.866667 ],
    [ u"ro",u"Faragau",1628,46.766667,24.516667 ],
    [ u"ro",u"Faraoani",5141,46.433333,26.9 ],
    [ u"ro",u"Farau",1866,46.333333,24.016667 ],
    [ u"ro",u"Farcasa",3716,47.583333,23.333333 ],
    [ u"ro",u"Farcasa",3173,47.166667,25.833333 ],
    [ u"ro",u"Farcasele",5045,44.133333,24.466667 ],
    [ u"ro",u"Farcasesti",3857,44.866667,23.2 ],
    [ u"ro",u"Farcasu",3620,44.6,23.75 ],
    [ u"ro",u"Farliug",2186,45.488333,21.849444 ],
    [ u"ro",u"Fartanesti",5325,45.816667,27.983333 ],
    [ u"ro",u"Fartatesti",4561,44.783333,24 ],
    [ u"ro",u"Faurei",4043,45.066667,27.233333 ],
    [ u"ro",u"Faurei",2344,46.916667,26.683333 ],
    [ u"ro",u"Fauresti",3623,44.566667,24.016667 ],
    [ u"ro",u"Feldioara",6307,45.816667,25.6 ],
    [ u"ro",u"Feldru",6967,47.283333,24.6 ],
    [ u"ro",u"Feleacu",3764,46.716667,23.616667 ],
    [ u"ro",u"Feliceni",2984,46.266667,25.266667 ],
    [ u"ro",u"Felnac",5097,46.116667,21.15 ],
    [ u"ro",u"Fetesti",32867,44.383333,27.833333 ],
    [ u"ro",u"Fieni",7567,45.133333,25.416667 ],
    [ u"ro",u"Fildu de Jos",1542,46.933333,23.066667 ],
    [ u"ro",u"Filiasi",18995,44.55,23.516667 ],
    [ u"ro",u"Filipeni",2441,46.533333,27.183333 ],
    [ u"ro",u"Filipesti",4678,46.75,26.883333 ],
    [ u"ro",u"Filipestii de Padure",10169,45,25.75 ],
    [ u"ro",u"Filipestii de Targ",7794,44.983333,25.783333 ],
    [ u"ro",u"Finta",4613,44.8,25.8 ],
    [ u"ro",u"Fitionesti",2853,45.983333,27.05 ],
    [ u"ro",u"Fizesu Gherlii",2614,47.016667,23.983333 ],
    [ u"ro",u"Flamanzi",11806,47.55,26.866667 ],
    [ u"ro",u"Floresti",7397,46.733333,23.483333 ],
    [ u"ro",u"Floresti",2832,44.763056,22.947778 ],
    [ u"ro",u"Floresti",7507,45.05,25.783333 ],
    [ u"ro",u"Focsani",105114,45.7,27.183333 ],
    [ u"ro",u"Focuri",6030,47.35,27.216667 ],
    [ u"ro",u"Foeni",1836,47.7,22.383333 ],
    [ u"ro",u"Foeni",1695,45.498611,20.875833 ],
    [ u"ro",u"Foltesti",3294,45.75,28.05 ],
    [ u"ro",u"Forasti",4912,47.35,26.466667 ],
    [ u"ro",u"Forotic",1855,45.230278,21.5875 ],
    [ u"ro",u"Francesti",5490,45,24.1 ],
    [ u"ro",u"Frasinet",2023,44.316667,26.8 ],
    [ u"ro",u"Frasin",6519,47.533333,25.8 ],
    [ u"ro",u"Frata",4323,46.7,24.05 ],
    [ u"ro",u"Fratautii Noi",5512,47.95,25.85 ],
    [ u"ro",u"Fratautii Vechi",4635,47.9,25.883333 ],
    [ u"ro",u"Fratesti",5527,43.966667,25.966667 ],
    [ u"ro",u"Frecatei",1494,44.916667,28.15 ],
    [ u"ro",u"Frecatei",3797,45.1,28.666667 ],
    [ u"ro",u"Frumoasa",3599,46.45,25.85 ],
    [ u"ro",u"Frumoasa",2587,43.8,25.466667 ],
    [ u"ro",u"Frumosu",3571,47.616667,25.65 ],
    [ u"ro",u"Frumusani",5111,44.296111,26.325556 ],
    [ u"ro",u"Frumusica",6069,47.533333,26.9 ],
    [ u"ro",u"Frumusita",5206,45.666667,28.066667 ],
    [ u"ro",u"Fundata",990,45.45,25.3 ],
    [ u"ro",u"Fundeni",3954,45.533333,27.533333 ],
    [ u"ro",u"Fundeni",5443,44.383333,26.35 ],
    [ u"ro",u"Fundulea",6668,44.466667,26.516667 ],
    [ u"ro",u"Fundu Moldovei",4135,47.533333,25.4 ],
    [ u"ro",u"Furculesti",3872,43.866667,25.15 ],
    [ u"ro",u"Gaesti",15037,44.716667,25.316667 ],
    [ u"ro",u"Gagesti",2252,46.333333,27.966667 ],
    [ u"ro",u"Gaiceana",3063,46.333333,27.216667 ],
    [ u"ro",u"Gaiseni",5455,44.515,25.645278 ],
    [ u"ro",u"Galanesti",6211,47.916667,25.8 ],
    [ u"ro",u"Galateni",3175,44.216667,25.35 ],
    [ u"ro",u"Galati",294088,45.45,28.05 ],
    [ u"ro",u"Galatii Bistritei",2458,46.983333,24.4 ],
    [ u"ro",u"Galautas",2618,46.916667,25.433333 ],
    [ u"ro",u"Galbenu",3572,45.216667,27.166667 ],
    [ u"ro",u"Galbinasi",4013,45.083333,26.916667 ],
    [ u"ro",u"Galda de Jos",4772,46.183333,23.616667 ],
    [ u"ro",u"Galesti",2894,46.516667,24.75 ],
    [ u"ro",u"Galgau",2718,47.2,23.333333 ],
    [ u"ro",u"Galicea",4054,44.916667,24.283333 ],
    [ u"ro",u"Galicea Mare",4812,44.1,23.3 ],
    [ u"ro",u"Ganeasa",4074,44.416667,24.283333 ],
    [ u"ro",u"Ganeasa",4240,44.483333,26.283333 ],
    [ u"ro",u"Ganesti",3775,46.333333,24.35 ],
    [ u"ro",u"Gangiova",2966,43.9,23.85 ],
    [ u"ro",u"Garbau",2609,46.833333,23.35 ],
    [ u"ro",u"Garbou",2402,47.15,23.433333 ],
    [ u"ro",u"Garbova",2022,45.866667,23.733333 ],
    [ u"ro",u"Garbovi",4408,44.783333,26.766667 ],
    [ u"ro",u"Garceni",2561,46.766667,27.283333 ],
    [ u"ro",u"Garcina",4330,46.983333,26.3 ],
    [ u"ro",u"Garcovu",2684,43.766667,24.633333 ],
    [ u"ro",u"Garda de Sus",1822,46.45,22.816667 ],
    [ u"ro",u"Garleni",6263,46.666667,26.8 ],
    [ u"ro",u"Garliciu",1821,44.766667,28.083333 ],
    [ u"ro",u"Garnic",1480,44.786389,21.794444 ],
    [ u"ro",u"Garoafa",4624,45.783333,27.2 ],
    [ u"ro",u"Gataia",8002,45.431111,21.43 ],
    [ u"ro",u"Gaujani",2763,43.733333,25.7 ],
    [ u"ro",u"Gavojdia",3122,45.616667,22.016667 ],
    [ u"ro",u"Geaca",1734,46.866667,24.1 ],
    [ u"ro",u"Gemenele",1899,45.283333,27.616667 ],
    [ u"ro",u"Geoagiu",5918,45.916667,23.2 ],
    [ u"ro",u"George Enescu",3667,48.033333,26.483333 ],
    [ u"ro",u"Ghelari",2304,45.716667,22.783333 ],
    [ u"ro",u"Ghelinta",4702,45.95,26.233333 ],
    [ u"ro",u"Gheorghe Doja",2827,46.466667,24.5 ],
    [ u"ro",u"Gheorghe Lazar",2476,44.633333,27.45 ],
    [ u"ro",u"Gheorgheni",19777,46.716667,25.616667 ],
    [ u"ro",u"Gheraesti",6448,47.016667,26.816667 ],
    [ u"ro",u"Gheraseni",3740,45.033333,26.783333 ],
    [ u"ro",u"Ghergheasa",2726,45.266667,27.2 ],
    [ u"ro",u"Gherghesti",2785,46.5,27.516667 ],
    [ u"ro",u"Gherghita",3968,44.8,26.266667 ],
    [ u"ro",u"Gherla",23741,47.033333,23.916667 ],
    [ u"ro",u"Gherta Mica",3188,47.933333,23.233333 ],
    [ u"ro",u"Ghidfalau",2568,45.9,25.85 ],
    [ u"ro",u"Ghidigeni",6294,46.05,27.5 ],
    [ u"ro",u"Ghimbav",4967,45.666667,25.5 ],
    [ u"ro",u"Ghimes-Faget",5248,46.583333,26.066667 ],
    [ u"ro",u"Ghimpati",6040,44.191667,25.780278 ],
    [ u"ro",u"Ghindaresti",2669,44.65,28.033333 ],
    [ u"ro",u"Ghindari",4997,46.5,24.916667 ],
    [ u"ro",u"Ghioroc",3998,46.15,21.583333 ],
    [ u"ro",u"Ghioroiu",2144,44.7,23.833333 ],
    [ u"ro",u"Ghiroda",4857,45.763889,21.300278 ],
    [ u"ro",u"Ghizela",1290,45.824167,21.737222 ],
    [ u"ro",u"Giarmata",5357,45.838333,21.310833 ],
    [ u"ro",u"Giera",1310,45.407222,20.992222 ],
    [ u"ro",u"Gighera",3609,43.85,23.8 ],
    [ u"ro",u"Gilau",7745,46.75,23.383333 ],
    [ u"ro",u"Girisu de Cris",5170,47.066667,21.783333 ],
    [ u"ro",u"Giroc",4250,45.694167,21.235833 ],
    [ u"ro",u"Girov",7396,46.95,26.516667 ],
    [ u"ro",u"Giubega",4166,44.116667,23.416667 ],
    [ u"ro",u"Giulesti",3328,47.816667,23.933333 ],
    [ u"ro",u"Giulvaz",2992,45.548889,20.984444 ],
    [ u"ro",u"Giurgeni",1629,44.766667,27.883333 ],
    [ u"ro",u"Giurgita",3195,44.016667,23.633333 ],
    [ u"ro",u"Giurgiu",69068,43.883333,25.966667 ],
    [ u"ro",u"Giuvarasti",2676,43.8,24.7 ],
    [ u"ro",u"Glavanesti",3760,46.25,27.383333 ],
    [ u"ro",u"Glavile",2532,44.816667,24.15 ],
    [ u"ro",u"Glimboca",1865,45.483333,22.316667 ],
    [ u"ro",u"Glina",7227,44.383333,26.25 ],
    [ u"ro",u"Glodeanul Sarat",4683,44.866667,26.65 ],
    [ u"ro",u"Glodeanu-Silistea",4585,44.833333,26.8 ],
    [ u"ro",u"Glodeni",4367,45.016667,25.466667 ],
    [ u"ro",u"Glodeni",3719,46.65,24.6 ],
    [ u"ro",u"Glogova",1980,44.928056,22.906667 ],
    [ u"ro",u"Godeanu",766,44.801111,22.608611 ],
    [ u"ro",u"Godeni",3333,45.233333,24.983333 ],
    [ u"ro",u"Godinesti",2426,45,22.966667 ],
    [ u"ro",u"Gogosari",2244,43.866667,25.7 ],
    [ u"ro",u"Gogosu",1017,44.416667,23.366667 ],
    [ u"ro",u"Gohor",3886,46.066667,27.4 ],
    [ u"ro",u"Goicea",4676,43.916667,23.616667 ],
    [ u"ro",u"Golaesti",3797,47.233333,27.7 ],
    [ u"ro",u"Golesti",3446,45.666667,27.133333 ],
    [ u"ro",u"Gorbanesti",3587,47.783333,26.85 ],
    [ u"ro",u"Gorban",2991,46.876111,28.078889 ],
    [ u"ro",u"Gorgota",5459,44.783333,26.083333 ],
    [ u"ro",u"Gornesti",5787,46.666667,24.65 ],
    [ u"ro",u"Gornet-Cricov",2651,45.083333,26.266667 ],
    [ u"ro",u"Gornet",3076,45.116667,26.066667 ],
    [ u"ro",u"Goruia",921,45.187222,21.779167 ],
    [ u"ro",u"Gostavatu",3373,44.083333,24.533333 ],
    [ u"ro",u"Gostinari",2720,44.183333,26.233333 ],
    [ u"ro",u"Gostinu",2388,44,26.116667 ],
    [ u"ro",u"Gradinari",2129,45.118611,21.598889 ],
    [ u"ro",u"Gradinari",2489,44.566667,24.266667 ],
    [ u"ro",u"Gradinari",3738,44.392222,25.815556 ],
    [ u"ro",u"Gradistea",2626,45.266667,27.383333 ],
    [ u"ro",u"Gradistea",3057,44.866667,23.816667 ],
    [ u"ro",u"Gradistea",5232,44.233333,27.216667 ],
    [ u"ro",u"Gradistea",2924,44.666667,26.283333 ],
    [ u"ro",u"Grajduri",3264,46.966667,27.516667 ],
    [ u"ro",u"Gramesti",3097,47.916667,26.15 ],
    [ u"ro",u"Graniceri",2547,46.516667,21.3 ],
    [ u"ro",u"Granicesti",4916,47.816667,26.066667 ],
    [ u"ro",u"Gratia",2996,44.433333,25.45 ],
    [ u"ro",u"Greaca",2796,44.109444,26.339444 ],
    [ u"ro",u"Grebanu",5457,45.383333,26.966667 ],
    [ u"ro",u"Grecesti",2014,44.45,23.283333 ],
    [ u"ro",u"Greci",5384,45.183333,28.233333 ],
    [ u"ro",u"Greci",1508,44.55,23.116667 ],
    [ u"ro",u"Grindu",1561,45.4,28.216667 ],
    [ u"ro",u"Grindu",2412,44.766667,26.916667 ],
    [ u"ro",u"Grinties",2573,47.05,25.866667 ],
    [ u"ro",u"Grivita",7032,44.733333,27.283333 ],
    [ u"ro",u"Grivita",3694,45.716667,27.65 ],
    [ u"ro",u"Grojdibodu",3282,43.75,24.266667 ],
    [ u"ro",u"Gropnita",3414,47.35,27.25 ],
    [ u"ro",u"Grosi",2493,47.616667,23.616667 ],
    [ u"ro",u"Grozesti",1866,46.990833,28.050556 ],
    [ u"ro",u"Grozesti",2219,44.65,23.316667 ],
    [ u"ro",u"Gruia",3126,44.2675,22.704722 ],
    [ u"ro",u"Gruiu",7183,44.733333,26.233333 ],
    [ u"ro",u"Grumazesti",5385,47.133333,26.366667 ],
    [ u"ro",u"Gugesti",6478,45.566667,27.133333 ],
    [ u"ro",u"Gura Calitei",3111,45.583333,27.016667 ],
    [ u"ro",u"Gura Foii",2319,44.75,25.283333 ],
    [ u"ro",u"Gura Humorului",15728,47.55,25.9 ],
    [ u"ro",u"Gura Ocnitei",7856,44.933333,25.583333 ],
    [ u"ro",u"Gura Sutii",5355,44.75,25.516667 ],
    [ u"ro",u"Gura Teghii",3835,45.483333,26.416667 ],
    [ u"ro",u"Gura Vadului",2508,45.05,26.466667 ],
    [ u"ro",u"Gura Vaii",6075,46.333333,26.733333 ],
    [ u"ro",u"Gura Vitioarei",5947,45.15,26.033333 ],
    [ u"ro",u"Gurbanesti",1640,44.383333,26.7 ],
    [ u"ro",u"Gurghiu",6278,46.766667,24.85 ],
    [ u"ro",u"Gusoeni",1870,44.733333,24.116667 ],
    [ u"ro",u"Haghig",2175,45.833333,25.583333 ],
    [ u"ro",u"Halaucesti",5819,47.1,26.8 ],
    [ u"ro",u"Halchiu",6051,45.766667,25.55 ],
    [ u"ro",u"Halmasd",2578,47.15,22.616667 ],
    [ u"ro",u"Halmeu",7184,47.966667,23.016667 ],
    [ u"ro",u"Hamcearca",1624,45.116667,28.366667 ],
    [ u"ro",u"Hanesti",2339,47.916667,26.983333 ],
    [ u"ro",u"Hangu",4046,47.05,26.033333 ],
    [ u"ro",u"Harau",2098,45.9,22.95 ],
    [ u"ro",u"Harlau",11295,47.433333,26.9 ],
    [ u"ro",u"Harman",4321,45.716667,25.683333 ],
    [ u"ro",u"Harseni",2199,45.75,25.016667 ],
    [ u"ro",u"Harsesti",2841,44.533333,24.783333 ],
    [ u"ro",u"Harsova",10055,44.683333,27.933333 ],
    [ u"ro",u"Hartiesti",4913,45.116667,25.1 ],
    [ u"ro",u"Hateg",10865,45.616667,22.95 ],
    [ u"ro",u"Havarna",5088,48.066667,26.65 ],
    [ u"ro",u"Helegiu",7195,46.35,26.75 ],
    [ u"ro",u"Helesteni Harmaneasa",2652,47.2,26.866667 ],
    [ u"ro",u"Hemeius",3761,46.616667,26.85 ],
    [ u"ro",u"Hereclean",3685,47.25,23.016667 ],
    [ u"ro",u"Hida",3083,47.066667,23.283333 ],
    [ u"ro",u"Hidiselu de Sus",3262,46.95,22.05 ],
    [ u"ro",u"Hiliseu-Horia",3684,48.033333,26.25 ],
    [ u"ro",u"Hinova",2808,44.540556,22.776944 ],
    [ u"ro",u"Hlipiceni",3756,47.6,27.15 ],
    [ u"ro",u"Hoceni",3192,46.539167,28.006667 ],
    [ u"ro",u"Hodac",4892,46.766667,24.916667 ],
    [ u"ro",u"Hodod",3131,47.4,23.033333 ],
    [ u"ro",u"Hodosa",1390,46.633333,24.816667 ],
    [ u"ro",u"Hoghilag",2110,46.233333,24.616667 ],
    [ u"ro",u"Hoghiz",4876,45.983333,25.3 ],
    [ u"ro",u"Holboca",11708,47.15,27.7 ],
    [ u"ro",u"Holod",3493,46.783333,22.133333 ],
    [ u"ro",u"Homocea",9869,46.133333,27.233333 ],
    [ u"ro",u"Homorod-de Jos",2019,47.666667,23.083333 ],
    [ u"ro",u"Homorod",2344,46.05,25.266667 ],
    [ u"ro",u"Hoparta",1355,46.316667,23.866667 ],
    [ u"ro",u"Horezu",6743,45.15,24.016667 ],
    [ u"ro",u"Horgesti",4665,46.433333,27.066667 ],
    [ u"ro",u"Horia",1249,44.633333,28.116667 ],
    [ u"ro",u"Horia",1588,45.016667,28.45 ],
    [ u"ro",u"Horlesti",3112,47.116667,27.366667 ],
    [ u"ro",u"Horoatu Crasnei",2789,47.133333,22.883333 ],
    [ u"ro",u"Horodniceni",3699,47.533333,26.166667 ],
    [ u"ro",u"Hotarele",8790,44.1725,26.370278 ],
    [ u"ro",u"Hudesti",6360,48.15,26.5 ],
    [ u"ro",u"Huedin",9395,46.866667,23.05 ],
    [ u"ro",u"Hulubesti",3428,44.833333,25.233333 ],
    [ u"ro",u"Hunedoara",69136,45.75,22.9 ],
    [ u"ro",u"Hurezani",1826,44.8,23.65 ],
    [ u"ro",u"Huruesti",2821,46.266667,27.25 ],
    [ u"ro",u"Husasau de Tinca",2324,46.816667,21.916667 ],
    [ u"ro",u"Husi",29129,46.673611,28.059444 ],
    [ u"ro",u"Husnicioara",1699,44.678056,22.8425 ],
    [ u"ro",u"Iablanita",2566,44.950278,22.314167 ],
    [ u"ro",u"Iacobeni",3836,47.433333,25.316667 ],
    [ u"ro",u"Iacobeni",2637,46.05,24.716667 ],
    [ u"ro",u"Iana",3936,46.383333,27.55 ],
    [ u"ro",u"Ianca",11209,45.133333,27.45 ],
    [ u"ro",u"Ianca",4347,43.783333,24.183333 ],
    [ u"ro",u"Iancu Jianu",4375,44.5,24.033333 ],
    [ u"ro",u"Iara",4660,46.55,23.516667 ],
    [ u"ro",u"Iasi",318014,47.166667,27.6 ],
    [ u"ro",u"Ibanesti",4196,48.066667,26.366667 ],
    [ u"ro",u"Ibanesti",4434,46.766667,24.933333 ],
    [ u"ro",u"Iclanzel",2255,46.533333,24.283333 ],
    [ u"ro",u"Iclod",4351,46.983333,23.8 ],
    [ u"ro",u"Icoana",2281,44.416667,24.716667 ],
    [ u"ro",u"Icusesti",4648,46.8,26.933333 ],
    [ u"ro",u"Ideciu de Jos",1955,46.8,24.75 ],
    [ u"ro",u"Iepuresti",2334,44.258056,25.882222 ],
    [ u"ro",u"Iernut",9343,46.45,24.25 ],
    [ u"ro",u"Ieud",4139,47.683333,24.233333 ],
    [ u"ro",u"Ighiu",6294,46.15,23.516667 ],
    [ u"ro",u"Ileana",3805,44.516667,26.666667 ],
    [ u"ro",u"Ileanda",2546,47.333333,23.633333 ],
    [ u"ro",u"Ilia",3967,45.933333,22.65 ],
    [ u"ro",u"Ilieni",1826,45.8,25.766667 ],
    [ u"ro",u"Ilovat",1547,44.811389,22.767222 ],
    [ u"ro",u"Ilovita",1397,44.756389,22.472778 ],
    [ u"ro",u"Ilva Mare",2574,47.366667,24.9 ],
    [ u"ro",u"Ilva Mica",3431,47.316667,24.666667 ],
    [ u"ro",u"Independenta",4728,45.483333,27.75 ],
    [ u"ro",u"Independenta",3145,43.966667,28.083333 ],
    [ u"ro",u"Independenta",3863,44.283333,27.15 ],
    [ u"ro",u"Ineu",10051,46.433333,21.85 ],
    [ u"ro",u"Ineu",4007,47.083333,22.116667 ],
    [ u"ro",u"Insuratei",7309,44.916667,27.6 ],
    [ u"ro",u"Intorsura Buzaului",9026,45.683333,26.033333 ],
    [ u"ro",u"Intregalde",860,46.25,23.416667 ],
    [ u"ro",u"Ion Corvin",2137,44.116667,27.8 ],
    [ u"ro",u"Ionesti",2505,44.616667,23.433333 ],
    [ u"ro",u"Ionesti",4379,44.85,24.233333 ],
    [ u"ro",u"Ion Roata",3689,44.666667,26.766667 ],
    [ u"ro",u"Iordacheanu",5100,45.05,26.25 ],
    [ u"ro",u"Ipatele",2095,46.916667,27.416667 ],
    [ u"ro",u"Ip",3833,47.233333,22.65 ],
    [ u"ro",u"Ipotesti",4521,47.616667,26.283333 ],
    [ u"ro",u"Iratosu",2325,46.316667,21.2 ],
    [ u"ro",u"Isaccea",5375,45.266667,28.466667 ],
    [ u"ro",u"Isalnita",3955,44.4,23.733333 ],
    [ u"ro",u"Islaz",6029,43.733333,24.75 ],
    [ u"ro",u"Istria",2591,44.566667,28.716667 ],
    [ u"ro",u"Isverna",2476,44.979722,22.629167 ],
    [ u"ro",u"Ivanesti",4906,46.65,27.45 ],
    [ u"ro",u"Ivesti",4631,46.183333,27.533333 ],
    [ u"ro",u"Ivesti",9671,45.683333,27.516667 ],
    [ u"ro",u"Izbiceni",5089,43.833333,24.65 ],
    [ u"ro",u"Izvoare",2121,44.15,23.283333 ],
    [ u"ro",u"Izvoarele",6836,45.033333,25.266667 ],
    [ u"ro",u"Izvoarele",3792,44.266667,24.516667 ],
    [ u"ro",u"Izvoarele",2919,43.816667,25.383333 ],
    [ u"ro",u"Izvoarele",3817,45.033333,28.533333 ],
    [ u"ro",u"Izvoarele",4753,44.033889,25.774722 ],
    [ u"ro",u"Izvoarele Sucevei",2262,47.75,25.183333 ],
    [ u"ro",u"Izvoru Barzii",3059,44.706667,22.674167 ],
    [ u"ro",u"Izvoru Berheciului",1697,46.583333,27.216667 ],
    [ u"ro",u"Izvoru Crisului",1638,46.833333,23.1 ],
    [ u"ro",u"Jamu Mare",3289,45.254167,21.416944 ],
    [ u"ro",u"Jaristea",4088,45.783333,27.066667 ],
    [ u"ro",u"Jebel",5298,45.555556,21.213611 ],
    [ u"ro",u"Jegalia",4751,44.3,27.633333 ],
    [ u"ro",u"Jiana",4966,44.403056,22.711111 ],
    [ u"ro",u"Jibert",2469,46,25.066667 ],
    [ u"ro",u"Jibou",11183,47.266667,23.25 ],
    [ u"ro",u"Jichisu de Jos",1305,47.116667,23.8 ],
    [ u"ro",u"Jidvei",5146,46.216667,24.1 ],
    [ u"ro",u"Jijila",5770,45.3,28.15 ],
    [ u"ro",u"Jilava",12023,44.333333,26.078056 ],
    [ u"ro",u"Jilavele",3747,44.766667,26.533333 ],
    [ u"ro",u"Jimbolia",10860,45.791389,20.717222 ],
    [ u"ro",u"Jina",4013,45.783333,23.683333 ],
    [ u"ro",u"Jirlau",3397,45.166667,27.166667 ],
    [ u"ro",u"Jitia",1717,45.583333,26.716667 ],
    [ u"ro",u"Joita",8616,44.494167,25.853889 ],
    [ u"ro",u"Jorasti",1944,45.983333,27.866667 ],
    [ u"ro",u"Joseni",5635,46.7,25.5 ],
    [ u"ro",u"Jugureni",730,45.1,26.45 ],
    [ u"ro",u"Jupanesti",2388,44.9,23.533333 ],
    [ u"ro",u"Jurilovca",5133,44.766667,28.866667 ],
    [ u"ro",u"Ladesti",2188,44.883333,24.05 ],
    [ u"ro",u"Lalosu",2606,44.55,24.016667 ],
    [ u"ro",u"Lapugiu de Jos",1725,45.883333,22.483333 ],
    [ u"ro",u"Lapus",3769,47.5,24.016667 ],
    [ u"ro",u"Lapusnicel",1279,44.983056,22.226944 ],
    [ u"ro",u"Lapusnicu Mare",1929,44.913056,21.944167 ],
    [ u"ro",u"Largu",1769,44.966667,27.15 ],
    [ u"ro",u"Laslea",3147,46.216667,24.65 ],
    [ u"ro",u"Laza",6694,46.65,27.583333 ],
    [ u"ro",u"Lazarea",3555,46.75,25.533333 ],
    [ u"ro",u"Lazareni",2982,46.866667,22.066667 ],
    [ u"ro",u"Lazuri",5237,47.85,22.866667 ],
    [ u"ro",u"Lechinta",5939,47.016667,24.35 ],
    [ u"ro",u"Lehliu-Gara",6538,44.433333,26.85 ],
    [ u"ro",u"Lehliu",2953,44.433333,26.85 ],
    [ u"ro",u"Leleasca",1819,44.783333,24.433333 ],
    [ u"ro",u"Lelese",505,45.733333,22.7 ],
    [ u"ro",u"Lelesti",1951,45.1,23.2 ],
    [ u"ro",u"Lemnia",3416,46.05,26.266667 ],
    [ u"ro",u"Lenauheim",5605,45.871944,20.799444 ],
    [ u"ro",u"Leorda",2734,47.816667,26.45 ],
    [ u"ro",u"Leordeni",6019,44.783333,25.116667 ],
    [ u"ro",u"Leordina",2537,47.783333,24.25 ],
    [ u"ro",u"Leresti",4960,45.333333,25.066667 ],
    [ u"ro",u"Lespezi",6138,47.366667,26.7 ],
    [ u"ro",u"Lesu",2961,47.316667,24.75 ],
    [ u"ro",u"Letca",2185,47.333333,23.45 ],
    [ u"ro",u"Letcani",6642,47.183333,27.416667 ],
    [ u"ro",u"Letca Noua",3849,44.235556,25.738889 ],
    [ u"ro",u"Letea Veche",4893,46.55,26.95 ],
    [ u"ro",u"Leu",5404,44.183333,24 ],
    [ u"ro",u"Licuriciu",2590,44.916667,23.616667 ],
    [ u"ro",u"Liebling",3705,45.5775,21.321667 ],
    [ u"ro",u"Liesti",10956,45.616667,27.516667 ],
    [ u"ro",u"Limanu",4661,43.8,28.533333 ],
    [ u"ro",u"Lipanesti",4985,45.05,26.016667 ],
    [ u"ro",u"Lipnita",3716,44.1,27.6 ],
    [ u"ro",u"Lipova",11041,46.083333,21.7 ],
    [ u"ro",u"Lipova",2916,46.716667,27.233333 ],
    [ u"ro",u"Lipovat",4403,46.566667,27.7 ],
    [ u"ro",u"Lipovu",3152,44.1,23.633333 ],
    [ u"ro",u"Lisa",1653,45.716667,24.85 ],
    [ u"ro",u"Lisa",2576,43.8,25.133333 ],
    [ u"ro",u"Lita",3166,43.8,24.816667 ],
    [ u"ro",u"Liteni",9833,47.566667,26.2 ],
    [ u"ro",u"Livada",2840,46.216667,21.383333 ],
    [ u"ro",u"Livada",6833,47.866667,23.133333 ],
    [ u"ro",u"Livezeni",3704,46.55,24.633333 ],
    [ u"ro",u"Livezile",1491,46.35,23.633333 ],
    [ u"ro",u"Livezile",4248,47.183333,24.566667 ],
    [ u"ro",u"Livezile",1985,44.512222,22.863333 ],
    [ u"ro",u"Livezi",5255,46.4,26.733333 ],
    [ u"ro",u"Livezi",2586,44.85,23.816667 ],
    [ u"ro",u"Loamnes",3231,45.933333,24.1 ],
    [ u"ro",u"Logresti",3001,44.9,23.7 ],
    [ u"ro",u"Lopadea Noua",2931,46.283333,23.816667 ],
    [ u"ro",u"Lopatari",4385,45.483333,26.583333 ],
    [ u"ro",u"Lovrin",8851,45.968056,20.770278 ],
    [ u"ro",u"Lozna",1187,47.316667,23.466667 ],
    [ u"ro",u"Lucieni",6286,44.85,25.433333 ],
    [ u"ro",u"Luciu",2922,44.966667,27.083333 ],
    [ u"ro",u"Ludesti",5011,44.866667,25.233333 ],
    [ u"ro",u"Ludos",786,45.916667,23.9 ],
    [ u"ro",u"Ludus",17165,46.483333,24.1 ],
    [ u"ro",u"Lueta",3473,46.266667,25.483333 ],
    [ u"ro",u"Lugasu de Jos",3252,47.066667,22.35 ],
    [ u"ro",u"Lugoj",43244,45.688611,21.903056 ],
    [ u"ro",u"Luica",2269,44.233333,26.583333 ],
    [ u"ro",u"Luizi-Calugara",4596,46.533333,26.833333 ],
    [ u"ro",u"Lumina",7168,44.283333,28.566667 ],
    [ u"ro",u"Lunca Banului",3931,46.595,28.168333 ],
    [ u"ro",u"Lunca Bradului",2123,46.95,25.1 ],
    [ u"ro",u"Lunca Cernii de Jos",1099,45.633333,22.616667 ],
    [ u"ro",u"Lunca Corbului",3350,44.7,24.75 ],
    [ u"ro",u"Lunca de Jos",5152,46.566667,25.983333 ],
    [ u"ro",u"Lunca de Sus",3375,46.533333,25.966667 ],
    [ u"ro",u"Lunca Ilvei",3275,47.366667,24.983333 ],
    [ u"ro",u"Lunca",3081,46.516667,22.466667 ],
    [ u"ro",u"Lunca",4921,47.616667,26.983333 ],
    [ u"ro",u"Lunca",2809,46.85,24.566667 ],
    [ u"ro",u"Lunca",6485,43.833333,24.766667 ],
    [ u"ro",u"Lunca Muresului",2617,46.433333,23.9 ],
    [ u"ro",u"Luncavita",7050,45.283333,28.266667 ],
    [ u"ro",u"Luncavita",2842,45.083333,22.266667 ],
    [ u"ro",u"Luncoiu de Jos",1997,46.1,22.766667 ],
    [ u"ro",u"Lungani",5065,47.183333,27.15 ],
    [ u"ro",u"Lungesti",3628,44.566667,24.183333 ],
    [ u"ro",u"Lunguletu",5718,44.616667,25.65 ],
    [ u"ro",u"Lupac",2922,45.28,21.812778 ],
    [ u"ro",u"Lupeni",4370,46.383333,25.216667 ],
    [ u"ro",u"Lupeni",30488,45.35,23.233333 ],
    [ u"ro",u"Lupsa",3765,46.366667,23.2 ],
    [ u"ro",u"Lupsanu",3797,44.383333,26.9 ],
    [ u"ro",u"Macea",6056,46.383333,21.3 ],
    [ u"ro",u"Macesu de Jos",1650,43.883333,23.716667 ],
    [ u"ro",u"Macesu de Sus",1692,43.916667,23.7 ],
    [ u"ro",u"Macin",10295,45.25,28.15 ],
    [ u"ro",u"Maciuca",2193,44.75,24.016667 ],
    [ u"ro",u"Madaras",2964,46.833333,21.683333 ],
    [ u"ro",u"Madarjac",1566,47.05,27.25 ],
    [ u"ro",u"Madulari",1718,45.033333,24 ],
    [ u"ro",u"Maeriste",3436,47.316667,22.8 ],
    [ u"ro",u"Magesti",2824,47.016667,22.45 ],
    [ u"ro",u"Magherani",2681,46.566667,24.9 ],
    [ u"ro",u"Magiresti",4477,46.516667,26.55 ],
    [ u"ro",u"Maglavit",5753,44.033333,23.1 ],
    [ u"ro",u"Magura Ilvei",3767,47.383333,24.8 ],
    [ u"ro",u"Magura",3936,46.55,26.833333 ],
    [ u"ro",u"Magura",4657,45.266667,26.583333 ],
    [ u"ro",u"Magura",3070,44.033333,25.4 ],
    [ u"ro",u"Magurele",4812,45.1,26.033333 ],
    [ u"ro",u"Magurele",9375,44.35,26.033333 ],
    [ u"ro",u"Magureni",6515,45.066667,25.733333 ],
    [ u"ro",u"Maguri-Racatau",2379,46.633333,23.133333 ],
    [ u"ro",u"Mahmudia",4876,45.083333,29.083333 ],
    [ u"ro",u"Maicanesti",5312,45.5,27.5 ],
    [ u"ro",u"Maieru",7259,47.4,24.75 ],
    [ u"ro",u"Maierus",2472,45.9,25.533333 ],
    [ u"ro",u"Malaia",1886,45.35,24.033333 ],
    [ u"ro",u"Maldaeni",4755,44.116667,24.933333 ],
    [ u"ro",u"Maldaresti",2033,45.116667,24 ],
    [ u"ro",u"Malini",7163,47.45,26.1 ],
    [ u"ro",u"Malnas",4804,46.016667,25.833333 ],
    [ u"ro",u"Malovat",2943,44.704444,22.731111 ],
    [ u"ro",u"Malu cu Flori",2698,45.15,25.2 ],
    [ u"ro",u"Malu Mare",4995,44.233333,23.866667 ],
    [ u"ro",u"Malureni",4762,45.1,24.8 ],
    [ u"ro",u"Malusteni",2988,46.183333,27.916667 ],
    [ u"ro",u"Manasia",4617,44.7,26.666667 ],
    [ u"ro",u"Manastirea Casin",5505,46.15,26.683333 ],
    [ u"ro",u"Manastirea Homorului",3573,47.6,25.866667 ],
    [ u"ro",u"Manastirea",6123,44.216667,26.9 ],
    [ u"ro",u"Manastireni",1771,46.766667,23.083333 ],
    [ u"ro",u"Manastiur",1757,45.816667,22.066667 ],
    [ u"ro",u"Mandra",2856,45.816667,25.05 ],
    [ u"ro",u"Maneciu",11033,45.316667,25.983333 ],
    [ u"ro",u"Manesti",4612,44.966667,25.283333 ],
    [ u"ro",u"Manesti",7186,44.866667,25.85 ],
    [ u"ro",u"Mangalia",39620,43.8,28.583333 ],
    [ u"ro",u"Manoleasa",3705,47.983333,27.066667 ],
    [ u"ro",u"Manzalesti",3005,45.5,26.65 ],
    [ u"ro",u"Maracineni",4468,44.9,24.883333 ],
    [ u"ro",u"Maracineni",7096,45.2,26.8 ],
    [ u"ro",u"Marasesti",11769,45.883333,27.233333 ],
    [ u"ro",u"Marasu",3453,44.85,27.966667 ],
    [ u"ro",u"Marca",2890,47.216667,22.566667 ],
    [ u"ro",u"Marga",1263,45.5,22.516667 ],
    [ u"ro",u"Margaritesti",866,45.433333,26.833333 ],
    [ u"ro",u"Margau",1844,46.75,22.966667 ],
    [ u"ro",u"Marghita",18935,47.35,22.333333 ],
    [ u"ro",u"Margina",2333,45.85,22.266667 ],
    [ u"ro",u"Marginea",9489,47.816667,25.816667 ],
    [ u"ro",u"Margineni",8033,46.6,26.9 ],
    [ u"ro",u"Margineni",3995,46.9,26.633333 ],
    [ u"ro",u"Marisel",1649,46.65,23.133333 ],
    [ u"ro",u"Mariselu",2534,47.016667,24.516667 ],
    [ u"ro",u"Marpod",840,45.866667,24.5 ],
    [ u"ro",u"Marsa",2745,44.374167,25.556944 ],
    [ u"ro",u"Marsani",5238,44.016667,24.016667 ],
    [ u"ro",u"Martinesti",1035,45.816667,23.133333 ],
    [ u"ro",u"Martinis",2968,46.233333,25.383333 ],
    [ u"ro",u"Maruntei",4397,44.2,24.466667 ],
    [ u"ro",u"Marzanesti",4326,43.933333,25.466667 ],
    [ u"ro",u"Masca",3498,46.3,21.683333 ],
    [ u"ro",u"Masloc",3935,45.998056,21.449722 ],
    [ u"ro",u"Mastacani",5185,45.783333,28.033333 ],
    [ u"ro",u"Matasari",5411,44.85,23.083333 ],
    [ u"ro",u"Matasaru",5722,44.716667,25.416667 ],
    [ u"ro",u"Matca",11642,45.85,27.533333 ],
    [ u"ro",u"Mateesti",3232,45.066667,23.85 ],
    [ u"ro",u"Matei",2949,46.983333,24.266667 ],
    [ u"ro",u"Maureni",2553,45.403889,21.5025 ],
    [ u"ro",u"Mavrodin",5628,44.033333,25.25 ],
    [ u"ro",u"Maxineni",3758,45.4,27.633333 ],
    [ u"ro",u"Medgidia",43315,44.25,28.283333 ],
    [ u"ro",u"Medias",53041,46.166667,24.35 ],
    [ u"ro",u"Mediesu Aurit",7122,47.783333,23.15 ],
    [ u"ro",u"Mehadia",4336,44.900833,22.366944 ],
    [ u"ro",u"Mehadica",891,45.033333,22.266667 ],
    [ u"ro",u"Melinesti",4429,44.566667,23.716667 ],
    [ u"ro",u"Mera",3938,45.766667,26.95 ],
    [ u"ro",u"Merei",7137,45.133333,26.683333 ],
    [ u"ro",u"Mereni",4155,44.05,28.366667 ],
    [ u"ro",u"Meresti",1395,46.233333,25.45 ],
    [ u"ro",u"Merghindeal",1256,45.966667,24.733333 ],
    [ u"ro",u"Merisani",4390,44.966667,24.733333 ],
    [ u"ro",u"Mesesenii de Jos",3017,47.15,22.983333 ],
    [ u"ro",u"Metes",3114,46.1,23.416667 ],
    [ u"ro",u"Mica",3799,47.133333,23.933333 ],
    [ u"ro",u"Mica",4626,46.366667,24.416667 ],
    [ u"ro",u"Micasasa",2384,46.083333,24.116667 ],
    [ u"ro",u"Micesti",4061,44.95,24.866667 ],
    [ u"ro",u"Miclesti",2961,46.816667,27.833333 ],
    [ u"ro",u"Micula",3707,47.9,22.95 ],
    [ u"ro",u"Miercurea-Ciuc",41282,46.35,25.8 ],
    [ u"ro",u"Miercurea Nirajului",5741,46.533333,24.8 ],
    [ u"ro",u"Miercurea Sibiului",3981,45.883333,23.8 ],
    [ u"ro",u"Mihaesti",5825,45.116667,25 ],
    [ u"ro",u"Mihaesti",6263,45.033333,24.25 ],
    [ u"ro",u"Mihaesti",1957,44.133333,24.783333 ],
    [ u"ro",u"Mihai Bravu",2640,44.95,28.65 ],
    [ u"ro",u"Mihai Bravu",2718,44.140556,26.062778 ],
    [ u"ro",u"Mihail Eminescu",6451,47.783333,26.916667 ],
    [ u"ro",u"Mihaileni",2605,46.466667,25.816667 ],
    [ u"ro",u"Mihaileni",1050,45.983333,24.35 ],
    [ u"ro",u"Mihaileni",5037,47.966667,26.15 ],
    [ u"ro",u"Mihailesti",3719,44.916667,26.666667 ],
    [ u"ro",u"Mihail Kogalniceanu",9970,44.366667,28.45 ],
    [ u"ro",u"Mihail Kogalniceanu",6181,44.683333,27.733333 ],
    [ u"ro",u"Mihail Kogalniceanu",3210,45.033333,28.733333 ],
    [ u"ro",u"Mihai Viteazu",5659,46.533333,23.75 ],
    [ u"ro",u"Mihai Viteazu",3291,44.633333,28.683333 ],
    [ u"ro",u"Mihalaseni",2438,47.883333,27.066667 ],
    [ u"ro",u"Mihalt",3601,46.15,23.733333 ],
    [ u"ro",u"Milas",1546,46.816667,24.433333 ],
    [ u"ro",u"Milcoiu",1276,45.05,24.466667 ],
    [ u"ro",u"Milcovul",8547,45.65,27.25 ],
    [ u"ro",u"Mileanca",2985,48.083333,26.7 ],
    [ u"ro",u"Milisauti",8399,47.783333,26 ],
    [ u"ro",u"Milosesti",3056,44.733333,27.233333 ],
    [ u"ro",u"Mintiu Gherlii",3806,47.05,23.95 ],
    [ u"ro",u"Mioveni",36339,44.95,24.95 ],
    [ u"ro",u"Miraslau",2298,46.366667,23.716667 ],
    [ u"ro",u"Mircea Voda",6983,44.283333,28.166667 ],
    [ u"ro",u"Mircea Voda",3594,45.116667,27.383333 ],
    [ u"ro",u"Mircesti",6797,47.083333,26.833333 ],
    [ u"ro",u"Miresu Mare",5054,47.5,23.333333 ],
    [ u"ro",u"Mironeasa",4324,46.966667,27.416667 ],
    [ u"ro",u"Mirosi",2789,44.416667,24.933333 ],
    [ u"ro",u"Miroslava",8127,47.15,27.516667 ],
    [ u"ro",u"Miroslovesti",7072,47.15,26.65 ],
    [ u"ro",u"Mirsid",2246,47.233333,23.133333 ],
    [ u"ro",u"Mischii",1841,44.383333,23.85 ],
    [ u"ro",u"Mitoc",2023,48.1,27.033333 ],
    [ u"ro",u"Mitocu Dragomirnei",3976,47.733333,26.25 ],
    [ u"ro",u"Mitreni",4831,44.166667,26.6 ],
    [ u"ro",u"Mizil",15532,45.016667,26.45 ],
    [ u"ro",u"Moacsa",2274,45.866667,25.966667 ],
    [ u"ro",u"Moara Vlasiei",5912,44.633333,26.216667 ],
    [ u"ro",u"Mociu",3454,46.8,24.033333 ],
    [ u"ro",u"Modelu",9672,44.2,27.383333 ],
    [ u"ro",u"Moftinu Mare",4242,47.666667,22.666667 ],
    [ u"ro",u"Mogosani",4549,44.683333,25.4 ],
    [ u"ro",u"Mogosesti",4946,47.033333,27.533333 ],
    [ u"ro",u"Mogosesti-Siret",4044,47.133333,26.783333 ],
    [ u"ro",u"Mogos",1087,46.266667,23.266667 ],
    [ u"ro",u"Mogosoaia",5304,44.529167,26 ],
    [ u"ro",u"Moinesti",23981,46.466667,26.483333 ],
    [ u"ro",u"Moisei",8877,47.65,24.55 ],
    [ u"ro",u"Moldova Noua",13264,44.7375,21.666944 ],
    [ u"ro",u"Moldova Sulita",2059,47.683333,25.25 ],
    [ u"ro",u"Moldovenesti",3618,46.5,23.65 ],
    [ u"ro",u"Moldoveni",2508,46.833333,26.766667 ],
    [ u"ro",u"Moldovita",4985,47.683333,25.533333 ],
    [ u"ro",u"Monor",1581,46.966667,24.7 ],
    [ u"ro",u"Moraresti",2201,45.016667,24.566667 ],
    [ u"ro",u"Moravita",2368,45.255833,21.270278 ],
    [ u"ro",u"Moreni",20596,44.983333,25.65 ],
    [ u"ro",u"Moroeni",5042,45.216667,25.433333 ],
    [ u"ro",u"Morteni",3088,44.666667,25.233333 ],
    [ u"ro",u"Morunglav",2958,44.466667,24.116667 ],
    [ u"ro",u"Mosna",1939,46.916667,27.95 ],
    [ u"ro",u"Mosna",3187,46.083333,24.4 ],
    [ u"ro",u"Mosnita Noua",4268,45.717222,21.325278 ],
    [ u"ro",u"Mosoaia",4267,44.816667,24.766667 ],
    [ u"ro",u"Mosteni",1681,43.866667,25.133333 ],
    [ u"ro",u"Motaeni",2210,45.1,25.416667 ],
    [ u"ro",u"Motatei",7898,44.033333,23.2 ],
    [ u"ro",u"Motca",5095,47.25,26.616667 ],
    [ u"ro",u"Motoseni",4007,46.333333,27.383333 ],
    [ u"ro",u"Motru",22319,44.803333,22.971944 ],
    [ u"ro",u"Movila Banului",2760,44.983333,26.683333 ],
    [ u"ro",u"Movila Miresei",4341,45.216667,27.6 ],
    [ u"ro",u"Movila",2195,44.55,27.7 ],
    [ u"ro",u"Movileni",3129,47.316667,27.35 ],
    [ u"ro",u"Movileni",3839,44.366667,24.65 ],
    [ u"ro",u"Movileni",3200,45.766667,27.35 ],
    [ u"ro",u"Movilita",3911,45.95,27.1 ],
    [ u"ro",u"Movilita",4766,44.65,26.483333 ],
    [ u"ro",u"Mozaceni",2684,44.566667,25.166667 ],
    [ u"ro",u"Muereasca",2591,45.183333,24.333333 ],
    [ u"ro",u"Mugeni",5784,46.25,25.216667 ],
    [ u"ro",u"Munteni Buzau",3824,44.633333,26.983333 ],
    [ u"ro",u"Muntenii de Jos",3826,46.616667,27.766667 ],
    [ u"ro",u"Munteni",9760,45.933333,27.433333 ],
    [ u"ro",u"Murgasi",2750,44.5,23.866667 ],
    [ u"ro",u"Murgeni",7665,46.204444,28.019722 ],
    [ u"ro",u"Murgesti",1140,45.4,26.883333 ],
    [ u"ro",u"Murighiol",3761,45.033333,29.166667 ],
    [ u"ro",u"Musenita",2232,47.966667,26 ],
    [ u"ro",u"Musetesti",2270,45.15,23.466667 ],
    [ u"ro",u"Nades",2368,46.316667,24.733333 ],
    [ u"ro",u"Nadlac",8067,46.166667,20.75 ],
    [ u"ro",u"Nadrag",2897,45.65,22.183333 ],
    [ u"ro",u"Naeni",2008,45.1,26.483333 ],
    [ u"ro",u"Naidas",1272,44.881667,21.588056 ],
    [ u"ro",u"Nalbant",2789,45.05,28.616667 ],
    [ u"ro",u"Namoloasa",2373,45.533333,27.55 ],
    [ u"ro",u"Nana",2606,44.266667,26.583333 ],
    [ u"ro",u"Nanesti",2427,45.55,27.5 ],
    [ u"ro",u"Nanov",3545,44,25.3 ],
    [ u"ro",u"Napradea",2961,47.366667,23.316667 ],
    [ u"ro",u"Naruja",1914,45.833333,26.783333 ],
    [ u"ro",u"Nasaud",10380,47.283333,24.4 ],
    [ u"ro",u"Nasturelu",2809,43.666667,25.466667 ],
    [ u"ro",u"Navodari",33107,44.316667,28.6 ],
    [ u"ro",u"Neaua",1521,46.483333,24.833333 ],
    [ u"ro",u"Necsesti",1562,44.25,25.15 ],
    [ u"ro",u"Negomiru",3810,44.833333,23.166667 ],
    [ u"ro",u"Negrasi",2811,44.6,25.116667 ],
    [ u"ro",u"Negresti",10043,46.833333,27.433333 ],
    [ u"ro",u"Negresti-Oas",13456,47.866667,23.433333 ],
    [ u"ro",u"Negri",3101,46.7,26.966667 ],
    [ u"ro",u"Negru Voda",5585,43.816667,28.2 ],
    [ u"ro",u"Nehoiu",11350,45.416667,26.3 ],
    [ u"ro",u"Nereju",4202,45.716667,26.716667 ],
    [ u"ro",u"Nicolae Balcescu",10140,46.466667,26.916667 ],
    [ u"ro",u"Nicolae Balcescu",4813,44.383333,28.383333 ],
    [ u"ro",u"Nicolae Balcescu",1692,44.45,26.766667 ],
    [ u"ro",u"Nicolae Titulescu",3095,44.3,24.8 ],
    [ u"ro",u"Nicoresti",6147,45.933333,27.283333 ],
    [ u"ro",u"Nicseni",2878,47.866667,26.633333 ],
    [ u"ro",u"Niculitel",4690,45.183333,28.483333 ],
    [ u"ro",u"Nistoresti",2335,45.833333,26.733333 ],
    [ u"ro",u"Nitchidorf",1567,45.583333,21.533333 ],
    [ u"ro",u"Nocrich",2612,45.9,24.45 ],
    [ u"ro",u"Nojorid",4484,46.983333,21.883333 ],
    [ u"ro",u"Noslac",1992,46.4,23.933333 ],
    [ u"ro",u"Novaci",6033,45.183333,23.666667 ],
    [ u"ro",u"Nucet",2362,46.466667,22.583333 ],
    [ u"ro",u"Nucet",4348,44.783333,25.55 ],
    [ u"ro",u"Nuci",3174,44.716667,26.3 ],
    [ u"ro",u"Nucsoara",1687,45.333333,24.783333 ],
    [ u"ro",u"Nufaru",2388,45.15,28.916667 ],
    [ u"ro",u"Nuseni",3221,47.1,24.2 ],
    [ u"ro",u"Nusfalau",5436,47.2,22.733333 ],
    [ u"ro",u"Oancea",1559,45.916667,28.1 ],
    [ u"ro",u"Oarja",2851,44.766667,24.966667 ],
    [ u"ro",u"Oarta de Jos",1387,47.45,23.133333 ],
    [ u"ro",u"Obarsia-Closani",1102,45.016667,22.683333 ],
    [ u"ro",u"Oboga",3620,44.416667,24.1 ],
    [ u"ro",u"Obreja",3136,45.483333,22.25 ],
    [ u"ro",u"Ocland",1383,46.166667,25.416667 ],
    [ u"ro",u"Ocna de Fier",766,45.333333,21.783333 ],
    [ u"ro",u"Ocna Mures",15316,46.383333,23.85 ],
    [ u"ro",u"Ocna Sibiului",4021,45.883333,24.05 ],
    [ u"ro",u"Ocna Sugatag",4147,47.783333,23.933333 ],
    [ u"ro",u"Ocnele Mari",3554,45.083333,24.316667 ],
    [ u"ro",u"Ocnita",4348,44.983333,25.55 ],
    [ u"ro",u"Ocolis",832,46.483333,23.466667 ],
    [ u"ro",u"Odaile",1080,45.383333,26.55 ],
    [ u"ro",u"Odobesti",8026,45.766667,27.05 ],
    [ u"ro",u"Odobesti",5211,44.616667,25.566667 ],
    [ u"ro",u"Odoreu",4765,47.8,23 ],
    [ u"ro",u"Odorheiu Secuiesc",36531,46.3,25.3 ],
    [ u"ro",u"Ogra",2403,46.433333,24.316667 ],
    [ u"ro",u"Ogrezeni",4893,44.419722,25.768333 ],
    [ u"ro",u"Ohaba Lunga",1212,45.908056,21.974444 ],
    [ u"ro",u"Ohaba",916,46.066667,23.783333 ],
    [ u"ro",u"Oinacu",3892,43.95,26.016667 ],
    [ u"ro",u"Oituz",9596,46.2,26.616667 ],
    [ u"ro",u"Ojdula",3465,45.983333,26.25 ],
    [ u"ro",u"Olanu",3340,44.866667,24.3 ],
    [ u"ro",u"Olari",1905,46.383333,21.55 ],
    [ u"ro",u"Olcea",2909,46.683333,21.983333 ],
    [ u"ro",u"Oltenesti",3041,46.583333,27.9 ],
    [ u"ro",u"Olteni",3352,44.183333,25.283333 ],
    [ u"ro",u"Oltenita",26356,44.083333,26.633333 ],
    [ u"ro",u"Oltina",3030,44.166667,27.666667 ],
    [ u"ro",u"Oncesti",1686,46.466667,27.25 ],
    [ u"ro",u"Onesti",50489,46.25,26.75 ],
    [ u"ro",u"Oniceni",3284,46.816667,27.15 ],
    [ u"ro",u"Oporelu",1265,44.6,24.416667 ],
    [ u"ro",u"Oprisor",3030,44.283333,23.083333 ],
    [ u"ro",u"Optasi",3581,44.583333,24.65 ],
    [ u"ro",u"Oradea",203841,47.066667,21.933333 ],
    [ u"ro",u"Orastie",20763,45.833333,23.2 ],
    [ u"ro",u"Orastioara de Sus",2428,45.733333,23.166667 ],
    [ u"ro",u"Orasu Nou",6737,47.833333,23.283333 ],
    [ u"ro",u"Oravita",12332,45.0325,21.689444 ],
    [ u"ro",u"Orbeni",4140,46.283333,27.016667 ],
    [ u"ro",u"Orlat",3193,45.75,23.966667 ],
    [ u"ro",u"Orlea",4591,43.75,24.383333 ],
    [ u"ro",u"Orlesti",3372,44.8,24.216667 ],
    [ u"ro",u"Ormenis",3325,46.016667,25.55 ],
    [ u"ro",u"Orodel",3269,44.233333,23.233333 ],
    [ u"ro",u"Orsova",12350,44.725278,22.396111 ],
    [ u"ro",u"Ortisoara",4042,45.963611,21.198333 ],
    [ u"ro",u"Osesti",3146,46.766667,27.466667 ],
    [ u"ro",u"Osica de Sus",5351,44.25,24.316667 ],
    [ u"ro",u"Osorheiu",5764,47.033333,22.05 ],
    [ u"ro",u"Ostra",3145,47.4,25.766667 ],
    [ u"ro",u"Ostroveni",5731,43.8,23.9 ],
    [ u"ro",u"Ostrov",2210,44.933333,28.15 ],
    [ u"ro",u"Ostrov",5516,44.116667,27.366667 ],
    [ u"ro",u"Oteleni",3841,47.083333,27.033333 ],
    [ u"ro",u"Otelu Rosu",11482,45.533333,22.366667 ],
    [ u"ro",u"Otesani",3001,45.066667,24.033333 ],
    [ u"ro",u"Otopeni",10332,44.55,26.066667 ],
    [ u"ro",u"Ovidiu",13258,44.266667,28.566667 ],
    [ u"ro",u"Ozun",4493,45.8,25.85 ],
    [ u"ro",u"Pacureti",2252,45.15,26.133333 ],
    [ u"ro",u"Pades",5071,45.016667,22.85 ],
    [ u"ro",u"Padina",4774,44.833333,27.116667 ],
    [ u"ro",u"Padureni",4429,45.933333,27.216667 ],
    [ u"ro",u"Palanca",3733,46.533333,26.116667 ],
    [ u"ro",u"Palatca",1368,46.85,23.983333 ],
    [ u"ro",u"Paltinis",3302,48.216667,26.65 ],
    [ u"ro",u"Paltinis",2595,45.433333,22.15 ],
    [ u"ro",u"Paltinoasa",5635,47.55,25.95 ],
    [ u"ro",u"Paltin",3687,45.783333,26.716667 ],
    [ u"ro",u"Panaci",2308,47.266667,25.383333 ],
    [ u"ro",u"Panatau",2835,45.316667,26.383333 ],
    [ u"ro",u"Pancesti",4272,46.333333,27.083333 ],
    [ u"ro",u"Panciu",8810,45.9,27.083333 ],
    [ u"ro",u"Pancota",7133,46.333333,21.7 ],
    [ u"ro",u"Panet",5880,46.55,24.466667 ],
    [ u"ro",u"Pangarati",5170,46.933333,26.15 ],
    [ u"ro",u"Pantelimon",16206,44.45,26.2 ],
    [ u"ro",u"Pantelimon",1870,44.55,28.333333 ],
    [ u"ro",u"Panticeu",1985,47.033333,23.566667 ],
    [ u"ro",u"Papiu Ilarian",997,46.55,24.2 ],
    [ u"ro",u"Parau",2092,45.85,25.183333 ],
    [ u"ro",u"Parava",3367,46.3,27 ],
    [ u"ro",u"Pardina",702,45.3,28.966667 ],
    [ u"ro",u"Pardosi",572,45.366667,26.9 ],
    [ u"ro",u"Parincea",3836,46.483333,27.1 ],
    [ u"ro",u"Parjol",6688,46.583333,26.6 ],
    [ u"ro",u"Parscoveni",4817,44.3,24.233333 ],
    [ u"ro",u"Parscov",5968,45.283333,26.55 ],
    [ u"ro",u"Partestii de Jos",2998,47.633333,25.966667 ],
    [ u"ro",u"Parva",2611,47.4,24.55 ],
    [ u"ro",u"Pasareni",1889,46.483333,24.7 ],
    [ u"ro",u"Pascani",42203,47.25,26.733333 ],
    [ u"ro",u"Pastraveni",3798,47.166667,26.566667 ],
    [ u"ro",u"Patarlagele",8101,45.316667,26.35 ],
    [ u"ro",u"Patrauti",4283,47.716667,26.2 ],
    [ u"ro",u"Patulele",4395,44.345278,22.772778 ],
    [ u"ro",u"Pauca",2191,46.016667,23.9 ],
    [ u"ro",u"Pauleni-Ciuc",1711,46.4,25.833333 ],
    [ u"ro",u"Paulesti",5069,45,25.983333 ],
    [ u"ro",u"Paulesti",4258,47.783333,22.916667 ],
    [ u"ro",u"Paulis",4036,46.116667,21.583333 ],
    [ u"ro",u"Paunesti",6778,46.033333,27.1 ],
    [ u"ro",u"Pausesti-Maglasi",3775,45.133333,24.25 ],
    [ u"ro",u"Pausesti",2973,45.066667,24.116667 ],
    [ u"ro",u"Peceneaga",2042,45.016667,28.133333 ],
    [ u"ro",u"Pechea",11287,45.633333,27.8 ],
    [ u"ro",u"Pecica",12804,46.166667,21.066667 ],
    [ u"ro",u"Pecineaga",3040,43.9,28.5 ],
    [ u"ro",u"Peciu Nou",4937,45.606389,21.057778 ],
    [ u"ro",u"Peregu Mare",1770,46.233333,20.9 ],
    [ u"ro",u"Peretu",7816,44.05,25.083333 ],
    [ u"ro",u"Periam",6563,46.05,20.866667 ],
    [ u"ro",u"Periceiu",3922,47.233333,22.883333 ],
    [ u"ro",u"Perieni",5258,46.3,27.616667 ],
    [ u"ro",u"Perieti",3638,44.55,27.216667 ],
    [ u"ro",u"Perieti",3963,44.4,24.55 ],
    [ u"ro",u"Perisani",3781,45.383333,24.4 ],
    [ u"ro",u"Perisor",1896,44.133333,23.5 ],
    [ u"ro",u"Perisoru",5535,44.45,27.55 ],
    [ u"ro",u"Peris",7235,44.684722,26.013889 ],
    [ u"ro",u"Pesceana",2017,44.816667,24.15 ],
    [ u"ro",u"Pesceana",2017,44.883333,24.15 ],
    [ u"ro",u"Pestera",3496,44.183333,28.133333 ],
    [ u"ro",u"Pestisani",4187,45.066667,23.033333 ],
    [ u"ro",u"Pestisu Mic",1272,45.8,22.883333 ],
    [ u"ro",u"Petelea",2735,46.733333,24.716667 ],
    [ u"ro",u"Petrachioaia",2866,44.583333,26.3 ],
    [ u"ro",u"Petrestii de Jos",1861,46.583333,23.65 ],
    [ u"ro",u"Petresti",1646,47.6,22.366667 ],
    [ u"ro",u"Petresti",6020,44.65,25.333333 ],
    [ u"ro",u"Petricani",5580,47.166667,26.466667 ],
    [ u"ro",u"Petrila",25234,45.45,23.416667 ],
    [ u"ro",u"Petrosani",44187,45.416667,23.366667 ],
    [ u"ro",u"Petrova",2664,47.833333,24.233333 ],
    [ u"ro",u"Piatra Neamt",102689,46.916667,26.333333 ],
    [ u"ro",u"Piatra Olt",6313,44.366667,24.266667 ],
    [ u"ro",u"Piatra",3731,43.816667,25.166667 ],
    [ u"ro",u"Piatra Soimului",7848,46.833333,26.433333 ],
    [ u"ro",u"Pielesti",3647,44.333333,23.95 ],
    [ u"ro",u"Pietrari",3257,45.1,24.133333 ],
    [ u"ro",u"Pietroasa",1162,45.833333,22.4 ],
    [ u"ro",u"Pietroasele",3690,45.1,26.566667 ],
    [ u"ro",u"Pietrosani",3351,43.716667,25.633333 ],
    [ u"ro",u"Pietrosani",5871,45.183333,24.85 ],
    [ u"ro",u"Pietrosita",3298,45.183333,25.433333 ],
    [ u"ro",u"Pilu",1943,46.566667,21.35 ],
    [ u"ro",u"Pipirig",8569,47.25,26.066667 ],
    [ u"ro",u"Pir",1738,47.466667,22.366667 ],
    [ u"ro",u"Pischia",2974,45.903056,21.337222 ],
    [ u"ro",u"Piscolt",3199,47.583333,22.3 ],
    [ u"ro",u"Piscu",5002,45.5,27.733333 ],
    [ u"ro",u"Piscu Vechi",5445,43.9,23.166667 ],
    [ u"ro",u"Pitesti",167671,44.85,24.866667 ],
    [ u"ro",u"Plaiesii-de-Jos",2936,46.216667,26.1 ],
    [ u"ro",u"Plataresti",4260,44.35,26.366667 ],
    [ u"ro",u"Plenita",5260,44.216667,23.183333 ],
    [ u"ro",u"Plesoiu",3365,44.466667,24.266667 ],
    [ u"ro",u"Ploiesti",228853,44.95,26.016667 ],
    [ u"ro",u"Plopana",3291,46.683333,27.216667 ],
    [ u"ro",u"Plopeni",9580,45.066667,25.983333 ],
    [ u"ro",u"Plopii Slavitesti",4716,43.966667,24.683333 ],
    [ u"ro",u"Plopis",2731,47.133333,22.683333 ],
    [ u"ro",u"Plopsoru",6576,44.783333,23.35 ],
    [ u"ro",u"Plopu",2282,45.016667,26.15 ],
    [ u"ro",u"Plosca",6404,44.033333,25.133333 ],
    [ u"ro",u"Plugari",3694,47.483333,27.1 ],
    [ u"ro",u"Poarta Alba",4739,44.216667,28.4 ],
    [ u"ro",u"Poboru",2367,44.666667,24.5 ],
    [ u"ro",u"Pocola",1646,46.683333,22.283333 ],
    [ u"ro",u"Podari",6302,44.25,23.783333 ],
    [ u"ro",u"Podenii Noi",4644,45.116667,26.166667 ],
    [ u"ro",u"Podeni",1148,44.881389,22.543333 ],
    [ u"ro",u"Podgoria",3312,45.416667,27.016667 ],
    [ u"ro",u"Podoleni",5520,46.8,26.616667 ],
    [ u"ro",u"Podu Iloaiei",9752,47.216667,27.266667 ],
    [ u"ro",u"Poduri",7937,46.466667,26.533333 ],
    [ u"ro",u"Podu Turcului",5081,46.2,27.383333 ],
    [ u"ro",u"Poenarii-Burchi",5681,44.75,26.016667 ],
    [ u"ro",u"Poenari",1157,45.316667,24.65 ],
    [ u"ro",u"Poenari",3592,45.216667,25.05 ],
    [ u"ro",u"Poeni",3335,44.4,25.333333 ],
    [ u"ro",u"Pogaceaua",1952,46.683333,24.3 ],
    [ u"ro",u"Pogana",3378,46.316667,27.566667 ],
    [ u"ro",u"Pogoanele",7778,44.916667,27 ],
    [ u"ro",u"Poiana Blenchii",1311,47.3,23.75 ],
    [ u"ro",u"Poiana Cristei",2775,45.65,26.983333 ],
    [ u"ro",u"Poiana Lacului",6705,44.816667,24.733333 ],
    [ u"ro",u"Poiana Mare",12633,43.916667,23.066667 ],
    [ u"ro",u"Poiana Marului",4926,45.6,25.3 ],
    [ u"ro",u"Poiana",3930,44.566667,25.683333 ],
    [ u"ro",u"Poiana Sibiului",2748,45.8,23.733333 ],
    [ u"ro",u"Poiana Stampei",2315,47.316667,25.133333 ],
    [ u"ro",u"Poiana Teiului",5145,47.1,25.966667 ],
    [ u"ro",u"Poiana Vadului",1276,46.4,22.883333 ],
    [ u"ro",u"Poian",2886,46.066667,26.15 ],
    [ u"ro",u"Poienari",3273,46.9,27.133333 ],
    [ u"ro",u"Poienesti",3141,46.616667,27.533333 ],
    [ u"ro",u"Poienile de sub Munte",9865,47.816667,24.433333 ],
    [ u"ro",u"Poienile Izei",1016,47.7,24.116667 ],
    [ u"ro",u"Poieni",5719,46.916667,22.9 ],
    [ u"ro",u"Pojejena",3187,44.774167,21.579167 ],
    [ u"ro",u"Pojorata",3107,47.516667,25.45 ],
    [ u"ro",u"Polovragi",2911,45.183333,23.8 ],
    [ u"ro",u"Pomarla",2964,48.066667,26.316667 ],
    [ u"ro",u"Pomezeu",3310,46.783333,22.283333 ],
    [ u"ro",u"Pomi",2312,47.7,23.316667 ],
    [ u"ro",u"Ponoarele",2906,44.973889,22.764444 ],
    [ u"ro",u"Ponor",702,46.333333,23.416667 ],
    [ u"ro",u"Popesti-Leordeni",15279,44.383333,26.166667 ],
    [ u"ro",u"Popesti",4104,44.766667,25.066667 ],
    [ u"ro",u"Popesti",8386,47.233333,22.416667 ],
    [ u"ro",u"Popesti",4143,47.15,27.233333 ],
    [ u"ro",u"Popesti",3164,44.983333,24.1 ],
    [ u"ro",u"Poplaca",1742,45.716667,24.05 ],
    [ u"ro",u"Popricani",6752,47.3,27.516667 ],
    [ u"ro",u"Poroina Mare",1384,44.495278,22.936389 ],
    [ u"ro",u"Poroschia",4544,43.933333,25.366667 ],
    [ u"ro",u"Porumbacu de Jos",3166,45.75,24.45 ],
    [ u"ro",u"Posta Calnau",5982,45.233333,26.85 ],
    [ u"ro",u"Potcoava",6022,44.483333,24.65 ],
    [ u"ro",u"Potlogi",8299,44.55,25.583333 ],
    [ u"ro",u"Praid",6738,46.55,25.133333 ],
    [ u"ro",u"Prajeni",3265,47.516667,27.016667 ],
    [ u"ro",u"Predeal",5270,45.5,25.566667 ],
    [ u"ro",u"Predesti",3433,44.35,23.6 ],
    [ u"ro",u"Prejmer",8106,45.716667,25.766667 ],
    [ u"ro",u"Preutesti",9048,47.45,26.416667 ],
    [ u"ro",u"Priboieni",3583,44.883333,25.083333 ],
    [ u"ro",u"Prigoria",3481,45.066667,23.683333 ],
    [ u"ro",u"Prigor",2880,44.938333,22.113333 ],
    [ u"ro",u"Prim Decembrie",9537,44.290833,26.058056 ],
    [ u"ro",u"Priponesti",2574,46.083333,27.433333 ],
    [ u"ro",u"Prisacani",3578,47.083333,27.883333 ],
    [ u"ro",u"Priseaca",1920,44.516667,24.45 ],
    [ u"ro",u"Pristol",1774,44.224722,22.709167 ],
    [ u"ro",u"Probota",3685,47.383333,27.5 ],
    [ u"ro",u"Produlesti",3546,44.7,25.5 ],
    [ u"ro",u"Provita de Jos",2513,45.116667,25.65 ],
    [ u"ro",u"Provita de Sus",2333,45.133333,25.633333 ],
    [ u"ro",u"Prundeni",4596,44.733333,24.266667 ],
    [ u"ro",u"Prundu",4708,44.094722,26.226944 ],
    [ u"ro",u"Prunisor",2531,44.609444,22.915278 ],
    [ u"ro",u"Puchenii Mari",8869,44.816667,26.083333 ],
    [ u"ro",u"Pucheni",2201,45.183333,25.283333 ],
    [ u"ro",u"Pucioasa",14971,45.083333,25.416667 ],
    [ u"ro",u"Pufesti",4179,46,27.2 ],
    [ u"ro",u"Puiesti",5050,46.416667,27.5 ],
    [ u"ro",u"Pui",4680,45.516667,23.1 ],
    [ u"ro",u"Pungesti",3453,46.7,27.333333 ],
    [ u"ro",u"Punghina",3322,44.281944,22.934722 ],
    [ u"ro",u"Putineiu",2822,43.9,24.966667 ],
    [ u"ro",u"Putna",3727,47.866667,25.616667 ],
    [ u"ro",u"Rabagani",2269,46.75,22.233333 ],
    [ u"ro",u"Racaciuni",7839,46.333333,26.983333 ],
    [ u"ro",u"Racari",6828,44.633333,25.733333 ],
    [ u"ro",u"Racasdia",2101,44.993056,21.618056 ],
    [ u"ro",u"Rachiti",4333,47.766667,26.683333 ],
    [ u"ro",u"Rachitoasa",5009,46.433333,27.366667 ],
    [ u"ro",u"Rachitova",1467,45.6,22.75 ],
    [ u"ro",u"Raciu",3694,46.683333,24.4 ],
    [ u"ro",u"Racoasa",3463,46,26.883333 ],
    [ u"ro",u"Racos",3077,46.083333,25.533333 ],
    [ u"ro",u"Racova",3488,46.7,26.75 ],
    [ u"ro",u"Racovita",1395,45.3,27.45 ],
    [ u"ro",u"Racovita",2824,45.683333,24.35 ],
    [ u"ro",u"Racovita",3260,45.698333,21.635833 ],
    [ u"ro",u"Racovita",1824,45.416667,24.316667 ],
    [ u"ro",u"Racoviteni",1462,45.366667,26.9 ],
    [ u"ro",u"Radaseni",4404,47.466667,26.25 ],
    [ u"ro",u"Radauti",27241,47.85,25.916667 ],
    [ u"ro",u"Radesti",1379,46.266667,23.716667 ],
    [ u"ro",u"Radomiresti",3995,44.116667,24.683333 ],
    [ u"ro",u"Radovan",3259,44.166667,23.616667 ],
    [ u"ro",u"Radovanu",5065,44.2,26.516667 ],
    [ u"ro",u"Raducaneni",7706,46.95,27.933333 ],
    [ u"ro",u"Ramet",734,46.3,23.533333 ],
    [ u"ro",u"Ramna",1721,45.438333,21.688333 ],
    [ u"ro",u"Ramnicelu",2286,45.283333,27.533333 ],
    [ u"ro",u"Ramnicu Sarat",38526,45.383333,27.05 ],
    [ u"ro",u"Ramnicu Valcea",107558,45.1,24.366667 ],
    [ u"ro",u"Rapoltu Mare",2040,45.866667,23.066667 ],
    [ u"ro",u"Rasca",5127,47.366667,26.233333 ],
    [ u"ro",u"Rasinari",5403,45.7,24.066667 ],
    [ u"ro",u"Rasmiresti",1163,43.983333,25.55 ],
    [ u"ro",u"Rasnov",15253,45.583333,25.45 ],
    [ u"ro",u"Rasova",3909,44.25,27.933333 ],
    [ u"ro",u"Rastolita",2193,46.983333,25.033333 ],
    [ u"ro",u"Rastu",3757,43.883333,23.283333 ],
    [ u"ro",u"Rasuceni",3090,44.091667,25.663889 ],
    [ u"ro",u"Ratesti",3368,44.733333,25.133333 ],
    [ u"ro",u"Raucesti",8204,47.25,26.416667 ],
    [ u"ro",u"Rauseni",2987,47.566667,27.2 ],
    [ u"ro",u"Razboieni",2381,47.083333,26.533333 ],
    [ u"ro",u"Razvad",8305,44.933333,25.533333 ],
    [ u"ro",u"Rebra",3028,47.316667,24.5 ],
    [ u"ro",u"Rebricea",3605,46.866667,27.55 ],
    [ u"ro",u"Rebrisoara",4638,47.283333,24.45 ],
    [ u"ro",u"Recas",8508,45.798889,21.500833 ],
    [ u"ro",u"Recea Cristur",1680,47.066667,23.533333 ],
    [ u"ro",u"Recea",3213,45.716667,24.933333 ],
    [ u"ro",u"Recea",5360,47.633333,23.516667 ],
    [ u"ro",u"Recea",3229,44.533333,25.016667 ],
    [ u"ro",u"Reci",2204,45.85,25.933333 ],
    [ u"ro",u"Redea",3217,44.05,24.3 ],
    [ u"ro",u"Rediu",3855,45.716667,27.833333 ],
    [ u"ro",u"Rediu",6548,47.216667,27.5 ],
    [ u"ro",u"Rediu",5182,46.75,26.566667 ],
    [ u"ro",u"Reghin",35490,46.766667,24.7 ],
    [ u"ro",u"Reghiu",2677,45.783333,26.833333 ],
    [ u"ro",u"Remetea Chioarului",2965,47.533333,23.55 ],
    [ u"ro",u"Remetea Mare",3473,45.779444,21.376111 ],
    [ u"ro",u"Remetea",3084,46.733333,22.35 ],
    [ u"ro",u"Remetea",6225,46.783333,25.45 ],
    [ u"ro",u"Remeti",3001,47.983333,23.633333 ],
    [ u"ro",u"Repedea",4688,47.833333,24.4 ],
    [ u"ro",u"Resita",81229,45.300833,21.889167 ],
    [ u"ro",u"Reviga",3337,44.716667,27.1 ],
    [ u"ro",u"Ribita",1579,46.183333,22.766667 ],
    [ u"ro",u"Rimetea",1191,46.45,23.566667 ],
    [ u"ro",u"Ripiceni",2259,47.95,27.133333 ],
    [ u"ro",u"Roata de Jos",8350,44.410833,25.543333 ],
    [ u"ro",u"Robeasca",1290,45.166667,27.133333 ],
    [ u"ro",u"Rociu",2980,44.666667,25.033333 ],
    [ u"ro",u"Rodna",6218,47.416667,24.816667 ],
    [ u"ro",u"Roesti",2280,44.916667,24.083333 ],
    [ u"ro",u"Rogova",1464,44.471667,22.806667 ],
    [ u"ro",u"Romanesti",2026,47.283333,27.316667 ],
    [ u"ro",u"Romani",4597,46.783333,26.683333 ],
    [ u"ro",u"Roman",67820,46.916667,26.916667 ],
    [ u"ro",u"Romanu",1913,45.283333,27.733333 ],
    [ u"ro",u"Roma",3218,47.833333,26.6 ],
    [ u"ro",u"Romos",2824,45.833333,23.283333 ],
    [ u"ro",u"Romuli",1737,47.533333,24.433333 ],
    [ u"ro",u"Rona de Jos",2089,47.916667,24.016667 ],
    [ u"ro",u"Rona de Sus",4630,47.9,24.05 ],
    [ u"ro",u"Roseti",5843,44.216667,27.433333 ],
    [ u"ro",u"Rosia de Amaradia",3463,45.05,23.75 ],
    [ u"ro",u"Rosia de Secas",1660,46.05,23.883333 ],
    [ u"ro",u"Rosia Montana",3776,46.3,23.133333 ],
    [ u"ro",u"Rosia",2594,46.8,22.4 ],
    [ u"ro",u"Rosia",4733,45.816667,24.316667 ],
    [ u"ro",u"Rosiesti",3769,46.433333,27.883333 ],
    [ u"ro",u"Rosiile",2985,44.866667,23.933333 ],
    [ u"ro",u"Rosiori de Vede",30774,44.116667,24.983333 ],
    [ u"ro",u"Rosiori",2137,46.716667,27.083333 ],
    [ u"ro",u"Rosiori",3083,44.8,27.383333 ],
    [ u"ro",u"Rotunda",3194,43.983333,24.316667 ],
    [ u"ro",u"Rovinari",12259,44.916667,23.183333 ],
    [ u"ro",u"Rozavlea",6076,47.733333,24.216667 ],
    [ u"ro",u"Roznov",8688,46.833333,26.516667 ],
    [ u"ro",u"Rucar",6142,45.4,25.166667 ],
    [ u"ro",u"Ruginesti",4438,46.066667,27.116667 ],
    [ u"ro",u"Ruginoasa",6220,47.25,26.85 ],
    [ u"ro",u"Runcu",5760,45.116667,23.133333 ],
    [ u"ro",u"Runcu",1138,45.166667,24.45 ],
    [ u"ro",u"Runcu",4435,45.183333,25.383333 ],
    [ u"ro",u"Rupea",5610,46.033333,25.216667 ],
    [ u"ro",u"Rusanesti",4819,43.933333,24.6 ],
    [ u"ro",u"Rusca Montana",2023,45.566667,22.45 ],
    [ u"ro",u"Ruscova",4760,47.8,24.283333 ],
    [ u"ro",u"Rusetu",4254,44.95,27.216667 ],
    [ u"ro",u"Rusii Munti",2216,46.916667,24.85 ],
    [ u"ro",u"Rus",2608,47.283333,23.6 ],
    [ u"ro",u"Sabaoani",10218,47.016667,26.85 ],
    [ u"ro",u"Sacadat",1882,47.033333,22.15 ],
    [ u"ro",u"Sacalaseni",5733,47.583333,23.566667 ],
    [ u"ro",u"Sacalaz",6176,45.758333,21.112222 ],
    [ u"ro",u"Sacaseni",1319,47.483333,22.683333 ],
    [ u"ro",u"Sacele",29918,45.616667,25.683333 ],
    [ u"ro",u"Sacele",2196,44.483333,28.65 ],
    [ u"ro",u"Sacel",3723,47.633333,24.433333 ],
    [ u"ro",u"Sacel",1303,46.3,24.933333 ],
    [ u"ro",u"Sacelu",1834,45.1,23.533333 ],
    [ u"ro",u"Saceni",1661,44.233333,25.066667 ],
    [ u"ro",u"Sacosu Turcesc",3121,45.651944,21.428889 ],
    [ u"ro",u"Sacueni",11443,47.35,22.1 ],
    [ u"ro",u"Sacuieu",1617,46.833333,22.933333 ],
    [ u"ro",u"Sacu",1629,45.566667,22.116667 ],
    [ u"ro",u"Sadova",8277,43.9,23.95 ],
    [ u"ro",u"Sadova",2474,47.533333,25.5 ],
    [ u"ro",u"Sadu",2430,45.666667,24.183333 ],
    [ u"ro",u"Sageata",5427,45.1,26.983333 ],
    [ u"ro",u"Sagna",7443,46.983333,27.016667 ],
    [ u"ro",u"Sag",3391,47.083333,22.816667 ],
    [ u"ro",u"Sag",4461,45.648611,21.175556 ],
    [ u"ro",u"Sagu",3797,46.05,21.283333 ],
    [ u"ro",u"Sahateni",3333,45.033333,26.516667 ],
    [ u"ro",u"Salacea",3138,47.466667,22.316667 ],
    [ u"ro",u"Salard",4109,47.216667,22.05 ],
    [ u"ro",u"Salasu de Sus",2748,45.516667,22.95 ],
    [ u"ro",u"Salatig",3094,47.366667,23.133333 ],
    [ u"ro",u"Salatrucel",2206,45.25,24.383333 ],
    [ u"ro",u"Salatrucu",2251,45.333333,24.516667 ],
    [ u"ro",u"Salcea",8655,47.65,26.366667 ],
    [ u"ro",u"Salcia",3337,44.140833,22.927778 ],
    [ u"ro",u"Salcia",1189,45.183333,26.333333 ],
    [ u"ro",u"Salcia Tudor",3017,45.366667,27.516667 ],
    [ u"ro",u"Salciile",2286,44.816667,26.483333 ],
    [ u"ro",u"Salcioara",2595,44.533333,26.883333 ],
    [ u"ro",u"Salcioara",4125,44.716667,25.583333 ],
    [ u"ro",u"Salcuta",2509,44.25,23.433333 ],
    [ u"ro",u"Salistea de Sus",5119,47.65,24.35 ],
    [ u"ro",u"Salistea",2328,45.9,23.4 ],
    [ u"ro",u"Saliste",5660,45.783333,23.883333 ],
    [ u"ro",u"Salonta",17562,46.8,21.65 ],
    [ u"ro",u"Salsig",3097,47.533333,23.3 ],
    [ u"ro",u"Salva",4368,47.3,24.35 ],
    [ u"ro",u"Samarinesti",1949,44.75,23.05 ],
    [ u"ro",u"Sambata",1641,46.8,22.2 ],
    [ u"ro",u"Samburesti",1458,44.8,24.416667 ],
    [ u"ro",u"Samsud",1725,47.35,22.95 ],
    [ u"ro",u"Sanandrei",5302,45.853056,21.168056 ],
    [ u"ro",u"Sancel",2735,46.2,23.95 ],
    [ u"ro",u"Sancraieni",6105,46.3,25.85 ],
    [ u"ro",u"Sancraiul-de-Mures",6161,46.55,24.5 ],
    [ u"ro",u"Sancraiu",1826,46.833333,22.983333 ],
    [ u"ro",u"Sandominic",6306,46.583333,25.783333 ],
    [ u"ro",u"Sanduleni",4287,46.45,26.733333 ],
    [ u"ro",u"Sandulesti",1856,46.583333,23.716667 ],
    [ u"ro",u"Sangeorg-de Mures",7776,46.566667,24.6 ],
    [ u"ro",u"Sangeorgiu-de-Padure",5398,46.433333,24.833333 ],
    [ u"ro",u"Sangeorz-Bai",10254,47.366667,24.683333 ],
    [ u"ro",u"Sanger",2491,46.55,24.133333 ],
    [ u"ro",u"Sangeru",5271,45.133333,26.35 ],
    [ u"ro",u"Sanislau",5072,47.633333,22.333333 ],
    [ u"ro",u"Sanmartin",1721,46.9,23.566667 ],
    [ u"ro",u"Sanmartin",4272,46.266667,25.933333 ],
    [ u"ro",u"Sanmihaiu de Campie",1614,46.9,24.333333 ],
    [ u"ro",u"Sanmihaiul-Almasului",1758,47.016667,23.3 ],
    [ u"ro",u"Sanmihaiu Roman",4343,45.704444,21.088889 ],
    [ u"ro",u"Sannicolaul Mare",12888,46.083333,20.633333 ],
    [ u"ro",u"Sanpaul",2523,46.883333,23.416667 ],
    [ u"ro",u"Sanpaul",3959,46.45,24.35 ],
    [ u"ro",u"Sanpetru-de-Campie",3142,46.716667,24.266667 ],
    [ u"ro",u"Sanpetrul-Mare",5782,46.05,20.666667 ],
    [ u"ro",u"Sansimion",3397,46.25,25.883333 ],
    [ u"ro",u"Santamaria Orlea",3485,45.583333,22.966667 ],
    [ u"ro",u"Santa-Maria",3062,47.616667,27.35 ],
    [ u"ro",u"Santana-de-Mures",4201,46.566667,24.55 ],
    [ u"ro",u"Santana",12706,46.35,21.5 ],
    [ u"ro",u"Santandrei",3902,47.066667,21.866667 ],
    [ u"ro",u"Santau",2580,47.516667,22.516667 ],
    [ u"ro",u"Santimbru",2679,46.133333,23.65 ],
    [ u"ro",u"Sant",3312,47.45,24.9 ],
    [ u"ro",u"Sanzieni",4634,46.05,26.133333 ],
    [ u"ro",u"Sapanta",3234,47.966667,23.7 ],
    [ u"ro",u"Sapoca",3156,45.25,26.75 ],
    [ u"ro",u"Saraiu",1464,44.716667,28.15 ],
    [ u"ro",u"Sarasau",2379,47.95,23.816667 ],
    [ u"ro",u"Sarbeni",1740,44.466667,25.383333 ],
    [ u"ro",u"Sarbi",2943,47.183333,22.133333 ],
    [ u"ro",u"Sarichioi",7483,44.95,28.85 ],
    [ u"ro",u"Sarmasag",6400,47.35,22.833333 ],
    [ u"ro",u"Sarmas",4074,46.883333,25.466667 ],
    [ u"ro",u"Sarmasu",7371,46.75,24.166667 ],
    [ u"ro",u"Sarmizegetusa",1369,45.516667,22.783333 ],
    [ u"ro",u"Saru Dornei",4301,47.283333,25.35 ],
    [ u"ro",u"Sarulesti",1559,45.5,26.75 ],
    [ u"ro",u"Sarulesti",3134,44.416667,26.65 ],
    [ u"ro",u"Sasca Montana",1830,44.882778,21.703889 ],
    [ u"ro",u"Saschiz",2009,46.183333,24.966667 ],
    [ u"ro",u"Sasciori",5822,45.866667,23.583333 ],
    [ u"ro",u"Sascut",10031,46.183333,27.066667 ],
    [ u"ro",u"Satchinez",4586,45.9375,21.040556 ],
    [ u"ro",u"Satulung",5334,47.566667,23.433333 ],
    [ u"ro",u"Satu Mare",112491,47.8,22.883333 ],
    [ u"ro",u"Satu Mare",4091,47.833333,26.016667 ],
    [ u"ro",u"Sauca",1434,47.466667,22.483333 ],
    [ u"ro",u"Saucesti",4042,46.616667,26.933333 ],
    [ u"ro",u"Saulesti",2452,44.8,23.483333 ],
    [ u"ro",u"Saulia",2083,46.633333,24.216667 ],
    [ u"ro",u"Savadisla",4433,46.683333,23.45 ],
    [ u"ro",u"Saveni",8126,47.95,26.866667 ],
    [ u"ro",u"Saveni",5579,44.6,27.65 ],
    [ u"ro",u"Savinesti",6012,46.85,26.466667 ],
    [ u"ro",u"Scaesti",2294,44.466667,23.583333 ],
    [ u"ro",u"Scanteia",4245,46.916667,27.566667 ],
    [ u"ro",u"Scanteiesti",2707,45.683333,27.983333 ],
    [ u"ro",u"Scarisoara",1808,46.466667,22.85 ],
    [ u"ro",u"Scarisoara",3221,44,24.566667 ],
    [ u"ro",u"Scheia",4742,46.933333,27.516667 ],
    [ u"ro",u"Scheia",7533,47.65,26.233333 ],
    [ u"ro",u"Schela",3548,45.5,27.816667 ],
    [ u"ro",u"Schela",1993,45.166667,23.3 ],
    [ u"ro",u"Schitu-Duca",4347,47.033333,27.766667 ],
    [ u"ro",u"Schitu-Golesti",4945,45.2,25 ],
    [ u"ro",u"Schitu",3112,44.35,24.566667 ],
    [ u"ro",u"Schitu",2227,44.140833,25.836667 ],
    [ u"ro",u"Scoarta",4973,45.016667,23.45 ],
    [ u"ro",u"Scobinti",7618,47.383333,26.933333 ],
    [ u"ro",u"Scornicesti",12456,44.566667,24.55 ],
    [ u"ro",u"Scortaru Nou",1483,45.316667,27.6 ],
    [ u"ro",u"Scorteni",3159,46.55,26.65 ],
    [ u"ro",u"Scorteni",5995,45.1,25.85 ],
    [ u"ro",u"Scortoasa",3374,45.366667,26.666667 ],
    [ u"ro",u"Scrioastea",4244,44.15,24.95 ],
    [ u"ro",u"Scundu",2203,44.833333,24.2 ],
    [ u"ro",u"Scurtu Mare",2066,44.35,25.266667 ],
    [ u"ro",u"Scutelnici",2615,44.85,26.916667 ],
    [ u"ro",u"Seaca de Camp",2238,43.933333,23.216667 ],
    [ u"ro",u"Seaca de Padure",1370,44.366667,23.3 ],
    [ u"ro",u"Seaca",2302,44.166667,24.75 ],
    [ u"ro",u"Sebes",27246,45.966667,23.566667 ],
    [ u"ro",u"Secaria",1341,45.283333,25.683333 ],
    [ u"ro",u"Secas",301,45.885,21.819167 ],
    [ u"ro",u"Secuieni",4375,46.65,27.1 ],
    [ u"ro",u"Secu",1319,44.466667,23.3 ],
    [ u"ro",u"Secusigiu",5748,46.083333,20.983333 ],
    [ u"ro",u"Segarcea",7944,44.1,23.75 ],
    [ u"ro",u"Segarcea Vale",3768,43.816667,24.8 ],
    [ u"ro",u"Seica Mare",4739,46.016667,24.15 ],
    [ u"ro",u"Seica Mica",1709,46.05,24.133333 ],
    [ u"ro",u"Seimeni",2239,44.383333,28.066667 ],
    [ u"ro",u"Seini",10382,47.75,23.283333 ],
    [ u"ro",u"Seitin",2943,46.1,20.85 ],
    [ u"ro",u"Selaru",3924,44.466667,25.3 ],
    [ u"ro",u"Seleus",3140,46.383333,21.716667 ],
    [ u"ro",u"Selimbar",4829,45.766667,24.2 ],
    [ u"ro",u"Semlac",3727,46.116667,20.933333 ],
    [ u"ro",u"Sendreni",3126,45.4,27.916667 ],
    [ u"ro",u"Sendriceni",4200,47.95,26.3 ],
    [ u"ro",u"Serbanesti",3120,44.333333,24.7 ],
    [ u"ro",u"Sercaia",2988,45.833333,25.133333 ],
    [ u"ro",u"Sfantu Gheorghe",979,44.883333,29.6 ],
    [ u"ro",u"Sfintesti",1437,44.183333,25.1 ],
    [ u"ro",u"Sibiu",151895,45.8,24.15 ],
    [ u"ro",u"Sibot",2427,45.95,23.333333 ],
    [ u"ro",u"Sichevita",2643,44.735,21.848611 ],
    [ u"ro",u"Sic",2725,46.933333,23.883333 ],
    [ u"ro",u"Sicula",4503,46.433333,21.75 ],
    [ u"ro",u"Siculeni",6806,46.416667,25.75 ],
    [ u"ro",u"Sieu-Magherus",3830,47.083333,24.383333 ],
    [ u"ro",u"Sieu-Odorhei",2526,47.15,24.316667 ],
    [ u"ro",u"Sieu",3103,46.983333,24.65 ],
    [ u"ro",u"Sieut",2754,46.983333,24.65 ],
    [ u"ro",u"Sighetu Marmatiei",40654,47.933333,23.883333 ],
    [ u"ro",u"Sighisoara",31429,46.216667,24.8 ],
    [ u"ro",u"Sihlea",5354,45.5,27.116667 ],
    [ u"ro",u"Silindia",943,46.35,21.916667 ],
    [ u"ro",u"Silistea Crucii",1826,44.033333,23.483333 ],
    [ u"ro",u"Silistea",1855,45.3,27.85 ],
    [ u"ro",u"Silistea",1442,44.4,28.166667 ],
    [ u"ro",u"Silistea",4391,44.383333,25.35 ],
    [ u"ro",u"Simand",4064,46.433333,21.45 ],
    [ u"ro",u"Simeria",13827,45.85,23.016667 ],
    [ u"ro",u"Simian",3977,47.483333,22.1 ],
    [ u"ro",u"Simian",9434,44.614167,22.707222 ],
    [ u"ro",u"Siminicea",3107,47.7,26.4 ],
    [ u"ro",u"Simleu Silvaniei",15721,47.233333,22.8 ],
    [ u"ro",u"Simnicu de Sus",4380,44.383333,23.8 ],
    [ u"ro",u"Simonesti",3685,46.333333,25.1 ],
    [ u"ro",u"Sinaia",11918,45.35,25.55 ],
    [ u"ro",u"Sincai",1614,46.65,24.383333 ],
    [ u"ro",u"Sinesti",4264,47.116667,27.183333 ],
    [ u"ro",u"Sinesti",2636,44.95,23.85 ],
    [ u"ro",u"Sinesti",2575,44.566667,26.383333 ],
    [ u"ro",u"Singureni",3477,44.233611,25.943333 ],
    [ u"ro",u"Sintea Mare",3609,46.516667,21.6 ],
    [ u"ro",u"Sintereag",3806,47.183333,24.3 ],
    [ u"ro",u"Sinteu",1267,47.15,22.483333 ],
    [ u"ro",u"Sipote",5800,47.466667,27.216667 ],
    [ u"ro",u"Siretel",4046,47.4,26.733333 ],
    [ u"ro",u"Siret",9247,47.95,26.066667 ],
    [ u"ro",u"Siria",8004,46.266667,21.633333 ],
    [ u"ro",u"Sirineasa",2571,44.933333,24.2 ],
    [ u"ro",u"Sirna",5331,44.8,25.95 ],
    [ u"ro",u"Sisesti",5403,47.633333,23.7 ],
    [ u"ro",u"Sisesti",3129,44.7775,22.839444 ],
    [ u"ro",u"Sistarovat",374,46.016667,21.733333 ],
    [ u"ro",u"Sita Buzaului",4788,45.65,26.066667 ],
    [ u"ro",u"Slanic-Moldova",4955,46.2,26.433333 ],
    [ u"ro",u"Slanic",6967,45.25,25.933333 ],
    [ u"ro",u"Slatina",78989,44.433333,24.366667 ],
    [ u"ro",u"Slatina",5196,47.45,26.016667 ],
    [ u"ro",u"Slatina-Timis",3037,45.25,22.283333 ],
    [ u"ro",u"Slatioara",3575,45.116667,23.916667 ],
    [ u"ro",u"Slatioara",2528,44.4,24.316667 ],
    [ u"ro",u"Slimnic",3592,45.916667,24.166667 ],
    [ u"ro",u"Slivilesti",3778,44.783333,23.133333 ],
    [ u"ro",u"Slobozia Bradului",5060,45.5,27.05 ],
    [ u"ro",u"Slobozia-Ciorasti",2077,45.616667,27.2 ],
    [ u"ro",u"Slobozia-Conachi",7234,45.583333,27.783333 ],
    [ u"ro",u"Slobozia-Mandra",4159,43.916667,24.7 ],
    [ u"ro",u"Slobozia Moara",2340,44.6,25.716667 ],
    [ u"ro",u"Slobozia",52693,44.566667,27.366667 ],
    [ u"ro",u"Slobozia",2626,43.85,25.9 ],
    [ u"ro",u"Smardan",3961,45.483333,27.933333 ],
    [ u"ro",u"Smardioasa",2658,43.85,25.433333 ],
    [ u"ro",u"Smeeni",7015,44.983333,26.85 ],
    [ u"ro",u"Smulti",1611,45.933333,27.75 ],
    [ u"ro",u"Snagov",6126,44.7,26.183333 ],
    [ u"ro",u"Soars",1870,45.933333,24.916667 ],
    [ u"ro",u"Socodor",2248,46.516667,21.433333 ],
    [ u"ro",u"Socol",2226,44.860833,21.370278 ],
    [ u"ro",u"Socond",2535,47.566667,22.95 ],
    [ u"ro",u"Sofronea",2527,46.266667,21.3 ],
    [ u"ro",u"Sohatu",3511,44.316667,26.5 ],
    [ u"ro",u"Sohodol",2038,46.35,23.033333 ],
    [ u"ro",u"Soimari",3127,45.183333,26.2 ],
    [ u"ro",u"Soimi",2951,46.683333,22.116667 ],
    [ u"ro",u"Soimus",3502,45.916667,22.9 ],
    [ u"ro",u"Solca",4391,47.7,25.85 ],
    [ u"ro",u"Soldanu",3488,44.216667,26.516667 ],
    [ u"ro",u"Solesti",3862,46.766667,27.783333 ],
    [ u"ro",u"Solont",3866,46.55,26.516667 ],
    [ u"ro",u"Solovastru",2800,46.766667,24.766667 ],
    [ u"ro",u"Somcuta Mare",7584,47.516667,23.466667 ],
    [ u"ro",u"Somes-Odorhei",2993,47.316667,23.266667 ],
    [ u"ro",u"Somova",4463,45.183333,28.666667 ],
    [ u"ro",u"Sona",4425,46.216667,24.016667 ],
    [ u"ro",u"Sopot",1985,44.416667,23.5 ],
    [ u"ro",u"Sopotu Nou",1397,44.841944,21.862778 ],
    [ u"ro",u"Sotanga",6939,44.983333,25.366667 ],
    [ u"ro",u"Sotrile",3530,45.216667,25.716667 ],
    [ u"ro",u"Sovarna",1416,44.853611,22.7925 ],
    [ u"ro",u"Sovata",11465,46.583333,25.066667 ],
    [ u"ro",u"Spantov",4616,44.116667,26.783333 ],
    [ u"ro",u"Spermezeu",2573,47.3,24.15 ],
    [ u"ro",u"Spineni",2359,44.7,24.566667 ],
    [ u"ro",u"Spinus",1245,47.2,22.2 ],
    [ u"ro",u"Sprancenata",2983,44.083333,24.633333 ],
    [ u"ro",u"Spring",2492,45.966667,23.783333 ],
    [ u"ro",u"Stalpeni",5088,45.05,24.966667 ],
    [ u"ro",u"Stalpu",3175,45.083333,26.716667 ],
    [ u"ro",u"Stanceni",1523,46.983333,25.233333 ],
    [ u"ro",u"Stancuta",3852,44.9,27.833333 ],
    [ u"ro",u"Stanesti",2647,45.116667,23.25 ],
    [ u"ro",u"Stanesti",3228,43.916667,25.833333 ],
    [ u"ro",u"Stangaceaua",1602,44.6,23.316667 ],
    [ u"ro",u"Stanilesti",5874,46.618333,28.171389 ],
    [ u"ro",u"Stanisesti",4684,46.433333,27.3 ],
    [ u"ro",u"Stanita",2203,47.016667,27.1 ],
    [ u"ro",u"Starchiojd",6592,45.316667,26.183333 ],
    [ u"ro",u"Stauceni",3279,47.716667,26.75 ],
    [ u"ro",u"Stefan cel Mare",2093,43.816667,24.216667 ],
    [ u"ro",u"Stefan cel Mare",3386,46.983333,26.516667 ],
    [ u"ro",u"Stefan cel Mare",3370,46.716667,27.633333 ],
    [ u"ro",u"Stefan cel Mare",2632,44.5,25.25 ],
    [ u"ro",u"Stefanestii de Jos",4183,44.533333,26.2 ],
    [ u"ro",u"Stefanesti",12837,44.866667,24.933333 ],
    [ u"ro",u"Stefanesti",5607,47.8,27.2 ],
    [ u"ro",u"Stefanesti",3663,44.616667,24.25 ],
    [ u"ro",u"Stefan Voda",2467,44.316667,27.316667 ],
    [ u"ro",u"Stefesti",2365,45.216667,25.9 ],
    [ u"ro",u"Stei",8320,46.533333,22.45 ],
    [ u"ro",u"Stejari",3046,44.766667,23.683333 ],
    [ u"ro",u"Stejaru",2301,44.766667,28.55 ],
    [ u"ro",u"Stejaru",2249,44.183333,24.883333 ],
    [ u"ro",u"Stelnica",1834,44.416667,27.883333 ],
    [ u"ro",u"Stiubieni",2853,47.966667,26.783333 ],
    [ u"ro",u"Stiuca",1821,45.571389,21.976667 ],
    [ u"ro",u"Stoenesti",2391,44.116667,24.5 ],
    [ u"ro",u"Stoenesti",3863,45.116667,24.166667 ],
    [ u"ro",u"Stoenesti",2540,44.144444,25.895 ],
    [ u"ro",u"Stoicanesti",3015,44.183333,24.633333 ],
    [ u"ro",u"Stoilesti",4316,44.9,24.383333 ],
    [ u"ro",u"Stoina",2791,44.683333,23.633333 ],
    [ u"ro",u"Stolniceni-Prajescu",5625,47.2,26.733333 ],
    [ u"ro",u"Stolnici",3784,44.566667,24.783333 ],
    [ u"ro",u"Storobaneasa",3645,43.883333,25.45 ],
    [ u"ro",u"Straja",5304,47.916667,25.55 ],
    [ u"ro",u"Stramtura",4156,47.783333,24.133333 ],
    [ u"ro",u"Straoane",4049,45.933333,27.05 ],
    [ u"ro",u"Strehaia",11607,44.616667,23.2 ],
    [ u"ro",u"Strejesti",3404,44.533333,24.266667 ],
    [ u"ro",u"Stremt",2761,46.216667,23.633333 ],
    [ u"ro",u"Stroesti",3076,45.083333,23.9 ],
    [ u"ro",u"Stroiesti",3524,47.616667,26.133333 ],
    [ u"ro",u"Strugari",2629,46.533333,26.716667 ],
    [ u"ro",u"Strunga",4508,47.166667,26.983333 ],
    [ u"ro",u"Studina",4723,43.966667,24.416667 ],
    [ u"ro",u"Stulpicani",6234,47.466667,25.766667 ],
    [ u"ro",u"Suatu",1923,46.766667,23.966667 ],
    [ u"ro",u"Subcetate",2075,46.85,25.45 ],
    [ u"ro",u"Suceava",105797,47.633333,26.25 ],
    [ u"ro",u"Suceveni",2160,46.012222,28.018056 ],
    [ u"ro",u"Sucevita",2584,47.783333,25.716667 ],
    [ u"ro",u"Suciu de Sus",6125,47.433333,24.033333 ],
    [ u"ro",u"Suditi",2281,44.583333,27.6 ],
    [ u"ro",u"Sugag",3175,45.766667,23.633333 ],
    [ u"ro",u"Suhaia",4744,43.733333,25.25 ],
    [ u"ro",u"Suharau",5356,48.133333,26.416667 ],
    [ u"ro",u"Suici",2897,45.25,24.533333 ],
    [ u"ro",u"Suletea",2535,46.283333,27.9 ],
    [ u"ro",u"Sulina",4443,45.15,29.666667 ],
    [ u"ro",u"Suncuius",3444,46.933333,22.533333 ],
    [ u"ro",u"Suplac",2332,46.383333,24.516667 ],
    [ u"ro",u"Suplacu de Barcau",4517,47.25,22.533333 ],
    [ u"ro",u"Supuru de Jos",4598,47.466667,22.8 ],
    [ u"ro",u"Suraia",7770,45.683333,27.4 ],
    [ u"ro",u"Sura Mare",3253,45.85,24.166667 ],
    [ u"ro",u"Sura Mica",2311,45.833333,24.066667 ],
    [ u"ro",u"Surani",1838,45.2,26.166667 ],
    [ u"ro",u"Surdila-Gaiseanca",2726,45.066667,27.333333 ],
    [ u"ro",u"Surdila-Greci",1635,45.066667,27.266667 ],
    [ u"ro",u"Surduc",3934,47.25,23.35 ],
    [ u"ro",u"Susani",3875,44.6,24.083333 ],
    [ u"ro",u"Susani",3875,44.583333,24.1 ],
    [ u"ro",u"Suseni",3492,44.716667,24.95 ],
    [ u"ro",u"Suseni",5079,46.666667,25.55 ],
    [ u"ro",u"Suseni",2282,46.816667,24.75 ],
    [ u"ro",u"Sutesti",4740,45.216667,27.433333 ],
    [ u"ro",u"Sutesti",3596,44.65,24.216667 ],
    [ u"ro",u"Svinita",1105,44.499722,22.106111 ],
    [ u"ro",u"Tacuta",3410,46.916667,27.683333 ],
    [ u"ro",u"Taga",2124,46.95,24.05 ],
    [ u"ro",u"Talea",1184,45.216667,25.55 ],
    [ u"ro",u"Talmaciu",8660,45.65,24.266667 ],
    [ u"ro",u"Tamadau Mare",2579,44.466667,26.55 ],
    [ u"ro",u"Tamaseni",8292,46.983333,26.933333 ],
    [ u"ro",u"Tamasi",6330,46.483333,26.983333 ],
    [ u"ro",u"Tamboesti",4565,45.516667,27.05 ],
    [ u"ro",u"Tamna",3656,44.566667,23.016667 ],
    [ u"ro",u"Tanacu",5986,46.683333,27.816667 ],
    [ u"ro",u"Tanasoaia",2341,46.1,27.366667 ],
    [ u"ro",u"Tandarei",12231,44.65,27.666667 ],
    [ u"ro",u"Tansa",3081,46.916667,27.233333 ],
    [ u"ro",u"Tantareni",5762,44.6,23.483333 ],
    [ u"ro",u"Tarcau",3504,46.866667,26.133333 ],
    [ u"ro",u"Tarcea",2652,47.45,22.183333 ],
    [ u"ro",u"Targoviste",88436,44.933333,25.45 ],
    [ u"ro",u"Targsorul-Vechi",8460,44.866667,25.916667 ],
    [ u"ro",u"Targu Bujor",7532,45.866667,27.9 ],
    [ u"ro",u"Targu Carbunesti",8646,44.95,23.516667 ],
    [ u"ro",u"Targu Jiu",97178,45.05,23.283333 ],
    [ u"ro",u"Targu-Lapus",13145,47.45,23.866667 ],
    [ u"ro",u"Targu-Mures",146864,46.55,24.566667 ],
    [ u"ro",u"Targu-Neamt",20473,47.2,26.366667 ],
    [ u"ro",u"Targu Ocna",13127,46.283333,26.616667 ],
    [ u"ro",u"Targusor",2937,44.45,28.416667 ],
    [ u"ro",u"Targu-Trotus",5305,46.266667,26.666667 ],
    [ u"ro",u"Tarlisua",3693,47.383333,24.183333 ],
    [ u"ro",u"Tarlungeni",7219,45.633333,25.75 ],
    [ u"ro",u"Tarnaveni",25721,46.333333,24.283333 ],
    [ u"ro",u"Tarnova",6146,46.316667,21.8 ],
    [ u"ro",u"Tarnova",1844,45.3425,22.006111 ],
    [ u"ro",u"Tarsolt",2973,47.95,23.35 ],
    [ u"ro",u"Tartasesti",5066,44.577222,25.812778 ],
    [ u"ro",u"Tasca",2682,46.9,26.016667 ],
    [ u"ro",u"Tasnad",9467,47.483333,22.583333 ],
    [ u"ro",u"Tatarani",5422,45,25.266667 ],
    [ u"ro",u"Tatarani",2551,46.7,27.966667 ],
    [ u"ro",u"Tataranu",4904,45.516667,27.316667 ],
    [ u"ro",u"Tatarastii de Jos",4228,44.366667,25.183333 ],
    [ u"ro",u"Tatarastii de Sus",3271,44.416667,25.116667 ],
    [ u"ro",u"Tatarasti",2630,46.216667,27.2 ],
    [ u"ro",u"Tatarusi",5651,47.35,26.6 ],
    [ u"ro",u"Tataru",1255,45.1,26.333333 ],
    [ u"ro",u"Tatulesti",1324,44.633333,24.633333 ],
    [ u"ro",u"Taureni",1033,46.266667,25.25 ],
    [ u"ro",u"Tauteu",4377,47.266667,22.333333 ],
    [ u"ro",u"Tautii Margheraus",6597,47.65,23.483333 ],
    [ u"ro",u"Taut",2139,46.283333,21.916667 ],
    [ u"ro",u"Tazlau",3002,46.716667,26.466667 ],
    [ u"ro",u"Teaca",5954,46.916667,24.516667 ],
    [ u"ro",u"Techirghiol",7083,44.05,28.6 ],
    [ u"ro",u"Tecuci",41154,45.866667,27.416667 ],
    [ u"ro",u"Teisani",3968,45.233333,25.983333 ],
    [ u"ro",u"Teius",7112,46.2,23.683333 ],
    [ u"ro",u"Teiu",1853,44.65,25.133333 ],
    [ u"ro",u"Telciu",5314,47.433333,24.4 ],
    [ u"ro",u"Telega",6358,45.133333,25.783333 ],
    [ u"ro",u"Telesti",2779,45.016667,23.083333 ],
    [ u"ro",u"Teliucu Inferior",2527,45.716667,22.883333 ],
    [ u"ro",u"Teliu",3610,45.7,25.85 ],
    [ u"ro",u"Tepu",2538,45.966667,27.366667 ],
    [ u"ro",u"Terebesti",1551,47.683333,22.716667 ],
    [ u"ro",u"Teregova",4207,45.15,22.283333 ],
    [ u"ro",u"Teremia Mare",4108,45.935278,20.525 ],
    [ u"ro",u"Terpezita",1952,44.283333,23.516667 ],
    [ u"ro",u"Teslui",2822,44.516667,24.366667 ],
    [ u"ro",u"Tetchea",3105,47.05,22.316667 ],
    [ u"ro",u"Tetoiu",2995,44.75,23.916667 ],
    [ u"ro",u"Tia Mare",4853,43.866667,24.633333 ],
    [ u"ro",u"Tibana",7098,46.983333,27.333333 ],
    [ u"ro",u"Tibanesti",7662,46.916667,27.333333 ],
    [ u"ro",u"Tibucani",4403,47.1,26.533333 ],
    [ u"ro",u"Tichilesti",4270,45.116667,27.9 ],
    [ u"ro",u"Ticleni",5250,44.883333,23.4 ],
    [ u"ro",u"Ticusul",849,45.933333,25.1 ],
    [ u"ro",u"Ticvaniu Mare",1894,45.135278,21.638056 ],
    [ u"ro",u"Tifesti",5202,45.85,27.1 ],
    [ u"ro",u"Tiganasi",4283,47.333333,27.466667 ],
    [ u"ro",u"Tiganesti",5397,43.9,25.366667 ],
    [ u"ro",u"Tigveni",3634,45.133333,24.583333 ],
    [ u"ro",u"Tileagd",6994,47.066667,22.2 ],
    [ u"ro",u"Tilisca",1656,45.8,23.85 ],
    [ u"ro",u"Timisesti",4004,47.233333,26.55 ],
    [ u"ro",u"Timisoara",315055,45.749444,21.227222 ],
    [ u"ro",u"Tinca",7335,46.766667,21.95 ],
    [ u"ro",u"Tinosu",2551,44.816667,26.016667 ],
    [ u"ro",u"Tintesti",4475,45.066667,26.866667 ],
    [ u"ro",u"Tiream",2317,47.616667,22.466667 ],
    [ u"ro",u"Tisau",5114,45.166667,26.516667 ],
    [ u"ro",u"Tismana",7751,45.05,22.966667 ],
    [ u"ro",u"Titesti",4581,45.016667,25 ],
    [ u"ro",u"Titu",10081,44.65,25.533333 ],
    [ u"ro",u"Todireni",3579,47.616667,27.116667 ],
    [ u"ro",u"Todiresti",6970,47.316667,26.833333 ],
    [ u"ro",u"Todiresti",5763,47.7,26.033333 ],
    [ u"ro",u"Todiresti",5388,46.85,27.366667 ],
    [ u"ro",u"Tomesti",1279,46.216667,22.65 ],
    [ u"ro",u"Tomesti",11828,47.116667,27.683333 ],
    [ u"ro",u"Tomsani",4550,44.95,26.283333 ],
    [ u"ro",u"Tomsani",4123,45.116667,24.05 ],
    [ u"ro",u"Topalu",1891,44.55,28.05 ],
    [ u"ro",u"Topana",1220,44.816667,24.516667 ],
    [ u"ro",u"Toplet",2812,44.797222,22.394444 ],
    [ u"ro",u"Topliceni",4374,45.416667,27 ],
    [ u"ro",u"Toplita",870,45.683333,22.783333 ],
    [ u"ro",u"Toplita",15663,46.916667,25.333333 ],
    [ u"ro",u"Topolog",4982,44.883333,28.366667 ],
    [ u"ro",u"Topolovatu Mare",2942,45.773889,21.618889 ],
    [ u"ro",u"Topoloveni",11039,44.816667,25.083333 ],
    [ u"ro",u"Toporu",2536,44.010556,25.652778 ],
    [ u"ro",u"Topraisar",5329,44.016667,28.45 ],
    [ u"ro",u"Tormac",2706,45.520833,21.493611 ],
    [ u"ro",u"Tortoman",1819,44.35,28.216667 ],
    [ u"ro",u"Totesti",1990,45.566667,22.883333 ],
    [ u"ro",u"Traian",4662,46.633333,27.033333 ],
    [ u"ro",u"Traian",3684,45.183333,27.733333 ],
    [ u"ro",u"Traian",3419,44.016667,24.45 ],
    [ u"ro",u"Traian",2170,43.766667,25 ],
    [ u"ro",u"Traian Vuia",2215,45.8,22.066667 ],
    [ u"ro",u"Treznea",1012,47.1,23.116667 ],
    [ u"ro",u"Trifesti",5232,47.45,27.516667 ],
    [ u"ro",u"Trifesti",5018,46.916667,26.816667 ],
    [ u"ro",u"Tritenii de Jos",5008,46.583333,24 ],
    [ u"ro",u"Trivalea-Mosteni",3359,44.266667,25.233333 ],
    [ u"ro",u"Troianul",3502,44,25 ],
    [ u"ro",u"Trusesti",5748,47.766667,27.016667 ],
    [ u"ro",u"Tudora",5139,47.516667,26.633333 ],
    [ u"ro",u"Tudor Vladimirescu",5327,45.216667,27.8 ],
    [ u"ro",u"Tudor Vladimirescu",5498,45.566667,27.65 ],
    [ u"ro",u"Tufeni",3286,44.366667,24.783333 ],
    [ u"ro",u"Tufesti",5784,45.05,27.816667 ],
    [ u"ro",u"Tuglui",2969,44.183333,23.816667 ],
    [ u"ro",u"Tulca",2849,46.783333,21.783333 ],
    [ u"ro",u"Tulcea",92475,45.166667,28.8 ],
    [ u"ro",u"Tulghes",3543,46.95,25.766667 ],
    [ u"ro",u"Tulnici",5803,45.916667,26.666667 ],
    [ u"ro",u"Tulucesti",7503,45.566667,28.033333 ],
    [ u"ro",u"Tunari",3859,44.55,26.15 ],
    [ u"ro",u"Tupilati",2388,47.066667,26.633333 ],
    [ u"ro",u"Turburea",4652,44.716667,23.516667 ],
    [ u"ro",u"Turceni",8458,44.683333,23.366667 ],
    [ u"ro",u"Turcinesti",2373,45.1,23.333333 ],
    [ u"ro",u"Turcoaia",3646,45.116667,28.183333 ],
    [ u"ro",u"Turdas",1931,45.85,23.116667 ],
    [ u"ro",u"Turda",54587,46.566667,23.783333 ],
    [ u"ro",u"Tureni",2545,46.616667,23.7 ],
    [ u"ro",u"Turia",3846,46.033333,26.05 ],
    [ u"ro",u"Turnu Magurele",28784,43.75,24.866667 ],
    [ u"ro",u"Turnu Rosu",2578,45.633333,24.3 ],
    [ u"ro",u"Turt",6693,47.983333,23.216667 ],
    [ u"ro",u"Turulung",3815,47.933333,23.083333 ],
    [ u"ro",u"Tusnad",2084,46.2,25.9 ],
    [ u"ro",u"Tutora",2126,47.133333,27.783333 ],
    [ u"ro",u"Tutova",5619,46.116667,27.55 ],
    [ u"ro",u"Tuzla",6292,44,28.633333 ],
    [ u"ro",u"Ucea",2069,45.733333,24.683333 ],
    [ u"ro",u"Uda",2567,44.916667,24.566667 ],
    [ u"ro",u"Udesti",7177,47.566667,26.416667 ],
    [ u"ro",u"Uivar",4378,45.658056,20.905833 ],
    [ u"ro",u"Uliesti",4494,44.583333,25.416667 ],
    [ u"ro",u"Ulies",1255,46.216667,25.233333 ],
    [ u"ro",u"Ulma",2285,47.883333,25.3 ],
    [ u"ro",u"Ulmeni",3283,45.066667,26.65 ],
    [ u"ro",u"Ulmeni",7047,47.466667,23.3 ],
    [ u"ro",u"Ulmeni",5285,44.15,26.716667 ],
    [ u"ro",u"Ulmi",3899,44.9,25.5 ],
    [ u"ro",u"Ulmi",7606,44.486667,25.780278 ],
    [ u"ro",u"Ulmu",1927,44.266667,26.916667 ],
    [ u"ro",u"Ulmu",4397,44.95,27.316667 ],
    [ u"ro",u"Umbraresti",7116,45.716667,27.466667 ],
    [ u"ro",u"Ungheni",3983,47.2,27.783333 ],
    [ u"ro",u"Ungheni",6449,46.483333,24.466667 ],
    [ u"ro",u"Ungheni",3678,44.5,24.966667 ],
    [ u"ro",u"Ungra",1983,45.983333,25.266667 ],
    [ u"ro",u"Unguras",3031,47.116667,24.05 ],
    [ u"ro",u"Ungureni",3728,46.516667,26.95 ],
    [ u"ro",u"Unirea",2550,45.116667,27.816667 ],
    [ u"ro",u"Unirea",5377,45.616667,22.883333 ],
    [ u"ro",u"Unirea",4225,44.15,23.183333 ],
    [ u"ro",u"Unirea",2954,44.266667,27.633333 ],
    [ u"ro",u"Unteni",3022,47.8,26.783333 ],
    [ u"ro",u"Urdari",3162,44.8,23.3 ],
    [ u"ro",u"Urecheni",4007,47.166667,26.516667 ],
    [ u"ro",u"Urechesti",3999,46.133333,27.083333 ],
    [ u"ro",u"Urechesti",5856,45.6,27.066667 ],
    [ u"ro",u"Uricani",9924,45.333333,23.15 ],
    [ u"ro",u"Uriu",3572,47.2,24.05 ],
    [ u"ro",u"Urlati",11798,44.983333,26.233333 ],
    [ u"ro",u"Urmenis",2253,46.766667,24.366667 ],
    [ u"ro",u"Urziceni",1479,47.733333,22.4 ],
    [ u"ro",u"Urziceni",16771,44.716667,26.633333 ],
    [ u"ro",u"Urzicuta",3118,44.016667,23.55 ],
    [ u"ro",u"Vacaresti",7812,44.85,25.483333 ],
    [ u"ro",u"Vaculesti",2247,47.883333,26.416667 ],
    [ u"ro",u"Vadastra",3631,43.866667,24.366667 ],
    [ u"ro",u"Vadastrita",3715,43.85,24.333333 ],
    [ u"ro",u"Vadeni",4173,45.366667,27.933333 ],
    [ u"ro",u"Vadu Crisului",4311,46.983333,22.516667 ],
    [ u"ro",u"Vadu Izei",2794,47.883333,23.95 ],
    [ u"ro",u"Vadu Moldovei",7325,47.383333,26.366667 ],
    [ u"ro",u"Vadu Motilor",1523,46.4,22.966667 ],
    [ u"ro",u"Vadu Pasii",9034,45.166667,26.9 ],
    [ u"ro",u"Vad",2118,47.2,23.75 ],
    [ u"ro",u"Vagiulesti",3113,44.716667,23.083333 ],
    [ u"ro",u"Vaideeni",4198,45.166667,23.933333 ],
    [ u"ro",u"Valcanesti",3924,45.116667,25.933333 ],
    [ u"ro",u"Valcau de Jos",3232,47.116667,22.733333 ],
    [ u"ro",u"Valcelele",1811,45.083333,26.633333 ],
    [ u"ro",u"Valcele",3646,45.85,25.683333 ],
    [ u"ro",u"Valea Argovei",2756,44.35,26.783333 ],
    [ u"ro",u"Valea Calugareasca",10378,44.966667,26.15 ],
    [ u"ro",u"Valea Chioarului",2252,47.433333,23.483333 ],
    [ u"ro",u"Valea Ciorii",1996,44.716667,27.566667 ],
    [ u"ro",u"Valea Crisului",3405,45.916667,25.766667 ],
    [ u"ro",u"Valea Danului",3089,45.183333,24.65 ],
    [ u"ro",u"Valea Dragului",3214,44.212222,26.303611 ],
    [ u"ro",u"Valea Iasului",2778,45.183333,24.716667 ],
    [ u"ro",u"Valea Ierii",1010,46.65,23.35 ],
    [ u"ro",u"Valea Larga",3326,46.616667,24.066667 ],
    [ u"ro",u"Valea lui Mihai",10240,47.516667,22.15 ],
    [ u"ro",u"Valea Lunga",3199,46.083333,22.783333 ],
    [ u"ro",u"Valea Lunga",5097,45.066667,25.55 ],
    [ u"ro",u"Valea Macrisului",2090,44.75,26.833333 ],
    [ u"ro",u"Valea Mare-Pravat",4210,45.283333,25.083333 ],
    [ u"ro",u"Valea Mare",1156,45.766667,26 ],
    [ u"ro",u"Valea Mare",2533,44.783333,25.233333 ],
    [ u"ro",u"Valea Mare",3165,44.666667,24 ],
    [ u"ro",u"Valea Mare",3961,44.466667,24.433333 ],
    [ u"ro",u"Valea Marului",3717,45.833333,27.683333 ],
    [ u"ro",u"Valea Moldovei",5814,47.466667,26.033333 ],
    [ u"ro",u"Valea Nucarilor",3968,45.033333,28.933333 ],
    [ u"ro",u"Valea Salciei",862,45.5,26.816667 ],
    [ u"ro",u"Valea Sarii",2093,45.883333,26.8 ],
    [ u"ro",u"Valea Seaca",3516,46.466667,26.866667 ],
    [ u"ro",u"Valea Seaca",5865,47.283333,26.666667 ],
    [ u"ro",u"Valea Stanciului",6264,43.983333,23.866667 ],
    [ u"ro",u"Valea Ursului",3916,46.816667,27.083333 ],
    [ u"ro",u"Valea Viilor",1991,46.083333,24.283333 ],
    [ u"ro",u"Valea Vinului",2221,47.716667,23.183333 ],
    [ u"ro",u"Valenii de Munte",13276,45.183333,26.033333 ],
    [ u"ro",u"Valeni",6723,46.592778,28.0625 ],
    [ u"ro",u"Valeni",3317,44.233333,24.783333 ],
    [ u"ro",u"Valisoara",1369,46.05,22.85 ],
    [ u"ro",u"Valiug",953,45.233333,22.033333 ],
    [ u"ro",u"Valu lui Traian",8733,44.166667,28.466667 ],
    [ u"ro",u"Vama Buzaului",3289,45.583333,25.983333 ],
    [ u"ro",u"Vama",3576,47.833333,23.4 ],
    [ u"ro",u"Vama",5995,47.566667,25.683333 ],
    [ u"ro",u"Vanatorii Mici",4965,44.490278,25.558889 ],
    [ u"ro",u"Vanatori-Neamt",8707,47.2,26.316667 ],
    [ u"ro",u"Vanatori",4126,45.533333,28.016667 ],
    [ u"ro",u"Vanatori",3702,46.233333,24.933333 ],
    [ u"ro",u"Vanatori",4782,47.233333,27.533333 ],
    [ u"ro",u"Vanatori",4570,44.242778,22.928889 ],
    [ u"ro",u"Vanatori",5521,45.733333,27.25 ],
    [ u"ro",u"Vanjulet",1894,44.441111,22.7925 ],
    [ u"ro",u"Varadia",1483,45.078333,21.546944 ],
    [ u"ro",u"Varasti",6412,44.237778,26.248611 ],
    [ u"ro",u"Varbilau",7084,45.183333,25.95 ],
    [ u"ro",u"Varciorog",2314,46.966667,22.3 ],
    [ u"ro",u"Varfurile",3247,46.316667,22.516667 ],
    [ u"ro",u"Vargata",1976,46.566667,24.8 ],
    [ u"ro",u"Varghis",1876,46.133333,25.533333 ],
    [ u"ro",u"Varias",6054,46.016667,20.95 ],
    [ u"ro",u"Varlezi",2185,45.9,27.85 ],
    [ u"ro",u"Varsag",1493,46.516667,25.35 ],
    [ u"ro",u"Varsolt",2406,47.2,22.933333 ],
    [ u"ro",u"Vartescoiu",3425,45.733333,27.083333 ],
    [ u"ro",u"Vartoapele-de-Jos",3201,44.183333,25.2 ],
    [ u"ro",u"Vartop",1818,44.2,23.35 ],
    [ u"ro",u"Varvoru",3344,44.233333,23.633333 ],
    [ u"ro",u"Vasilati",7840,44.287778,26.4475 ],
    [ u"ro",u"Vaslui",69226,46.633333,27.733333 ],
    [ u"ro",u"Vata de Jos",4239,46.183333,22.6 ],
    [ u"ro",u"Vatava",2099,46.966667,24.766667 ],
    [ u"ro",u"Vatra Dornei",16055,47.35,25.366667 ],
    [ u"ro",u"Vatra Moldovitei",4653,47.65,25.566667 ],
    [ u"ro",u"Vedea",4243,44.783333,24.616667 ],
    [ u"ro",u"Vedea",3108,44.083333,25.066667 ],
    [ u"ro",u"Vedea",5785,43.783333,25.783333 ],
    [ u"ro",u"Vela",2211,44.283333,23.416667 ],
    [ u"ro",u"Verbita",1583,44.3,23.166667 ],
    [ u"ro",u"Veresti",7089,47.6,26.433333 ],
    [ u"ro",u"Verguleasa",3439,44.65,24.316667 ],
    [ u"ro",u"Vermes",1705,45.520556,21.659722 ],
    [ u"ro",u"Vernesti",8603,45.216667,26.733333 ],
    [ u"ro",u"Vetca",849,46.35,24.783333 ],
    [ u"ro",u"Vetel",2722,45.9,22.816667 ],
    [ u"ro",u"Vetis",4365,47.8,22.766667 ],
    [ u"ro",u"Vetrisoaia",3452,46.43,28.208333 ],
    [ u"ro",u"Vicovu de Jos",5956,47.9,25.733333 ],
    [ u"ro",u"Vicovu de Sus",14077,47.933333,25.683333 ],
    [ u"ro",u"Victoria",3942,44.816667,27.616667 ],
    [ u"ro",u"Victoria",4305,47.283333,27.583333 ],
    [ u"ro",u"Victoria",8812,45.733333,24.683333 ],
    [ u"ro",u"Victor Vlad Delamarina",2879,45.640556,21.892778 ],
    [ u"ro",u"Videle",11813,44.278056,25.524444 ],
    [ u"ro",u"Vidra",1924,46.383333,22.916667 ],
    [ u"ro",u"Vidra",7424,45.916667,26.9 ],
    [ u"ro",u"Vidra",8322,44.260556,26.169722 ],
    [ u"ro",u"Viile Satu Mare",3178,47.666667,22.95 ],
    [ u"ro",u"Viisoara",1344,47.383333,22.45 ],
    [ u"ro",u"Viisoara",2298,48.166667,26.733333 ],
    [ u"ro",u"Viisoara",5786,46.55,23.916667 ],
    [ u"ro",u"Viisoara",1635,46.283333,24.6 ],
    [ u"ro",u"Viisoara",5014,46.933333,26.233333 ],
    [ u"ro",u"Viisoara",3894,46.383333,27.883333 ],
    [ u"ro",u"Viisoara",2242,43.783333,25.166667 ],
    [ u"ro",u"Vima Mica",1621,47.4,23.716667 ],
    [ u"ro",u"Vinderei",4716,46.15,27.8 ],
    [ u"ro",u"Vinga",6283,46.016667,21.2 ],
    [ u"ro",u"Vintila Voda",3367,45.466667,26.716667 ],
    [ u"ro",u"Vintileasca",2155,45.6,26.733333 ],
    [ u"ro",u"Viperesti",3600,45.233333,26.466667 ],
    [ u"ro",u"Visani",2819,45.15,27.283333 ],
    [ u"ro",u"Viseu de Jos",5201,47.733333,24.366667 ],
    [ u"ro",u"Viseu de Sus",16321,47.716667,24.433333 ],
    [ u"ro",u"Visina",3311,43.866667,24.45 ],
    [ u"ro",u"Visina",6604,44.583333,25.333333 ],
    [ u"ro",u"Visinesti",2372,45.1,25.55 ],
    [ u"ro",u"Vitanesti",3214,44,25.416667 ],
    [ u"ro",u"Vitomiresti",2678,44.866667,24.4 ],
    [ u"ro",u"Vizantea",4201,45.983333,26.783333 ],
    [ u"ro",u"Viziru",6305,45.016667,27.7 ],
    [ u"ro",u"Vladaia",2185,44.35,23.033333 ],
    [ u"ro",u"Vladeni",4963,47.716667,26.516667 ],
    [ u"ro",u"Vladeni",2230,44.616667,27.883333 ],
    [ u"ro",u"Vladeni",4498,47.416667,27.333333 ],
    [ u"ro",u"Vladesti",3131,45.15,24.916667 ],
    [ u"ro",u"Vladesti",2228,45.85,28.083333 ],
    [ u"ro",u"Vladesti",2411,45.116667,24.3 ],
    [ u"ro",u"Vladila",2198,44,24.4 ],
    [ u"ro",u"Vladimirescu",10451,46.15,21.4 ],
    [ u"ro",u"Vladimir",3435,44.833333,23.566667 ],
    [ u"ro",u"Vlad Tepes",2584,44.35,27.083333 ],
    [ u"ro",u"Vlahita",6922,46.35,25.516667 ],
    [ u"ro",u"Vlasinesti",3380,47.933333,26.883333 ],
    [ u"ro",u"Voicesti",1752,44.6,24.283333 ],
    [ u"ro",u"Voila",4513,45.816667,24.85 ],
    [ u"ro",u"Voineasa",1695,45.416667,23.95 ],
    [ u"ro",u"Voineasa",2310,44.283333,24.133333 ],
    [ u"ro",u"Voinesti",6159,45.066667,25.25 ],
    [ u"ro",u"Voinesti",6161,47.066667,27.416667 ],
    [ u"ro",u"Voinesti",3785,46.566667,27.416667 ],
    [ u"ro",u"Voiteg",2402,45.468889,21.239167 ],
    [ u"ro",u"Voivodeni",1930,46.7,24.633333 ],
    [ u"ro",u"Voloiac",2038,44.616667,23.1 ],
    [ u"ro",u"Volovat",6990,47.816667,25.9 ],
    [ u"ro",u"Voluntari",30323,44.466667,26.133333 ],
    [ u"ro",u"Vorniceni",4490,47.983333,26.666667 ],
    [ u"ro",u"Vorona",7992,47.6,26.633333 ],
    [ u"ro",u"Vorta",1071,46.016667,22.683333 ],
    [ u"ro",u"Voslobeni",2026,46.65,25.633333 ],
    [ u"ro",u"Vrancioaia",3018,45.85,26.733333 ],
    [ u"ro",u"Vrani",1215,45.038333,21.4925 ],
    [ u"ro",u"Vulcana Bai",2972,45.083333,25.383333 ],
    [ u"ro",u"Vulcan",5493,45.633333,25.416667 ],
    [ u"ro",u"Vulcan",28869,45.383333,23.266667 ],
    [ u"ro",u"Vulpeni",2669,44.466667,23.916667 ],
    [ u"ro",u"Vultureni",1551,46.966667,23.566667 ],
    [ u"ro",u"Vultureni",2171,46.333333,27.3 ],
    [ u"ro",u"Vulturesti",2790,44.733333,24.316667 ],
    [ u"ro",u"Vulturesti",3771,47.516667,26.45 ],
    [ u"ro",u"Vulturesti",2320,46.816667,27.533333 ],
    [ u"ro",u"Vulturu",741,44.65,28.266667 ],
    [ u"ro",u"Vurpar",2322,45.9,24.35 ],
    [ u"ro",u"Vutcani",2391,46.466667,27.966667 ],
    [ u"ro",u"Zabala",4729,45.9,26.183333 ],
    [ u"ro",u"Zabrani",4392,46.066667,21.55 ],
    [ u"ro",u"Zagar",1197,46.35,24.616667 ],
    [ u"ro",u"Zagon",5416,45.766667,26.116667 ],
    [ u"ro",u"Zagra",3725,47.333333,24.283333 ],
    [ u"ro",u"Zalau",63232,47.2,23.05 ],
    [ u"ro",u"Zalha",1152,47.183333,23.533333 ],
    [ u"ro",u"Zamostea",3177,47.866667,26.2 ],
    [ u"ro",u"Zanesti",6077,46.816667,26.55 ],
    [ u"ro",u"Zapodeni",4207,46.75,27.65 ],
    [ u"ro",u"Zarand",2629,46.4,21.65 ],
    [ u"ro",u"Zarnesti",25126,45.55,25.3 ],
    [ u"ro",u"Zarnesti",5459,45.3,26.866667 ],
    [ u"ro",u"Zatreni",4524,44.766667,23.85 ],
    [ u"ro",u"Zavoaia",3482,44.933333,27.533333 ],
    [ u"ro",u"Zavoaia",3482,44.95,27.483333 ],
    [ u"ro",u"Zavoi",4205,45.516667,22.416667 ],
    [ u"ro",u"Zemes",5171,46.583333,26.416667 ],
    [ u"ro",u"Zerind",1442,46.616667,21.516667 ],
    [ u"ro",u"Zetea",5670,46.383333,25.366667 ],
    [ u"ro",u"Ziduri",4736,45.3,27.083333 ],
    [ u"ro",u"Zimandu Nou",4412,46.283333,21.4 ],
    [ u"ro",u"Zimbor",1262,47,23.266667 ],
    [ u"ro",u"Zimnicea",15228,43.666667,25.366667 ],
    [ u"ro",u"Zlatna",8393,46.116667,23.216667 ],
    [ u"ro",u"Zorleni",9511,46.266667,27.716667 ],
    [ u"ro",u"Zorlentu Mare",1176,45.450556,21.956111 ],
    [ u"ro",u"Zvoristea",6275,47.833333,26.283333 ],
    [ u"rs",u"Ada",10259,45.8025,20.125833 ],
    [ u"rs",u"Aleksinac",16652,43.541667,21.707778 ],
    [ u"rs",u"Alibunar",3353,45.080833,20.965833 ],
    [ u"rs",u"Apatin",19677,45.671111,18.984722 ],
    [ u"rs",u"Arandelovac",24674,44.306944,20.56 ],
    [ u"rs",u"Arilje",6921,43.753056,20.095556 ],
    [ u"rs",u"Azanja",4603,44.433056,20.879722 ],
    [ u"rs",u"Babusnica",4606,43.059722,22.411667 ],
    [ u"rs",u"Bac",6110,45.391944,19.236667 ],
    [ u"rs",u"Backa Palanka",30208,45.250833,19.391944 ],
    [ u"rs",u"Backa Topola",16082,45.815,19.636111 ],
    [ u"rs",u"Backi Jarak",6250,45.370278,19.875 ],
    [ u"rs",u"Backi Petrovac",6649,45.360556,19.591667 ],
    [ u"rs",u"Backo Gradiste",5453,45.532778,20.028333 ],
    [ u"rs",u"Backo Petrovo Selo",7129,45.708056,20.075278 ],
    [ u"rs",u"Badovinci",5402,44.785833,19.371389 ],
    [ u"rs",u"Bajina Basta",9812,43.970833,19.5675 ],
    [ u"rs",u"Bajmok",8599,45.967778,19.423333 ],
    [ u"rs",u"Baljevac",1625,43.3925,20.636389 ],
    [ u"rs",u"Banatski Karlovac",5799,45.047222,21.016111 ],
    [ u"rs",u"Banatsko Novo Selo",7397,44.989722,20.783611 ],
    [ u"rs",u"Banja Koviljaca",6540,44.5125,19.158333 ],
    [ u"rs",u"Barajevo",8828,44.608889,20.454722 ],
    [ u"rs",u"Barajevo",8828,44.578889,20.415833 ],
    [ u"rs",u"Baric",6837,44.652222,20.259444 ],
    [ u"rs",u"Batocina",5622,44.153611,21.081667 ],
    [ u"rs",u"Bavaniste",6027,44.818889,20.875833 ],
    [ u"rs",u"Becej",25562,45.618889,20.036111 ],
    [ u"rs",u"Bela Crkva",10586,44.8975,21.417222 ],
    [ u"rs",u"Bela Palanka",8763,43.218333,22.311111 ],
    [ u"rs",u"Belgrade",1115200,44.818611,20.468056 ],
    [ u"rs",u"Beli Potok",3645,43.535833,22.082222 ],
    [ u"rs",u"Beocin",8122,45.198333,19.7225 ],
    [ u"rs",u"Beska",6328,45.129722,20.066111 ],
    [ u"rs",u"Bezdan",5270,45.852778,18.930556 ],
    [ u"rs",u"Bogatic",7370,44.8375,19.480556 ],
    [ u"rs",u"Bogovina",1201,43.895,21.940278 ],
    [ u"rs",u"Bolec",6050,44.724722,20.603333 ],
    [ u"rs",u"Boljevac",3765,43.830278,21.953056 ],
    [ u"rs",u"Bor",39388,44.078333,22.095278 ],
    [ u"rs",u"Borca",37844,44.870278,20.458611 ],
    [ u"rs",u"Bosilegrad",2713,42.4975,22.468611 ],
    [ u"rs",u"Brus",4651,43.383611,21.033611 ],
    [ u"rs",u"Brza Palanka",1054,44.466667,22.45 ],
    [ u"rs",u"Brzi Brod",4656,43.310278,21.966667 ],
    [ u"rs",u"Bujanovac",12109,42.459167,21.766667 ],
    [ u"rs",u"Cacak",75062,43.891389,20.349722 ],
    [ u"rs",u"Cajetina",3309,43.75,19.716667 ],
    [ u"rs",u"Cantavir",7039,45.920278,19.763056 ],
    [ u"rs",u"Celarevo",5554,45.269444,19.525278 ],
    [ u"rs",u"Cicevac",5031,43.720278,21.445833 ],
    [ u"rs",u"Coka",4617,45.9425,20.143333 ],
    [ u"rs",u"Crepaja",4794,45.009444,20.635556 ],
    [ u"rs",u"Crvenka",10147,45.658611,19.455556 ],
    [ u"rs",u"Cuprija",20373,43.9275,21.37 ],
    [ u"rs",u"Curug",8876,45.473056,20.071389 ],
    [ u"rs",u"Despotovac",4489,44.0925,21.446944 ],
    [ u"rs",u"Dimitrovgrad",6887,43.014167,22.775556 ],
    [ u"rs",u"Dobanovci",8217,44.826944,20.225556 ],
    [ u"rs",u"Dolovo",6861,44.901111,20.8775 ],
    [ u"rs",u"Donja Vrezina",4676,43.328889,21.950556 ],
    [ u"rs",u"Donji Komren",5969,43.349167,21.880556 ],
    [ u"rs",u"Donji Milanovac",3069,44.475556,22.115833 ],
    [ u"rs",u"Durdevo",5295,45.324722,20.064722 ],
    [ u"rs",u"Futog",19340,45.241111,19.71 ],
    [ u"rs",u"Gnjilane",88287,42.468889,21.463333 ],
    [ u"rs",u"Gornji Milanovac",24555,44.033333,20.45 ],
    [ u"rs",u"Grdelica",2371,42.901667,22.07 ],
    [ u"rs",u"Grocka",8580,44.672222,20.7175 ],
    [ u"rs",u"Guca",2014,43.776667,20.225278 ],
    [ u"rs",u"Horgos",6123,46.155556,19.9725 ],
    [ u"rs",u"Indija",27228,45.049167,20.079167 ],
    [ u"rs",u"Irig",4988,45.101111,19.858333 ],
    [ u"rs",u"Ivanjica",12667,43.580278,20.231111 ],
    [ u"rs",u"Jagodina",35282,43.981389,21.262222 ],
    [ u"rs",u"Jakovo",6077,44.756389,20.260556 ],
    [ u"rs",u"Jasa Tomic",2876,45.446944,20.855278 ],
    [ u"rs",u"Josanicka Banja",1145,43.389167,20.752222 ],
    [ u"rs",u"Kacarevo",7556,44.966389,20.693611 ],
    [ u"rs",u"Kac",11635,45.304167,19.941944 ],
    [ u"rs",u"Kaluderica",23712,44.751944,20.553333 ],
    [ u"rs",u"Kanjiza",9972,46.066667,20.05 ],
    [ u"rs",u"Karavukovo",4894,45.495,19.188056 ],
    [ u"rs",u"Kikinda",41704,45.829722,20.465278 ],
    [ u"rs",u"Kisac",5395,45.350278,19.728611 ],
    [ u"rs",u"Kladovo",9061,44.606667,22.611944 ],
    [ u"rs",u"Kljajicevo",6115,45.769722,19.277778 ],
    [ u"rs",u"Klupci",7366,44.531389,19.251944 ],
    [ u"rs",u"Koceljeva",4748,44.473611,19.811667 ],
    [ u"rs",u"Kosjeric",4200,43.996111,19.906944 ],
    [ u"rs",u"Kosovo Polje",32098,42.639444,21.096111 ],
    [ u"rs",u"Kosovska Mitrovica",84736,42.883333,20.866667 ],
    [ u"rs",u"Kostolac",9248,44.735,21.195556 ],
    [ u"rs",u"Kostolac",9248,44.711944,21.168889 ],
    [ u"rs",u"Kovacica",6693,45.111667,20.621389 ],
    [ u"rs",u"Kovilj",5736,45.227778,20.021667 ],
    [ u"rs",u"Kovin",14472,44.7475,20.976111 ],
    [ u"rs",u"Kragujevac",149275,44.016667,20.916667 ],
    [ u"rs",u"Kraljevo",58140,43.725833,20.689444 ],
    [ u"rs",u"Krupanj",4913,44.365556,19.361944 ],
    [ u"rs",u"Krusevac",57417,43.58,21.333889 ],
    [ u"rs",u"Kucevo",4552,44.4775,21.67 ],
    [ u"rs",u"Kucura",4653,45.518889,19.588056 ],
    [ u"rs",u"Kula",19395,45.608889,19.526389 ],
    [ u"rs",u"Kursumlija",13979,43.145833,21.268611 ],
    [ u"rs",u"Kusadak",5630,44.399722,20.803333 ],
    [ u"rs",u"Lacarak",11170,45.002222,19.568611 ],
    [ u"rs",u"Lajkovac",3450,44.369444,20.165278 ],
    [ u"rs",u"Lapovo",7302,44.183333,21.1 ],
    [ u"rs",u"Lazarevac",24503,44.379722,20.263889 ],
    [ u"rs",u"Lebane",10086,42.923889,21.7375 ],
    [ u"rs",u"Leskovac",63683,42.998056,21.946111 ],
    [ u"rs",u"Lesnica",4715,44.6525,19.31 ],
    [ u"rs",u"Lestane",9024,44.730556,20.575833 ],
    [ u"rs",u"Ljig",3060,44.224444,20.240278 ],
    [ u"rs",u"Ljubovija",4243,44.189444,19.376667 ],
    [ u"rs",u"Loznica",21287,44.534167,19.224167 ],
    [ u"rs",u"Loznicko Polje",7841,44.558056,19.215833 ],
    [ u"rs",u"Lozovik",5545,44.4625,21.103333 ],
    [ u"rs",u"Lucani",4324,43.860833,20.138056 ],
    [ u"rs",u"Macvanska Mitrovica",3862,44.965556,19.598056 ],
    [ u"rs",u"Majdanpek",9606,44.424444,21.935833 ],
    [ u"rs",u"Majur",6984,44.769722,19.654444 ],
    [ u"rs",u"Mali Idos",5412,45.708333,19.665278 ],
    [ u"rs",u"Mali Zvornik",4875,44.395278,19.115833 ],
    [ u"rs",u"Mataruska Banja",2887,43.688611,20.610556 ],
    [ u"rs",u"Medveda",2759,43.629167,21.078333 ],
    [ u"rs",u"Melenci",6439,45.513889,20.317222 ],
    [ u"rs",u"Mionica",1724,44.251944,20.081667 ],
    [ u"rs",u"Mladenovac",22087,44.466667,20.716667 ],
    [ u"rs",u"Mladenovac",22087,44.438611,20.699167 ],
    [ u"rs",u"Mokrin",5833,45.935833,20.407222 ],
    [ u"rs",u"Mol",6649,45.764167,20.131111 ],
    [ u"rs",u"Negotin",18000,44.226389,22.530833 ],
    [ u"rs",u"Nis",173775,43.324722,21.903333 ],
    [ u"rs",u"Nova Pazova",18986,44.944722,20.219722 ],
    [ u"rs",u"Nova Varos",10166,43.460556,19.811389 ],
    [ u"rs",u"Novi Banovci",10378,44.954722,20.281944 ],
    [ u"rs",u"Novi Becej",14243,45.598611,20.135556 ],
    [ u"rs",u"Novi Knezevac",7499,46.05,20.1 ],
    [ u"rs",u"Novi Pazar",56028,43.136667,20.512222 ],
    [ u"rs",u"Novi Sad",194405,45.251667,19.836944 ],
    [ u"rs",u"Obrenovac",24257,44.653889,20.2 ],
    [ u"rs",u"Odzaci",9749,45.506667,19.261111 ],
    [ u"rs",u"Omoljica",6490,44.760556,20.728056 ],
    [ u"rs",u"Opovo",4657,45.052222,20.430278 ],
    [ u"rs",u"Orahovac",25889,42.399444,20.654722 ],
    [ u"rs",u"Osecina",3272,44.373056,19.601389 ],
    [ u"rs",u"Ostruznica",4005,44.728333,20.319167 ],
    [ u"rs",u"Ovca",2300,44.887778,20.535556 ],
    [ u"rs",u"Padina",5731,45.118056,20.727222 ],
    [ u"rs",u"Padinska Skela",9353,44.943889,20.429722 ],
    [ u"rs",u"Palic",7822,46.108889,19.767222 ],
    [ u"rs",u"Pancevo",77201,44.870833,20.640278 ],
    [ u"rs",u"Paracin",25411,43.860833,21.407778 ],
    [ u"rs",u"Pec",93161,42.66,20.292222 ],
    [ u"rs",u"Petrovac",7920,44.376944,21.419167 ],
    [ u"rs",u"Petrovaradin",14787,45.246667,19.879444 ],
    [ u"rs",u"Pinosava",2871,44.695278,20.480833 ],
    [ u"rs",u"Pirot",40928,43.153056,22.586111 ],
    [ u"rs",u"Pocerski Pricinovic",6187,44.722222,19.707222 ],
    [ u"rs",u"Podujevo",46513,42.910556,21.193056 ],
    [ u"rs",u"Pozarevac",42057,44.615278,21.1825 ],
    [ u"rs",u"Pozega",13403,43.846389,20.041389 ],
    [ u"rs",u"Predejane",1174,42.829444,22.131111 ],
    [ u"rs",u"Presevo",13537,42.309167,21.649167 ],
    [ u"rs",u"Priboj",19139,43.583611,19.525833 ],
    [ u"rs",u"Prigrevica",4808,45.678611,19.086667 ],
    [ u"rs",u"Prijepolje",14811,43.371944,19.640556 ],
    [ u"rs",u"Pristina",254023,42.666667,21.166667 ],
    [ u"rs",u"Prizren",159145,42.213889,20.739722 ],
    [ u"rs",u"Prokuplje",26937,43.234167,21.588056 ],
    [ u"rs",u"Raca",2757,44.919167,19.287222 ],
    [ u"rs",u"Radinac",4918,44.626944,20.968056 ],
    [ u"rs",u"Raska",6622,43.287222,20.615278 ],
    [ u"rs",u"Resavica",2309,44.066389,21.520278 ],
    [ u"rs",u"Ribnica",2770,43.71,20.690833 ],
    [ u"rs",u"Ripanj",10827,44.638611,20.520833 ],
    [ u"rs",u"Rudovci",1779,44.366667,20.416667 ],
    [ u"rs",u"Ruma",33116,45.008056,19.822222 ],
    [ u"rs",u"Rumenka",6139,45.293056,19.743889 ],
    [ u"rs",u"Rusanj",4839,44.681667,20.440556 ],
    [ u"rs",u"Ruski Krstur",5122,45.562778,19.415833 ],
    [ u"rs",u"Sabac",55114,44.746667,19.69 ],
    [ u"rs",u"Sajkas",4785,45.272222,20.089722 ],
    [ u"rs",u"Senta",19891,45.9275,20.077222 ],
    [ u"rs",u"Sevojno",7692,43.845,19.898611 ],
    [ u"rs",u"Sid",16937,45.128333,19.226389 ],
    [ u"rs",u"Sivac",8899,45.704167,19.379722 ],
    [ u"rs",u"Sjenica",12888,43.273056,19.999444 ],
    [ u"rs",u"Smederevo",63058,44.662778,20.93 ],
    [ u"rs",u"Smederevska Palanka",25516,44.365833,20.962778 ],
    [ u"rs",u"Sombor",51607,45.774167,19.112222 ],
    [ u"rs",u"Sonta",4881,45.594722,19.098056 ],
    [ u"rs",u"Sopot",1775,44.519722,20.573611 ],
    [ u"rs",u"Srbobran",13170,45.553889,19.802778 ],
    [ u"rs",u"Sremcica",19077,44.676944,20.393056 ],
    [ u"rs",u"Sremska Kamenica",12220,45.223333,19.843056 ],
    [ u"rs",u"Sremska Mitrovica",39286,44.976389,19.612222 ],
    [ u"rs",u"Sremski Karlovci",9255,45.2025,19.934444 ],
    [ u"rs",u"Stanisic",4748,45.94,19.165278 ],
    [ u"rs",u"Stara Moravica",5559,45.868889,19.466111 ],
    [ u"rs",u"Stara Pazova",19183,44.985,20.160833 ],
    [ u"rs",u"Starcevo",7629,44.807222,20.704722 ],
    [ u"rs",u"Stari Banovci",5916,44.986389,20.286667 ],
    [ u"rs",u"Subotica",99595,46.1,19.666667 ],
    [ u"rs",u"Surcin",14867,44.793056,20.280278 ],
    [ u"rs",u"Surdulica",10816,42.690556,22.170833 ],
    [ u"rs",u"Svilajnac",9677,44.229444,21.197222 ],
    [ u"rs",u"Svrljig",7813,43.413333,22.121111 ],
    [ u"rs",u"Temerin",19877,45.408611,19.889167 ],
    [ u"rs",u"Titel",5831,45.206111,20.294444 ],
    [ u"rs",u"Topola",5663,44.254167,20.6825 ],
    [ u"rs",u"Trstenik",17309,43.616944,21.0025 ],
    [ u"rs",u"Tutin",9224,42.990278,20.331389 ],
    [ u"rs",u"Ub",6068,44.456111,20.073889 ],
    [ u"rs",u"Ugrinovci",7971,44.878333,20.186944 ],
    [ u"rs",u"Umka",5336,44.678056,20.304722 ],
    [ u"rs",u"Urosevac",94278,42.370556,21.155278 ],
    [ u"rs",u"Uzice",55670,43.855833,19.841111 ],
    [ u"rs",u"Valjevo",62471,44.270833,19.884167 ],
    [ u"rs",u"Velika Plana",16148,44.326111,21.074167 ],
    [ u"rs",u"Veliki Crljeni",4565,44.4675,20.284444 ],
    [ u"rs",u"Veliki Trnovac",6812,42.476667,21.740278 ],
    [ u"rs",u"Veliko Gradiste",5752,44.756667,21.513611 ],
    [ u"rs",u"Veternik",21018,45.253333,19.759444 ],
    [ u"rs",u"Vinca",6027,44.76,20.619722 ],
    [ u"rs",u"Vladicin Han",8453,42.707778,22.063333 ],
    [ u"rs",u"Vlasotince",16673,42.963611,22.123056 ],
    [ u"rs",u"Vojka",5173,44.939722,20.153889 ],
    [ u"rs",u"Vranje",56199,42.551389,21.900278 ],
    [ u"rs",u"Vranjska Banja",6159,42.555,21.992222 ],
    [ u"rs",u"Vrbas",25991,45.571389,19.640833 ],
    [ u"rs",u"Vrcin",8949,44.668611,20.594167 ],
    [ u"rs",u"Vrnjacka Banja",9998,43.616667,20.9 ],
    [ u"rs",u"Vrsac",36036,45.116667,21.303611 ],
    [ u"rs",u"Vucje",3190,42.865278,21.911389 ],
    [ u"rs",u"Zabalj",9844,45.372222,20.063889 ],
    [ u"rs",u"Zajecar",39849,43.904167,22.284722 ],
    [ u"rs",u"Zitiste",3297,45.485,20.549722 ],
    [ u"rs",u"Zlatibor",2497,43.723333,19.704167 ],
    [ u"rs",u"Zrenjanin",79410,45.383611,20.381944 ],
    [ u"rs",u"Zvecka",6180,44.638889,20.164722 ],
    [ u"ru",u"Abadzekhskaya",4010,44.393889,40.221389 ],
    [ u"ru",u"Abagur",6530,53.6882,87.2263 ],
    [ u"ru",u"Abakan",167291,53.715556,91.429167 ],
    [ u"ru",u"Aban",9670,56.6787,96.0658 ],
    [ u"ru",u"Abatskoye",8195,56.28748,70.455533 ],
    [ u"ru",u"Abaza",18094,52.655,90.092778 ],
    [ u"ru",u"Abdulino",21195,53.7,53.666667 ],
    [ u"ru",u"Abinsk",34669,44.87258,38.161109 ],
    [ u"ru",u"Abramovka",3396,51.1886,41.0202 ],
    [ u"ru",u"Abramtsevo",236,55.832157,37.837866 ],
    [ u"ru",u"Abrau-Dyurso",3021,44.699734,37.600983 ],
    [ u"ru",u"Achikulak",7040,44.551667,44.837778 ],
    [ u"ru",u"Achinsk",117635,56.2694,90.4993 ],
    [ u"ru",u"Achisu",1737,42.651969,47.682816 ],
    [ u"ru",u"Achit",5036,56.7985,57.8994 ],
    [ u"ru",u"Achkhoy-Martan",16779,43.189969,45.283733 ],
    [ u"ru",u"Adamovka",7994,51.5223,59.9396 ],
    [ u"ru",u"Adil-Yangiyurt",4017,43.563282,46.584624 ],
    [ u"ru",u"Adyge-Khabl",3666,44.334345,41.939224 ],
    [ u"ru",u"Adygeysk",12208,44.882479,39.191943 ],
    [ u"ru",u"Afanasyevo",3368,58.865525,53.257957 ],
    [ u"ru",u"Afipskiy",18209,44.902121,38.843933 ],
    [ u"ru",u"Afonino",3182,56.262011,44.095026 ],
    [ u"ru",u"Afrikanda",1800,67.442893,32.782792 ],
    [ u"ru",u"Agalatovo",5028,60.219499,30.273877 ],
    [ u"ru",u"Agapovka",6362,53.2973,59.1348 ],
    [ u"ru",u"Ageyevo",5934,54.15883,36.469266 ],
    [ u"ru",u"Agidel",19218,55.9077,53.9355 ],
    [ u"ru",u"Aginskoye",6077,55.2586,94.9079 ],
    [ u"ru",u"Aginskoye",11491,51.1,114.533333 ],
    [ u"ru",u"Agirish",2886,61.924722,63.023056 ],
    [ u"ru",u"Agronom",3820,45.138714,39.193865 ],
    [ u"ru",u"Agvali",2158,42.538528,46.119672 ],
    [ u"ru",u"Ak-Dovurak",12593,51.183333,90.6 ],
    [ u"ru",u"Akhtanizovskaya",3342,45.321276,37.100708 ],
    [ u"ru",u"Akhtubinsk",44552,48.279548,46.172167 ],
    [ u"ru",u"Akhty",14080,41.459677,47.73123 ],
    [ u"ru",u"Akhtyrskiy",19468,44.8546,38.3031 ],
    [ u"ru",u"Akkermanovka",1264,51.193755,58.212224 ],
    [ u"ru",u"Aknada",4070,42.401548,46.172284 ],
    [ u"ru",u"Aksakovo",3179,54.033333,54.15 ],
    [ u"ru",u"Aksarayskiy",3323,46.792439,48.011876 ],
    [ u"ru",u"Aksarka",2576,66.560556,67.7975 ],
    [ u"ru",u"Aksay",8924,43.372543,46.444966 ],
    [ u"ru",u"Aksay",38871,47.258381,39.866746 ],
    [ u"ru",u"Aksha",3950,50.281389,113.286667 ],
    [ u"ru",u"Aktanysh",8163,55.721563,54.082925 ],
    [ u"ru",u"Aktash",3374,50.3,87.733333 ],
    [ u"ru",u"Aktyubinskiy",9964,54.813725,52.805589 ],
    [ u"ru",u"Akusha",4810,42.268846,47.341142 ],
    [ u"ru",u"Alabino",612,55.526787,37.010277 ],
    [ u"ru",u"Alabushevo",2733,56.016667,37.15 ],
    [ u"ru",u"Alagir",21542,43.000829,44.216752 ],
    [ u"ru",u"Alakurtti",6293,66.967203,30.349053 ],
    [ u"ru",u"Alburikent",7335,42.973889,47.471111 ],
    [ u"ru",u"Aldan",24426,58.603056,125.389444 ],
    [ u"ru",u"Aleksandriya",4223,45.094722,43.245556 ],
    [ u"ru",u"Aleksandriyskaya",10279,44.227222,43.345278 ],
    [ u"ru",u"Aleksandro-Nevskiy",4030,53.4751,40.2095 ],
    [ u"ru",u"Aleksandrov",64089,56.39516,38.712161 ],
    [ u"ru",u"Aleksandrov Gay",9919,50.147043,48.570368 ],
    [ u"ru",u"Aleksandrovka",4129,52.683333,54.416667 ],
    [ u"ru",u"Aleksandrovka",4731,46.7885,38.98126 ],
    [ u"ru",u"Aleksandrovsk",15486,59.158043,57.562414 ],
    [ u"ru",u"Aleksandrovskaya",4014,43.483333,43.65 ],
    [ u"ru",u"Aleksandrovskaya",1159,59.730833,30.332222 ],
    [ u"ru",u"Aleksandrovskiy Zavod",2516,50.9237,117.9374 ],
    [ u"ru",u"Aleksandrovskoye",28006,44.714167,43.000833 ],
    [ u"ru",u"Aleksandrovskoye",7999,56.740833,85.390556 ],
    [ u"ru",u"Aleksandrovsk-Sakhalinskiy",12025,50.8975,142.156111 ],
    [ u"ru",u"Alekseyevka",3966,54.85,55.233333 ],
    [ u"ru",u"Alekseyevka",39849,50.6309,38.6903 ],
    [ u"ru",u"Alekseyevka",4590,52.584,51.28 ],
    [ u"ru",u"Alekseyevka",2127,52.305833,48.026111 ],
    [ u"ru",u"Alekseyevsk",3082,57.835,108.356111 ],
    [ u"ru",u"Alekseyevskaya",3303,45.771667,40.155278 ],
    [ u"ru",u"Alekseyevskaya",4205,50.2896,42.1845 ],
    [ u"ru",u"Alekseyevskoye",9738,55.307064,50.113532 ],
    [ u"ru",u"Aleksin",66886,54.50503,37.067403 ],
    [ u"ru",u"Aleysk",28020,52.4926,82.7822 ],
    [ u"ru",u"Ali-Berdukovskiy",5093,43.989521,41.742123 ],
    [ u"ru",u"Alikovo",2886,55.738267,46.754928 ],
    [ u"ru",u"Aliskerovo",7,67.766667,167.583333 ],
    [ u"ru",u"Ali-Yurt",7593,43.1425,44.8525 ],
    [ u"ru",u"Alkhan-Churt",7666,43.351944,44.786944 ],
    [ u"ru",u"Alkhan-Kala",10168,43.258611,45.539167 ],
    [ u"ru",u"Alkhan-Yurt",8879,43.231789,45.572278 ],
    [ u"ru",u"Alkhazurovo",5452,43.063903,45.65134 ],
    [ u"ru",u"Allakh-Yun",296,61.133333,138.05 ],
    [ u"ru",u"Alleroy",10247,43.087056,46.304703 ],
    [ u"ru",u"Alleroy",10247,43.217106,46.282094 ],
    [ u"ru",u"Almaznyy",3080,48.044755,40.045014 ],
    [ u"ru",u"Almaznyy",1699,62.449167,114.327778 ],
    [ u"ru",u"Almenevo",4456,54.943889,63.577778 ],
    [ u"ru",u"Almetyevsk",142727,54.904424,52.315397 ],
    [ u"ru",u"Alnashi",6205,56.187378,52.479185 ],
    [ u"ru",u"Alpatovo",5192,43.702795,45.241542 ],
    [ u"ru",u"Altayskoye",13852,51.953333,85.3325 ],
    [ u"ru",u"Altud",5578,43.721944,43.865833 ],
    [ u"ru",u"Altukhovo",1908,52.675589,34.36703 ],
    [ u"ru",u"Alzamay",7058,55.5562,98.6644 ],
    [ u"ru",u"Amazar",2527,53.858,120.875 ],
    [ u"ru",u"Amderma",609,69.7576,61.6655 ],
    [ u"ru",u"Amga",6151,60.895278,131.960833 ],
    [ u"ru",u"Amursk",46383,50.226111,136.899444 ],
    [ u"ru",u"Amurzet",5213,47.696667,131.098056 ],
    [ u"ru",u"Amzya",4843,56.235416,54.386852 ],
    [ u"ru",u"Anadyr",10318,64.75,177.483333 ],
    [ u"ru",u"Anapskaya",13965,44.896714,37.386005 ],
    [ u"ru",u"Anastasiyevskaya",11204,45.215764,37.892577 ],
    [ u"ru",u"Andi",5318,42.783595,46.261709 ],
    [ u"ru",u"Andra",2013,62.514722,65.887778 ],
    [ u"ru",u"Andreapol",9209,56.651336,32.266395 ],
    [ u"ru",u"Andreyevka",8395,55.980278,37.135 ],
    [ u"ru",u"Andreyevo",5204,55.9465,41.1505 ],
    [ u"ru",u"Andzhiyevskiy",6755,44.238889,43.085556 ],
    [ u"ru",u"Angarsk",243161,52.536667,103.886389 ],
    [ u"ru",u"Aniva",7963,46.714445,142.529389 ],
    [ u"ru",u"Anna",19148,51.4842,40.4299 ],
    [ u"ru",u"Annino",3315,59.770556,30.056111 ],
    [ u"ru",u"Anopino",1972,55.698092,40.667075 ],
    [ u"ru",u"Ansalta",5654,42.68941,46.117819 ],
    [ u"ru",u"Antipino",5147,57.106792,65.757554 ],
    [ u"ru",u"Antipovka",3021,49.829938,45.312162 ],
    [ u"ru",u"Antropovo",3736,58.398758,43.006594 ],
    [ u"ru",u"Anuchino",4658,43.962222,133.054444 ],
    [ u"ru",u"Anzhero-Sudzhensk",82527,56.081,86.0285 ],
    [ u"ru",u"Apastovo",4575,55.202926,48.510908 ],
    [ u"ru",u"Apatity",61187,67.564142,33.4031 ],
    [ u"ru",u"Aprelevka",17780,55.551936,37.080103 ],
    [ u"ru",u"Apsheronsk",40452,44.464722,39.734167 ],
    [ u"ru",u"Aramil",15237,56.6977,60.8369 ],
    [ u"ru",u"Arbagar",712,51.933333,116.25 ],
    [ u"ru",u"Arbazh",3943,57.680405,48.306469 ],
    [ u"ru",u"Ardatov",9478,54.7623,46.2633 ],
    [ u"ru",u"Ardatov",9946,55.242053,43.096988 ],
    [ u"ru",u"Ardon",2775,52.735241,32.308569 ],
    [ u"ru",u"Ardon",18313,43.177196,44.297024 ],
    [ u"ru",u"Argayash",10096,55.4888,60.8767 ],
    [ u"ru",u"Argudan",8250,43.421389,43.915833 ],
    [ u"ru",u"Arkadak",14393,51.932614,43.497785 ],
    [ u"ru",u"Arkhangelsk",344603,64.5401,40.5433 ],
    [ u"ru",u"Arkhangelskaya",9144,45.679722,40.275556 ],
    [ u"ru",u"Arkhangelskoye",5652,54.067804,56.40803 ],
    [ u"ru",u"Arkhangelskoye",3582,55.787906,37.299835 ],
    [ u"ru",u"Arkhangelskoye",5217,44.613889,44.089444 ],
    [ u"ru",u"Arkhangelskoye",2690,53.255833,37.705833 ],
    [ u"ru",u"Arkhara",10430,49.4212,130.0842 ],
    [ u"ru",u"Arkhipo-Osipovka",8170,44.371944,38.529722 ],
    [ u"ru",u"Arkhipovka",1741,56.662923,41.254339 ],
    [ u"ru",u"Arkhonskaya",7991,43.11,44.5125 ],
    [ u"ru",u"Arkul",2537,57.280854,50.043998 ],
    [ u"ru",u"Arman",1411,59.7,150.166667 ],
    [ u"ru",u"Armavir",199551,44.9892,41.1234 ],
    [ u"ru",u"Armizonskoye",4711,55.946111,67.673611 ],
    [ u"ru",u"Aromashevo",5573,56.860179,68.637538 ],
    [ u"ru",u"Arsenyev",61620,44.163056,133.273333 ],
    [ u"ru",u"Arshan",3542,46.2732,44.22 ],
    [ u"ru",u"Arsk",17243,56.09151,49.877831 ],
    [ u"ru",u"Arti",13564,56.423436,58.532761 ],
    [ u"ru",u"Artyk",612,64.2,145.1 ],
    [ u"ru",u"Artyshta",3090,54.1222,86.2909 ],
    [ u"ru",u"Arya",4931,57.491459,45.966911 ],
    [ u"ru",u"Arzamas",109480,55.394852,43.83992 ],
    [ u"ru",u"Arzgir",15838,45.372778,44.220556 ],
    [ u"ru",u"Asbest",74584,57.009934,61.457763 ],
    [ u"ru",u"Asbestovskiy",1209,57.755742,61.396717 ],
    [ u"ru",u"Asekeyevo",5267,53.57425,52.797236 ],
    [ u"ru",u"Asha",33007,54.9973,57.2722 ],
    [ u"ru",u"Ashitkovo",3285,55.451732,38.59518 ],
    [ u"ru",u"Ashukino",6310,56.166667,37.95 ],
    [ u"ru",u"Asino",27070,56.9979,86.1452 ],
    [ u"ru",u"Askarovo",7081,53.337222,58.508889 ],
    [ u"ru",u"Askino",6866,56.090131,56.578311 ],
    [ u"ru",u"Askiz",6928,53.131944,90.526389 ],
    [ u"ru",u"Assinovskaya",10270,43.241667,45.181944 ],
    [ u"ru",u"Astrakhan",502537,46.349683,48.040756 ],
    [ u"ru",u"Atagay",1805,55.1033,99.3875 ],
    [ u"ru",u"Atamanovka",9053,51.933333,113.633333 ],
    [ u"ru",u"Atamanskaya",3930,46.1773,39.6358 ],
    [ u"ru",u"Atemar",4052,54.180972,45.409089 ],
    [ u"ru",u"Ateptsevo",3424,55.323643,36.750016 ],
    [ u"ru",u"Atig",3842,56.693071,59.422714 ],
    [ u"ru",u"Atka",560,60.833333,151.8 ],
    [ u"ru",u"Atkarsk",27554,51.871853,45.007752 ],
    [ u"ru",u"Atyashevo",5935,54.564431,46.069047 ],
    [ u"ru",u"Atyuryevo",4628,54.322896,43.339571 ],
    [ u"ru",u"Aushiger",4955,43.396111,43.731667 ],
    [ u"ru",u"Avdon",4980,54.666667,55.716667 ],
    [ u"ru",u"Avsyunino",5148,55.558177,39.066637 ],
    [ u"ru",u"Avtury",18370,43.163543,46.001198 ],
    [ u"ru",u"Ayan",1286,56.45,138.166667 ],
    [ u"ru",u"Ayat",861,57.0336,60.2334 ],
    [ u"ru",u"Aykhal",15267,66,111.5 ],
    [ u"ru",u"Aykino",3358,62.224808,49.992218 ],
    [ u"ru",u"Aysha",3086,55.870354,48.631871 ],
    [ u"ru",u"Ayutinskiy",10623,47.782279,40.14763 ],
    [ u"ru",u"Azanka",3210,58.040124,64.789272 ],
    [ u"ru",u"Azov",82134,47.10779,39.416481 ],
    [ u"ru",u"Azovo",5311,54.699716,73.023672 ],
    [ u"ru",u"Azovskaya",3960,44.790833,38.626389 ],
    [ u"ru",u"Babayurt",13857,43.600204,46.778877 ],
    [ u"ru",u"Babino",2456,56.22564,43.623799 ],
    [ u"ru",u"Babstovo",3685,48.116667,132.483333 ],
    [ u"ru",u"Babushkin",4578,51.712222,105.864722 ],
    [ u"ru",u"Babynino",4009,54.393847,35.770128 ],
    [ u"ru",u"Bachatskiy",14618,54.2927,86.1285 ],
    [ u"ru",u"Bachi-Yurt",14788,43.224166,46.194226 ],
    [ u"ru",u"Bada",5149,51.392,109.8717 ],
    [ u"ru",u"Bagan",5803,54.100137,77.664616 ],
    [ u"ru",u"Bagdarin",4676,54.433333,113.6 ],
    [ u"ru",u"Bakal",21763,54.9417,58.8083 ],
    [ u"ru",u"Bakaly",9532,55.178889,53.802778 ],
    [ u"ru",u"Bakchar",7195,57.018611,82.071111 ],
    [ u"ru",u"Baksan",37520,43.688056,43.536944 ],
    [ u"ru",u"Baksanenok",7058,43.689722,43.654722 ],
    [ u"ru",u"Baksheyevo",2296,55.708595,39.876664 ],
    [ u"ru",u"Balabanovo",24233,55.181608,36.660599 ],
    [ u"ru",u"Balagansk",4195,53.7188,103.3281 ],
    [ u"ru",u"Balakhninskiy",1675,58.010556,114.276944 ],
    [ u"ru",u"Balakhonovskoye",4377,44.7767,41.7842 ],
    [ u"ru",u"Balakhta",7721,55.387778,91.603056 ],
    [ u"ru",u"Balakirevo",8932,56.505883,38.843241 ],
    [ u"ru",u"Balakovo",201923,51.9284,47.9172 ],
    [ u"ru",u"Balasheyka",3080,53.2841,48.0851 ],
    [ u"ru",u"Balashikha",150105,55.809452,37.958055 ],
    [ u"ru",u"Balashov",98108,51.5502,43.1667 ],
    [ u"ru",u"Baley",13404,51.6,116.633333 ],
    [ u"ru",u"Balezino",16618,57.979634,53.01057 ],
    [ u"ru",u"Balgazyn",3342,51,95.2 ],
    [ u"ru",u"Baltasi",7009,56.3462,50.2062 ],
    [ u"ru",u"Baltay",3959,52.46525,46.630806 ],
    [ u"ru",u"Baltiysk",34541,54.65382,19.911036 ],
    [ u"ru",u"Balyaga",3559,51.1507,108.921 ],
    [ u"ru",u"Bammatyurt",3863,43.343153,46.608533 ],
    [ u"ru",u"Bamut",5148,43.159855,45.19734 ],
    [ u"ru",u"Barabash",3603,43.2,131.483333 ],
    [ u"ru",u"Barabinsk",31509,55.357091,78.356971 ],
    [ u"ru",u"Baranchinskiy",10970,58.1617,59.6991 ],
    [ u"ru",u"Baranikha",31,68.516667,168.25 ],
    [ u"ru",u"Barashevo",3651,54.48565,43.269473 ],
    [ u"ru",u"Barda",8279,56.927679,55.593454 ],
    [ u"ru",u"Barguzin",6052,53.616667,109.616667 ],
    [ u"ru",u"Barnaul",599586,53.360556,83.763611 ],
    [ u"ru",u"Barsovo",5710,61.166667,73.166667 ],
    [ u"ru",u"Barsuki",3500,54.265476,37.487463 ],
    [ u"ru",u"Barsukovskaya",5529,44.7632,41.8191 ],
    [ u"ru",u"Barvikha",4193,55.718838,37.277734 ],
    [ u"ru",u"Baryatino",2645,54.31206,34.520959 ],
    [ u"ru",u"Barybino",3994,55.221874,37.833319 ],
    [ u"ru",u"Barysh",18547,53.655326,47.112289 ],
    [ u"ru",u"Baryshevo",5024,54.9564,83.1822 ],
    [ u"ru",u"Barzas",2230,55.716667,86.316667 ],
    [ u"ru",u"Bashmakovo",9654,53.213292,43.034202 ],
    [ u"ru",u"Basyanovskiy",1744,58.308889,60.739113 ],
    [ u"ru",u"Batagay-Alyta",1666,67.800556,130.411389 ],
    [ u"ru",u"Batagay",4439,67.633333,134.633333 ],
    [ u"ru",u"Batashyurt",3786,43.308008,46.509905 ],
    [ u"ru",u"Bataysk",109964,47.139747,39.75181 ],
    [ u"ru",u"Batayurt",4093,43.318655,46.683713 ],
    [ u"ru",u"Batetskiy",2223,58.646101,30.302677 ],
    [ u"ru",u"Baturinskaya",3678,45.792674,39.370648 ],
    [ u"ru",u"Batyrëvo",5648,55.0675,47.611111 ],
    [ u"ru",u"Bavleny",3209,56.394482,39.565038 ],
    [ u"ru",u"Bavly",22982,54.393042,53.260231 ],
    [ u"ru",u"Bavtugay",5398,43.168084,46.834152 ],
    [ u"ru",u"Bayanday",2854,53.066111,105.513889 ],
    [ u"ru",u"Bayangol",1432,50.6977,103.4656 ],
    [ u"ru",u"Bayevo",5134,53.283333,80.766667 ],
    [ u"ru",u"Baykal",491,51.8792,104.7894 ],
    [ u"ru",u"Baykalovo",6043,57.398108,63.768406 ],
    [ u"ru",u"Baykalsk",15530,51.5151,104.1402 ],
    [ u"ru",u"Bay-Khaak",3058,51.166667,94.5 ],
    [ u"ru",u"Baykit",3748,61.676944,96.379167 ],
    [ u"ru",u"Baymak",17494,52.466667,58.25 ],
    [ u"ru",u"Bazarnyye Mataki",5339,54.883333,49.933333 ],
    [ u"ru",u"Bazarnyy Karabulak",10389,52.268333,46.414444 ],
    [ u"ru",u"Bazarnyy Syzgan",6039,53.751174,46.753539 ],
    [ u"ru",u"Bazhovo",11537,55.0604,61.6054 ],
    [ u"ru",u"Bednodemyanovsk",7475,53.925586,43.183938 ],
    [ u"ru",u"Begichevskiy",2616,53.796046,38.254984 ],
    [ u"ru",u"Begunitsy",3558,59.585518,29.317569 ],
    [ u"ru",u"Bekeshevskaya",3800,44.113889,42.426944 ],
    [ u"ru",u"Bekhteyevka",3332,50.807214,37.208531 ],
    [ u"ru",u"Bekovo",6800,52.466323,43.711993 ],
    [ u"ru",u"Belaya",2810,51.054444,35.716111 ],
    [ u"ru",u"Belaya Glina",17997,46.078016,40.86651 ],
    [ u"ru",u"Belaya Gora",2383,68.533333,146.416667 ],
    [ u"ru",u"Belaya Kalitva",47521,48.185853,40.774244 ],
    [ u"ru",u"Belaya Kholunitsa",11658,58.84,50.852778 ],
    [ u"ru",u"Belaya Rechka",3424,43.438056,43.535 ],
    [ u"ru",u"Belaya Rechka",2603,56.284912,39.406648 ],
    [ u"ru",u"Belebey",62583,54.116667,54.116667 ],
    [ u"ru",u"Belgatoy",3254,42.983658,46.233971 ],
    [ u"ru",u"Belgorod",345293,50.610743,36.580152 ],
    [ u"ru",u"Belichan",30,62.9,148.1 ],
    [ u"ru",u"Belidzhi",3676,41.87313,48.387686 ],
    [ u"ru",u"Belinskiy",8800,52.964739,43.416472 ],
    [ u"ru",u"Belogorsk",66271,50.915833,128.461111 ],
    [ u"ru",u"Belogorsk",3452,55.017778,88.489722 ],
    [ u"ru",u"Belokurikha",14734,51.9959,84.9896 ],
    [ u"ru",u"Belomorsk",12165,64.523222,34.766796 ],
    [ u"ru",u"Beloomut",6971,54.944776,39.339414 ],
    [ u"ru",u"Beloostrov",1654,60.151185,30.001511 ],
    [ u"ru",u"Belorechensk",1473,58.772505,52.293567 ],
    [ u"ru",u"Belorechensk",54527,44.767329,39.874236 ],
    [ u"ru",u"Belorechka",265,57.331944,60.034722 ],
    [ u"ru",u"Beloretsk",70469,53.963056,58.398056 ],
    [ u"ru",u"Belousovo",8421,55.094995,36.673203 ],
    [ u"ru",u"Belovo",79424,54.4165,86.2976 ],
    [ u"ru",u"Beloyarsk",10733,53.4461,83.9048 ],
    [ u"ru",u"Beloyarskiy",12438,56.7584,61.4143 ],
    [ u"ru",u"Beloye",3067,45.048318,39.651426 ],
    [ u"ru",u"Belozërnyy",4315,45.064334,38.679015 ],
    [ u"ru",u"Belozërskoye",4364,55.821389,65.584167 ],
    [ u"ru",u"Belushya Guba",2522,71.539238,52.332117 ],
    [ u"ru",u"Belyy",4189,55.8402,32.9419 ],
    [ u"ru",u"Belyye Berega",10425,53.20851,34.664047 ],
    [ u"ru",u"Belyye Stolby",5563,55.331365,37.854003 ],
    [ u"ru",u"Belyy Gorodok",2735,56.965,37.5125 ],
    [ u"ru",u"Belyy Yar",8951,53.603889,91.390278 ],
    [ u"ru",u"Belyy Yar",8245,58.444722,85.0425 ],
    [ u"ru",u"Beno-Yurt",5642,43.69305,45.050254 ],
    [ u"ru",u"Berdigestyakh",5948,62.098889,126.699167 ],
    [ u"ru",u"Berdsk",90251,54.7551,83.0967 ],
    [ u"ru",u"Berdyaush",5631,55.1619,59.1464 ],
    [ u"ru",u"Berdyuzhye",5223,55.804444,68.320556 ],
    [ u"ru",u"Beregovoy",7961,55.173007,73.219836 ],
    [ u"ru",u"Bereslavka",4817,48.62541,44.044914 ],
    [ u"ru",u"Berëza",5846,53.51833,50.139671 ],
    [ u"ru",u"Berezanskaya",6568,45.705617,39.593244 ],
    [ u"ru",u"Berezayka",2432,57.988333,33.903611 ],
    [ u"ru",u"Bereznik",6218,62.855142,42.707188 ],
    [ u"ru",u"Berezniki",167750,59.415189,56.812371 ],
    [ u"ru",u"Berëzovka",3885,53.4034,84.0009 ],
    [ u"ru",u"Berëzovka",3455,50.6,127.866667 ],
    [ u"ru",u"Berezovyy",5633,51.666667,135.7 ],
    [ u"ru",u"Berikulskiy",932,55.532778,88.141111 ],
    [ u"ru",u"Beringovskiy",1861,63.05,179.316667 ],
    [ u"ru",u"Berkakit",4764,56.5807,124.7681 ],
    [ u"ru",u"Bershet",3489,57.7309,56.3783 ],
    [ u"ru",u"Beshpagir",4183,45.021667,42.380833 ],
    [ u"ru",u"Besleney",3189,44.2405,41.7387 ],
    [ u"ru",u"Besskorbnaya",5837,44.6447,41.311 ],
    [ u"ru",u"Bessonovka",3060,50.526436,36.301069 ],
    [ u"ru",u"Bessonovka",9880,53.309677,45.040694 ],
    [ u"ru",u"Betki",3756,54.8,53.633333 ],
    [ u"ru",u"Betlitsa",3825,54.009456,33.958752 ],
    [ u"ru",u"Beya",5338,53.053333,90.913889 ],
    [ u"ru",u"Bezenchuk",23736,52.982,49.4333 ],
    [ u"ru",u"Bezhanitsy",4711,56.976695,29.890654 ],
    [ u"ru",u"Bezhetsk",28114,57.785064,36.696512 ],
    [ u"ru",u"Bezhta",3994,42.133797,46.128284 ],
    [ u"ru",u"Bezopasnoye",7176,45.648332,41.936028 ],
    [ u"ru",u"Bezymyannyy",107,58.757778,126.248889 ],
    [ u"ru",u"Bichura",9559,50.588056,107.602222 ],
    [ u"ru",u"Bikin",19659,46.816111,134.26 ],
    [ u"ru",u"Bilibino",5757,68.05,166.333333 ],
    [ u"ru",u"Bilimbay",5875,56.968891,59.814897 ],
    [ u"ru",u"Bira",4176,49,132.466667 ],
    [ u"ru",u"Birakan",2463,49.016667,131.7 ],
    [ u"ru",u"Birobidzhan",76146,48.8,132.95 ],
    [ u"ru",u"Birsk",41015,55.421111,55.542778 ],
    [ u"ru",u"Biryusinsk",9583,55.9634,97.8235 ],
    [ u"ru",u"Biser",1006,58.413611,58.880278 ],
    [ u"ru",u"Bisert",11077,56.861742,59.052312 ],
    [ u"ru",u"Biskamzha",1961,53.449722,89.527222 ],
    [ u"ru",u"Biysk",215433,52.536389,85.207222 ],
    [ u"ru",u"Bizhbulyak",6385,53.6967,54.2642 ],
    [ u"ru",u"Blagodarnyy",35996,45.097778,43.436389 ],
    [ u"ru",u"Blagodatnoye",5230,45.399722,42.586667 ],
    [ u"ru",u"Blagoveshchenka",12319,52.833333,79.866667 ],
    [ u"ru",u"Blagoveshchensk",221298,50.266667,127.533333 ],
    [ u"ru",u"Blagoveshchensk",34238,55.035,55.978056 ],
    [ u"ru",u"Blagoyevo",2510,63.366667,47.916667 ],
    [ u"ru",u"Blechepsin",3031,44.820278,40.500278 ],
    [ u"ru",u"Blizhne-Pesochnoye",2634,55.3456,42.1015 ],
    [ u"ru",u"Bobrov",20587,51.0695,40.1364 ],
    [ u"ru",u"Bobrovka",3560,54.047,61.7455 ],
    [ u"ru",u"Bobrovskiy",5198,56.6732,60.9807 ],
    [ u"ru",u"Bodaybo",15934,57.850556,114.193333 ],
    [ u"ru",u"Bogandinskiy",9586,56.893749,65.893777 ],
    [ u"ru",u"Bogashevo",3773,56.368333,85.144722 ],
    [ u"ru",u"Bogatoye",6391,53.0601,51.3325 ],
    [ u"ru",u"Bogatyr",1098,53.4298,49.9455 ],
    [ u"ru",u"Bogatyye Saby",7209,56.0102,50.4483 ],
    [ u"ru",u"Bogdanovich",32270,56.780278,62.049444 ],
    [ u"ru",u"Bogolyubovo",4121,56.190516,40.523129 ],
    [ u"ru",u"Bogoroditsk",30216,53.771663,38.124079 ],
    [ u"ru",u"Bogorodsk",36652,56.105135,43.512939 ],
    [ u"ru",u"Bogorodskoye",2998,57.046945,41.013539 ],
    [ u"ru",u"Bogorodskoye",4108,52.365833,140.445556 ],
    [ u"ru",u"Bogorodskoye",3123,57.828486,50.748557 ],
    [ u"ru",u"Bogorodskoye",9275,56.55,37.883333 ],
    [ u"ru",u"Bogoslovka",4636,53.208372,44.801328 ],
    [ u"ru",u"Bogotol",23623,56.171667,89.586111 ],
    [ u"ru",u"Bogovarovo",2327,58.97849,47.024617 ],
    [ u"ru",u"Bograd",4623,54.234444,90.832778 ],
    [ u"ru",u"Boguchany",11209,58.381389,97.453056 ],
    [ u"ru",u"Boguchar",15048,49.935767,40.545003 ],
    [ u"ru",u"Bokhan",5387,53.153,103.7714 ],
    [ u"ru",u"Bokino",4016,52.637435,41.459683 ],
    [ u"ru",u"Bokovskaya",5032,49.228988,41.830603 ],
    [ u"ru",u"Boksitogorsk",17366,59.47405,33.848531 ],
    [ u"ru",u"Bolgar",8641,54.95,49.066667 ],
    [ u"ru",u"Bolkhov",11904,53.443333,36.004444 ],
    [ u"ru",u"Bologoye",25142,57.828782,34.038339 ],
    [ u"ru",u"Bolokhovo",10084,54.083777,37.82895 ],
    [ u"ru",u"Bolotnoye",17704,55.671667,84.398056 ],
    [ u"ru",u"Bolshaya Atnya",3658,56.250833,49.452778 ],
    [ u"ru",u"Bolshaya Chernigovka",6269,52.093934,50.866089 ],
    [ u"ru",u"Bolshaya Dzhalga",3877,45.976389,42.696667 ],
    [ u"ru",u"Bolshaya Glushitsa",10055,52.389976,50.471202 ],
    [ u"ru",u"Bolshaya Irba",4949,54.076944,92.930556 ],
    [ u"ru",u"Bolshaya Izhora",3812,59.937959,29.577206 ],
    [ u"ru",u"Bolshaya Martynovka",6813,47.274208,41.66681 ],
    [ u"ru",u"Bolshaya Murta",8304,56.905833,93.149722 ],
    [ u"ru",u"Bolshaya Orlovka",4293,47.328877,41.274194 ],
    [ u"ru",u"Bolshaya Rechka",2368,51.9536,104.7335 ],
    [ u"ru",u"Bolshaya Sosnova",4297,57.668802,54.600973 ],
    [ u"ru",u"Bolshaya Vishera",1811,58.914611,32.08712 ],
    [ u"ru",u"Bolshaya Yelkhovka",4020,54.280504,45.323436 ],
    [ u"ru",u"Bolshegrivskoye",3763,53.913611,74.913056 ],
    [ u"ru",u"Bolsheustikinskoye",7571,55.9506,58.268 ],
    [ u"ru",u"Bolshevik",344,62.733333,147.5 ],
    [ u"ru",u"Bolshevik",5229,51.0228,41.6131 ],
    [ u"ru",u"Bolshëvo",10133,55.934861,37.830021 ],
    [ u"ru",u"Bolshiye Berezniki",6252,54.176293,45.970838 ],
    [ u"ru",u"Bolshiye Chapurniki",3212,48.419488,44.585759 ],
    [ u"ru",u"Bolshiye Dvory",4801,55.820052,38.645147 ],
    [ u"ru",u"Bolshiye Kaybitsy",1581,55.403581,48.185204 ],
    [ u"ru",u"Bolshiye Klyuchishchi",3691,54.141148,48.235753 ],
    [ u"ru",u"Bolshiye Kolpany",4214,59.523333,30.069444 ],
    [ u"ru",u"Bolshiye Saly",3250,47.391389,39.684722 ],
    [ u"ru",u"Bolshiye Uki",4331,56.946857,72.630283 ],
    [ u"ru",u"Bolshoye Bunkovo",3412,55.849874,38.598246 ],
    [ u"ru",u"Bolshoye Ignatovo",2735,55.020728,45.575911 ],
    [ u"ru",u"Bolshoye Kozino",5568,56.403972,43.714245 ],
    [ u"ru",u"Bolshoye Murashkino",6269,55.782612,44.775411 ],
    [ u"ru",u"Bolshoye Nagatkino",5189,54.5187,47.9716 ],
    [ u"ru",u"Bolshoye Pikino",2622,56.347573,44.193714 ],
    [ u"ru",u"Bolshoye Polpino",4521,53.239531,34.507776 ],
    [ u"ru",u"Bolshoye Selo",3643,57.717742,38.933411 ],
    [ u"ru",u"Bolshoye Soldatskoye",2647,51.335278,35.511389 ],
    [ u"ru",u"Bolshoye Sorokino",5462,56.634457,69.818913 ],
    [ u"ru",u"Bolshoy Istok",6619,56.7195,60.7833 ],
    [ u"ru",u"Bolshoy Kamen",37480,43.1225,132.358333 ],
    [ u"ru",u"Bolshoy Log",3726,47.30205,39.912692 ],
    [ u"ru",u"Bolshoy Lug",4391,52.065556,104.083889 ],
    [ u"ru",u"Bolshoy Nimnyr",463,58.043611,125.484722 ],
    [ u"ru",u"Bolshoy Tsaryn",4936,47.851944,45.424167 ],
    [ u"ru",u"Bolshoy Uluy",3364,56.6558,90.578 ],
    [ u"ru",u"Bor",60648,56.358078,44.074772 ],
    [ u"ru",u"Borgustanskaya",4250,44.0547,42.5288 ],
    [ u"ru",u"Borinskoye",5998,52.4569,39.3713 ],
    [ u"ru",u"Borisoglebsk",68598,51.367129,42.084942 ],
    [ u"ru",u"Borisoglebskiy",5832,57.2586,39.1508 ],
    [ u"ru",u"Borisovka",14253,50.601555,36.015489 ],
    [ u"ru",u"Borodino",19603,55.8726,94.9676 ],
    [ u"ru",u"Borodinskiy",6447,53.998591,37.817922 ],
    [ u"ru",u"Borogontsy",5280,62.668333,131.168333 ],
    [ u"ru",u"Borovichi",56572,58.387779,33.915463 ],
    [ u"ru",u"Borovikha",6712,53.5072,83.8379 ],
    [ u"ru",u"Borovoy",5942,55.433333,86.083333 ],
    [ u"ru",u"Borovoy",1821,63.230047,52.890313 ],
    [ u"ru",u"Borovsk",11578,55.206389,36.486111 ],
    [ u"ru",u"Borovskiy",15406,57.040959,65.720179 ],
    [ u"ru",u"Borskoye",9119,53.033333,51.716667 ],
    [ u"ru",u"Borzoy",4218,42.841474,45.627461 ],
    [ u"ru",u"Borzya",30421,50.383333,116.516667 ],
    [ u"ru",u"Boshnyakovo",1491,49.633333,142.166667 ],
    [ u"ru",u"Botlikh",11131,42.644419,46.229669 ],
    [ u"ru",u"Bratsk",259994,56.1497,101.6085 ],
    [ u"ru",u"Bratskoye",5053,43.653611,44.888889 ],
    [ u"ru",u"Bredy",10450,52.415278,60.341111 ],
    [ u"ru",u"Breytovo",3632,58.299253,37.861717 ],
    [ u"ru",u"Brindakit",15,59.983333,137.55 ],
    [ u"ru",u"Brinkovskaya",4821,46.028712,38.585781 ],
    [ u"ru",u"Brodokalmak",3466,55.5748,62.082 ],
    [ u"ru",u"Bronnitsy",18645,55.421119,38.261878 ],
    [ u"ru",u"Brusyanskiy",3277,53.984922,38.035934 ],
    [ u"ru",u"Bryansk",427241,53.252089,34.371666 ],
    [ u"ru",u"Bryukhovetskaya",22309,45.806034,38.999593 ],
    [ u"ru",u"Budogoshch",3865,59.281584,32.470739 ],
    [ u"ru",u"Bugry",4715,60.071211,30.392251 ],
    [ u"ru",u"Bugulma",93507,54.5378,52.7985 ],
    [ u"ru",u"Buguruslan",53512,53.6554,52.442 ],
    [ u"ru",u"Buinsk",1606,55.195,47.0608 ],
    [ u"ru",u"Buinsk",20267,54.97119,48.291841 ],
    [ u"ru",u"Bukachacha",3372,52.983333,116.916667 ],
    [ u"ru",u"Bulanash",13056,57.278248,61.996496 ],
    [ u"ru",u"Burayevo",8963,55.840693,55.408336 ],
    [ u"ru",u"Burevestnik",3054,56.144029,43.788324 ],
    [ u"ru",u"Bureya",5383,49.8133,129.8131 ],
    [ u"ru",u"Buribay",4461,51.961667,58.159167 ],
    [ u"ru",u"Burkhala",530,62.7,148.966667 ],
    [ u"ru",u"Burla",4682,53.3362,78.3301 ],
    [ u"ru",u"Burlatskoye",3637,45.056389,43.635 ],
    [ u"ru",u"Burmakino",3318,57.416635,40.236875 ],
    [ u"ru",u"Buron",496,42.792806,44.008122 ],
    [ u"ru",u"Bursol",978,53.1682,78.4434 ],
    [ u"ru",u"Burtunay",4014,42.988601,46.630336 ],
    [ u"ru",u"Butka",3510,56.717882,63.786609 ],
    [ u"ru",u"Buturlino",6857,55.566732,44.897377 ],
    [ u"ru",u"Buturlinovka",28581,50.823889,40.609167 ],
    [ u"ru",u"Buy",26486,58.480668,41.536992 ],
    [ u"ru",u"Buynaksk",62690,42.819001,47.119197 ],
    [ u"ru",u"Buzdyak",9752,54.583333,54.55 ],
    [ u"ru",u"Buzuluk",87715,52.7807,52.2635 ],
    [ u"ru",u"Bykov",4672,47.316667,142.55 ],
    [ u"ru",u"Bykovo",9159,55.620753,38.079696 ],
    [ u"ru",u"Bykovo",8268,49.766182,45.388664 ],
    [ u"ru",u"Bystrogorskiy",3859,48.208134,41.140967 ],
    [ u"ru",u"Bystryy Istok",4455,52.3479,84.4698 ],
    [ u"ru",u"Bytosh",4425,53.818611,34.091159 ],
    [ u"ru",u"Bytosh",4425,53.901389,34.123889 ],
    [ u"ru",u"Chaadayevka",7072,53.11355,45.967559 ],
    [ u"ru",u"Chaa-Khol",3424,51.533333,92.383333 ],
    [ u"ru",u"Chadan",9247,51.283333,91.583333 ],
    [ u"ru",u"Chagda",568,58.7475,130.619722 ],
    [ u"ru",u"Chagoda",7288,59.1371,35.2916 ],
    [ u"ru",u"Chaltyr",14689,47.28477,39.482323 ],
    [ u"ru",u"Chamlykskaya",3722,44.715833,40.878611 ],
    [ u"ru",u"Chany",8923,55.312046,76.76468 ],
    [ u"ru",u"Chapaevsk",70148,52.9771,49.7086 ],
    [ u"ru",u"Chaplygin",13488,53.243187,39.962879 ],
    [ u"ru",u"Chara",1974,56.906389,118.263056 ],
    [ u"ru",u"Charyshskoye",3371,51.3978,83.5598 ],
    [ u"ru",u"Chastoozerye",2779,55.564444,67.909167 ],
    [ u"ru",u"Chastyye",4907,57.288761,54.972781 ],
    [ u"ru",u"Chaykovskaya",3007,58.127903,55.537808 ],
    [ u"ru",u"Chaykovskiy",86714,56.768637,54.114844 ],
    [ u"ru",u"Chebarkul",46503,54.9749,60.3633 ],
    [ u"ru",u"Chebenki",3496,51.93872,55.700977 ],
    [ u"ru",u"Cheboksary",446786,56.132222,47.251944 ],
    [ u"ru",u"Chebsara",1742,59.146295,38.756893 ],
    [ u"ru",u"Chechen-Aul",7134,43.2,45.788889 ],
    [ u"ru",u"Chegdomyn",14855,51.116667,133.016667 ],
    [ u"ru",u"Chegem",18429,43.283333,43.133333 ],
    [ u"ru",u"Chegem Vtoroy",10951,43.595833,43.599444 ],
    [ u"ru",u"Chekalin",1105,54.052774,36.29139 ],
    [ u"ru",u"Chekhov",75645,55.147696,37.477277 ],
    [ u"ru",u"Chekhov",4653,47.442778,141.978889 ],
    [ u"ru",u"Chekmagush",11225,55.131944,54.655556 ],
    [ u"ru",u"Chelbasskaya",7080,45.979237,39.371858 ],
    [ u"ru",u"Chelno-Vershiny",6015,54.433333,51.1 ],
    [ u"ru",u"Chelyabinsk-40",91096,55.755556,60.702778 ],
    [ u"ru",u"Chelyabinsk-70",50086,56.085,60.731389 ],
    [ u"ru",u"Chelyabinsk",1062931,55.154444,61.429722 ],
    [ u"ru",u"Chemal",3284,51.411111,86.005 ],
    [ u"ru",u"Chemodanovka",5002,53.231621,45.247377 ],
    [ u"ru",u"Cherdakly",11939,54.359402,48.84497 ],
    [ u"ru",u"Cherdyn",5585,60.402946,56.478685 ],
    [ u"ru",u"Cheremisinovo",3983,51.8855,37.2646 ],
    [ u"ru",u"Cheremkhovo",57395,53.156111,103.0675 ],
    [ u"ru",u"Cheremnoye",4458,53.169722,83.213333 ],
    [ u"ru",u"Cheremshan",5646,54.666667,51.5 ],
    [ u"ru",u"Cheremshanka",1161,56.119202,60.268036 ],
    [ u"ru",u"Cherëmukhovo",7270,60.348423,59.985068 ],
    [ u"ru",u"Cheremushskiy",1093,61.273056,47.263611 ],
    [ u"ru",u"Cherepanovo",20125,54.2222,83.381 ],
    [ u"ru",u"Cherepet",2070,54.11784,36.378773 ],
    [ u"ru",u"Cherepovets",311854,59.133333,37.9 ],
    [ u"ru",u"Cherkasskoye",3434,52.428947,47.210482 ],
    [ u"ru",u"Cherkessk",117157,44.223333,42.057778 ],
    [ u"ru",u"Cherkizovo",3439,55.975833,37.7875 ],
    [ u"ru",u"Cherlak",12122,54.155,74.8055 ],
    [ u"ru",u"Chermen",8550,43.148611,44.706944 ],
    [ u"ru",u"Chermoz",4079,58.786962,56.14894 ],
    [ u"ru",u"Chërnaya Kholunitsa",1539,58.851145,51.715449 ],
    [ u"ru",u"Chern",6689,53.452316,36.914498 ],
    [ u"ru",u"Chernenko",42778,55.540278,89.200833 ],
    [ u"ru",u"Chernigovka",13969,44.338889,132.572778 ],
    [ u"ru",u"Chernitsyno",2959,51.50739,36.051012 ],
    [ u"ru",u"Chernogolovka",20117,56,38.366667 ],
    [ u"ru",u"Chernogorsk",71583,53.823611,91.284167 ],
    [ u"ru",u"Chernoistochinsk",3646,57.736389,59.871944 ],
    [ u"ru",u"Chernolesskoye",5386,44.715556,43.713333 ],
    [ u"ru",u"Chernomorskiy",8454,44.850556,38.493611 ],
    [ u"ru",u"Chërnoye",5755,55.746111,38.068889 ],
    [ u"ru",u"Chernoyerkovskaya",3856,45.433056,37.768611 ],
    [ u"ru",u"Chernukha",3448,55.597388,43.7556 ],
    [ u"ru",u"Chernushka",35942,56.507215,56.076613 ],
    [ u"ru",u"Chernyakhovsk",45188,54.63345,21.815566 ],
    [ u"ru",u"Chernyanka",15261,50.940947,37.806934 ],
    [ u"ru",u"Chernyshevsk",12466,52.5243,117.0174 ],
    [ u"ru",u"Chernyshevskiy",5137,63.012778,112.471389 ],
    [ u"ru",u"Chernyshkovskiy",5458,48.421875,42.230825 ],
    [ u"ru",u"Chërnyy Yar",8006,48.06242,46.10911 ],
    [ u"ru",u"Cherskiy",3707,68.75,161.3 ],
    [ u"ru",u"Chertkovo",11012,49.384705,40.154709 ],
    [ u"ru",u"Cherusti",2867,55.549756,40.010711 ],
    [ u"ru",u"Chervishevo",3113,56.946347,65.427817 ],
    [ u"ru",u"Chesma",5789,53.811111,60.653333 ],
    [ u"ru",u"Cheuskiny",3752,61.116667,72.4 ],
    [ u"ru",u"Chibizhëk",348,54.397222,93.597778 ],
    [ u"ru",u"Chik",4991,54.9928,82.4311 ],
    [ u"ru",u"Chikola",7142,43.190552,43.920926 ],
    [ u"ru",u"Chikoy",705,50.266111,106.917778 ],
    [ u"ru",u"Chinar",4665,42.107983,48.143206 ],
    [ u"ru",u"Chiri-Yurt",5136,43.088693,45.743225 ],
    [ u"ru",u"Chirkey",7959,42.961314,46.978664 ],
    [ u"ru",u"Chistogorskiy",4240,53.9835,87.3843 ],
    [ u"ru",u"Chistoye",1065,56.537527,43.004452 ],
    [ u"ru",u"Chita",308294,52.031712,113.500867 ],
    [ u"ru",u"Chkalovsk",13577,56.767756,43.25135 ],
    [ u"ru",u"Chkalovskoye",3606,44.839167,133.043611 ],
    [ u"ru",u"Chokurdakh",2506,70.633333,147.916667 ],
    [ u"ru",u"Chontaul",8241,43.304809,46.859673 ],
    [ u"ru",u"Choya",1930,52.0108,86.5467 ],
    [ u"ru",u"Chuchkovo",4404,54.269309,41.446478 ],
    [ u"ru",u"Chudovo",17377,59.116667,31.683333 ],
    [ u"ru",u"Chufarovo",2671,54.0963,47.3367 ],
    [ u"ru",u"Chugunash",657,52.8734,87.7825 ],
    [ u"ru",u"Chuguyevka",13354,44.165278,133.863333 ],
    [ u"ru",u"Chukhloma",5430,58.753748,42.683184 ],
    [ u"ru",u"Chulman",10430,56.8479,124.9104 ],
    [ u"ru",u"Chulym",11975,55.099722,80.957222 ],
    [ u"ru",u"Chumikan",1305,54.718333,135.315 ],
    [ u"ru",u"Chunoyar",3240,57.446667,97.321667 ],
    [ u"ru",u"Chunskiy",16199,56.0815,99.6342 ],
    [ u"ru",u"Chupa",3954,66.270013,33.054858 ],
    [ u"ru",u"Churapcha",7280,62.0025,132.4325 ],
    [ u"ru",u"Chusovoy",50205,58.3013,57.8131 ],
    [ u"ru",u"Dachnoye",4579,42.960668,44.659441 ],
    [ u"ru",u"Dagestanskiye Ogni",27835,42.115886,48.192039 ],
    [ u"ru",u"Dalmatovo",14526,56.26,62.9362 ],
    [ u"ru",u"Dalnegorsk",38454,44.5558,135.5674 ],
    [ u"ru",u"Dalnerechensk",29377,45.933889,133.7225 ],
    [ u"ru",u"Dalneye Konstantinovo",4902,55.810253,44.095949 ],
    [ u"ru",u"Danilov",16808,58.1908,40.171707 ],
    [ u"ru",u"Danilovka",5956,50.355732,44.116807 ],
    [ u"ru",u"Dankov",22914,53.251554,39.155533 ],
    [ u"ru",u"Darasun",7755,51.659398,113.975147 ],
    [ u"ru",u"Darovskoy",7261,58.769992,47.956424 ],
    [ u"ru",u"Dauriya",4058,49.933333,116.866667 ],
    [ u"ru",u"Davenda",978,53.5506,119.3214 ],
    [ u"ru",u"Davlekanovo",23953,54.22145,55.03434 ],
    [ u"ru",u"Davydovka",5841,51.157809,39.429146 ],
    [ u"ru",u"Davydovo",10606,55.608594,38.861087 ],
    [ u"ru",u"Debin",854,62.35,150.766667 ],
    [ u"ru",u"Dedenevo",6455,56.25,37.516667 ],
    [ u"ru",u"Dedovichi",9606,57.551663,29.950176 ],
    [ u"ru",u"Dedovsk",27001,55.868611,37.122222 ],
    [ u"ru",u"Degtyarsk",15294,56.704,60.0879 ],
    [ u"ru",u"De-Kastri",3615,51.466667,140.783333 ],
    [ u"ru",u"Demidov",8516,55.270628,31.514975 ],
    [ u"ru",u"Demikhovo",5474,55.796854,38.884039 ],
    [ u"ru",u"Demyanovo",6228,60.351111,47.084167 ],
    [ u"ru",u"Demyansk",5693,57.643008,32.466 ],
    [ u"ru",u"Deputatskiy",3484,69.3,139.9 ],
    [ u"ru",u"Derbent",105967,42.067795,48.289874 ],
    [ u"ru",u"Dergachi",9570,51.2328,48.7659 ],
    [ u"ru",u"Desnogorsk",32454,54.150769,33.28151 ],
    [ u"ru",u"Detchino",4838,54.809234,36.307499 ],
    [ u"ru",u"Devitsa",4389,51.6352,38.945 ],
    [ u"ru",u"Devyatka",93838,56.251111,93.531944 ],
    [ u"ru",u"Deyskoye",4736,43.475457,44.161824 ],
    [ u"ru",u"Digora",12000,43.158056,44.156944 ],
    [ u"ru",u"Dikson",1113,73.506944,80.546389 ],
    [ u"ru",u"Dimitrovgrad",132228,54.25,49.55 ],
    [ u"ru",u"Dinskaya",34573,45.21782,39.228328 ],
    [ u"ru",u"Diveyevo",6390,55.043289,43.24178 ],
    [ u"ru",u"Divnogorsk",30018,55.9581,92.3726 ],
    [ u"ru",u"Divnomorskoye",5880,44.5017,38.1342 ],
    [ u"ru",u"Divnoye",15700,45.908889,43.354722 ],
    [ u"ru",u"Dmitriyevka",3796,54.448661,55.193746 ],
    [ u"ru",u"Dmitriyevka",9015,52.8832,40.7855 ],
    [ u"ru",u"Dmitriyev-Lgovskiy",8445,52.1257,35.0755 ],
    [ u"ru",u"Dmitriyevskaya",3412,45.656389,40.765278 ],
    [ u"ru",u"Dmitriyevskoye",3442,45.805291,41.89667 ],
    [ u"ru",u"Dmitrov",61608,56.35,37.516667 ],
    [ u"ru",u"Dmitrovsk-Orlovskiy",6366,52.505,35.1464 ],
    [ u"ru",u"Dneprovskaya",3236,45.623586,38.808069 ],
    [ u"ru",u"Dno",9608,57.827718,29.963682 ],
    [ u"ru",u"Dobrinka",10063,52.165278,40.473056 ],
    [ u"ru",u"Dobroye",5550,52.8678,39.8109 ],
    [ u"ru",u"Dobrun",4123,53.18512,34.246245 ],
    [ u"ru",u"Dobryanka",36972,58.461954,56.416455 ],
    [ u"ru",u"Dobryatino",1934,55.5055,41.3195 ],
    [ u"ru",u"Dokshukino",35020,43.5575,43.850833 ],
    [ u"ru",u"Dolakovo",9994,43.237588,44.589639 ],
    [ u"ru",u"Dolgoderevenskoye",6976,55.344444,61.344444 ],
    [ u"ru",u"Dolgoprudnyy",68260,55.904114,37.560643 ],
    [ u"ru",u"Dolgorukovo",5599,52.319454,38.345269 ],
    [ u"ru",u"Dolgoye",4953,52.057778,37.533333 ],
    [ u"ru",u"Dolinsk",11989,47.35,142.8 ],
    [ u"ru",u"Dolmatovskiy",423,57.497988,42.331873 ],
    [ u"ru",u"Dolzhanskaya",7194,46.633694,37.802456 ],
    [ u"ru",u"Dombarovskiy",9556,50.7587,59.5386 ],
    [ u"ru",u"Dombay",405,43.291667,41.621667 ],
    [ u"ru",u"Domna",6576,51.897122,113.157302 ],
    [ u"ru",u"Domodedovo",53888,55.4413,37.75367 ],
    [ u"ru",u"Dondukovskaya",6609,44.881897,40.362708 ],
    [ u"ru",u"Donetsk",47829,48.333722,39.94776 ],
    [ u"ru",u"Donskoy",13627,47.414044,40.257424 ],
    [ u"ru",u"Donskoy",31968,53.68103,38.647755 ],
    [ u"ru",u"Donskoye",3212,54.938424,19.968208 ],
    [ u"ru",u"Donskoye",3860,52.6174,38.9738 ],
    [ u"ru",u"Donskoye",15469,45.455176,41.974109 ],
    [ u"ru",u"Donskoye",4305,52.774946,41.477586 ],
    [ u"ru",u"Dormidontovka",1623,47.77,134.913333 ],
    [ u"ru",u"Dorogino",3762,54.3598,83.3198 ],
    [ u"ru",u"Dorogobuzh",12294,54.915,33.297222 ],
    [ u"ru",u"Dorokhovo",4313,55.550556,36.374444 ],
    [ u"ru",u"Doschatoye",5004,55.3886,42.1032 ],
    [ u"ru",u"Dovolnoye",7220,54.496496,79.667273 ],
    [ u"ru",u"Drakino",3071,51.138978,39.402151 ],
    [ u"ru",u"Drezna",11387,55.742082,38.847526 ],
    [ u"ru",u"Drovyanaya",3090,51.554928,113.037564 ],
    [ u"ru",u"Druzhba",3621,42.241082,47.997981 ],
    [ u"ru",u"Druzhba",3153,44.1953,42.017 ],
    [ u"ru",u"Druzhba",4058,55.886033,37.74267 ],
    [ u"ru",u"Druzhinino",2897,56.78945,59.514283 ],
    [ u"ru",u"Druzhnaya Gorka",3677,59.276111,30.1425 ],
    [ u"ru",u"Duba-Yurt",5751,43.035339,45.730464 ],
    [ u"ru",u"Dubenskiy",596,51.454722,56.633611 ],
    [ u"ru",u"Dubinino",11841,55.619167,89.091111 ],
    [ u"ru",u"Dubki",5576,43.021163,46.837457 ],
    [ u"ru",u"Dubki",388,55.669537,37.211232 ],
    [ u"ru",u"Dubki",3385,57.3,40.25 ],
    [ u"ru",u"Dubna",60605,56.733333,37.166667 ],
    [ u"ru",u"Dubna",6019,54.154165,36.961732 ],
    [ u"ru",u"Dubovka",8946,53.820307,38.008118 ],
    [ u"ru",u"Dubovka",15218,49.058246,44.829004 ],
    [ u"ru",u"Dubovskoye",8019,47.4142,42.7697 ],
    [ u"ru",u"Dubovyy Umët",3105,52.976286,50.285686 ],
    [ u"ru",u"Dubrovka",8427,53.6907,33.5071 ],
    [ u"ru",u"Dubrovka",1916,59.228658,51.155776 ],
    [ u"ru",u"Dubrovka",5405,59.844722,30.934167 ],
    [ u"ru",u"Dudinka",23619,69.405833,86.177778 ],
    [ u"ru",u"Due",195,50.8325,142.101944 ],
    [ u"ru",u"Dugna",783,54.407995,36.852095 ],
    [ u"ru",u"Dugulubgey",20965,43.6625,43.536944 ],
    [ u"ru",u"Dukat",1194,62.55,155.55 ],
    [ u"ru",u"Dukhovnitskoye",5943,52.4828,48.2137 ],
    [ u"ru",u"Dukhovshchina",4494,55.1919,32.4111 ],
    [ u"ru",u"Duldurga",6259,50.676111,113.593056 ],
    [ u"ru",u"Dulyapino",1456,57.257831,40.814715 ],
    [ u"ru",u"Duminichi",7779,53.917637,35.097791 ],
    [ u"ru",u"Durgeli",5185,42.666999,47.294349 ],
    [ u"ru",u"Duvan",3710,55.694968,57.902372 ],
    [ u"ru",u"Dvinskoy",2845,62.153512,45.11751 ],
    [ u"ru",u"Dvubratskiy",10272,45.238879,39.804994 ],
    [ u"ru",u"Dvurechensk",5121,56.5982,61.0953 ],
    [ u"ru",u"Dyadkovskaya",4514,45.553751,39.193336 ],
    [ u"ru",u"Dyakonovo",4031,51.5806,35.9202 ],
    [ u"ru",u"Dyatkovo",33339,53.597822,34.338248 ],
    [ u"ru",u"Dylym",8069,43.070991,46.634541 ],
    [ u"ru",u"Dyshne-Vedeno",3330,42.964345,46.11578 ],
    [ u"ru",u"Dyurtyuli",31088,55.491057,54.868828 ],
    [ u"ru",u"Dzerzhinsk",256540,56.241432,43.455393 ],
    [ u"ru",u"Dzerzhinskiy",41146,55.629448,37.856545 ],
    [ u"ru",u"Dzerzhinskoye",7775,56.834444,95.228333 ],
    [ u"ru",u"Dzhalil",14797,55.0239,52.7358 ],
    [ u"ru",u"Dzhalka",6306,43.318605,45.987872 ],
    [ u"ru",u"Dzhebariki-Khaya",2056,62.216667,135.8 ],
    [ u"ru",u"Dzheguta",3734,43.967095,42.042616 ],
    [ u"ru",u"Dzheyrakh",1174,42.820425,44.681389 ],
    [ u"ru",u"Dzhida",4913,50.677222,106.180556 ],
    [ u"ru",u"Dzhiginka",4079,45.132996,37.338255 ],
    [ u"ru",u"Dzhubga",5314,44.3211,38.7073 ],
    [ u"ru",u"Edissiya",5775,44.051111,44.540833 ],
    [ u"ru",u"Egvekinot",2248,66.316667,-179.166667 ],
    [ u"ru",u"Ekazhevo",25549,43.212222,44.823056 ],
    [ u"ru",u"Ekhabi",507,53.499722,142.968611 ],
    [ u"ru",u"Ekimchan",1177,53.066667,132.966667 ],
    [ u"ru",u"Elban",12531,50.09,136.5 ],
    [ u"ru",u"Elbrus",3476,43.257705,42.644348 ],
    [ u"ru",u"Elbrusskiy",243,43.558234,42.13232 ],
    [ u"ru",u"Eldikan",2050,60.8,135.183333 ],
    [ u"ru",u"Elektrogorsk",20724,55.884309,38.786403 ],
    [ u"ru",u"Elektrostal",144389,55.789593,38.446711 ],
    [ u"ru",u"Elektrougli",16257,55.724448,38.209081 ],
    [ u"ru",u"Elginskiy",379,64.583333,141.783333 ],
    [ u"ru",u"Elista",106972,46.307778,44.255833 ],
    [ u"ru",u"Elkhotovo",12425,43.339498,44.204858 ],
    [ u"ru",u"Emmauss",3404,56.78055,36.115 ],
    [ u"ru",u"Endirey",6927,43.163156,46.65401 ],
    [ u"ru",u"Enem",17665,44.927102,38.908525 ],
    [ u"ru",u"Energetik",9136,51.7445,58.7934 ],
    [ u"ru",u"Engels",196013,51.483889,46.105278 ],
    [ u"ru",u"Engel-Yurt",5508,43.326328,46.360479 ],
    [ u"ru",u"Erken-Shakhar",4170,44.3778,41.9584 ],
    [ u"ru",u"Erpeli",3619,42.805838,46.977321 ],
    [ u"ru",u"Ertil",12622,51.8066,40.516 ],
    [ u"ru",u"Erzin",2952,50.261,95.1623 ],
    [ u"ru",u"Ese-Khayya",332,67.516667,134.666667 ],
    [ u"ru",u"Esso",1965,55.933333,158.7 ],
    [ u"ru",u"Etoka",3152,43.919444,43.048333 ],
    [ u"ru",u"Evensk",2024,61.95,159.233333 ],
    [ u"ru",u"Fakel",2006,57.632457,53.02524 ],
    [ u"ru",u"Fastovetskaya",8806,45.918889,40.158889 ],
    [ u"ru",u"Fatezh",5722,52.0891,35.8632 ],
    [ u"ru",u"Fëdorovskoye",3013,59.663056,30.532222 ],
    [ u"ru",u"Ferma",3402,57.9016,56.3064 ],
    [ u"ru",u"Fershampenuaz",4403,53.5202,59.8117 ],
    [ u"ru",u"Ferzikovo",4344,54.519127,36.756709 ],
    [ u"ru",u"Fevralsk",4510,52.466667,130.716667 ],
    [ u"ru",u"Filimonovo",3127,56.201111,95.461111 ],
    [ u"ru",u"Firovo",2746,57.481354,33.702108 ],
    [ u"ru",u"Firsanovka",2824,55.953611,37.240833 ],
    [ u"ru",u"Foki",3792,56.693005,54.349846 ],
    [ u"ru",u"Fokino",25827,42.983611,132.404722 ],
    [ u"ru",u"Fornosovo",4841,59.568889,30.554444 ],
    [ u"ru",u"Fosforitnyy",4158,55.328917,38.895093 ],
    [ u"ru",u"Frolishchi",1659,56.421772,42.651873 ],
    [ u"ru",u"Frolovo",40882,49.771326,43.662221 ],
    [ u"ru",u"Fryanovo",11088,56.133333,38.45 ],
    [ u"ru",u"Fryazino",52256,55.960556,38.045556 ],
    [ u"ru",u"Furmanov",38381,57.253632,41.108488 ],
    [ u"ru",u"Gagatli",3442,42.801305,46.291618 ],
    [ u"ru",u"Gagino",3933,55.231418,45.03386 ],
    [ u"ru",u"Galashki",6928,43.088056,44.9875 ],
    [ u"ru",u"Galbshtadt",2001,53.2264,78.9845 ],
    [ u"ru",u"Galchino",2980,55.341111,35.713056 ],
    [ u"ru",u"Galich",18595,58.378842,42.346326 ],
    [ u"ru",u"Galimyy",174,62.333333,155.983333 ],
    [ u"ru",u"Galitsy",1060,56.177589,42.84588 ],
    [ u"ru",u"Galyugayevskaya",3313,43.696944,44.934444 ],
    [ u"ru",u"Gamovo",4362,57.8652,56.1056 ],
    [ u"ru",u"Gaptsakh",3501,41.451741,47.930269 ],
    [ u"ru",u"Garbolovo",3830,60.341273,30.495511 ],
    [ u"ru",u"Gari",3134,59.430745,62.349666 ],
    [ u"ru",u"Gastello",1042,49.116667,142.966667 ],
    [ u"ru",u"Gatchina",89763,59.576389,30.128333 ],
    [ u"ru",u"Gavrilovka",700,56.231681,43.724211 ],
    [ u"ru",u"Gavrilovka Vtoraya",2699,52.876971,42.766331 ],
    [ u"ru",u"Gavrilov Posad",6948,56.5593,40.121 ],
    [ u"ru",u"Gavrilov-Yam",18618,57.301852,39.853313 ],
    [ u"ru",u"Gayduk",7266,44.784894,37.700502 ],
    [ u"ru",u"Gay",41620,51.4666,58.4552 ],
    [ u"ru",u"Gayny",4331,60.307069,54.324116 ],
    [ u"ru",u"Gazimurskiy Zavod",2358,51.5461,118.3266 ],
    [ u"ru",u"Gdov",5521,58.744242,27.819767 ],
    [ u"ru",u"Gedzhukh",6816,42.127865,48.064744 ],
    [ u"ru",u"Gekhi",9714,43.163543,45.472379 ],
    [ u"ru",u"Gelendzhik",50715,44.5622,38.0848 ],
    [ u"ru",u"Georgievsk",72652,44.151944,43.469722 ],
    [ u"ru",u"Georgiu-Dezh",55940,50.984053,39.515447 ],
    [ u"ru",u"Georgiyevka",3638,53.274379,50.998484 ],
    [ u"ru",u"Georgiyevskaya",5610,44.111389,43.492222 ],
    [ u"ru",u"Georgiyevskoye",2744,58.731005,45.024041 ],
    [ u"ru",u"Gereykhanovskoye",3418,41.701102,48.281127 ],
    [ u"ru",u"Gerga",3778,42.346452,47.963332 ],
    [ u"ru",u"Gergebil",5107,42.504722,47.066111 ],
    [ u"ru",u"Germenchik",4129,43.593889,43.766111 ],
    [ u"ru",u"Germenchuk",9285,43.185705,45.921004 ],
    [ u"ru",u"Gerzel-Aul",3527,43.247283,46.402488 ],
    [ u"ru",u"Giaginskaya",15169,44.862084,40.07195 ],
    [ u"ru",u"Gidrotorf",7540,56.475619,43.538132 ],
    [ u"ru",u"Gigant",10034,46.506646,41.341848 ],
    [ u"ru",u"Gikalo",5130,43.22831,45.733121 ],
    [ u"ru",u"Gimry",3599,42.759736,46.839591 ],
    [ u"ru",u"Girey",6712,45.4012,40.6587 ],
    [ u"ru",u"Gizel",7256,42.97138,44.574948 ],
    [ u"ru",u"Glazov",100677,58.139411,52.658419 ],
    [ u"ru",u"Glazunovka",6666,52.500573,36.319965 ],
    [ u"ru",u"Glebychevo",3243,60.452903,28.721394 ],
    [ u"ru",u"Glinishchevo",4156,53.304162,34.065226 ],
    [ u"ru",u"Glinka",1964,54.64043,32.878109 ],
    [ u"ru",u"Glotovka",3039,53.949059,46.704218 ],
    [ u"ru",u"Glubokiy",3513,44.946731,41.018451 ],
    [ u"ru",u"Glubokiy",11225,48.527592,40.327923 ],
    [ u"ru",u"Glushkovo",5618,51.339167,34.632778 ],
    [ u"ru",u"Glyadyanskoye",4237,54.9075,65.088333 ],
    [ u"ru",u"Gofitskoye",5493,45.079167,43.046389 ],
    [ u"ru",u"Golitsyno",16056,55.60928,36.982121 ],
    [ u"ru",u"Golovchino",5356,50.5341,35.797 ],
    [ u"ru",u"Golovino",2990,55.849807,40.227425 ],
    [ u"ru",u"Golubitskaya",4138,45.322222,37.282222 ],
    [ u"ru",u"Golynki",3782,54.869638,31.386092 ],
    [ u"ru",u"Golyshmanovo",13424,56.3979,68.372786 ],
    [ u"ru",u"Goragorskiy",4783,43.500199,45.085743 ],
    [ u"ru",u"Gorbatov",2495,56.131103,43.063628 ],
    [ u"ru",u"Gorbatovka",3265,56.257159,43.745774 ],
    [ u"ru",u"Gorbunki",7566,59.818247,29.984076 ],
    [ u"ru",u"Gordeyevka",3005,52.9569,31.9703 ],
    [ u"ru",u"Gorelki",7655,54.256172,37.610799 ],
    [ u"ru",u"Goreloye",3933,52.936971,41.504352 ],
    [ u"ru",u"Gorin",3695,51.198333,136.666944 ],
    [ u"ru",u"Gorkovskiy",15315,48.682356,44.329045 ],
    [ u"ru",u"Gorkovskoye",5644,55.368585,74.368913 ],
    [ u"ru",u"Gorno-Altaysk",54917,51.956111,85.955 ],
    [ u"ru",u"Gorno-Chuyskiy",605,57.642778,111.721944 ],
    [ u"ru",u"Gornopravdinsk",5048,60.05,69.9 ],
    [ u"ru",u"Gornorechenskiy",3409,44.2624,135.1133 ],
    [ u"ru",u"Gornouralskiy",4198,58.0701,59.8703 ],
    [ u"ru",u"Gornoye Loo",3156,43.712939,39.604916 ],
    [ u"ru",u"Gornozavodsk",5579,46.562222,141.847222 ],
    [ u"ru",u"Gornozavodsk",12796,58.375833,58.321111 ],
    [ u"ru",u"Gornyak",15669,50.994167,81.466111 ],
    [ u"ru",u"Gornyak",13946,55.1362,61.6833 ],
    [ u"ru",u"Gornyatskiy",9292,48.291469,40.957498 ],
    [ u"ru",u"Gornyye Klyuchi",5146,45.25,133.5 ],
    [ u"ru",u"Gornyy",1625,50.760833,136.439722 ],
    [ u"ru",u"Gornyy",9807,55.1153,83.9059 ],
    [ u"ru",u"Gornyy",214,44.842222,133.959722 ],
    [ u"ru",u"Gornyy",2716,47.815918,40.203632 ],
    [ u"ru",u"Gornyy",7045,51.7578,48.5413 ],
    [ u"ru",u"Gornyy Shchit",4648,56.688153,60.519469 ],
    [ u"ru",u"Gorodets",31789,56.654932,43.472726 ],
    [ u"ru",u"Gorodishche",3492,51.1249,38.0788 ],
    [ u"ru",u"Gorodishche",8334,53.2775,45.7017 ],
    [ u"ru",u"Gorodishche",19509,48.804542,44.47439 ],
    [ u"ru",u"Gorodovikovsk",10706,46.087847,41.933533 ],
    [ u"ru",u"Gorokhovets",14247,56.201523,42.693508 ],
    [ u"ru",u"Gorshechnoye",6758,51.5244,38.0365 ],
    [ u"ru",u"Goryachegorsk",873,55.401667,88.915556 ],
    [ u"ru",u"Goryachevodskiy",35075,44.023611,43.092222 ],
    [ u"ru",u"Goryachiy Klyuch",28078,44.630833,39.13 ],
    [ u"ru",u"Gostilitsy",3563,59.748316,29.622048 ],
    [ u"ru",u"Goyty",13250,43.164167,45.622778 ],
    [ u"ru",u"Grabovo",7303,53.387514,45.063946 ],
    [ u"ru",u"Grakhovo",3400,56.05017,51.967584 ],
    [ u"ru",u"Gramoteino",14010,54.5368,86.3839 ],
    [ u"ru",u"Grayvoron",6212,50.4767,35.6773 ],
    [ u"ru",u"Grazhdanskoye Pervoye",3097,44.23,42.7698 ],
    [ u"ru",u"Grebenskaya",5066,43.530861,46.371736 ],
    [ u"ru",u"Gremyachinsk",12094,58.5603,57.851 ],
    [ u"ru",u"Gremyachye",3383,51.9742,38.8001 ],
    [ u"ru",u"Gribanovskiy",17220,51.45792,41.976365 ],
    [ u"ru",u"Grigoropolisskaya",9310,45.297222,41.056667 ],
    [ u"ru",u"Gritsovskiy",6568,54.137607,38.160428 ],
    [ u"ru",u"Grivenskaya",5208,45.647302,38.175974 ],
    [ u"ru",u"Grushevskaya",4044,47.439641,39.985982 ],
    [ u"ru",u"Gryazi",47414,52.496573,39.935932 ],
    [ u"ru",u"Gryazovets",16133,58.88,40.2525 ],
    [ u"ru",u"Gubakha",31424,58.871596,57.601492 ],
    [ u"ru",u"Gubden",7997,42.568079,47.565791 ],
    [ u"ru",u"Gubkin",88495,51.281667,37.545833 ],
    [ u"ru",u"Gubkinskiy",20463,64.455278,76.616944 ],
    [ u"ru",u"Gubskaya",3178,44.316389,40.635833 ],
    [ u"ru",u"Gudermes",32769,43.35071,46.109247 ],
    [ u"ru",u"Gukovo",66080,48.0242,39.8737 ],
    [ u"ru",u"Gulkevichi",35843,45.359,40.7026 ],
    [ u"ru",u"Gumrak",5227,48.782553,44.382403 ],
    [ u"ru",u"Gundorovskiy",5210,46.780474,41.896803 ],
    [ u"ru",u"Gunib",2576,42.387581,46.965086 ],
    [ u"ru",u"Gurbuki",4592,42.611284,47.600669 ],
    [ u"ru",u"Gurskoye",822,50.316667,138.116667 ],
    [ u"ru",u"Guryevsk",11653,54.773232,20.605211 ],
    [ u"ru",u"Guryevsk",27160,54.283333,85.933333 ],
    [ u"ru",u"Gusev",28690,54.592222,22.199722 ],
    [ u"ru",u"Gusevskiy",3473,55.661988,40.562668 ],
    [ u"ru",u"Gusino",3211,54.707685,31.409644 ],
    [ u"ru",u"Gusinoye Ozero",3208,51.114444,106.261389 ],
    [ u"ru",u"Gus-Khrustalnyy",65268,55.611131,40.651862 ],
    [ u"ru",u"Gus-Zheleznyy",2381,55.058114,41.16556 ],
    [ u"ru",u"Gvardeysk",15099,54.647721,21.065131 ],
    [ u"ru",u"Gvardeyskoye",7200,43.673056,44.958889 ],
    [ u"ru",u"Gzhatsk",28880,55.552907,34.995369 ],
    [ u"ru",u"Ibresi",9113,55.3011,47.038 ],
    [ u"ru",u"Idrinskoye",5498,54.370833,92.135833 ],
    [ u"ru",u"Idritsa",5623,56.331571,28.898842 ],
    [ u"ru",u"Igarka",7470,67.4655,86.6027 ],
    [ u"ru",u"Iglino",13958,54.832441,56.412641 ],
    [ u"ru",u"Ignatovka",2853,53.947871,47.653601 ],
    [ u"ru",u"Igra",22033,57.546676,53.064691 ],
    [ u"ru",u"Igrim",9545,63.1906,64.4162 ],
    [ u"ru",u"Iki-Burul",3709,45.820833,44.647222 ],
    [ u"ru",u"Ikon-Khalk",4220,44.3051,41.9142 ],
    [ u"ru",u"Ikovka",5243,55.608889,64.9375 ],
    [ u"ru",u"Ikryanoye",9880,46.093232,47.730776 ],
    [ u"ru",u"Iksha",3707,56.166667,37.516667 ],
    [ u"ru",u"Ilanskiy",16668,56.2325,96.0652 ],
    [ u"ru",u"Ilaskhan-Yurt",4496,43.279098,46.102287 ],
    [ u"ru",u"Ilek",9898,51.527091,53.383061 ],
    [ u"ru",u"Ileza",1430,61.053284,43.900208 ],
    [ u"ru",u"Ilinka",4612,46.238299,47.900683 ],
    [ u"ru",u"Ilinogorsk",8291,56.227747,42.953849 ],
    [ u"ru",u"Ilinskaya",4911,45.7223,40.7213 ],
    [ u"ru",u"Ilinskiy",3119,61.013459,32.666308 ],
    [ u"ru",u"Ilinskiy",851,47.997778,142.209167 ],
    [ u"ru",u"Ilinskiy",6342,58.57217,55.696343 ],
    [ u"ru",u"Ilinsko-Podomskoye",2860,61.114444,47.978611 ],
    [ u"ru",u"Ilinskoye-Khovanskoye",3640,56.971802,39.768403 ],
    [ u"ru",u"Ilka",2199,51.7201,108.5161 ],
    [ u"ru",u"Ilovka",3308,50.7053,38.637 ],
    [ u"ru",u"Ilovlya",11930,49.303336,43.979652 ],
    [ u"ru",u"Ilskiy",22612,44.842221,38.566857 ],
    [ u"ru",u"Imeni Babushkina",4026,59.757271,43.128469 ],
    [ u"ru",u"Imeni Karla Libknekhta",8030,51.6195,35.4763 ],
    [ u"ru",u"Imeni Lva Tolstogo",3554,54.609097,36.039122 ],
    [ u"ru",u"Imeni Morozova",10623,59.975723,31.037623 ],
    [ u"ru",u"Imeni Poliny Osipenko",2479,52.4201,136.4853 ],
    [ u"ru",u"Imeni Stepana Razina",3123,54.893203,44.296266 ],
    [ u"ru",u"Imeni Sverdlova",9151,59.796111,30.665833 ],
    [ u"ru",u"Imeni Telmana",1075,48.547222,134.971111 ],
    [ u"ru",u"Imeni Tsyurupy",3926,55.495673,38.650636 ],
    [ u"ru",u"Imeni Vorovskogo",5303,55.731899,38.323684 ],
    [ u"ru",u"Imeni Vorovskogo",2110,55.616667,40.666667 ],
    [ u"ru",u"Imeni Zhelyabova",1261,58.9544,36.5956 ],
    [ u"ru",u"Inderka",4031,53.248456,46.258235 ],
    [ u"ru",u"Industrialnyy",3923,45.094185,39.109643 ],
    [ u"ru",u"Insar",8838,53.865311,44.373824 ],
    [ u"ru",u"Inskoy",13326,54.4297,86.44 ],
    [ u"ru",u"Inta",38403,66.083333,60.133333 ],
    [ u"ru",u"Inza",19737,53.856715,46.356224 ],
    [ u"ru",u"Inzer",4388,54.2167,57.5556 ],
    [ u"ru",u"Inzhavino",10278,52.318474,42.493688 ],
    [ u"ru",u"Ipatovo",29073,45.718056,42.903611 ],
    [ u"ru",u"Irbeyskoye",4681,55.6396,95.4515 ],
    [ u"ru",u"Irbit",41647,57.670525,63.071 ],
    [ u"ru",u"Irgakly",3997,44.361111,44.755556 ],
    [ u"ru",u"Irklievskaya",3068,45.856352,39.653813 ],
    [ u"ru",u"Irkutsk",586702,52.297778,104.296389 ],
    [ u"ru",u"Irsha",1436,55.9273,94.7999 ],
    [ u"ru",u"Irtyshskiy",3284,54.814262,73.587221 ],
    [ u"ru",u"Irtyshskiy",4434,58.333333,68.133333 ],
    [ u"ru",u"Isakly",4417,54.133333,51.533333 ],
    [ u"ru",u"Iset",3191,56.9779,60.3718 ],
    [ u"ru",u"Isetskoye",7170,56.4858,65.3226 ],
    [ u"ru",u"Ishcherskaya",4941,43.713594,45.133706 ],
    [ u"ru",u"Isheyevka",9944,54.42789,48.266746 ],
    [ u"ru",u"Ishimbay",70422,53.454462,56.041487 ],
    [ u"ru",u"Ishim",67763,56.112807,69.490148 ],
    [ u"ru",u"Ishkhoy-Yurt",3051,43.212783,46.389362 ],
    [ u"ru",u"Ishlei",3160,56.023172,47.050535 ],
    [ u"ru",u"Ishnya",3297,57.190696,39.360037 ],
    [ u"ru",u"Isilkul",26429,54.91091,71.272823 ],
    [ u"ru",u"Is",4729,58.79328,59.718321 ],
    [ u"ru",u"Iskateley",6545,67.664439,53.118598 ],
    [ u"ru",u"Iskitim",61828,54.6122,83.4006 ],
    [ u"ru",u"Islamey",10899,43.675556,43.455 ],
    [ u"ru",u"Ispravnaya",4606,44.0682,41.6102 ],
    [ u"ru",u"Issa",5532,53.87049,44.857807 ],
    [ u"ru",u"Istok",3072,52.095278,106.2475 ],
    [ u"ru",u"Istok",5670,56.777,60.8825 ],
    [ u"ru",u"Istra",33391,55.91997,36.868667 ],
    [ u"ru",u"Itaka",431,53.8882,118.7088 ],
    [ u"ru",u"Itatskiy",4235,56.07,89.036944 ],
    [ u"ru",u"Itum-Kale",2922,42.735568,45.575757 ],
    [ u"ru",u"Ivangorod",11074,59.371549,28.216251 ],
    [ u"ru",u"Ivanino",2333,51.6434,35.5769 ],
    [ u"ru",u"Ivanishchi",2149,55.774174,40.42731 ],
    [ u"ru",u"Ivankovskiy",451,56.678076,40.1075 ],
    [ u"ru",u"Ivanovka",6505,50.357778,128.003889 ],
    [ u"ru",u"Ivanovka",3011,43.966389,132.484167 ],
    [ u"ru",u"Ivanovo",420843,56.997192,40.971392 ],
    [ u"ru",u"Ivanovskaya",9415,45.276012,38.464346 ],
    [ u"ru",u"Ivanovskoye",7003,44.5795,41.8764 ],
    [ u"ru",u"Ivanteyevka",51086,55.971111,37.920833 ],
    [ u"ru",u"Ivanteyevka",6127,52.2667,49.1055 ],
    [ u"ru",u"Ivdel",19380,60.691111,60.420556 ],
    [ u"ru",u"Ivnya",7824,51.062939,36.134263 ],
    [ u"ru",u"Ivolginsk",7109,51.749191,107.283743 ],
    [ u"ru",u"Ivot",6294,53.675556,34.187222 ],
    [ u"ru",u"Izberbash",42122,42.569554,47.864471 ],
    [ u"ru",u"Izhevsk",631044,56.849756,53.204479 ],
    [ u"ru",u"Izhevskoye",3703,54.557,40.8753 ],
    [ u"ru",u"Izhma",3599,65.008331,53.911278 ],
    [ u"ru",u"Izhmorskiy",5950,56.194,86.6414 ],
    [ u"ru",u"Izmalkovo",4072,52.688705,37.963978 ],
    [ u"ru",u"Izmaylovo",3075,53.721142,47.245811 ],
    [ u"ru",u"Iznoski",1905,54.988056,35.310833 ],
    [ u"ru",u"Izobilnyy",40122,45.370922,41.708387 ],
    [ u"ru",u"Izoplit",4299,56.625578,36.221982 ],
    [ u"ru",u"Izumrud",1307,56.9701,61.4597 ],
    [ u"ru",u"Izvestkovyy",2159,48.983333,131.55 ],
    [ u"ru",u"Kaa-Khem",10375,51.683333,94.733333 ],
    [ u"ru",u"Kabakovo",3078,54.5218,56.0845 ],
    [ u"ru",u"Kabansk",6257,52.048611,106.652778 ],
    [ u"ru",u"Kabardinka",7395,44.651389,37.942778 ],
    [ u"ru",u"Kachkanar",43984,58.699988,59.49482 ],
    [ u"ru",u"Kachug",7532,53.960556,105.881667 ],
    [ u"ru",u"Kadaya",1167,50.9327,119.2911 ],
    [ u"ru",u"Kadnikov",5312,59.502184,40.338031 ],
    [ u"ru",u"Kadom",6027,54.559167,42.4675 ],
    [ u"ru",u"Kadoshkino",4763,54.0257,44.4191 ],
    [ u"ru",u"Kaduy",11570,59.2,37.15 ],
    [ u"ru",u"Kadykchan",812,63.033333,146.833333 ],
    [ u"ru",u"Kadyy",3783,57.787037,43.190288 ],
    [ u"ru",u"Kafyr-Kumukh",4274,42.83754,47.154123 ],
    [ u"ru",u"Kagalnik",7939,47.076947,39.32301 ],
    [ u"ru",u"Kagalnitskaya",6838,46.880555,40.146566 ],
    [ u"ru",u"Kakashura",5575,42.651944,47.382778 ],
    [ u"ru",u"Kakhun",7490,43.543056,43.876389 ],
    [ u"ru",u"Kalachinsk",24059,55.052862,74.575111 ],
    [ u"ru",u"Kalach-na-Donu",27522,48.690988,43.526381 ],
    [ u"ru",u"Kalanguy",2679,51.016667,116.516667 ],
    [ u"ru",u"Kalashnikovo",5032,57.28237,35.226172 ],
    [ u"ru",u"Kalevala",5431,65.20519,31.175629 ],
    [ u"ru",u"Kalga",3573,50.9251,118.898 ],
    [ u"ru",u"Kalikino",3352,52.9493,39.8269 ],
    [ u"ru",u"Kalininaul",4752,43.071209,46.566786 ],
    [ u"ru",u"Kaliningrad",434959,54.706493,20.510951 ],
    [ u"ru",u"Kalinin",3423,47.246783,39.510884 ],
    [ u"ru",u"Kalinino",34594,45.086677,39.043556 ],
    [ u"ru",u"Kalininskaya",13363,45.484403,38.662212 ],
    [ u"ru",u"Kalininsk",18685,51.5,44.4758 ],
    [ u"ru",u"Kalino",2473,58.2504,57.6085 ],
    [ u"ru",u"Kalinovo",2901,57.1317,60.1464 ],
    [ u"ru",u"Kalinovskaya",8305,43.573832,45.520899 ],
    [ u"ru",u"Kalinovskoye",3951,44.8635,42.9622 ],
    [ u"ru",u"Kalmanka",3628,52.899167,83.543333 ],
    [ u"ru",u"Kalnibolotskaya",6578,46.005825,40.456822 ],
    [ u"ru",u"Kaltan",25904,53.5347,87.2457 ],
    [ u"ru",u"Kaltasy",4454,55.969264,54.803214 ],
    [ u"ru",u"Kaluga",338982,54.529302,36.275415 ],
    [ u"ru",u"Kalya",6676,60.241025,59.989847 ],
    [ u"ru",u"Kalyazin",14655,57.240278,37.843333 ],
    [ u"ru",u"Kama",3439,56.305116,54.093615 ],
    [ u"ru",u"Kambarka",12464,56.269436,54.206167 ],
    [ u"ru",u"Kambileyevskoye",7770,43.078578,44.752165 ],
    [ u"ru",u"Kamenetskiy",2788,54.01353,38.221148 ],
    [ u"ru",u"Kamenka",3258,65.887591,44.112612 ],
    [ u"ru",u"Kamenka",4124,57.392137,41.793828 ],
    [ u"ru",u"Kamenka",3525,43.533333,43.516667 ],
    [ u"ru",u"Kamenka",8071,60.446391,29.082901 ],
    [ u"ru",u"Kamenka",40974,53.181389,44.049444 ],
    [ u"ru",u"Kamenka",1693,44.456944,136.012222 ],
    [ u"ru",u"Kamenka",9450,51.3223,42.7678 ],
    [ u"ru",u"Kamen-na-Obi",44564,53.7884,81.3423 ],
    [ u"ru",u"Kamennogorsk",6208,60.954514,29.133907 ],
    [ u"ru",u"Kamennomostskiy",7585,44.2891,40.188 ],
    [ u"ru",u"Kamennomostskoye",6316,43.737222,43.051389 ],
    [ u"ru",u"Kamenolomni",12262,47.668525,40.205104 ],
    [ u"ru",u"Kamen-Rybolov",11489,44.748056,132.040278 ],
    [ u"ru",u"Kamenskiy",3617,50.885472,45.48801 ],
    [ u"ru",u"Kamenskoye",609,62.5,166.2 ],
    [ u"ru",u"Kamensk-Shakhtinskiy",75815,48.317794,40.259475 ],
    [ u"ru",u"Kamensk-Uralskiy",181884,56.4185,61.9329 ],
    [ u"ru",u"Kameshkovo",13935,56.35305,41.009412 ],
    [ u"ru",u"Kaminskiy",1645,57.151593,41.473181 ],
    [ u"ru",u"Kamskiye Polyany",15077,55.430676,51.417088 ],
    [ u"ru",u"Kamskoye Ustye",4459,55.204,49.2683 ],
    [ u"ru",u"Kamyshevatskaya",5201,46.413159,37.956316 ],
    [ u"ru",u"Kamyshin",128628,50.098331,45.416013 ],
    [ u"ru",u"Kamyshla",4789,54.116933,52.142617 ],
    [ u"ru",u"Kamyshlov",28006,56.842778,62.711111 ],
    [ u"ru",u"Kamyzyak",16191,46.109949,48.073644 ],
    [ u"ru",u"Kanadey",2076,53.167858,47.526436 ],
    [ u"ru",u"Kanashevo",3244,55.2169,62.0634 ],
    [ u"ru",u"Kanash",49886,55.509618,47.491266 ],
    [ u"ru",u"Kandalaksha",38432,67.162002,32.412287 ],
    [ u"ru",u"Kandry",12100,54.533333,54.05 ],
    [ u"ru",u"Kanelovskaya",4332,46.5896,39.1944 ],
    [ u"ru",u"Kanevskaya",45334,46.0849,38.9596 ],
    [ u"ru",u"Kangalassy",1721,62.346389,129.962778 ],
    [ u"ru",u"Kangly",3494,44.254444,43.030833 ],
    [ u"ru",u"Kankunskiy",95,57.625278,126.109444 ],
    [ u"ru",u"Kansk",101503,56.201667,95.7175 ],
    [ u"ru",u"Kantemirovka",12770,49.708871,39.859222 ],
    [ u"ru",u"Kantyshevo",17363,43.214463,44.677116 ],
    [ u"ru",u"Kapustin Yar-1",31922,48.5842,45.7338 ],
    [ u"ru",u"Kapustin Yar",6476,48.581752,45.744807 ],
    [ u"ru",u"Karabanovo",15615,56.316667,38.7 ],
    [ u"ru",u"Karabash",15631,55.4808,60.2157 ],
    [ u"ru",u"Karabash",5149,54.692998,52.583586 ],
    [ u"ru",u"Karabudakhkent",13207,42.708703,47.56735 ],
    [ u"ru",u"Karabulak",34512,43.305128,44.899489 ],
    [ u"ru",u"Karachev",19758,53.122918,34.985167 ],
    [ u"ru",u"Karagach",5870,43.805278,43.775 ],
    [ u"ru",u"Karagay",6586,58.26669,54.936783 ],
    [ u"ru",u"Karagaylinskiy",4326,54.1465,86.6044 ],
    [ u"ru",u"Karaidel",5184,55.833725,56.906922 ],
    [ u"ru",u"Karaidelskiy",201,55.821827,57.106155 ],
    [ u"ru",u"Karakulino",5052,56.012004,53.706691 ],
    [ u"ru",u"Karamakhi",3904,42.619336,47.260171 ],
    [ u"ru",u"Karamken",691,60.2,151.166667 ],
    [ u"ru",u"Karasuk",28589,53.737718,78.040255 ],
    [ u"ru",u"Karata",4838,42.594858,46.339299 ],
    [ u"ru",u"Karatuzskoye",7900,53.607222,92.866667 ],
    [ u"ru",u"Kara-Tyube",3359,44.633611,45.436944 ],
    [ u"ru",u"Karaul",824,70.076667,83.191389 ],
    [ u"ru",u"Karavayevo",7472,57.736389,41.074167 ],
    [ u"ru",u"Kardailovo",3036,51.538611,53.904167 ],
    [ u"ru",u"Kardonikskaya",7830,43.865774,41.71432 ],
    [ u"ru",u"Kardymovo",4951,54.890164,32.431113 ],
    [ u"ru",u"Kardzhin",3154,43.264639,44.295374 ],
    [ u"ru",u"Kargala",1973,51.890667,54.869167 ],
    [ u"ru",u"Kargalinskaya",5371,43.743813,46.478211 ],
    [ u"ru",u"Kargapolye",8547,55.864167,64.216944 ],
    [ u"ru",u"Kargasok",8572,59.055556,80.857222 ],
    [ u"ru",u"Kargat",10881,55.195556,80.281111 ],
    [ u"ru",u"Kargopol",10966,61.507072,38.945636 ],
    [ u"ru",u"Karmaskaly",7858,54.3709,56.1837 ],
    [ u"ru",u"Karpinsk",30071,59.7654,60.0085 ],
    [ u"ru",u"Karpogory",4441,64.001893,44.445128 ],
    [ u"ru",u"Karpuninskiy",588,58.7165,61.798506 ],
    [ u"ru",u"Karpushikha",1497,57.501667,59.895556 ],
    [ u"ru",u"Karsun",8128,54.199409,46.982697 ],
    [ u"ru",u"Kartaly",28504,53.052222,60.646667 ],
    [ u"ru",u"Karymskoye",11901,51.616667,114.35 ],
    [ u"ru",u"Kashary",6292,49.04001,41.005569 ],
    [ u"ru",u"Kashin",16599,57.359167,37.608056 ],
    [ u"ru",u"Kashira",40084,54.844444,38.166944 ],
    [ u"ru",u"Kashirskoye",4564,51.419446,39.612479 ],
    [ u"ru",u"Kashkhatau",5367,43.318484,43.60804 ],
    [ u"ru",u"Kasimov",35355,54.90271,41.336431 ],
    [ u"ru",u"Kasli",17911,55.8909,60.7616 ],
    [ u"ru",u"Kaspiyskiy",14045,45.392878,47.370728 ],
    [ u"ru",u"Kaspiysk",81753,42.881648,47.639194 ],
    [ u"ru",u"Kastornoye",4390,51.8334,38.1302 ],
    [ u"ru",u"Kasumkent",12225,41.677248,48.146009 ],
    [ u"ru",u"Katangli",850,51.7,143.233333 ],
    [ u"ru",u"Katav-Ivanovsk",19339,54.753056,58.195556 ],
    [ u"ru",u"Kataysk",15620,56.289,62.5841 ],
    [ u"ru",u"Katunino",3255,64.3862,40.6298 ],
    [ u"ru",u"Katunki",815,56.831305,43.219679 ],
    [ u"ru",u"Katyr-Yurt",9202,43.170066,45.371139 ],
    [ u"ru",u"Kavalerovo",16945,44.2661,135.0572 ],
    [ u"ru",u"Kavkazskaya",11680,45.4453,40.6765 ],
    [ u"ru",u"Kavkazskiy",3052,44.2672,42.2347 ],
    [ u"ru",u"Kayakent",11805,42.387356,47.903007 ],
    [ u"ru",u"Kayasula",4982,44.325,45 ],
    [ u"ru",u"Kayerkan",27295,69.378611,87.743889 ],
    [ u"ru",u"Kazachinskoye",2581,56.266667,107.58 ],
    [ u"ru",u"Kazachinskoye",3987,57.7004,93.2809 ],
    [ u"ru",u"Kazachka",1042,53.3644,38.0694 ],
    [ u"ru",u"Kazaki",3227,52.624837,38.264876 ],
    [ u"ru",u"Kazan",1104750,55.78874,49.122144 ],
    [ u"ru",u"Kazanovka",781,53.634167,38.046667 ],
    [ u"ru",u"Kazanskaya",10794,45.4106,40.4361 ],
    [ u"ru",u"Kazanskaya",4946,49.793333,41.146667 ],
    [ u"ru",u"Kazanskoye",5851,55.644774,69.235003 ],
    [ u"ru",u"Kaz",4854,52.9113,87.3105 ],
    [ u"ru",u"Kazminskoye",6078,44.5872,41.6734 ],
    [ u"ru",u"Kaznacheyevskiy",465,54.027578,37.559916 ],
    [ u"ru",u"Kedrovka",17752,55.533333,86.05 ],
    [ u"ru",u"Kedrovoye",2163,57.1576,60.5698 ],
    [ u"ru",u"Kedrovyy",3061,57.519722,79.515556 ],
    [ u"ru",u"Kemerovo",477096,55.333333,86.083333 ],
    [ u"ru",u"Kem",13830,64.95546,34.579294 ],
    [ u"ru",u"Kemlya",4761,54.639,45.736 ],
    [ u"ru",u"Kenzhe",10636,43.501667,43.557222 ],
    [ u"ru",u"Kerchevskiy",2990,59.945957,56.288369 ],
    [ u"ru",u"Kerva",2784,55.611669,39.576652 ],
    [ u"ru",u"Kerzhenets",668,56.467369,44.423392 ],
    [ u"ru",u"Kesova Gora",3946,57.583611,37.292222 ],
    [ u"ru",u"Ketchenery",3834,47.308682,44.521617 ],
    [ u"ru",u"Ketovo",6966,55.355,65.325833 ],
    [ u"ru",u"Kevsala",3532,45.798333,42.690278 ],
    [ u"ru",u"Kez",10792,57.897855,53.715207 ],
    [ u"ru",u"Khabarovsk",578307,48.480833,135.092778 ],
    [ u"ru",u"Khabary",5895,53.625877,79.534501 ],
    [ u"ru",u"Khabez",5806,44.0434,41.772 ],
    [ u"ru",u"Khadyzhensk",21685,44.4258,39.5362 ],
    [ u"ru",u"Khadzhalmakhi",6088,42.419997,47.182056 ],
    [ u"ru",u"Khakurinokhabl",3830,45.010278,40.225 ],
    [ u"ru",u"Khalimbekaul",4292,42.845994,47.138725 ],
    [ u"ru",u"Khamamatyurt",4935,43.608091,46.500602 ],
    [ u"ru",u"Khambi-Irze",3130,43.23502,45.453024 ],
    [ u"ru",u"Khandagayty",3146,50.733333,92.05 ],
    [ u"ru",u"Khandyga",6796,62.666667,135.6 ],
    [ u"ru",u"Khani",903,57.033333,120.966667 ],
    [ u"ru",u"Khanino",1256,54.211002,36.622923 ],
    [ u"ru",u"Khankala",7925,43.302121,45.755638 ],
    [ u"ru",u"Khanskaya",11297,44.67702,39.961599 ],
    [ u"ru",u"Kharabali",18224,47.419585,47.256781 ],
    [ u"ru",u"Kharitonovo",1402,61.400924,47.497792 ],
    [ u"ru",u"Kharovsk",11115,59.964247,40.19121 ],
    [ u"ru",u"Kharp",7298,66.801389,65.808056 ],
    [ u"ru",u"Khasan",776,42.422222,130.653056 ],
    [ u"ru",u"Khasanya",10495,43.433333,43.578611 ],
    [ u"ru",u"Khatanga",3205,71.966667,102.5 ],
    [ u"ru",u"Khatassy",3676,61.903611,129.638333 ],
    [ u"ru",u"Khatukay",4538,45.190742,39.663205 ],
    [ u"ru",u"Khazar",3736,41.997402,48.333246 ],
    [ u"ru",u"Khebda",2749,42.444233,46.551722 ],
    [ u"ru",u"Khelyulya",3082,61.733333,30.683333 ],
    [ u"ru",u"Khilok",10627,51.3674,110.4676 ],
    [ u"ru",u"Khimki",142620,55.897037,37.429687 ],
    [ u"ru",u"Khingansk",2093,49.116667,131.183333 ],
    [ u"ru",u"Khislavichi",4496,54.187142,32.158166 ],
    [ u"ru",u"Khiv",2401,41.754277,47.930634 ],
    [ u"ru",u"Khlevnoye",6150,52.195116,39.093164 ],
    [ u"ru",u"Khodz",3028,44.5102,40.7142 ],
    [ u"ru",u"Khokhlovo",2478,59.149231,37.39978 ],
    [ u"ru",u"Khokhol",4876,51.5628,38.7683 ],
    [ u"ru",u"Khokholskiy",7776,51.5628,38.7683 ],
    [ u"ru",u"Khokhryaki",3544,56.915608,53.322102 ],
    [ u"ru",u"Kholbon",2537,51.883333,116.25 ],
    [ u"ru",u"Kholm",4228,59.266667,32.85 ],
    [ u"ru",u"Kholmogory",4417,64.2229,41.656 ],
    [ u"ru",u"Kholmskaya",17494,44.846944,38.385 ],
    [ u"ru",u"Kholmsk",32682,47.051111,142.056944 ],
    [ u"ru",u"Kholm-Zhirkovskiy",3726,55.518889,33.473056 ],
    [ u"ru",u"Kholodnyy",1247,62.716667,147.95 ],
    [ u"ru",u"Kholst",45,42.82777,44.145644 ],
    [ u"ru",u"Kholtoson",1040,50.2981,103.3097 ],
    [ u"ru",u"Kholuy",996,56.577317,41.867299 ],
    [ u"ru",u"Khomutovka",4936,51.9207,34.5619 ],
    [ u"ru",u"Khomutovo",4918,52.465833,104.4025 ],
    [ u"ru",u"Khomutovo",4647,52.853863,37.438799 ],
    [ u"ru",u"Khonuu",2413,66.45,143.1 ],
    [ u"ru",u"Khorinsk",7986,52.1657,109.7726 ],
    [ u"ru",u"Khor",11503,47.886111,134.946389 ],
    [ u"ru",u"Khorlovo",3852,55.332697,38.813647 ],
    [ u"ru",u"Khorol",11245,44.426111,132.0725 ],
    [ u"ru",u"Khotkovo",20464,56.25,38 ],
    [ u"ru",u"Khotynets",4182,53.128601,35.396599 ],
    [ u"ru",u"Khovu-Aksy",3675,51.133333,93.6 ],
    [ u"ru",u"Khrebtovaya",2017,56.7032,104.2494 ],
    [ u"ru",u"Khrenovoye",5476,51.12,40.288889 ],
    [ u"ru",u"Khristoforovo",817,60.898931,47.253413 ],
    [ u"ru",u"Khrustalnyy",3577,44.350556,135.097222 ],
    [ u"ru",u"Khryashchevka",3210,53.8119,49.0916 ],
    [ u"ru",u"Khuchni",3637,41.949859,47.948538 ],
    [ u"ru",u"Khumalag",3906,43.240311,44.475208 ],
    [ u"ru",u"Khunzakh",3955,42.542404,46.70689 ],
    [ u"ru",u"Khurba",5537,50.407222,136.881944 ],
    [ u"ru",u"Khuzhir",1118,53.193889,107.339722 ],
    [ u"ru",u"Khvalynsk",13438,52.4906,48.1058 ],
    [ u"ru",u"Khvastovichi",4545,53.46942,35.094093 ],
    [ u"ru",u"Khvatovka",2301,52.35236,46.562823 ],
    [ u"ru",u"Khvorostyanka",4899,52.6096,48.9597 ],
    [ u"ru",u"Khvoynaya",6637,58.9,34.533333 ],
    [ u"ru",u"Kichera",1593,55.9375,110.099722 ],
    [ u"ru",u"Kichmengskiy Gorodok",6624,59.981644,45.785433 ],
    [ u"ru",u"Kidero",655,42.193699,45.95882 ],
    [ u"ru",u"Kikerino",1995,59.462043,29.629934 ],
    [ u"ru",u"Kiknur",5246,57.27,47.1845 ],
    [ u"ru",u"Kildinstroy",2699,68.803881,33.099369 ],
    [ u"ru",u"Kilemary",3903,56.778253,46.865937 ],
    [ u"ru",u"Kilmez",5880,56.943894,51.065003 ],
    [ u"ru",u"Kilmez",3106,57.013844,51.340555 ],
    [ u"ru",u"Kimovsk",31947,53.971638,38.53186 ],
    [ u"ru",u"Kimry",52071,56.866667,37.35 ],
    [ u"ru",u"Kinel-Cherkassy",18393,53.470596,51.474305 ],
    [ u"ru",u"Kinel",34337,53.225708,50.629074 ],
    [ u"ru",u"Kineshma",92984,57.439139,42.128943 ],
    [ u"ru",u"Kingisepp",50567,59.373314,28.613433 ],
    [ u"ru",u"Kipen",3098,59.676486,29.853107 ],
    [ u"ru",u"Kirensk",13309,57.785278,108.111944 ],
    [ u"ru",u"Kireyevsk",25513,53.933607,37.927924 ],
    [ u"ru",u"Kirgiz-Miyaki",7673,53.6324,54.7979 ],
    [ u"ru",u"Kirillov",8236,59.862993,38.381275 ],
    [ u"ru",u"Kirishi",56191,59.447119,32.020494 ],
    [ u"ru",u"Kirovgrad",22685,57.429722,60.059722 ],
    [ u"ru",u"Kirov",39319,54.066863,34.29955 ],
    [ u"ru",u"Kirov",457387,58.596654,49.660068 ],
    [ u"ru",u"Kirovo-Chepetsk",90253,58.553859,50.03986 ],
    [ u"ru",u"Kirovskaya",5918,46.9748,40.0402 ],
    [ u"ru",u"Kirovskiy",2249,45.846389,48.124722 ],
    [ u"ru",u"Kirovskiy",3043,51.289432,36.705602 ],
    [ u"ru",u"Kirovskiy",9467,45.091667,133.513611 ],
    [ u"ru",u"Kirovsk",24678,59.881009,30.995068 ],
    [ u"ru",u"Kirovsk",29606,67.614749,33.672739 ],
    [ u"ru",u"Kirpilskaya",5727,45.374688,39.699017 ],
    [ u"ru",u"Kirsanov",17975,52.654941,42.722361 ],
    [ u"ru",u"Kirs",11385,59.338825,52.244671 ],
    [ u"ru",u"Kirya",2402,55.081023,46.860906 ],
    [ u"ru",u"Kirzhach",22131,55.911315,39.079457 ],
    [ u"ru",u"Kishcha",3821,42.176769,47.581172 ],
    [ u"ru",u"Kishpek",4327,43.655,43.640833 ],
    [ u"ru",u"Kislovodsk",132773,43.913333,42.720833 ],
    [ u"ru",u"Kislyakovskaya",5501,46.4417,39.675 ],
    [ u"ru",u"Kitovo",2934,56.865861,41.282461 ],
    [ u"ru",u"Kitoy",3953,52.595278,103.855556 ],
    [ u"ru",u"Kiyasovo",3265,56.349073,53.124392 ],
    [ u"ru",u"Kiyevskoye",4727,45.038287,37.888295 ],
    [ u"ru",u"Kizel",21808,59.059207,57.635603 ],
    [ u"ru",u"Kizema",3644,61.113044,44.83017 ],
    [ u"ru",u"Kizhinga",6459,51.8462,109.9097 ],
    [ u"ru",u"Kizilskoye",6449,52.723333,58.898889 ],
    [ u"ru",u"Kizlyar",50565,43.847118,46.714446 ],
    [ u"ru",u"Kizlyar",8544,43.703785,44.594402 ],
    [ u"ru",u"Kizner",9847,56.274888,51.507996 ],
    [ u"ru",u"Kletnya",13658,53.389674,33.217141 ],
    [ u"ru",u"Kletskaya",5362,49.31455,43.058437 ],
    [ u"ru",u"Klichka",2514,50.4457,117.996 ],
    [ u"ru",u"Klimovo",14482,52.380534,32.192328 ],
    [ u"ru",u"Klimovsk",55207,55.363521,37.529841 ],
    [ u"ru",u"Klin",80779,56.333333,36.733333 ],
    [ u"ru",u"Klintsy",66337,52.760186,32.239345 ],
    [ u"ru",u"Klyavlino",6318,54.264906,52.026738 ],
    [ u"ru",u"Klyazma",3439,55.975833,37.846111 ],
    [ u"ru",u"Klyuchevskiy",1621,53.5317,119.4519 ],
    [ u"ru",u"Klyuchevsk",1955,57.1216,60.9414 ],
    [ u"ru",u"Klyuchi",9205,52.266667,79.166667 ],
    [ u"ru",u"Klyuchi",6496,56.3,160.85 ],
    [ u"ru",u"Knevichi",4605,43.405,132.188889 ],
    [ u"ru",u"Knyaginino",6923,55.82278,45.034886 ],
    [ u"ru",u"Knyaze-Volkonskoye",8936,48.464167,135.456667 ],
    [ u"ru",u"Koboldo",530,52.966667,132.7 ],
    [ u"ru",u"Kobrinskoye",1158,59.4225,30.123889 ],
    [ u"ru",u"Kochevo",3261,59.599396,54.312481 ],
    [ u"ru",u"Kochki",4101,54.335833,80.480556 ],
    [ u"ru",u"Kochkurovo",3185,54.035762,45.418448 ],
    [ u"ru",u"Kochubeyevskoye",28491,44.649651,41.841779 ],
    [ u"ru",u"Kochubey",6815,44.386111,46.5825 ],
    [ u"ru",u"Kodino",1970,63.719756,39.644651 ],
    [ u"ru",u"Kodinsk",15672,58.688056,99.184444 ],
    [ u"ru",u"Kokhma",28984,56.934865,41.091504 ],
    [ u"ru",u"Kokino",4616,52.4964,34.7808 ],
    [ u"ru",u"Kokorevka",2403,52.5874,34.2692 ],
    [ u"ru",u"Kokoshkino",9818,55.597692,37.169501 ],
    [ u"ru",u"Kokrek",4181,43.236392,46.726647 ],
    [ u"ru",u"Koksovyy",8458,48.200579,40.650894 ],
    [ u"ru",u"Kokuy",7767,52.2037,117.5529 ],
    [ u"ru",u"Kola",10282,68.880621,33.018422 ],
    [ u"ru",u"Kolchugino",47080,56.299293,39.383036 ],
    [ u"ru",u"Kolendo",36,53.764444,142.787778 ],
    [ u"ru",u"Kolobovo",2910,56.70199,41.341728 ],
    [ u"ru",u"Kolodeznyy",5857,51.333333,39.183333 ],
    [ u"ru",u"Kologriv",3605,58.827483,44.317769 ],
    [ u"ru",u"Kolomna",147692,55.079444,38.778333 ],
    [ u"ru",u"Kolosovka",5759,56.467786,73.610957 ],
    [ u"ru",u"Kolpashevo",27876,58.313056,82.908889 ],
    [ u"ru",u"Kolpino",136078,59.744167,30.579444 ],
    [ u"ru",u"Kolpny",7081,52.228231,37.036828 ],
    [ u"ru",u"Koltsovo",9447,54.9376,83.1825 ],
    [ u"ru",u"Koltsovo",14493,56.774748,60.825227 ],
    [ u"ru",u"Koltubanovskiy",3831,52.9407,52.0269 ],
    [ u"ru",u"Kolyshley",8371,52.7005,44.5367 ],
    [ u"ru",u"Kolyubakino",2724,55.668004,36.532345 ],
    [ u"ru",u"Kolyvan",10807,55.3053,82.7391 ],
    [ u"ru",u"Komarichi",7090,52.4151,34.7905 ],
    [ u"ru",u"Komarikhinskiy",1510,58.0979,57.1163 ],
    [ u"ru",u"Komarovo",1039,60.184083,29.817523 ],
    [ u"ru",u"Kommunarka",4684,55.569519,37.489322 ],
    [ u"ru",u"Kommunar",2730,54.353889,89.292222 ],
    [ u"ru",u"Kommunar",17359,59.620556,30.39 ],
    [ u"ru",u"Kommunar",3135,56.112218,40.44666 ],
    [ u"ru",u"Kommunisticheskiy",2690,61.678889,64.481944 ],
    [ u"ru",u"Komsomolets",3143,44.019722,43.569722 ],
    [ u"ru",u"Komsomolets",3678,52.768602,41.286825 ],
    [ u"ru",u"Komsomolskiy",556,69.166667,172.7 ],
    [ u"ru",u"Komsomolskiy",2748,43.978329,46.69852 ],
    [ u"ru",u"Komsomolskiy",3878,45.330002,46.042798 ],
    [ u"ru",u"Komsomolskiy",3846,67.55,63.783333 ],
    [ u"ru",u"Komsomolskiy",13906,54.445219,45.831358 ],
    [ u"ru",u"Komsomolskiy",3198,53.236404,50.842207 ],
    [ u"ru",u"Komsomolskiy",2899,53.904603,38.264543 ],
    [ u"ru",u"Komsomolskiy",3280,57.4637,57.1269 ],
    [ u"ru",u"Komsomolsk",9156,57.029132,40.372664 ],
    [ u"ru",u"Komsomolsk",2566,55.645,88.179167 ],
    [ u"ru",u"Komsomolsk-na-Amure",275168,50.551986,137.015244 ],
    [ u"ru",u"Komsomolskoye",4793,55.261027,47.544734 ],
    [ u"ru",u"Komsomolskoye",8710,43.195644,46.895302 ],
    [ u"ru",u"Komsomolskoye",3112,43.389548,46.155166 ],
    [ u"ru",u"Konakovo",42240,56.7,36.766667 ],
    [ u"ru",u"Kondinskoye",4166,59.648056,67.41 ],
    [ u"ru",u"Kondol",3612,52.818889,45.057977 ],
    [ u"ru",u"Kondopoga",34360,62.205654,34.261382 ],
    [ u"ru",u"Kondratovo",5594,57.9804,56.1066 ],
    [ u"ru",u"Kondrovo",17151,54.806389,35.927778 ],
    [ u"ru",u"Konëvo",2951,62.121522,39.319207 ],
    [ u"ru",u"Konokovo",7507,44.8616,41.3266 ],
    [ u"ru",u"Konosha",12383,60.9736,40.257 ],
    [ u"ru",u"Konstantinovka",5702,49.616667,127.983333 ],
    [ u"ru",u"Konstantinovo",3565,56.55,38.033333 ],
    [ u"ru",u"Konstantinovskaya",4149,44.835278,40.726944 ],
    [ u"ru",u"Konstantinovskaya",7137,44.045556,43.158333 ],
    [ u"ru",u"Konstantinovskiy",5718,57.830054,39.589891 ],
    [ u"ru",u"Konstantinovsk",18876,47.582778,41.092222 ],
    [ u"ru",u"Konstantinovskoye",5816,45.299167,42.636667 ],
    [ u"ru",u"Konyshevka",4038,51.8418,35.2941 ],
    [ u"ru",u"Kopanskaya",4008,46.277853,38.47955 ],
    [ u"ru",u"Kopeysk",70786,55.131,61.6792 ],
    [ u"ru",u"Kopyevo",4863,54.991389,89.8225 ],
    [ u"ru",u"Korablino",14469,53.916389,40.013333 ],
    [ u"ru",u"Korenëvo",7319,55.671944,38.007778 ],
    [ u"ru",u"Korenovsk",41666,45.468993,39.451364 ],
    [ u"ru",u"Korfovskiy",5652,48.218333,135.056389 ],
    [ u"ru",u"Korkino",40047,54.8913,61.3969 ],
    [ u"ru",u"Korkmaskala",6402,43.023789,47.294364 ],
    [ u"ru",u"Kormilovka",10166,55.002644,74.10281 ],
    [ u"ru",u"Korocha",6081,50.813203,37.185976 ],
    [ u"ru",u"Korsakov",35091,46.632768,142.781296 ],
    [ u"ru",u"Korsakovo",1465,53.267665,37.35689 ],
    [ u"ru",u"Kortkeros",4429,61.810565,51.580564 ],
    [ u"ru",u"Koryazhma",42628,61.31433,47.169136 ],
    [ u"ru",u"Korzhevskiy",3927,45.194136,37.719488 ],
    [ u"ru",u"Kosa",2199,59.944528,54.997704 ],
    [ u"ru",u"Kosaya Gora",17619,54.118956,37.544592 ],
    [ u"ru",u"Kosh-Agach",5732,50,88.666667 ],
    [ u"ru",u"Koshekhabl",7313,44.897222,40.511944 ],
    [ u"ru",u"Koshkeldy",5221,43.250233,46.352658 ],
    [ u"ru",u"Koshki",8086,54.209142,50.467667 ],
    [ u"ru",u"Koshurnikovo",3743,54.166667,93.3 ],
    [ u"ru",u"Kosikha",5612,53.361667,84.582222 ],
    [ u"ru",u"Kosino",2330,58.412719,51.27819 ],
    [ u"ru",u"Koslan",2547,63.456415,48.898912 ],
    [ u"ru",u"Kosmynino",1670,57.550838,40.737585 ],
    [ u"ru",u"Kostek",4137,43.343865,46.854111 ],
    [ u"ru",u"Kosterevo",9350,55.929895,39.614376 ],
    [ u"ru",u"Kostino",3466,58.909656,53.269066 ],
    [ u"ru",u"Kostomuksha",30138,64.686485,30.815064 ],
    [ u"ru",u"Kostroma",277658,57.766468,40.926864 ],
    [ u"ru",u"Kosya",504,58.795629,59.349606 ],
    [ u"ru",u"Kotelnich",26837,58.3089,48.348 ],
    [ u"ru",u"Kotelniki",17601,55.635464,37.844504 ],
    [ u"ru",u"Kotelnikovo",19424,47.63009,43.140682 ],
    [ u"ru",u"Kotlas",59181,61.257452,46.649634 ],
    [ u"ru",u"Kotlyarevskaya",3887,43.573442,44.061344 ],
    [ u"ru",u"Kotovo",26981,50.321128,44.80119 ],
    [ u"ru",u"Kotovsk",33077,52.58666,41.502104 ],
    [ u"ru",u"Kovalevskoye",3139,45.1665,41.0039 ],
    [ u"ru",u"Kovdor",19519,67.566165,30.475758 ],
    [ u"ru",u"Kovernino",6759,57.128177,43.813501 ],
    [ u"ru",u"Kovrov",154226,56.357222,41.319167 ],
    [ u"ru",u"Kovylkino",21838,54.038764,43.913855 ],
    [ u"ru",u"Koyelga",4053,54.652238,60.904895 ],
    [ u"ru",u"Koygorodok",2924,60.444984,50.996802 ],
    [ u"ru",u"Kozelsk",19809,54.037457,35.771589 ],
    [ u"ru",u"Kozhevnikovo",7970,56.258889,83.971389 ],
    [ u"ru",u"Kozhva",3374,65.107269,57.045903 ],
    [ u"ru",u"Kozhym",53,65.734,59.524353 ],
    [ u"ru",u"Kozlovka",13069,55.842837,48.249198 ],
    [ u"ru",u"Kozlovka",3343,50.862222,40.455556 ],
    [ u"ru",u"Kozlovo",4248,56.509771,36.273258 ],
    [ u"ru",u"Kozmodemyansk",22536,56.341898,46.563528 ],
    [ u"ru",u"Kozulka",8663,56.1606,91.3858 ],
    [ u"ru",u"Krapivinskiy",7909,54.9992,86.8133 ],
    [ u"ru",u"Krasavino",7912,60.962251,46.483206 ],
    [ u"ru",u"Kraskino",3369,42.711389,130.779444 ],
    [ u"ru",u"Kraskovo",11832,55.649722,37.987778 ],
    [ u"ru",u"Krasnaya Gora",6468,52.9995,31.6023 ],
    [ u"ru",u"Krasnaya Gorbatka",9225,55.8703,41.7641 ],
    [ u"ru",u"Krasnaya Gorka",4079,55.196168,56.667266 ],
    [ u"ru",u"Krasnaya Gorka",1088,55.386663,46.10925 ],
    [ u"ru",u"Krasnaya Polyana",7828,56.242044,51.14425 ],
    [ u"ru",u"Krasnaya Polyana",3090,45.0548,41.1031 ],
    [ u"ru",u"Krasnaya Polyana",3728,46.112927,41.501569 ],
    [ u"ru",u"Krasnaya Poyma",3113,55.001378,39.079973 ],
    [ u"ru",u"Krasnaya Yaruga",7924,50.800833,35.658333 ],
    [ u"ru",u"Krasnaya Zarya",1802,52.7825,37.680556 ],
    [ u"ru",u"Krasnenkaya",4489,52.760921,41.449989 ],
    [ u"ru",u"Krasnoarmeyskiy",3716,47.0114,42.2072 ],
    [ u"ru",u"Krasnoarmeysk",25689,56.1,38.133333 ],
    [ u"ru",u"Krasnoarmeysk",25841,51.023889,45.696944 ],
    [ u"ru",u"Krasnoarmeyskoye",4296,55.768128,47.172438 ],
    [ u"ru",u"Krasnoarmeyskoye",5403,52.7196,50.0213 ],
    [ u"ru",u"Krasnoborsk",4838,61.559777,45.933956 ],
    [ u"ru",u"Krasnobrodskiy",11565,54.1581,86.4486 ],
    [ u"ru",u"Krasnodar",649860,45.0488,38.9725 ],
    [ u"ru",u"Krasnofarfornyy",1613,59.136403,31.850232 ],
    [ u"ru",u"Krasnogorodsk",4563,56.835685,28.282236 ],
    [ u"ru",u"Krasnogorskiy",13603,54.6025,61.231 ],
    [ u"ru",u"Krasnogorskiy",2994,54.5471,86.281 ],
    [ u"ru",u"Krasnogorskiy",7065,56.1525,48.325833 ],
    [ u"ru",u"Krasnogorsk",92934,55.820356,37.330166 ],
    [ u"ru",u"Krasnogorsk",3304,48.4,142.1 ],
    [ u"ru",u"Krasnogorskoye",6703,52.2953,86.1979 ],
    [ u"ru",u"Krasnogorskoye",4508,57.708286,52.500024 ],
    [ u"ru",u"Krasnogvardeyets",3836,52.6804,52.3635 ],
    [ u"ru",u"Krasnogvardeyskiy",4746,57.379279,62.319523 ],
    [ u"ru",u"Krasnogvardeyskoye",9071,45.099969,39.544536 ],
    [ u"ru",u"Krasnogvardeyskoye",8183,50.6492,38.4036 ],
    [ u"ru",u"Krasnogvardeyskoye",16169,45.846038,41.518852 ],
    [ u"ru",u"Krasnokamensk",4773,54.333889,93.259444 ],
    [ u"ru",u"Krasnokamensk",54317,50.0661,118.1481 ],
    [ u"ru",u"Krasnokamsk",52690,58.080158,55.75411 ],
    [ u"ru",u"Krasnokholm",6041,51.59787,54.156698 ],
    [ u"ru",u"Krasnokholmskiy",8117,55.98729,55.046589 ],
    [ u"ru",u"Krasnokumskoye",13630,44.178056,43.501944 ],
    [ u"ru",u"Krasnolesnyy",5305,51.880716,39.587716 ],
    [ u"ru",u"Krasnomayskiy",5611,57.619405,34.409875 ],
    [ u"ru",u"Krasnoobsk",16894,54.9198,82.9909 ],
    [ u"ru",u"Krasnooktyabrskiy",5491,44.5797,40.0793 ],
    [ u"ru",u"Krasnooktyabrskiy",4254,56.675209,47.664561 ],
    [ u"ru",u"Krasnooktyabrskiy",11080,48.870824,44.758273 ],
    [ u"ru",u"Krasnorechenskiy",3833,44.6265,135.3532 ],
    [ u"ru",u"Krasnoselkup",4025,65.7,82.466667 ],
    [ u"ru",u"Krasnoselskiy",7558,45.391944,40.6075 ],
    [ u"ru",u"Krasnoshchëkovo",5463,51.670833,82.728889 ],
    [ u"ru",u"Krasnoslobodsk",10748,54.425303,43.789634 ],
    [ u"ru",u"Krasnoslobodsk",14334,48.707079,44.577018 ],
    [ u"ru",u"Krasnoturansk",5845,54.318611,91.563889 ],
    [ u"ru",u"Krasnoturinsk",64209,59.7666,60.2086 ],
    [ u"ru",u"Krasnoufimsk",43122,56.605854,57.766856 ],
    [ u"ru",u"Krasnouralsk",27656,58.3638,60.0407 ],
    [ u"ru",u"Krasnousolskiy",11819,53.8894,56.4746 ],
    [ u"ru",u"Krasnovishersk",18185,60.40783,57.081992 ],
    [ u"ru",u"Krasnovka",3966,48.817686,40.092261 ],
    [ u"ru",u"Krasnoyarka",4006,55.3317,73.0912 ],
    [ u"ru",u"Krasnoyarsk-45",71357,56.1124,94.5985 ],
    [ u"ru",u"Krasnoyarsk-66",5142,56.2747,91.5305 ],
    [ u"ru",u"Krasnoyarskaya",5198,47.4955,42.1856 ],
    [ u"ru",u"Krasnoyarskiy",3218,51.965,59.896667 ],
    [ u"ru",u"Krasnoyarsk",907460,56.0091,92.8628 ],
    [ u"ru",u"Krasnoye",2352,50.9297,38.6817 ],
    [ u"ru",u"Krasnoye",3426,54.6068,85.3899 ],
    [ u"ru",u"Krasnoye",3504,46.7373,39.5645 ],
    [ u"ru",u"Krasnoye",4021,52.7295,39.1629 ],
    [ u"ru",u"Krasnoye-na-Volge",7953,57.514826,41.239002 ],
    [ u"ru",u"Krasnoye Selo",43134,59.738333,30.089444 ],
    [ u"ru",u"Krasnozatonskiy",8078,61.675778,50.97939 ],
    [ u"ru",u"Krasnozavodsk",11694,56.45,38.216667 ],
    [ u"ru",u"Krasnozërskoye",10339,53.982774,79.237352 ],
    [ u"ru",u"Krasnoznamensk",3724,54.942222,22.489722 ],
    [ u"ru",u"Krasnyy Bogatyr",1019,56.014528,41.129576 ],
    [ u"ru",u"Krasnyy Bor",4852,59.681944,30.668056 ],
    [ u"ru",u"Krasnyy Chikoy",6824,50.3643,108.7512 ],
    [ u"ru",u"Krasnyye Baki",7810,57.130996,45.159924 ],
    [ u"ru",u"Krasnyye Barrikady",6275,46.2045,47.8535 ],
    [ u"ru",u"Krasnyye Chetai",2954,55.688708,46.138654 ],
    [ u"ru",u"Krasnyye Tkachi",4054,57.492593,39.756286 ],
    [ u"ru",u"Krasnyy Gulyay",3080,54.028214,48.333273 ],
    [ u"ru",u"Krasnyy Kholm",6120,58.060699,37.120318 ],
    [ u"ru",u"Krasnyy Klyuch",2348,55.38625,56.652871 ],
    [ u"ru",u"Krasnyy Kommunar",4167,51.964356,55.3668 ],
    [ u"ru",u"Krasnyy",4590,54.563399,31.432238 ],
    [ u"ru",u"Krasnyy Kurgan",3243,43.942222,42.610833 ],
    [ u"ru",u"Krasnyy Kut",14956,50.95,46.966667 ],
    [ u"ru",u"Krasnyy Luch",1452,57.066761,30.090317 ],
    [ u"ru",u"Krasnyy Mayak",856,56.048906,41.368455 ],
    [ u"ru",u"Krasnyy Oktyabr",4084,55.656667,64.813333 ],
    [ u"ru",u"Krasnyy Oktyabr",3303,51.435725,45.630915 ],
    [ u"ru",u"Krasnyy Oktyabr",1189,56.103468,41.383949 ],
    [ u"ru",u"Krasnyy Profintern",1468,57.744594,40.435015 ],
    [ u"ru",u"Krasnyy Sulin",44134,47.892208,40.070367 ],
    [ u"ru",u"Krasnyy Tekstilshchik",3276,51.360204,45.834816 ],
    [ u"ru",u"Krasnyy Tkach",3166,55.472102,39.080173 ],
    [ u"ru",u"Krasnyy Yar",10876,46.533138,48.345586 ],
    [ u"ru",u"Krasnyy Yar",5322,55.242422,72.926348 ],
    [ u"ru",u"Krasnyy Yar",7664,53.499878,50.39312 ],
    [ u"ru",u"Krasnyy Yar",3095,51.629167,46.421667 ],
    [ u"ru",u"Krasnyy Yar",3128,57.1275,84.530278 ],
    [ u"ru",u"Krasnyy Yar",7727,50.696524,44.72792 ],
    [ u"ru",u"Krasyukovskaya",4316,47.520982,40.079525 ],
    [ u"ru",u"Kratovo",6799,55.597284,38.177429 ],
    [ u"ru",u"Krechevitsy",3287,58.617028,31.40101 ],
    [ u"ru",u"Kremenki",11994,54.88626,37.119553 ],
    [ u"ru",u"Kresttsy",9737,58.245199,32.516475 ],
    [ u"ru",u"Krivodanovka",9006,55.0881,82.6551 ],
    [ u"ru",u"Krivopolyanye",5080,53.230215,39.929734 ],
    [ u"ru",u"Krivosheino",6010,57.343056,83.926111 ],
    [ u"ru",u"Krivyanskaya",10203,47.396248,40.1662 ],
    [ u"ru",u"Kromy",7098,52.687622,35.766646 ],
    [ u"ru",u"Kronshtadt",42987,59.99541,29.766679 ],
    [ u"ru",u"Kropachëvo",5252,55.0112,57.9896 ],
    [ u"ru",u"Kropotkin",1765,58.509444,115.321667 ],
    [ u"ru",u"Kropotkin",79600,45.4375,40.575556 ],
    [ u"ru",u"Krotovka",5398,53.285797,51.168604 ],
    [ u"ru",u"Kruglolesskoye",3249,44.658889,42.814167 ],
    [ u"ru",u"Krutaya Gorka",6779,55.364934,73.223096 ],
    [ u"ru",u"Krutikha",4294,53.9599,81.2093 ],
    [ u"ru",u"Krutinka",7752,56.005503,71.511312 ],
    [ u"ru",u"Krylovskaya",14605,46.319444,39.971111 ],
    [ u"ru",u"Krym",4475,47.300246,39.516371 ],
    [ u"ru",u"Krymsk",57556,44.929336,37.991166 ],
    [ u"ru",u"Ksenyevka",3344,53.5546,118.7255 ],
    [ u"ru",u"Kshenskiy",6504,51.840833,37.713611 ],
    [ u"ru",u"Kstovo",67243,56.147333,44.197871 ],
    [ u"ru",u"Kubachi",2977,42.085983,47.603384 ],
    [ u"ru",u"Kubanskiy",3200,45.929167,40.580556 ],
    [ u"ru",u"Kuba-Taba",3179,43.776111,43.442778 ],
    [ u"ru",u"Kubinka",25942,55.579569,36.703919 ],
    [ u"ru",u"Kudeyevskiy",2872,54.875833,56.756667 ],
    [ u"ru",u"Kudinovo",3381,54.81763,36.637729 ],
    [ u"ru",u"Kudryashovskiy",3935,55.0974,82.7742 ],
    [ u"ru",u"Kudymkar",31597,59.01729,54.655995 ],
    [ u"ru",u"Kugesi",11547,56.028947,47.292551 ],
    [ u"ru",u"Kugulta",5564,45.363611,42.388889 ],
    [ u"ru",u"Kukmor",16795,56.1855,50.8944 ],
    [ u"ru",u"Kukushtan",4870,57.6464,56.4952 ],
    [ u"ru",u"Kulary",4673,43.239722,45.504167 ],
    [ u"ru",u"Kuldur",1896,49.216667,131.633333 ],
    [ u"ru",u"Kulebaki",37623,55.413333,42.5325 ],
    [ u"ru",u"Kuleshovka",14668,47.078023,39.55794 ],
    [ u"ru",u"Kuli",3893,42.018451,47.243422 ],
    [ u"ru",u"Kulotino",3352,58.45,33.383333 ],
    [ u"ru",u"Kuloy",6557,61.030486,42.492519 ],
    [ u"ru",u"Kultayevo",4235,57.894347,55.939159 ],
    [ u"ru",u"Kultuk",4151,51.720833,103.695556 ],
    [ u"ru",u"Kulunda",15345,52.566,78.9385 ],
    [ u"ru",u"Kulzeb",3272,43.172757,47.011287 ],
    [ u"ru",u"Kumëny",5090,58.108866,49.916137 ],
    [ u"ru",u"Kumertau",65322,52.766667,55.783333 ],
    [ u"ru",u"Kuminskiy",2860,58.666667,66.566667 ],
    [ u"ru",u"Kumukh",2658,42.170363,47.116058 ],
    [ u"ru",u"Kumylzhenskaya",8061,49.8809,42.5898 ],
    [ u"ru",u"Kumysh",4306,43.883342,41.893235 ],
    [ u"ru",u"Kunashak",5950,55.7032,61.5498 ],
    [ u"ru",u"Kunerma",157,55.75,108.483333 ],
    [ u"ru",u"Kungur",66390,57.4368,56.9593 ],
    [ u"ru",u"Kungurtug",1820,50.599444,97.522778 ],
    [ u"ru",u"Kunya",3429,56.289805,30.974477 ],
    [ u"ru",u"Kupavna",6636,55.745764,38.131361 ],
    [ u"ru",u"Kupino",16333,54.366349,77.29805 ],
    [ u"ru",u"Kuragino",14076,53.8975,92.6725 ],
    [ u"ru",u"Kurakh",3364,41.584908,47.783062 ],
    [ u"ru",u"Kurchaloy",20903,43.201845,46.088098 ],
    [ u"ru",u"Kurchanskaya",6358,45.198333,37.507222 ],
    [ u"ru",u"Kurchatov",47319,51.6601,35.6521 ],
    [ u"ru",u"Kurdzhinovo",4234,43.988384,40.955186 ],
    [ u"ru",u"Kurganinsk",47682,44.88,40.598611 ],
    [ u"ru",u"Kurgan",343132,55.45,65.333333 ],
    [ u"ru",u"Kuri",4177,56.9171,62.1222 ],
    [ u"ru",u"Kurilsk",2185,45.233333,147.883333 ],
    [ u"ru",u"Kurkent",3224,41.711989,48.11531 ],
    [ u"ru",u"Kurkino",5944,53.425675,38.658239 ],
    [ u"ru",u"Kurlovo",7263,55.432524,40.485388 ],
    [ u"ru",u"Kurmanayevka",4552,52.5093,52.0675 ],
    [ u"ru",u"Kurovskoye",19173,55.581828,38.91994 ],
    [ u"ru",u"Kurovskoy",3648,54.531052,36.019633 ],
    [ u"ru",u"Kursavka",11043,44.4564,42.5093 ],
    [ u"ru",u"Kurskaya",12036,44.05,44.45 ],
    [ u"ru",u"Kursk",409435,51.737329,36.187349 ],
    [ u"ru",u"Kurtamysh",17936,54.910278,64.431944 ],
    [ u"ru",u"Kurumkan",5848,54.3,110.3 ],
    [ u"ru",u"Kurumoch",6443,53.489627,50.037478 ],
    [ u"ru",u"Kurush",7807,41.28413,47.834536 ],
    [ u"ru",u"Kurya",4258,51.6,82.316667 ],
    [ u"ru",u"Kusa",19819,55.338333,59.440556 ],
    [ u"ru",u"Kushchëvskaya",29915,46.5599,39.6321 ],
    [ u"ru",u"Kushnarënkovo",10650,55.105,55.350833 ],
    [ u"ru",u"Kushva",34059,58.290556,59.759167 ],
    [ u"ru",u"Kusye-Aleksandrovskiy",1895,58.283889,58.376389 ],
    [ u"ru",u"Kutulik",5390,53.350833,102.783889 ],
    [ u"ru",u"Kuvandyk",28707,51.4781,57.3552 ],
    [ u"ru",u"Kuvshinovo",10960,57.029532,34.172518 ],
    [ u"ru",u"Kuyanovo",3895,55.801389,54.537222 ],
    [ u"ru",u"Kuybyshevo",5790,47.81228,38.907312 ],
    [ u"ru",u"Kuybyshevskiy Zaton",2919,55.1593,49.1701 ],
    [ u"ru",u"Kuytun",10566,54.3423,101.5094 ],
    [ u"ru",u"Kuzedeyevo",3448,53.3308,87.2019 ],
    [ u"ru",u"Kuzhener",5797,56.811111,48.912778 ],
    [ u"ru",u"Kuzhenkino",3424,57.728333,33.9775 ],
    [ u"ru",u"Kuzhorskaya",3556,44.675122,40.310318 ],
    [ u"ru",u"Kuzino",3213,57.016667,59.566667 ],
    [ u"ru",u"Kuzino",1423,59.776647,38.3104 ],
    [ u"ru",u"Kuzmolovskiy",9676,60.109208,30.490915 ],
    [ u"ru",u"Kuznechikha",3227,57.216065,42.334772 ],
    [ u"ru",u"Kuznechnoye",4714,61.120041,29.868645 ],
    [ u"ru",u"Kuznetsk",90481,53.11675,46.600368 ],
    [ u"ru",u"Kuzovatovo",8607,53.546808,47.686588 ],
    [ u"ru",u"Kvarkeno",4161,52.083333,59.725 ],
    [ u"ru",u"Kvitok",3155,56.0724,98.4813 ],
    [ u"ru",u"Kyakhta",18431,50.350833,106.449444 ],
    [ u"ru",u"Kyakhulay",5731,42.968386,47.483007 ],
    [ u"ru",u"Kyra",4452,49.5776,111.9753 ],
    [ u"ru",u"Kyren",5334,51.6828,102.1408 ],
    [ u"ru",u"Kyshtovka",5724,56.554983,76.627127 ],
    [ u"ru",u"Kyshtym",41625,55.714,60.5528 ],
    [ u"ru",u"Kysyl-Syr",3491,63.898611,122.761667 ],
    [ u"ru",u"Kytlym",872,59.500494,59.201595 ],
    [ u"ru",u"Kytmanovo",4183,53.4593,85.4479 ],
    [ u"ru",u"Kyzburun Pervyy",5833,43.651667,43.395 ],
    [ u"ru",u"Kyzyl",108241,51.7,94.45 ],
    [ u"ru",u"Kyzyl-Mazhalyk",5004,51.133333,90.6 ],
    [ u"ru",u"Kyzyl-Oktyabr",3603,43.825701,41.786047 ],
    [ u"ru",u"Labinsk",61946,44.634167,40.735556 ],
    [ u"ru",u"Labytnangi",27067,66.657222,66.418333 ],
    [ u"ru",u"Ladovskaya Balka",5117,45.629649,41.402309 ],
    [ u"ru",u"Ladozhskaya",14904,45.309018,39.938031 ],
    [ u"ru",u"Ladushkin",3928,54.570254,20.170989 ],
    [ u"ru",u"Laishevo",7744,55.404642,49.550373 ],
    [ u"ru",u"Lakhdenpokhya",8448,61.519813,30.199173 ],
    [ u"ru",u"Lakinsk",16706,56.01931,39.948483 ],
    [ u"ru",u"Lalsk",4413,60.741459,47.586168 ],
    [ u"ru",u"Lashma",1736,54.932105,41.143788 ],
    [ u"ru",u"Latnaya",7232,51.6586,38.9011 ],
    [ u"ru",u"Lavrentiya",1242,65.583333,-171 ],
    [ u"ru",u"Lazarev",1906,52.225,141.513056 ],
    [ u"ru",u"Lazo",3240,45.871944,133.655833 ],
    [ u"ru",u"Lebedinyy",1213,58.483333,125.516667 ],
    [ u"ru",u"Lebedyan",22970,53.019423,39.16639 ],
    [ u"ru",u"Lebyazhye",4559,51.6869,80.8465 ],
    [ u"ru",u"Lebyazhye",3463,57.41585,49.523024 ],
    [ u"ru",u"Lebyazhye",6735,55.268889,66.494722 ],
    [ u"ru",u"Lebyazhye",5572,59.961244,29.414868 ],
    [ u"ru",u"Lechinkay",4334,43.564722,43.432778 ],
    [ u"ru",u"Lenina",5259,46.066667,39.783333 ],
    [ u"ru",u"Leninaul",7503,43.091377,46.574339 ],
    [ u"ru",u"Leningradskaya",38712,46.3214,39.3877 ],
    [ u"ru",u"Leningradskiy",712,69.383333,178.416667 ],
    [ u"ru",u"Leninkent",13912,42.968951,47.352019 ],
    [ u"ru",u"Leninogorsk",66264,54.602559,52.460871 ],
    [ u"ru",u"Leninskaya Sloboda",29,56.079456,44.469434 ],
    [ u"ru",u"Leninskiy",2043,58.577778,125.430556 ],
    [ u"ru",u"Leninskiy",9834,54.287683,37.459257 ],
    [ u"ru",u"Leninsk-Kuznetskiy",109025,54.6567,86.1737 ],
    [ u"ru",u"Leninsk",1701,54.903056,59.8675 ],
    [ u"ru",u"Leninsk",15167,48.702329,45.197981 ],
    [ u"ru",u"Leninskoye",5323,58.316374,47.088557 ],
    [ u"ru",u"Leninskoye",6827,47.935278,132.624167 ],
    [ u"ru",u"Lenki",3859,52.95,80.433333 ],
    [ u"ru",u"Lensk",23695,60.725278,114.927778 ],
    [ u"ru",u"Leonidovo",1283,49.283333,142.866667 ],
    [ u"ru",u"Lepley",3074,54.2684,42.8888 ],
    [ u"ru",u"Lermontovka",4479,47.145278,134.338333 ],
    [ u"ru",u"Lermontov",23369,44.106667,42.973333 ],
    [ u"ru",u"Leshukonskoye",4813,64.898939,45.762196 ],
    [ u"ru",u"Leskolovo",4039,60.255785,30.42893 ],
    [ u"ru",u"Lesnikovo",5864,55.282222,65.3175 ],
    [ u"ru",u"Lesnoye",1887,58.284064,35.515843 ],
    [ u"ru",u"Lesnoy Gorodok",5056,55.638933,37.208295 ],
    [ u"ru",u"Lesnoy",6915,59.780996,52.128377 ],
    [ u"ru",u"Lesnoy",8689,56.066667,37.916667 ],
    [ u"ru",u"Lesnoy",7335,54.2125,40.4713 ],
    [ u"ru",u"Lesnoy",52322,58.636667,59.802222 ],
    [ u"ru",u"Lesnyye Polyany",1731,59.003137,52.418024 ],
    [ u"ru",u"Lesnyye Polyany",3695,55.966667,37.866667 ],
    [ u"ru",u"Lesogorskiy",2989,61.045486,28.929376 ],
    [ u"ru",u"Lesogorsk",5809,56.0458,99.5136 ],
    [ u"ru",u"Lesogorsk",1061,55.097904,43.935525 ],
    [ u"ru",u"Lesosibirsk",65946,58.235833,92.482778 ],
    [ u"ru",u"Lesozavodsk",41779,45.479444,133.424444 ],
    [ u"ru",u"Letka",2984,59.601111,49.423206 ],
    [ u"ru",u"Letnik",3141,46.011,41.2657 ],
    [ u"ru",u"Letnyaya Stavka",4969,45.430556,43.447222 ],
    [ u"ru",u"Levashi",7817,42.430363,47.321481 ],
    [ u"ru",u"Levashovo",4007,60.103688,30.20683 ],
    [ u"ru",u"Levikha",3452,57.583611,59.900278 ],
    [ u"ru",u"Levokumka",5651,44.231667,43.15 ],
    [ u"ru",u"Levokumskoye",11377,44.821944,44.660556 ],
    [ u"ru",u"Lev Tolstoy",8955,53.213439,39.446038 ],
    [ u"ru",u"Lgov",23265,51.6888,35.2843 ],
    [ u"ru",u"Likhoslavl",12290,57.127468,35.464037 ],
    [ u"ru",u"Likhovskoy",13617,48.151882,40.179251 ],
    [ u"ru",u"Likhoy",3102,48.126615,40.205559 ],
    [ u"ru",u"Liman",8858,45.784572,47.224053 ],
    [ u"ru",u"Linda",5489,56.615711,44.095442 ],
    [ u"ru",u"Lipetsk",515659,52.603111,39.570762 ],
    [ u"ru",u"Lipin Bor",3771,60.262148,37.976278 ],
    [ u"ru",u"Lipki",9633,53.969938,37.70282 ],
    [ u"ru",u"Lipovtsy",6581,44.158333,131.745833 ],
    [ u"ru",u"Lisiy Nos",2508,60.016856,30.020082 ],
    [ u"ru",u"Listvyagi",4627,53.6772,86.951 ],
    [ u"ru",u"Listvyanka",1700,51.8535,104.8693 ],
    [ u"ru",u"Listvyanskiy",2673,54.1493,83.7202 ],
    [ u"ru",u"Litovko",2670,49.236111,135.174167 ],
    [ u"ru",u"Livadiya",12652,42.869167,132.676389 ],
    [ u"ru",u"Livenka",4154,50.4491,38.2959 ],
    [ u"ru",u"Livny",52916,52.425344,37.606888 ],
    [ u"ru",u"Lobanovo",3563,57.8595,56.3026 ],
    [ u"ru",u"Lobnya",61772,56.009722,37.481944 ],
    [ u"ru",u"Lobva",8403,59.185384,60.518458 ],
    [ u"ru",u"Lodeynoye Pole",22164,60.726004,33.553057 ],
    [ u"ru",u"Log",3695,49.484367,43.861255 ],
    [ u"ru",u"Loknya",4762,56.829983,30.146647 ],
    [ u"ru",u"Lokomotivnyy",10663,53.0118,60.5684 ],
    [ u"ru",u"Lokosovo",3915,61.133333,74.816667 ],
    [ u"ru",u"Lokot",11853,52.565,34.5776 ],
    [ u"ru",u"Lomintsevskiy",4666,53.985482,37.664714 ],
    [ u"ru",u"Lomonosov",36778,59.906121,29.772528 ],
    [ u"ru",u"Lomovka",3178,53.919444,58.367222 ],
    [ u"ru",u"Londoko",1298,49.033333,131.983333 ],
    [ u"ru",u"Lopandino",1938,52.364,34.8722 ],
    [ u"ru",u"Lopatino",4318,52.619487,45.811838 ],
    [ u"ru",u"Lopatinskiy",14219,55.341006,38.723658 ],
    [ u"ru",u"Losevo",4476,50.676667,40.045 ],
    [ u"ru",u"Losino-Petrovskiy",22116,55.869594,38.200646 ],
    [ u"ru",u"Losinyy",2189,57.138623,61.066631 ],
    [ u"ru",u"Lososina",3151,48.997495,140.310638 ],
    [ u"ru",u"Lotoshino",5623,56.234886,35.64273 ],
    [ u"ru",u"Loukhi",5764,66.076158,33.047454 ],
    [ u"ru",u"Lovozero",2963,68.006377,35.015892 ],
    [ u"ru",u"Loyga",1618,61.078451,44.607501 ],
    [ u"ru",u"Lubyany",1899,56.0378,51.400008 ],
    [ u"ru",u"Luchegorsk",21833,46.476389,134.256944 ],
    [ u"ru",u"Luga",40115,58.737222,29.845278 ],
    [ u"ru",u"Lugovaya",3086,56.05,37.483333 ],
    [ u"ru",u"Lugovoy",1994,59.733333,65.833333 ],
    [ u"ru",u"Lugovskiy",617,58.061389,112.892778 ],
    [ u"ru",u"Lugovskoy",2969,56.958488,64.528971 ],
    [ u"ru",u"Lukh",3157,57.012421,42.258382 ],
    [ u"ru",u"Lukhovitsy",32388,54.942621,39.023819 ],
    [ u"ru",u"Lukhovka",8892,54.148438,45.257277 ],
    [ u"ru",u"Lukino",3619,56.441832,43.629324 ],
    [ u"ru",u"Luknovo",2614,56.180447,42.039867 ],
    [ u"ru",u"Lukovetskiy",2701,64.2956,41.9211 ],
    [ u"ru",u"Lukovskaya",5299,43.729516,44.633454 ],
    [ u"ru",u"Lukoyanov",12913,55.027718,44.478653 ],
    [ u"ru",u"Lunino",8214,53.591759,45.227093 ],
    [ u"ru",u"Lutkun",3264,41.480838,47.685779 ],
    [ u"ru",u"Luza",11936,60.630815,47.251177 ],
    [ u"ru",u"Luzino",9897,54.948111,73.035312 ],
    [ u"ru",u"Lvovskiy",11808,55.318722,37.523371 ],
    [ u"ru",u"Lvovskoye",4771,45.007808,38.599928 ],
    [ u"ru",u"Lyambir",8274,54.281716,45.124938 ],
    [ u"ru",u"Lyamino",5000,58.2839,57.725 ],
    [ u"ru",u"Lyangasovo",12626,58.517586,49.447176 ],
    [ u"ru",u"Lyaskelya",3571,61.766667,31.016667 ],
    [ u"ru",u"Lyskovo",23570,56.032821,45.042197 ],
    [ u"ru",u"Lysogorskaya",10219,44.106389,43.275556 ],
    [ u"ru",u"Lysva",69637,58.108611,57.805278 ],
    [ u"ru",u"Lysyye Gory",7501,51.550633,44.841443 ],
    [ u"ru",u"Lytkarino",50620,55.582711,37.905162 ],
    [ u"ru",u"Lyuban",4494,59.35,31.216667 ],
    [ u"ru",u"Lyubertsy",154653,55.677193,37.893217 ],
    [ u"ru",u"Lyubim",6057,58.362504,40.684333 ],
    [ u"ru",u"Lyubinskiy",10461,55.15421,72.692472 ],
    [ u"ru",u"Lyubokhna",5188,53.503322,34.388469 ],
    [ u"ru",u"Lyubuchany",3537,55.250876,37.549876 ],
    [ u"ru",u"Lyubytino",3225,58.741737,33.502582 ],
    [ u"ru",u"Lyudinovo",41392,53.866389,34.447778 ],
    [ u"ru",u"Madzhalis",6173,42.121667,47.833333 ],
    [ u"ru",u"Magadan",95258,59.566667,150.8 ],
    [ u"ru",u"Magan",1686,62.105278,129.527778 ],
    [ u"ru",u"Magaramkent",6708,41.615855,48.347965 ],
    [ u"ru",u"Magdagachi",11739,53.45,125.8 ],
    [ u"ru",u"Magistralnyy",7429,56.1725,107.445833 ],
    [ u"ru",u"Magnitka",5784,55.3475,59.696111 ],
    [ u"ru",u"Magnitogorsk",413357,53.418611,59.047222 ],
    [ u"ru",u"Mago",2206,53.251389,140.182222 ],
    [ u"ru",u"Makarakskiy",442,55.591944,88.028611 ],
    [ u"ru",u"Makarov",6663,48.633333,142.8 ],
    [ u"ru",u"Makaryev",7588,57.885008,43.804903 ],
    [ u"ru",u"Makaryevo",218,56.0917,45.048806 ],
    [ u"ru",u"Makhachkala",497967,42.976378,47.502356 ],
    [ u"ru",u"Makhalino",5210,53.085435,46.221079 ],
    [ u"ru",u"Makkaveyevo",3922,51.753252,113.9454 ],
    [ u"ru",u"Maksatikha",9441,57.796946,35.882539 ],
    [ u"ru",u"Makushino",9682,55.210278,67.244167 ],
    [ u"ru",u"Malakhovka",18399,55.647761,38.024862 ],
    [ u"ru",u"Malaya Purga",6803,56.556661,53.004343 ],
    [ u"ru",u"Malaya Serdoba",4922,52.4661,44.9512 ],
    [ u"ru",u"Malaya Vishera",13834,58.845383,32.222175 ],
    [ u"ru",u"Malchevskaya",3922,48.98725,40.206928 ],
    [ u"ru",u"Malgobek",46340,43.51118,44.588211 ],
    [ u"ru",u"Malino",4327,55.111952,38.173843 ],
    [ u"ru",u"Malinovka",9981,53.4171,87.278 ],
    [ u"ru",u"Malinovoye Ozero",4101,51.675278,79.7825 ],
    [ u"ru",u"Malinovskiy",2672,61.195278,62.839722 ],
    [ u"ru",u"Malka",7220,43.803889,43.324167 ],
    [ u"ru",u"Malmyzh",8990,56.5205,50.6818 ],
    [ u"ru",u"Maloarkhangelsk",3905,52.400239,36.503322 ],
    [ u"ru",u"Maloshuyka",3044,63.712093,37.449603 ],
    [ u"ru",u"Maloyaroslavets",32669,55.014572,36.471853 ],
    [ u"ru",u"Maloyaz",4773,55.1815,58.1596 ],
    [ u"ru",u"Maloye Kozino",823,56.43829,43.674585 ],
    [ u"ru",u"Maloye Verevo",4088,59.613611,30.172778 ],
    [ u"ru",u"Malysheva",9955,57.118506,61.403446 ],
    [ u"ru",u"Malyye Derbety",5822,47.954722,44.680833 ],
    [ u"ru",u"Mamakan",2229,57.816111,114.002778 ],
    [ u"ru",u"Mama",4239,58.310556,112.898611 ],
    [ u"ru",u"Mamedkala",8965,42.167726,48.119877 ],
    [ u"ru",u"Mamonovo",7271,54.464269,19.938011 ],
    [ u"ru",u"Mamontovka",8817,55.980833,37.819722 ],
    [ u"ru",u"Mamontovo",9275,52.7055,81.6244 ],
    [ u"ru",u"Manaskent",5216,42.740204,47.691402 ],
    [ u"ru",u"Mankovo-Kalitvenskoye",4207,49.397852,40.275221 ],
    [ u"ru",u"Manturovo",18817,58.328889,44.764056 ],
    [ u"ru",u"Manturovo",2755,51.4547,37.1282 ],
    [ u"ru",u"Marevo",2571,57.314614,32.080447 ],
    [ u"ru",u"Marfino",3312,46.40852,48.713981 ],
    [ u"ru",u"Marfino",3687,55.702674,37.383217 ],
    [ u"ru",u"Mariinskiy Posad",10199,56.114974,47.718052 ],
    [ u"ru",u"Mariinsk",43122,56.213889,87.747222 ],
    [ u"ru",u"Marinskaya",9065,43.8825,43.491389 ],
    [ u"ru",u"Mari-Turek",5900,56.789461,49.623485 ],
    [ u"ru",u"Markha",11648,62.105278,129.726944 ],
    [ u"ru",u"Markova",6340,57.320556,107.088056 ],
    [ u"ru",u"Markovo",1253,56.683263,40.300369 ],
    [ u"ru",u"Marks",33106,51.711111,46.748611 ],
    [ u"ru",u"Maromitsa",1832,59.868282,48.012274 ],
    [ u"ru",u"Martan-Chu",5385,43.063663,45.562174 ],
    [ u"ru",u"Martyush",4110,56.4,61.881944 ],
    [ u"ru",u"Maryanovka",8302,54.961024,72.644149 ],
    [ u"ru",u"Maryanskaya",10353,45.103419,38.639991 ],
    [ u"ru",u"Maslova Pristan",5669,50.458736,36.740813 ],
    [ u"ru",u"Maslovka",7518,51.341243,39.54086 ],
    [ u"ru",u"Maslovskiy",3436,51.505732,39.293521 ],
    [ u"ru",u"Matveyevka",3276,52.15,56.183333 ],
    [ u"ru",u"Matveyev Kurgan",14342,47.5645,38.869468 ],
    [ u"ru",u"Mayachnyy",3506,52.6839,55.685 ],
    [ u"ru",u"Maykop",158453,44.607778,40.105833 ],
    [ u"ru",u"Maykopskoye",4171,45.393611,40.765833 ],
    [ u"ru",u"Maykor",3236,59.005856,55.879985 ],
    [ u"ru",u"Mayma",15428,52.019722,85.911389 ],
    [ u"ru",u"Mayna",5287,53.006389,91.483611 ],
    [ u"ru",u"Mayna",7904,54.1135,47.6231 ],
    [ u"ru",u"Mayrtup",10778,43.203478,46.132145 ],
    [ u"ru",u"Mayskiy",7537,50.519881,36.458777 ],
    [ u"ru",u"Mayskiy",27522,43.641401,44.038508 ],
    [ u"ru",u"Mayskiy",2883,48.997531,140.205277 ],
    [ u"ru",u"Mayskiy",12136,47.696,40.102586 ],
    [ u"ru",u"Mayskiy",2055,53.962159,38.211652 ],
    [ u"ru",u"Mayskiy",5224,58.102842,55.570559 ],
    [ u"ru",u"Mayya",6794,61.733333,130.281111 ],
    [ u"ru",u"Mazulskiy",1305,56.2042,90.3504 ],
    [ u"ru",u"Mechetinskaya",6517,46.771295,40.455969 ],
    [ u"ru",u"Mednogorskiy",4328,43.917804,41.182553 ],
    [ u"ru",u"Mednogorsk",30676,51.4128,57.595 ],
    [ u"ru",u"Medvedevo",16407,56.633885,47.804053 ],
    [ u"ru",u"Medveditskiy",1475,50.785214,44.71287 ],
    [ u"ru",u"Medvedka",796,58.742554,59.103584 ],
    [ u"ru",u"Medvedok",2041,57.389129,50.035096 ],
    [ u"ru",u"Medvedovskaya",16941,45.451511,39.024847 ],
    [ u"ru",u"Medvezhyegorsk",16773,62.917131,34.456886 ],
    [ u"ru",u"Medyn",7791,54.969167,35.858611 ],
    [ u"ru",u"Meget",8370,52.415,104.049444 ],
    [ u"ru",u"Megion",48691,61.0296,76.1136 ],
    [ u"ru",u"Mekhelta",2898,42.79474,46.492378 ],
    [ u"ru",u"Melekhovo",6922,56.277297,41.293457 ],
    [ u"ru",u"Melekhovskaya",3346,47.48106,40.486689 ],
    [ u"ru",u"Melenki",15902,55.3343,41.6295 ],
    [ u"ru",u"Meleuz",65363,52.966667,55.916667 ],
    [ u"ru",u"Melioratorov",5306,57.210647,65.607744 ],
    [ u"ru",u"Melnikovo",9745,56.555833,84.085 ],
    [ u"ru",u"Mendeleyevo",7964,56.033333,37.216667 ],
    [ u"ru",u"Mendeleyevo",4270,58.166667,68.3 ],
    [ u"ru",u"Mendeleyevo",3245,58.169759,54.99634 ],
    [ u"ru",u"Mendeleyevskiy",9350,54.137451,37.587422 ],
    [ u"ru",u"Mendeleyevsk",22970,55.908185,52.290472 ],
    [ u"ru",u"Menzelinsk",16858,55.727056,53.102578 ],
    [ u"ru",u"Meshcherino",4207,55.195671,38.360019 ],
    [ u"ru",u"Meshchovsk",4386,54.324444,35.280833 ],
    [ u"ru",u"Mesker-Yurt",11147,43.251474,45.907165 ],
    [ u"ru",u"Mesyagutovo",9780,55.530278,58.252778 ],
    [ u"ru",u"Metallostroy",25123,59.800833,30.547778 ],
    [ u"ru",u"Mezen",3673,65.840291,44.249269 ],
    [ u"ru",u"Mezhdurechenskiy",11121,59.6,65.933333 ],
    [ u"ru",u"Mezhdurechensk",101028,53.694167,88.060278 ],
    [ u"ru",u"Mezhdurechensk",1855,63.245556,48.553333 ],
    [ u"ru",u"Mezhdurechensk",3454,53.2665,49.1116 ],
    [ u"ru",u"Mezhevoy",5538,55.1413,58.7802 ],
    [ u"ru",u"Mezinovskiy",2116,55.479727,40.411998 ],
    [ u"ru",u"Mgachi",1632,51.05,142.266667 ],
    [ u"ru",u"Mga",9565,59.75,31.066667 ],
    [ u"ru",u"Mglin",8369,53.059073,32.847533 ],
    [ u"ru",u"Miasskoye",9524,55.2784,61.8905 ],
    [ u"ru",u"Miass",156563,55.045,60.108333 ],
    [ u"ru",u"Miatli",4424,43.081734,46.828597 ],
    [ u"ru",u"Michurinsk",93500,52.8978,40.4907 ],
    [ u"ru",u"Mikhaylovka",4344,54.7402,56.274 ],
    [ u"ru",u"Mikhaylovka",7937,52.9589,103.2846 ],
    [ u"ru",u"Mikhaylovka",59993,50.06,43.2379 ],
    [ u"ru",u"Mikhaylov",12907,54.2298,39.0269 ],
    [ u"ru",u"Mikhaylovskaya",8050,44.994722,40.596389 ],
    [ u"ru",u"Mikhaylovsk",59198,45.128333,42.025556 ],
    [ u"ru",u"Mikhaylovsk",10209,56.435833,59.12 ],
    [ u"ru",u"Mikhaylovskoye",11467,51.823889,79.717222 ],
    [ u"ru",u"Mikhaylovskoye",10479,43.099716,44.631637 ],
    [ u"ru",u"Mikun",11503,62.199384,49.942766 ],
    [ u"ru",u"Milkovo",8726,54.716667,158.616667 ],
    [ u"ru",u"Millerovo",38528,48.922653,40.396732 ],
    [ u"ru",u"Miloslavskoye",4693,53.581522,39.43992 ],
    [ u"ru",u"Milyutinskaya",2743,48.627878,41.667885 ],
    [ u"ru",u"Mindyak",2955,54.0231,58.7891 ],
    [ u"ru",u"Mineralnyye Vody",76281,44.210278,43.135278 ],
    [ u"ru",u"Mingrelskaya",5522,45.013817,38.340514 ],
    [ u"ru",u"Minusinsk",72782,53.710278,91.6875 ],
    [ u"ru",u"Minyar",10664,55.073333,57.555 ],
    [ u"ru",u"Mirnyy",29341,61.332893,44.535982 ],
    [ u"ru",u"Mirnyy",3508,58.493333,47.653889 ],
    [ u"ru",u"Mirnyy",40309,62.535278,113.961111 ],
    [ u"ru",u"Mirnyy",7393,53.50642,50.276575 ],
    [ u"ru",u"Mirnyy",3171,54.366072,48.729388 ],
    [ u"ru",u"Mirskoy",3095,45.5439,40.3998 ],
    [ u"ru",u"Mishelevka",7529,52.8575,103.171944 ],
    [ u"ru",u"Misheronskiy",3790,55.719271,39.738349 ],
    [ u"ru",u"Mishkino",5808,53.9997,59.1064 ],
    [ u"ru",u"Mishkino",8712,55.338889,63.9175 ],
    [ u"ru",u"Miskindzha",3611,41.424022,47.846685 ],
    [ u"ru",u"Mitrofanovka",5643,49.970833,39.693889 ],
    [ u"ru",u"Mizur",2934,42.853763,44.063929 ],
    [ u"ru",u"Mnogovershinnyy",2719,53.935278,139.924167 ],
    [ u"ru",u"Mochalishche",2225,56.3306,48.3547 ],
    [ u"ru",u"Mochishche",3314,55.1435,82.8461 ],
    [ u"ru",u"Mogocha",12648,53.733333,119.766667 ],
    [ u"ru",u"Mogochin",3191,57.710278,83.576667 ],
    [ u"ru",u"Mogoytuy",8420,51.283333,114.916667 ],
    [ u"ru",u"Mogzon",4262,51.7281,111.9619 ],
    [ u"ru",u"Mokhsogollokh",6947,61.468056,128.920278 ],
    [ u"ru",u"Mokrous",6738,51.2373,47.5137 ],
    [ u"ru",u"Mokrousovo",4851,55.810278,66.765278 ],
    [ u"ru",u"Mokshan",11652,53.436498,44.613217 ],
    [ u"ru",u"Molchanovo",6109,57.581667,83.769167 ],
    [ u"ru",u"Molochnoye",8421,59.291657,39.678681 ],
    [ u"ru",u"Molochnyy",5308,68.853892,33.020463 ],
    [ u"ru",u"Molokovo",2490,58.166111,36.762778 ],
    [ u"ru",u"Monastyrishche",4192,44.193056,132.497222 ],
    [ u"ru",u"Monastyrshchina",4501,54.34961,31.837951 ],
    [ u"ru",u"Monchegorsk",49869,67.939722,32.873889 ],
    [ u"ru",u"Monetnyy",5540,57.0472,60.8794 ],
    [ u"ru",u"Monino",19852,55.842439,38.193615 ],
    [ u"ru",u"Mordovo",7112,52.0834,40.77 ],
    [ u"ru",u"Morgaushi",2922,55.9643,46.7743 ],
    [ u"ru",u"Morki",9568,56.430278,48.994722 ],
    [ u"ru",u"Morozovsk",29290,48.355021,41.826269 ],
    [ u"ru",u"Morshansk",43312,53.44354,41.81065 ],
    [ u"ru",u"Mortka",3698,59.332222,66.021389 ],
    [ u"ru",u"Moryakovskiy Zaton",4745,56.695556,84.646667 ],
    [ u"ru",u"Mosalsk",4320,54.488056,34.981667 ],
    [ u"ru",u"Moscow",10381288,55.752222,37.615556 ],
    [ u"ru",u"Moshenskoye",2697,58.510163,34.591083 ],
    [ u"ru",u"Moshkovo",10541,55.3053,83.6104 ],
    [ u"ru",u"Moskovskiy",15435,55.599106,37.354948 ],
    [ u"ru",u"Moskovskiy",3450,57.111079,65.422978 ],
    [ u"ru",u"Moskovskoye",5482,45.2842,41.9103 ],
    [ u"ru",u"Mosta",622,56.530118,42.163202 ],
    [ u"ru",u"Mostovskoy",25188,44.412222,40.793611 ],
    [ u"ru",u"Motygino",6625,58.183056,94.759167 ],
    [ u"ru",u"Mozdok",43779,43.743593,44.651769 ],
    [ u"ru",u"Mozhaysk",31557,55.501944,36.027222 ],
    [ u"ru",u"Mozhga",47271,56.374511,52.255426 ],
    [ u"ru",u"Mrakovo",8394,52.716111,56.624444 ],
    [ u"ru",u"Mstera",5470,56.378889,41.92 ],
    [ u"ru",u"Mtsensk",47610,53.276567,36.573337 ],
    [ u"ru",u"Muchkapskiy",7814,51.851334,42.471747 ],
    [ u"ru",u"Mudyuga",938,63.783161,39.237572 ],
    [ u"ru",u"Mugi",3377,42.299444,47.42077 ],
    [ u"ru",u"Mugreyevskiy",917,56.600994,42.349586 ],
    [ u"ru",u"Mugur-Aksy",4012,50.35,90.5 ],
    [ u"ru",u"Mukhanovo",652,56.5,38.316667 ],
    [ u"ru",u"Mukhen",4617,48.1,136.1 ],
    [ u"ru",u"Mukhtolovo",5615,55.467507,43.199734 ],
    [ u"ru",u"Mulda",174,67.5,63.85 ],
    [ u"ru",u"Mulino",11513,56.289227,42.920053 ],
    [ u"ru",u"Mullovka",6383,54.2,49.4 ],
    [ u"ru",u"Mundybash",5870,53.211,87.2983 ],
    [ u"ru",u"Murashi",7190,59.3536,48.9776 ],
    [ u"ru",u"Muravlenko",39137,63.783333,73.5 ],
    [ u"ru",u"Murino",4977,60.049441,30.445874 ],
    [ u"ru",u"Murmansk",319266,68.979174,33.092514 ],
    [ u"ru",u"Murmashi",15416,68.815424,32.811469 ],
    [ u"ru",u"Murmino",3506,54.6043,40.0549 ],
    [ u"ru",u"Murom",126932,55.575,42.0426 ],
    [ u"ru",u"Muromtsevo",11147,56.372382,75.241749 ],
    [ u"ru",u"Mursalimkino",2527,55.0379,58.5585 ],
    [ u"ru",u"Murygino",7996,58.738307,49.458221 ],
    [ u"ru",u"Muslyumovo",7406,55.038056,53.159444 ],
    [ u"ru",u"Mutsalaul",6219,43.275475,46.730775 ],
    [ u"ru",u"Muyezerskiy",3901,63.933333,31.65 ],
    [ u"ru",u"Muzhi",3209,65.366667,64.666667 ],
    [ u"ru",u"Myatlevo",1969,54.89693,35.676192 ],
    [ u"ru",u"Myaundzha",1977,63.049444,147.185833 ],
    [ u"ru",u"Myshkin",6061,57.789727,38.454476 ],
    [ u"ru",u"Myskhako",5743,44.659167,37.766111 ],
    [ u"ru",u"Myski",44082,53.709,87.8014 ],
    [ u"ru",u"Mys Shmidta",657,68.933333,-179.5 ],
    [ u"ru",u"Mytishchi",160545,55.91163,37.730757 ],
    [ u"ru",u"Myurego",4548,42.410868,47.693038 ],
    [ u"ru",u"Nachalovo",4808,46.338004,48.201282 ],
    [ u"ru",u"Nadezhda",8426,44.1,44.6 ],
    [ u"ru",u"Nadterechnoye",7877,43.622714,45.339688 ],
    [ u"ru",u"Nadvoitsy",10780,63.866667,34.316667 ],
    [ u"ru",u"Nadym",46339,65.533333,72.516667 ],
    [ u"ru",u"Nagornskiy",560,58.772011,57.544132 ],
    [ u"ru",u"Nagornyy",6308,52.7959,83.5498 ],
    [ u"ru",u"Nagornyy",147,55.966667,124.95 ],
    [ u"ru",u"Nagorsk",4982,59.317222,50.807778 ],
    [ u"ru",u"Nagutskoye",3146,44.4415,42.8762 ],
    [ u"ru",u"Nakhabino",27985,55.848538,37.177885 ],
    [ u"ru",u"Nakhodka",146922,42.833333,132.894722 ],
    [ u"ru",u"Nalchik",282916,43.498056,43.618889 ],
    [ u"ru",u"Nalobikha",4451,53.200556,84.603889 ],
    [ u"ru",u"Namtsy",7980,62.716111,129.665833 ],
    [ u"ru",u"Narimanov",11907,46.6927,47.8498 ],
    [ u"ru",u"Naro-Fominsk",72633,55.387518,36.733074 ],
    [ u"ru",u"Narovchat",4340,53.876537,43.694577 ],
    [ u"ru",u"Nartan",12694,43.510833,43.699444 ],
    [ u"ru",u"Naryan-Mar",18041,67.641793,53.043071 ],
    [ u"ru",u"Naryshkino",9600,52.967775,35.726774 ],
    [ u"ru",u"Natalinsk",2060,56.473897,57.869782 ],
    [ u"ru",u"Natyrbovo",3377,44.73,40.626389 ],
    [ u"ru",u"Nauchnyy Gorodok",2687,53.4203,83.521 ],
    [ u"ru",u"Naurskaya",8550,43.650746,45.311725 ],
    [ u"ru",u"Naushki",3510,50.382778,106.105556 ],
    [ u"ru",u"Navashino",17552,55.5441,42.1968 ],
    [ u"ru",u"Navlya",13735,52.825438,34.499604 ],
    [ u"ru",u"Navoloki",10951,57.465719,41.963443 ],
    [ u"ru",u"Nazarovo",55253,56.0104,90.4011 ],
    [ u"ru",u"Naziya",5726,59.8,31.383333 ],
    [ u"ru",u"Nazran",164142,43.225967,44.773231 ],
    [ u"ru",u"Nebolchi",2198,59.12393,33.345372 ],
    [ u"ru",u"Nebug",3698,44.1717,39.0026 ],
    [ u"ru",u"Neftegorsk",4785,44.3658,39.7078 ],
    [ u"ru",u"Neftegorsk",19542,52.802,51.166 ],
    [ u"ru",u"Neftekamsk",126807,56.091991,54.270319 ],
    [ u"ru",u"Neftekumsk",28464,44.666667,44.916667 ],
    [ u"ru",u"Nefteyugansk",112634,61.083333,72.7 ],
    [ u"ru",u"Nekhayevskiy",4714,50.4106,41.7561 ],
    [ u"ru",u"Neklyudovo",9052,56.414213,43.977208 ],
    [ u"ru",u"Nekrasovka",9159,48.3525,135.2325 ],
    [ u"ru",u"Nekrasovka",7994,55.693277,37.911483 ],
    [ u"ru",u"Nekrasovskaya",4814,45.144681,39.748678 ],
    [ u"ru",u"Nekrasovskiy",9613,56.066667,37.5 ],
    [ u"ru",u"Nekrasovskoye",6353,57.676635,40.365673 ],
    [ u"ru",u"Nelidovo",25349,56.221072,32.777378 ],
    [ u"ru",u"Nelkan",135,64.25,142.966667 ],
    [ u"ru",u"Nema",3797,57.506751,50.501147 ],
    [ u"ru",u"Neman",12507,55.031111,22.026389 ],
    [ u"ru",u"Nemchinovka",4938,55.722885,37.36086 ],
    [ u"ru",u"Nerchinskiy Zavod",3012,51.3088,119.61 ],
    [ u"ru",u"Nerchinsk",15361,51.983333,116.583333 ],
    [ u"ru",u"Nerekhta",25353,57.458811,40.574708 ],
    [ u"ru",u"Nerl",2292,56.662849,40.389306 ],
    [ u"ru",u"Neryungri",66325,56.6709,124.6491 ],
    [ u"ru",u"Nesterov",5072,54.630556,22.571389 ],
    [ u"ru",u"Nesterovskaya",19186,43.238611,45.050278 ],
    [ u"ru",u"Nevel",17833,56.020945,29.928445 ],
    [ u"ru",u"Nevelsk",17639,46.673333,141.863333 ],
    [ u"ru",u"Neverkino",5105,52.785409,46.741736 ],
    [ u"ru",u"Never",2344,53.983333,124.166667 ],
    [ u"ru",u"Nevinnomyssk",134347,44.6333,41.9444 ],
    [ u"ru",u"Nevyansk",25822,57.4953,60.2112 ],
    [ u"ru",u"Neya",11145,58.297188,43.86808 ],
    [ u"ru",u"Neyvo-Rudyanka",2895,57.3444,60.1343 ],
    [ u"ru",u"Neyvo-Shaytanskiy",2602,57.728604,61.249558 ],
    [ u"ru",u"Nezhinka",5100,51.7676,55.3694 ],
    [ u"ru",u"Nezhinskiy",3991,43.928333,42.685556 ],
    [ u"ru",u"Nezlobnaya",18412,44.118056,43.402778 ],
    [ u"ru",u"Nikel",15596,69.412848,30.221977 ],
    [ u"ru",u"Nikitinskiy",2419,54.5845,86.0115 ],
    [ u"ru",u"Nikolayevka",5081,54.1451,45.1444 ],
    [ u"ru",u"Nikolayevka",4051,43.084722,133.204444 ],
    [ u"ru",u"Nikolayevka",5220,47.303845,38.840169 ],
    [ u"ru",u"Nikolayevka",27597,44.089167,43.083056 ],
    [ u"ru",u"Nikolayevka",6419,53.125699,47.2041 ],
    [ u"ru",u"Nikolayevka",7410,48.554722,134.785556 ],
    [ u"ru",u"Nikolayevskaya",3613,47.613912,41.502298 ],
    [ u"ru",u"Nikolayevsk-na-Amure",27152,53.140556,140.73 ],
    [ u"ru",u"Nikologory",6244,56.141298,41.992185 ],
    [ u"ru",u"Nikolo-Pavlovskoye",4721,57.783056,60.057778 ],
    [ u"ru",u"Nikolskiy",2916,60.918533,34.06427 ],
    [ u"ru",u"Nikolsk",23542,53.718862,46.071182 ],
    [ u"ru",u"Nikolsk",8656,59.535315,45.457434 ],
    [ u"ru",u"Nikolsko-Arkhangelskiy",18483,55.737222,37.973611 ],
    [ u"ru",u"Nikolskoye-na-Cheremshane",1967,54.05,49.233333 ],
    [ u"ru",u"Nikolskoye",5281,47.7624,46.4067 ],
    [ u"ru",u"Nikolskoye",4891,57.808308,41.103323 ],
    [ u"ru",u"Nikolskoye",17404,59.509167,34.968056 ],
    [ u"ru",u"Nikolskoye",5309,51.4652,38.8296 ],
    [ u"ru",u"Nikolskoye",763,55.193889,165.9925 ],
    [ u"ru",u"Niny",4894,44.487778,43.948889 ],
    [ u"ru",u"Nizhneangarsk",5493,55.783333,109.55 ],
    [ u"ru",u"Nizhnedevitsk",6320,51.5419,38.3657 ],
    [ u"ru",u"Nizhneivkino",2234,58.19398,49.521369 ],
    [ u"ru",u"Nizhnekamsk",234301,55.636571,51.824474 ],
    [ u"ru",u"Nizhneshilovka",5090,43.47362,40.000101 ],
    [ u"ru",u"Nizhnetroitskiy",3784,54.338515,53.68329 ],
    [ u"ru",u"Nizhneudinsk",38724,54.9076,99.0276 ],
    [ u"ru",u"Nizhnevartovsk",244940,60.9344,76.5531 ],
    [ u"ru",u"Nizhneyansk",678,71.433333,136.066667 ],
    [ u"ru",u"Nizhneye Kazanishche",11765,42.763691,47.160269 ],
    [ u"ru",u"Nizhniy Baskunchak",3153,48.219776,46.831053 ],
    [ u"ru",u"Nizhniy Bestyakh",3218,61.959444,129.908611 ],
    [ u"ru",u"Nizhniy Cherek",3098,43.513056,43.913889 ],
    [ u"ru",u"Nizhniy Chir",4765,48.359732,43.0865 ],
    [ u"ru",u"Nizhniy Dzhengutay",7450,42.700077,47.244882 ],
    [ u"ru",u"Nizhniye Achaluki",5248,43.402798,44.759079 ],
    [ u"ru",u"Nizhniye Sergi",12077,56.661389,59.303333 ],
    [ u"ru",u"Nizhniye Vyazovyye",8290,55.798772,48.52476 ],
    [ u"ru",u"Nizhniy Ingash",8458,56.2003,96.5373 ],
    [ u"ru",u"Nizhniy Kislyay",4394,50.8497,40.1719 ],
    [ u"ru",u"Nizhniy Kuranakh",6798,58.835278,125.486944 ],
    [ u"ru",u"Nizhniy Kurkuzhin",3674,43.748333,43.349722 ],
    [ u"ru",u"Nizhniy Lomov",23836,53.530412,43.676635 ],
    [ u"ru",u"Nizhniy Mamon",3914,50.1937,40.5083 ],
    [ u"ru",u"Nizhniy Novgorod",1284176,56.326944,44.0075 ],
    [ u"ru",u"Nizhniy Odes",11165,63.644511,54.855981 ],
    [ u"ru",u"Nizhniy Tagil-39",9508,58.039722,60.396111 ],
    [ u"ru",u"Nizhniy Tagil",381121,57.919444,59.965 ],
    [ u"ru",u"Nizhniy Tsasuchey",3278,50.516667,115.133333 ],
    [ u"ru",u"Nizhniy Ufaley",2818,55.915278,59.984167 ],
    [ u"ru",u"Nizhnyaya Maktama",10600,54.863564,52.428096 ],
    [ u"ru",u"Nizhnyaya Omka",5246,55.433755,74.942563 ],
    [ u"ru",u"Nizhnyaya Pavlovka",3691,51.713238,54.801463 ],
    [ u"ru",u"Nizhnyaya Poyma",9560,56.1643,97.2065 ],
    [ u"ru",u"Nizhnyaya Salda",17473,58.077557,60.720204 ],
    [ u"ru",u"Nizhnyaya Tavda",6711,57.673056,66.1725 ],
    [ u"ru",u"Nizhnyaya Tura",23835,58.6293,59.8118 ],
    [ u"ru",u"Noginsk",115981,55.866466,38.443799 ],
    [ u"ru",u"Nogir",11469,43.08162,44.636497 ],
    [ u"ru",u"Nogliki",10098,51.833333,143.166667 ],
    [ u"ru",u"Nolinsk",10282,57.559619,49.936294 ],
    [ u"ru",u"Norilsk",127504,69.3535,88.2027 ],
    [ u"ru",u"Novaya Bryan",4860,51.7159,108.2691 ],
    [ u"ru",u"Novaya Chigla",2978,51.223333,40.478056 ],
    [ u"ru",u"Novaya Igirma",10681,57.1334,103.9112 ],
    [ u"ru",u"Novaya Ladoga",9680,60.102457,32.30191 ],
    [ u"ru",u"Novaya Lyada",4851,52.713089,41.638717 ],
    [ u"ru",u"Novaya Lyalya",14246,59.05503,60.598989 ],
    [ u"ru",u"Novaya Maka",4545,41.771729,48.361489 ],
    [ u"ru",u"Novaya Malykla",3292,54.2,49.95 ],
    [ u"ru",u"Novaya Mayna",6448,54.15,49.75 ],
    [ u"ru",u"Novaya Tavolzhanka",5053,50.351234,36.8298 ],
    [ u"ru",u"Novaya Usman",22165,51.641766,39.408628 ],
    [ u"ru",u"Novaya Zaimka",4202,56.485715,66.924125 ],
    [ u"ru",u"Novichikha",4460,52.204,81.3877 ],
    [ u"ru",u"Novikovo",803,46.288333,143.393889 ],
    [ u"ru",u"Novki",1639,56.363864,41.086548 ],
    [ u"ru",u"Novoagansk",9907,61.9449,76.6625 ],
    [ u"ru",u"Novoaleksandrovsk",27610,45.494802,41.220753 ],
    [ u"ru",u"Novoalekseyevskaya",3578,44.818889,40.933889 ],
    [ u"ru",u"Novoaltaysk",61051,53.3917,83.9363 ],
    [ u"ru",u"Novoanninskiy",19231,50.5287,42.6747 ],
    [ u"ru",u"Novoasbest",2394,57.742254,60.28773 ],
    [ u"ru",u"Novobataysk",5097,46.898056,39.781944 ],
    [ u"ru",u"Novobelokatay",5923,55.7062,58.9549 ],
    [ u"ru",u"Novobessergenevka",3445,47.18465,38.846252 ],
    [ u"ru",u"Novobeysugskaya",3601,45.47195,39.88614 ],
    [ u"ru",u"Novobirilyussy",4274,56.9526,90.6807 ],
    [ u"ru",u"Novobiryusinskiy",4855,56.9578,97.7076 ],
    [ u"ru",u"Novoblagodarnoye",3146,44.143333,42.875 ],
    [ u"ru",u"Novobureyskiy",8550,49.798,129.8774 ],
    [ u"ru",u"Novocheboksarsk",128470,56.110947,47.47755 ],
    [ u"ru",u"Novocheremshansk",3294,54.357141,50.166624 ],
    [ u"ru",u"Novocherkassk",166976,47.420175,40.091325 ],
    [ u"ru",u"Novochernorechenskiy",3722,56.2652,91.0892 ],
    [ u"ru",u"Novoderevyankovskaya",6712,46.323116,38.747239 ],
    [ u"ru",u"Novodmitriyevskaya",5230,44.834722,38.877222 ],
    [ u"ru",u"Novodugino",3894,55.630525,34.284233 ],
    [ u"ru",u"Novodzherelievskaya",5365,45.773733,38.672267 ],
    [ u"ru",u"Novogagatli",4619,43.456769,46.481753 ],
    [ u"ru",u"Novogornyy",8132,55.63,60.7919 ],
    [ u"ru",u"Novogurovskiy",3702,54.467817,37.337093 ],
    [ u"ru",u"Novoilinskiy",3660,57.895057,55.476228 ],
    [ u"ru",u"Novoilinsk",5045,51.6829,108.7143 ],
    [ u"ru",u"Novokayakent",5991,42.393683,47.986078 ],
    [ u"ru",u"Novokizhinginsk",2214,51.6115,109.5917 ],
    [ u"ru",u"Novokorsunskaya",5133,45.640804,39.146412 ],
    [ u"ru",u"Novokruchininskiy",9391,51.783602,113.775912 ],
    [ u"ru",u"Novokubansk",36402,45.117,41.0267 ],
    [ u"ru",u"Novokuznetsk",539622,53.7557,87.1099 ],
    [ u"ru",u"Novolabinskaya",3733,45.109557,39.893993 ],
    [ u"ru",u"Novolakskoye",4463,43.119519,46.48281 ],
    [ u"ru",u"Novoleushkovskaya",6853,45.9956,39.9921 ],
    [ u"ru",u"Novolugovoye",3308,54.9792,83.1138 ],
    [ u"ru",u"Novolvovsk",1973,53.922376,38.790768 ],
    [ u"ru",u"Novomalorossiyskaya",5867,45.63483,39.894809 ],
    [ u"ru",u"Novomichurinsk",20821,54.0384,39.7479 ],
    [ u"ru",u"Novomikhaylovskiy",930,53.9,54.133333 ],
    [ u"ru",u"Novomikhaylovskiy",10370,44.2626,38.8585 ],
    [ u"ru",u"Novominskaya",12049,46.3163,38.9586 ],
    [ u"ru",u"Novomoskovsk",130984,54.0105,38.2846 ],
    [ u"ru",u"Novomyshastovskaya",9916,45.199086,38.582722 ],
    [ u"ru",u"Novonikolayevskaya",3753,45.586388,38.37494 ],
    [ u"ru",u"Novonikolayevskiy",10251,50.9738,42.3649 ],
    [ u"ru",u"Novonikolsk",4066,43.85,131.866667 ],
    [ u"ru",u"Novonukutskiy",3121,53.7002,102.7117 ],
    [ u"ru",u"Novoomskiy",4467,54.84152,73.301739 ],
    [ u"ru",u"Novoorsk",11212,51.3621,59.0323 ],
    [ u"ru",u"Novopavlovka",4102,51.2022,109.2194 ],
    [ u"ru",u"Novopavlovsk",24409,43.962222,43.634167 ],
    [ u"ru",u"Novopetrovskoye",5184,55.992778,36.471944 ],
    [ u"ru",u"Novopistsovo",3064,57.321768,41.853095 ],
    [ u"ru",u"Novoplatnirovskaya",3988,46.1065,39.4191 ],
    [ u"ru",u"Novopodrezkovo",10271,55.939722,37.344167 ],
    [ u"ru",u"Novopokrovka",3946,45.853056,134.508889 ],
    [ u"ru",u"Novopokrovka",2167,52.1331,40.8783 ],
    [ u"ru",u"Novopokrovskaya",19342,45.951389,40.700556 ],
    [ u"ru",u"Novoraychikhinsk",2835,49.7798,129.594 ],
    [ u"ru",u"Novorossiysk",241860,44.724386,37.767524 ],
    [ u"ru",u"Novorozhdestvenskaya",6780,45.860568,39.949679 ],
    [ u"ru",u"Novorudnyy",1930,51.5026,58.1873 ],
    [ u"ru",u"Novorzhev",3988,57.029416,29.333776 ],
    [ u"ru",u"Novoseleznëvo",3377,55.682073,69.205619 ],
    [ u"ru",u"Novoselitskoye",8723,44.750833,43.436944 ],
    [ u"ru",u"Novosemeykino",9646,53.370563,50.354278 ],
    [ u"ru",u"Novosergiyevka",13188,52.0934,53.6528 ],
    [ u"ru",u"Novoshakhtinsk",99480,47.760366,39.933351 ],
    [ u"ru",u"Novoshcherbinovskaya",6415,46.476686,38.647569 ],
    [ u"ru",u"Novosheshminsk",4585,55.065129,51.233756 ],
    [ u"ru",u"Novosibirsk",1419016,55.0415,82.9346 ],
    [ u"ru",u"Novosilikatnyy",15241,53.309722,83.623889 ],
    [ u"ru",u"Novosil",3989,52.973872,37.040481 ],
    [ u"ru",u"Novosineglazovskiy",14620,55.0401,61.3792 ],
    [ u"ru",u"Novosmolinskiy",5128,56.284096,43.050713 ],
    [ u"ru",u"Novosokolniki",9559,56.346345,30.157781 ],
    [ u"ru",u"Novospasskoye",10941,53.146833,47.751381 ],
    [ u"ru",u"Novosysoyevka",4903,44.235,133.364167 ],
    [ u"ru",u"Novotalitsy",8543,57.009373,40.850897 ],
    [ u"ru",u"Novotitarovskaya",22630,45.237565,38.98059 ],
    [ u"ru",u"Novotroitskaya",7910,45.326667,41.525278 ],
    [ u"ru",u"Novotroitsk",106187,51.203012,58.326653 ],
    [ u"ru",u"Novougolnyy",7072,53.986,38.294695 ],
    [ u"ru",u"Novoukrainskiy",3572,44.894198,38.048857 ],
    [ u"ru",u"Novoukrainskoye",5928,45.378333,40.529722 ],
    [ u"ru",u"Novoulyanovsk",17722,54.149609,48.38907 ],
    [ u"ru",u"Novouralsk",93849,57.243889,60.083889 ],
    [ u"ru",u"Novoutkinsk",5507,56.992947,59.557135 ],
    [ u"ru",u"Novouzensk",16932,50.459167,48.143056 ],
    [ u"ru",u"Novovarshavka",6487,54.1721,74.6946 ],
    [ u"ru",u"Novovelichkovskaya",8774,45.277814,38.843642 ],
    [ u"ru",u"Novovilvenskiy",411,58.383333,58.333333 ],
    [ u"ru",u"Novovoronezh",37392,51.307193,39.217316 ],
    [ u"ru",u"Novovyazniki",5611,56.197498,42.171112 ],
    [ u"ru",u"Novoye Atlashevo",3515,56.012346,47.556151 ],
    [ u"ru",u"Novoye Devyatkino",8802,60.072692,30.478374 ],
    [ u"ru",u"Novoyegoryevskoye",6168,51.7611,80.8997 ],
    [ u"ru",u"Novoye Leushino",1565,56.807324,40.514434 ],
    [ u"ru",u"Novozavedennoye",5336,44.262778,43.638056 ],
    [ u"ru",u"Novozavidovskiy",7641,56.55,36.433333 ],
    [ u"ru",u"Novozybkov",42572,52.5396,31.9275 ],
    [ u"ru",u"Novyy Buyan",3508,53.686107,50.046905 ],
    [ u"ru",u"Novyy Chirkey",7556,42.966111,46.899444 ],
    [ u"ru",u"Novyye Atagi",8760,43.135278,45.773056 ],
    [ u"ru",u"Novyye Burasy",6469,52.132361,46.071442 ],
    [ u"ru",u"Novyye Gorki",2877,56.725354,41.060145 ],
    [ u"ru",u"Novyye Lapsary",7582,56.0685,47.2142 ],
    [ u"ru",u"Novyye Lyady",9050,58.053567,56.603887 ],
    [ u"ru",u"Novyy Karachay",2172,43.820756,41.903218 ],
    [ u"ru",u"Novyy Khushet",7912,42.899415,47.560403 ],
    [ u"ru",u"Novyy Kostek",4000,43.335302,46.824664 ],
    [ u"ru",u"Novyy Nekouz",3629,57.902861,38.070037 ],
    [ u"ru",u"Novyy Oskol",21035,50.763302,37.86402 ],
    [ u"ru",u"Novyy Redant",4990,43.470136,44.806064 ],
    [ u"ru",u"Novyy Rogachik",7575,48.676853,44.060805 ],
    [ u"ru",u"Novyy Sulak",5454,43.212391,46.814258 ],
    [ u"ru",u"Novyy Urengoy",94214,66.083333,76.633333 ],
    [ u"ru",u"Novyy Urgal",7061,51.073611,132.564167 ],
    [ u"ru",u"Novyy Yegorlyk",3739,46.392701,41.871621 ],
    [ u"ru",u"Noyabrsk",98278,63.166667,75.616667 ],
    [ u"ru",u"Noybëra",6821,43.267631,46.279908 ],
    [ u"ru",u"Nozhay-Yurt",5073,43.092901,46.378682 ],
    [ u"ru",u"Nuradilovo",3371,43.284471,46.45763 ],
    [ u"ru",u"Nurlat",34452,54.427665,50.805109 ],
    [ u"ru",u"Nurma",3256,59.55,31.016667 ],
    [ u"ru",u"Nyagan",52138,62.140556,65.393611 ],
    [ u"ru",u"Nyandoma",22179,61.669031,40.199068 ],
    [ u"ru",u"Nyazepetrovsk",12717,56.053056,59.602778 ],
    [ u"ru",u"Nyrob",7314,60.733001,56.720244 ],
    [ u"ru",u"Nytva",20526,57.940419,55.333973 ],
    [ u"ru",u"Nyuksenitsa",4322,60.411593,44.233087 ],
    [ u"ru",u"Nyurba",9972,63.284167,118.331944 ],
    [ u"ru",u"Obilnoye",6739,44.244444,43.558056 ],
    [ u"ru",u"Oblivskaya",9528,48.53616,42.501381 ],
    [ u"ru",u"Obluche",10777,49,131.083333 ],
    [ u"ru",u"Obninsk",107394,55.096806,36.610064 ],
    [ u"ru",u"Ob",24239,54.9872,82.7166 ],
    [ u"ru",u"Oboyan",14434,51.209814,36.279194 ],
    [ u"ru",u"Obsharovka",5668,53.125,48.853056 ],
    [ u"ru",u"Ochër",15396,57.890347,54.720195 ],
    [ u"ru",u"Odesskoye",6025,54.2111,72.9651 ],
    [ u"ru",u"Odintsovo",137043,55.677976,37.277734 ],
    [ u"ru",u"Odoyev",6386,53.939333,36.686388 ],
    [ u"ru",u"Ogodzha",465,52.75,132.55 ],
    [ u"ru",u"Okhansk",7920,57.718547,55.387717 ],
    [ u"ru",u"Okha",26560,53.573889,142.947778 ],
    [ u"ru",u"Okhotsk",5570,59.383333,143.3 ],
    [ u"ru",u"Okoneshnikovo",5501,54.837668,75.083429 ],
    [ u"ru",u"Oksovskiy",2123,62.606234,39.898447 ],
    [ u"ru",u"Oktyabrskaya",11608,46.278,39.8151 ],
    [ u"ru",u"Oktyabrskiy",9697,61.09146,43.167665 ],
    [ u"ru",u"Oktyabrskiy",109498,54.48147,53.471031 ],
    [ u"ru",u"Oktyabrskiy",6988,50.445212,36.36066 ],
    [ u"ru",u"Oktyabrskiy",10198,54.9891,61.4743 ],
    [ u"ru",u"Oktyabrskiy",5713,56.0573,99.376 ],
    [ u"ru",u"Oktyabrskiy",1228,57.134034,40.325247 ],
    [ u"ru",u"Oktyabrskiy",6333,49.057975,140.248999 ],
    [ u"ru",u"Oktyabrskiy",1924,59.443512,48.905124 ],
    [ u"ru",u"Oktyabrskiy",627,67.566667,64.133333 ],
    [ u"ru",u"Oktyabrskiy",6110,57.44,97.518889 ],
    [ u"ru",u"Oktyabrskiy",10051,55.608062,37.977385 ],
    [ u"ru",u"Oktyabrskiy",7230,56.28423,44.189964 ],
    [ u"ru",u"Oktyabrskiy",4813,53.790399,39.476614 ],
    [ u"ru",u"Oktyabrskiy",116,57.034983,60.735393 ],
    [ u"ru",u"Oktyabrskiy",3263,53.6355,38.2002 ],
    [ u"ru",u"Oktyabrskiy",6679,54.340676,48.705314 ],
    [ u"ru",u"Oktyabrskiy",2052,56.072058,42.122715 ],
    [ u"ru",u"Oktyabrskiy",4497,47.970443,43.641577 ],
    [ u"ru",u"Oktyabrskiy",9790,56.509909,57.204514 ],
    [ u"ru",u"Oktyabrskiy",2201,52.663611,156.238611 ],
    [ u"ru",u"Oktyabrskiy",2112,50.071,118.2306 ],
    [ u"ru",u"Oktyabrsk",24726,53.167222,48.700556 ],
    [ u"ru",u"Oktyabrskoye",7507,54.4123,62.7354 ],
    [ u"ru",u"Oktyabrskoye",3933,62.458333,66.034167 ],
    [ u"ru",u"Oktyabrskoye",7600,52.333333,55.5 ],
    [ u"ru",u"Oktyabrskoye",10763,43.064512,44.74171 ],
    [ u"ru",u"Oktyabrskoye",3533,45.623333,42.831667 ],
    [ u"ru",u"Okulovka",13852,58.400833,33.290833 ],
    [ u"ru",u"Ola",6347,59.583333,151.283333 ],
    [ u"ru",u"Olenegorsk",23670,68.140359,33.273705 ],
    [ u"ru",u"Olenino",5079,56.209167,33.488882 ],
    [ u"ru",u"Olga",4347,43.744444,135.289167 ],
    [ u"ru",u"Olginskaya",4441,45.9461,38.548639 ],
    [ u"ru",u"Olginskaya",5255,47.187939,39.94925 ],
    [ u"ru",u"Olginskoye",3182,43.158889,44.688333 ],
    [ u"ru",u"Olkhovatka",4363,50.28308,39.28715 ],
    [ u"ru",u"Olkhovka",5314,49.857943,44.562052 ],
    [ u"ru",u"Olonets",10006,60.984746,32.969759 ],
    [ u"ru",u"Olovyannaya",8247,50.95,115.566667 ],
    [ u"ru",u"Olymskiy",3128,51.6798,38.1758 ],
    [ u"ru",u"Omsk",1129289,55,73.4 ],
    [ u"ru",u"Omsukchan",4201,62.533333,155.8 ],
    [ u"ru",u"Omutinskoye",9595,56.474532,67.670868 ],
    [ u"ru",u"Omutninsk",25364,58.670008,52.193195 ],
    [ u"ru",u"Onega",22693,63.906067,38.140348 ],
    [ u"ru",u"Onguday",5406,50.75,86.15 ],
    [ u"ru",u"Onokhino",3012,56.92501,65.539398 ],
    [ u"ru",u"Onokhoy",10478,51.932,108.0747 ],
    [ u"ru",u"Opalikha",5081,55.825932,37.252782 ],
    [ u"ru",u"Oparino",4986,59.851786,48.278256 ],
    [ u"ru",u"Opochka",13548,56.710477,28.661738 ],
    [ u"ru",u"Oranzherei",4367,45.847559,47.566347 ],
    [ u"ru",u"Orda",5270,57.195086,56.909078 ],
    [ u"ru",u"Ordynskoye",10314,54.3656,81.8994 ],
    [ u"ru",u"Ordzhonikidzevskaya",71841,43.319502,45.049109 ],
    [ u"ru",u"Ordzhonikidzevskiy",3246,43.842331,41.896362 ],
    [ u"ru",u"Orekhovo-Zuevo",120001,55.806722,38.961782 ],
    [ u"ru",u"Orel-Izumrud",4614,43.460047,39.923767 ],
    [ u"ru",u"Orël",333310,52.965076,36.078495 ],
    [ u"ru",u"Orgtrud",4393,56.1832,40.6149 ],
    [ u"ru",u"Orichi",7806,58.403562,49.057194 ],
    [ u"ru",u"Orlik",2008,52.5178,99.825 ],
    [ u"ru",u"Orlovka",3236,44.691389,44.174444 ],
    [ u"ru",u"Orlovo",4047,51.753972,39.587312 ],
    [ u"ru",u"Orlovskiy",19325,46.871389,42.059167 ],
    [ u"ru",u"Orlovskiy",2303,51.033333,114.833333 ],
    [ u"ru",u"Orotukan",2560,62.266667,151.7 ],
    [ u"ru",u"Orshanka",6750,56.916068,47.893346 ],
    [ u"ru",u"Orsha",2272,56.91196,36.228622 ],
    [ u"ru",u"Orsk",246839,51.204873,58.566848 ],
    [ u"ru",u"Osa",4454,53.387222,103.876944 ],
    [ u"ru",u"Osa",23292,57.282884,55.456694 ],
    [ u"ru",u"Osinki",3103,52.8432,49.5132 ],
    [ u"ru",u"Osinniki",48920,53.6239,87.3598 ],
    [ u"ru",u"Osinovo",7827,55.8809,48.881 ],
    [ u"ru",u"Ossora",2420,59.235278,163.071944 ],
    [ u"ru",u"Ostashkov",19563,57.146667,33.107534 ],
    [ u"ru",u"Oster",1894,54.017,32.8019 ],
    [ u"ru",u"Ostrogozhsk",34403,50.866398,39.075615 ],
    [ u"ru",u"Ostrovnoy",4747,68.053056,39.513056 ],
    [ u"ru",u"Ostrov",24355,57.343949,28.353681 ],
    [ u"ru",u"Ostrovskoye",5138,57.805744,42.243316 ],
    [ u"ru",u"Ostrovtsy",3683,55.5875,38.005556 ],
    [ u"ru",u"Otkaznoye",4090,44.326389,43.860833 ],
    [ u"ru",u"Otradinskiy",3022,53.25,36.4 ],
    [ u"ru",u"Otradnaya",22985,44.393333,41.520556 ],
    [ u"ru",u"Otradnoye",21397,59.7775,30.818056 ],
    [ u"ru",u"Otradnoye",3215,44.069444,145.863889 ],
    [ u"ru",u"Otradnyy",50127,53.375957,51.345197 ],
    [ u"ru",u"Otrado-Kubanskoye",3697,45.244167,40.840833 ],
    [ u"ru",u"Otrado-Olginskoye",3365,45.305278,40.9475 ],
    [ u"ru",u"Ous",1639,60.905833,61.518611 ],
    [ u"ru",u"Overyata",4507,58.03408,55.839187 ],
    [ u"ru",u"Ovsyanka",3588,53.583333,126.883333 ],
    [ u"ru",u"Ovsyanka",3722,55.9583,92.572 ],
    [ u"ru",u"Oyëk",3380,52.586111,104.455556 ],
    [ u"ru",u"Oyskhara",12795,43.264016,46.248027 ],
    [ u"ru",u"Ozerki",4327,53.6294,83.7085 ],
    [ u"ru",u"Ozernovskiy",2615,51.5,156.516667 ],
    [ u"ru",u"Ozinki",9733,51.1786,49.6769 ],
    [ u"ru",u"Pachelma",8620,53.244259,43.352046 ],
    [ u"ru",u"Palana",3671,59.116667,159.966667 ],
    [ u"ru",u"Palatka",4534,60.1,150.9 ],
    [ u"ru",u"Palekh",5616,56.802562,41.855077 ],
    [ u"ru",u"Palkino",3112,57.540885,28.01257 ],
    [ u"ru",u"Pallasovka",17139,50.05,46.883333 ],
    [ u"ru",u"Pamyat Parizhskoy Kommuny",4003,56.104795,44.495196 ],
    [ u"ru",u"Panfilovo",289,56.689941,41.186424 ],
    [ u"ru",u"Pangody",10898,65.916667,74.833333 ],
    [ u"ru",u"Panino",7164,51.6467,40.1346 ],
    [ u"ru",u"Pankovka",9828,58.500043,31.199903 ],
    [ u"ru",u"Pankrushikha",5160,53.831944,80.340556 ],
    [ u"ru",u"Parabel",6227,58.697778,81.4825 ],
    [ u"ru",u"Paranga",6634,56.703889,49.404722 ],
    [ u"ru",u"Paraul",4278,42.741926,47.355315 ],
    [ u"ru",u"Parfenyevo",2861,58.483958,43.408764 ],
    [ u"ru",u"Parfino",8254,57.973056,31.648056 ],
    [ u"ru",u"Pargolovo",11962,60.05,30.316667 ],
    [ u"ru",u"Parkovyy",4524,45.833056,40.145556 ],
    [ u"ru",u"Parma",1319,65.950714,57.46847 ],
    [ u"ru",u"Partizan",2462,53.950174,38.098008 ],
    [ u"ru",u"Partizanskoye",3915,55.4972,94.3922 ],
    [ u"ru",u"Partizansk",42490,43.125833,133.133889 ],
    [ u"ru",u"Partsa",3056,54.2667,42.7168 ],
    [ u"ru",u"Pashiya",4140,58.4324,58.2562 ],
    [ u"ru",u"Pashkovskiy",43634,45.024396,39.106788 ],
    [ u"ru",u"Pavda",677,59.250886,59.508019 ],
    [ u"ru",u"Pavelets",2152,53.788334,39.246006 ],
    [ u"ru",u"Pavino",2947,59.113899,46.141419 ],
    [ u"ru",u"Pavlodolskaya",5833,43.719225,44.478154 ],
    [ u"ru",u"Pavlogradka",6148,54.2024,73.5592 ],
    [ u"ru",u"Pavlovka",4277,55.420942,56.55426 ],
    [ u"ru",u"Pavlovka",5878,53.595685,46.766311 ],
    [ u"ru",u"Pavlovo",3348,59.808611,30.896667 ],
    [ u"ru",u"Pavlovo",63339,55.968598,43.091202 ],
    [ u"ru",u"Pavlovskaya",31133,46.1377,39.7832 ],
    [ u"ru",u"Pavlovskaya Sloboda",5937,55.815171,37.082461 ],
    [ u"ru",u"Pavlovskiy",3323,57.842403,54.843573 ],
    [ u"ru",u"Pavlovskiy Posad",60052,55.780713,38.654475 ],
    [ u"ru",u"Pavlovsk",14827,53.318611,82.982222 ],
    [ u"ru",u"Pavlovsk",13474,59.683333,30.434722 ],
    [ u"ru",u"Pavlovsk",26566,50.457778,40.108056 ],
    [ u"ru",u"Pechenga",2791,69.56101,31.220236 ],
    [ u"ru",u"Pechora",46113,65.147165,57.224392 ],
    [ u"ru",u"Pechory",13246,57.815034,27.607594 ],
    [ u"ru",u"Pelagiada",6871,45.206389,42.023611 ],
    [ u"ru",u"Peleduy",4556,59.628889,112.740556 ],
    [ u"ru",u"Pelym",3647,61.010833,61.997778 ],
    [ u"ru",u"Peno",5187,56.92624,32.742625 ],
    [ u"ru",u"Penza",512607,53.200656,45.004643 ],
    [ u"ru",u"Peredovaya",4204,44.117222,41.475556 ],
    [ u"ru",u"Pereleshino",3795,51.7376,40.1388 ],
    [ u"ru",u"Pereleshinskiy",3257,51.7148,40.1953 ],
    [ u"ru",u"Perelyub",5549,51.866667,50.366667 ],
    [ u"ru",u"Peremyshl",3199,54.263126,36.160631 ],
    [ u"ru",u"Perepravnaya",3186,44.3366,40.7849 ],
    [ u"ru",u"Pereslavl-Zalesskiy",43490,56.739341,38.856259 ],
    [ u"ru",u"Perevolotskiy",9667,51.876329,54.193776 ],
    [ u"ru",u"Perevoz",9228,55.596132,44.544606 ],
    [ u"ru",u"Pereyaslovskaya",8542,45.841207,39.023794 ],
    [ u"ru",u"Perm",982428,58.009282,56.284063 ],
    [ u"ru",u"Persianovskiy",15730,47.529722,39.418333 ],
    [ u"ru",u"Pervoavgustovskiy",1677,52.2264,35.0552 ],
    [ u"ru",u"Pervomayskaya",5026,43.403307,45.523435 ],
    [ u"ru",u"Pervomayskiy",41998,64.4165,40.8122 ],
    [ u"ru",u"Pervomayskiy",511,53.509246,55.88789 ],
    [ u"ru",u"Pervomayskiy",10681,54.866389,61.170278 ],
    [ u"ru",u"Pervomayskiy",3643,58.5166,49.7626 ],
    [ u"ru",u"Pervomayskiy",9964,55.517778,37.22 ],
    [ u"ru",u"Pervomayskiy",1086,56.614737,43.358254 ],
    [ u"ru",u"Pervomayskiy",6540,51.5367,55.004643 ],
    [ u"ru",u"Pervomayskiy",444,53.353932,51.593643 ],
    [ u"ru",u"Pervomayskiy",13345,53.1954,40.2646 ],
    [ u"ru",u"Pervomayskiy",10946,54.044824,37.508749 ],
    [ u"ru",u"Pervomayskiy",12530,51.670131,115.625433 ],
    [ u"ru",u"Pervomayskoye",5103,53.721111,84.018333 ],
    [ u"ru",u"Pervomayskoye",9073,43.919041,46.710193 ],
    [ u"ru",u"Pervomayskoye",5345,43.938471,42.476 ],
    [ u"ru",u"Pervomayskoye",4473,60.35922,29.742402 ],
    [ u"ru",u"Pervomayskoye",5817,57.0761,86.2313 ],
    [ u"ru",u"Pervomaysk",14810,54.8689,43.802717 ],
    [ u"ru",u"Pervouralsk",130016,56.905278,59.943611 ],
    [ u"ru",u"Pervoye Maya",2173,56.164031,44.719549 ],
    [ u"ru",u"Pervoye Maya",4512,50.889972,39.591904 ],
    [ u"ru",u"Peschanokopskoye",11340,46.195167,41.081431 ],
    [ u"ru",u"Peshkovo",3596,47.018667,39.388446 ],
    [ u"ru",u"Peski",3705,55.216256,38.762625 ],
    [ u"ru",u"Peski",7230,51.2531,42.4693 ],
    [ u"ru",u"Peskovka",6746,59.044781,52.360571 ],
    [ u"ru",u"Pesochenskiy",547,54.17436,36.109517 ],
    [ u"ru",u"Pesochnoye",3005,58.005972,39.177167 ],
    [ u"ru",u"Pesochnyy",6348,60.122946,30.164042 ],
    [ u"ru",u"Pestovo",15910,58.503501,35.676734 ],
    [ u"ru",u"Pestravka",6623,52.3982,49.961 ],
    [ u"ru",u"Pestretsy",7311,55.75313,49.654537 ],
    [ u"ru",u"Pestyaki",4172,56.708597,42.669545 ],
    [ u"ru",u"Petrodvorets",61974,59.87966,29.90257 ],
    [ u"ru",u"Petrokamenskoye",3688,57.716,60.6484 ],
    [ u"ru",u"Petropavlovka",7582,50.6114,105.3196 ],
    [ u"ru",u"Petropavlovka",5469,50.1017,40.8847 ],
    [ u"ru",u"Petropavlovskaya",6632,45.081894,40.451253 ],
    [ u"ru",u"Petropavlovskaya",3686,43.379444,45.826111 ],
    [ u"ru",u"Petropavlovsk-Kamchatskiy",187283,53.0452,158.6483 ],
    [ u"ru",u"Petropavlovskoye",2839,52.0712,84.107 ],
    [ u"ru",u"Petro-Slavyanka",1308,59.802222,30.506944 ],
    [ u"ru",u"Petrovskaya",13340,45.431389,37.955 ],
    [ u"ru",u"Petrovskiy",2943,56.642096,40.320255 ],
    [ u"ru",u"Petrovskoye",5324,57.010386,39.269279 ],
    [ u"ru",u"Petrovsk",33622,52.306389,45.391667 ],
    [ u"ru",u"Petrovsk-Zabaykalskiy",19843,51.2339,108.8489 ],
    [ u"ru",u"Petrov Val",14853,50.143374,45.209579 ],
    [ u"ru",u"Petrozavodsk",265027,61.796131,34.349295 ],
    [ u"ru",u"Petukhovo",12367,55.069167,67.901944 ],
    [ u"ru",u"Petushki",15866,55.926393,39.46104 ],
    [ u"ru",u"Pevek",4832,69.700833,170.313333 ],
    [ u"ru",u"Pichayevo",3463,53.236274,42.203232 ],
    [ u"ru",u"Pilna",7733,55.553935,45.921938 ],
    [ u"ru",u"Pindushi",5053,62.915187,34.579956 ],
    [ u"ru",u"Pinega",3620,64.700136,43.393619 ],
    [ u"ru",u"Pinerovka",3602,51.562,43.0689 ],
    [ u"ru",u"Pinyug",2915,60.250949,47.784252 ],
    [ u"ru",u"Pioner",6015,55.3166,85.9508 ],
    [ u"ru",u"Pionerskiy",11856,54.950826,20.227479 ],
    [ u"ru",u"Pionerskiy",5348,61.194722,62.868889 ],
    [ u"ru",u"Pionerskiy",3134,57.105955,63.750453 ],
    [ u"ru",u"Pirogovo",3363,56.779589,53.149543 ],
    [ u"ru",u"Pirogovskiy",6208,55.978056,37.733611 ],
    [ u"ru",u"Pirovskoye",3241,57.6188,92.2657 ],
    [ u"ru",u"Pistsovo",2775,57.179039,40.529828 ],
    [ u"ru",u"Pitelino",2355,54.577683,41.814484 ],
    [ u"ru",u"Piterka",5437,50.680297,47.445395 ],
    [ u"ru",u"Pitkyaranta",13090,61.573403,31.479152 ],
    [ u"ru",u"Pizhanka",3900,57.460416,48.541998 ],
    [ u"ru",u"Pizhma",4266,57.864183,47.117138 ],
    [ u"ru",u"Planovskoye",3482,43.398456,44.194899 ],
    [ u"ru",u"Plast",17050,54.327231,60.867323 ],
    [ u"ru",u"Plastunovskaya",9604,45.295563,39.266709 ],
    [ u"ru",u"Plastun",6082,44.756111,136.293889 ],
    [ u"ru",u"Platnirovskaya",11710,45.395314,39.384203 ],
    [ u"ru",u"Platonovka",3761,52.710584,41.951985 ],
    [ u"ru",u"Plavsk",16763,53.709444,37.291944 ],
    [ u"ru",u"Plekhanovo",8841,54.015056,37.717133 ],
    [ u"ru",u"Plesetsk",10870,62.708043,40.291594 ],
    [ u"ru",u"Pleshanovo",3746,52.833333,53.483333 ],
    [ u"ru",u"Plotnikovo",4983,55.024722,85.943611 ],
    [ u"ru",u"Plyussa",3749,58.416667,29.416667 ],
    [ u"ru",u"Pochinki",11724,54.698746,44.86678 ],
    [ u"ru",u"Pochinok",9310,54.346269,32.86212 ],
    [ u"ru",u"Podbelsk",3391,53.604148,51.802263 ],
    [ u"ru",u"Poddorye",1913,57.469472,31.115608 ],
    [ u"ru",u"Podgorenskiy",6652,50.404976,39.642953 ],
    [ u"ru",u"Podgornaya",5336,44.203056,43.429722 ],
    [ u"ru",u"Podgornoye",5024,57.788611,82.651944 ],
    [ u"ru",u"Podgornoye",3826,50.182586,39.522129 ],
    [ u"ru",u"Podgorodnyaya Pokrovka",3123,51.828077,54.987396 ],
    [ u"ru",u"Podkletnoye",3070,51.589934,39.4623 ],
    [ u"ru",u"Podkumskiy",3702,44.075556,43.210278 ],
    [ u"ru",u"Podlesnoye",4149,51.8161,47.009 ],
    [ u"ru",u"Podlesnyy",1745,53.940033,38.26872 ],
    [ u"ru",u"Podolsk",175326,55.424185,37.554717 ],
    [ u"ru",u"Podosinovets",4106,60.277581,47.06587 ],
    [ u"ru",u"Podporozhye",19658,60.911242,34.170644 ],
    [ u"ru",u"Podsineye",3249,53.665833,91.536389 ],
    [ u"ru",u"Podstepki",3140,53.5151,49.1355 ],
    [ u"ru",u"Podyuga",2977,61.095,40.864722 ],
    [ u"ru",u"Pogar",11242,52.553993,33.259067 ],
    [ u"ru",u"Pogranichnyy",11930,44.406389,131.376944 ],
    [ u"ru",u"Poim",3138,53.026394,43.187214 ],
    [ u"ru",u"Pokanayevka",723,56.5161,97.661 ],
    [ u"ru",u"Pokhvistnevo",27914,53.6431,52.2211 ],
    [ u"ru",u"Pokosnoye",3110,55.525833,101.053611 ],
    [ u"ru",u"Pokoynoye",9175,44.809722,44.251667 ],
    [ u"ru",u"Pokrovka",390,56.233333,36.833333 ],
    [ u"ru",u"Pokrovka",10614,43.95,131.65 ],
    [ u"ru",u"Pokrovo-Prigorodnoye",5012,52.684049,41.417521 ],
    [ u"ru",u"Pokrov",15867,55.917973,39.172416 ],
    [ u"ru",u"Pokrovskoye",3827,43.288724,46.665274 ],
    [ u"ru",u"Pokrovskoye",4566,52.4349,36.638008 ],
    [ u"ru",u"Pokrovskoye",12576,47.415701,38.897063 ],
    [ u"ru",u"Pokrovskoye",3573,56.4704,61.6092 ],
    [ u"ru",u"Pokrovsk",9763,61.478056,129.127222 ],
    [ u"ru",u"Pokrovsk-Uralskiy",1592,60.139942,59.823393 ],
    [ u"ru",u"Polazna",12973,58.294584,56.405459 ],
    [ u"ru",u"Polessk",7835,54.86205,21.102791 ],
    [ u"ru",u"Poletayevo",6532,55.0336,61.1138 ],
    [ u"ru",u"Polevskoy",65771,56.442222,60.187778 ],
    [ u"ru",u"Polotnyanyy Zavod",5679,54.721389,35.966111 ],
    [ u"ru",u"Polovinnoye",5103,54.791389,65.986389 ],
    [ u"ru",u"Polovinnoye",3530,53.756713,79.243271 ],
    [ u"ru",u"Poltavka",7103,54.36629,71.76319 ],
    [ u"ru",u"Poltavskaya",29009,45.366144,38.211711 ],
    [ u"ru",u"Polunochnoye",2848,60.869722,60.415278 ],
    [ u"ru",u"Polyany",6170,54.718008,39.829325 ],
    [ u"ru",u"Polyarnyye Zori",15092,67.366111,32.498056 ],
    [ u"ru",u"Polyarnyy",17332,69.198889,33.447778 ],
    [ u"ru",u"Polysayevo",28028,54.6012,86.2459 ],
    [ u"ru",u"Ponazyrevo",4861,58.357836,46.314211 ],
    [ u"ru",u"Ponezhukay",3390,44.887612,39.38551 ],
    [ u"ru",u"Pontonnyy",9001,59.786667,30.615278 ],
    [ u"ru",u"Ponyri",4591,52.317453,36.302611 ],
    [ u"ru",u"Poplevinskiy",667,53.684676,39.54423 ],
    [ u"ru",u"Popova",1285,42.960278,131.722778 ],
    [ u"ru",u"Poputnaya",6279,44.5125,41.4392 ],
    [ u"ru",u"Porechye-Rybnoye",1836,57.098053,39.383536 ],
    [ u"ru",u"Poretskoye",6420,55.197423,46.329078 ],
    [ u"ru",u"Porkhov",11886,57.765016,29.556121 ],
    [ u"ru",u"Poronaysk",16677,49.216667,143.116667 ],
    [ u"ru",u"Porosozero",3436,62.719118,32.727029 ],
    [ u"ru",u"Poselki",3069,53.132364,46.503068 ],
    [ u"ru",u"Posevnaya",4268,54.299,83.331 ],
    [ u"ru",u"Poshekhonye",6813,58.499279,39.135306 ],
    [ u"ru",u"Pospelikha",13586,51.95,81.766667 ],
    [ u"ru",u"Posyet",2857,42.652954,130.797066 ],
    [ u"ru",u"Potanino",8717,55.1786,61.6222 ],
    [ u"ru",u"Potma",4296,53.933236,42.979056 ],
    [ u"ru",u"Povarovo",7539,56.066667,37.05 ],
    [ u"ru",u"Povenets",2539,62.848698,34.826211 ],
    [ u"ru",u"Povolzhskiy",8952,53.5854,49.7629 ],
    [ u"ru",u"Povorino",18004,51.1945,42.2457 ],
    [ u"ru",u"Poyarkovo",7003,49.6,128.683333 ],
    [ u"ru",u"Poykovskiy",28080,61.233333,73.333333 ],
    [ u"ru",u"Pozhva",3677,59.091192,56.084673 ],
    [ u"ru",u"Praskoveya",11420,44.744444,44.203056 ],
    [ u"ru",u"Pravda",2412,46.939556,142.009033 ],
    [ u"ru",u"Pravdinskiy",10372,56.066667,37.85 ],
    [ u"ru",u"Pravdinsk",4515,54.442894,21.017853 ],
    [ u"ru",u"Pravokubanskiy",2971,43.917209,41.884134 ],
    [ u"ru",u"Pravokumskoye",5117,44.769444,44.647222 ],
    [ u"ru",u"Predivinsk",2028,57.0631,93.4374 ],
    [ u"ru",u"Predporozhnyy",239,65.166667,143.2 ],
    [ u"ru",u"Pregradnaya",6595,43.953946,41.189103 ],
    [ u"ru",u"Pregradnoye",3671,45.821834,41.746924 ],
    [ u"ru",u"Preobrazheniye",9113,42.901944,133.906389 ],
    [ u"ru",u"Preobrazhenskaya",5475,50.741611,43.051798 ],
    [ u"ru",u"Priamurskiy",3560,48.521667,134.902778 ],
    [ u"ru",u"Priargunsk",7902,50.3691,119.1012 ],
    [ u"ru",u"Pribelskiy",4969,54.3842,56.4519 ],
    [ u"ru",u"Pridonskoy",16896,51.684059,39.072696 ],
    [ u"ru",u"Prigorodka",3140,52.044719,39.712385 ],
    [ u"ru",u"Prigorodnoye",4863,43.253035,45.758077 ],
    [ u"ru",u"Prigorodnyy",3222,51.766083,55.266478 ],
    [ u"ru",u"Priiskovyy",1174,54.656111,88.687222 ],
    [ u"ru",u"Priiskovyy",1578,51.933333,116.633333 ],
    [ u"ru",u"Prikubanskiy",3168,45.0015,41.1795 ],
    [ u"ru",u"Priladozhskiy",5159,59.85,31.483333 ],
    [ u"ru",u"Primalkinskoye",4873,43.746667,44.008333 ],
    [ u"ru",u"Primore",859,54.941913,20.03745 ],
    [ u"ru",u"Primorka",3780,47.283954,39.064076 ],
    [ u"ru",u"Primorskiy",1708,43.098333,131.5875 ],
    [ u"ru",u"Primorsko-Akhtarsk",33103,46.0497,38.1747 ],
    [ u"ru",u"Primorsk",2222,54.739048,20.005529 ],
    [ u"ru",u"Primorsk",5107,60.365806,28.618205 ],
    [ u"ru",u"Primorsk",3235,49.265323,45.028888 ],
    [ u"ru",u"Prirechnyy",103,69.016556,30.274304 ],
    [ u"ru",u"Pristen",5463,51.235512,36.695937 ],
    [ u"ru",u"Pritomskiy",4261,53.7482,87.3141 ],
    [ u"ru",u"Priupskiy",3324,53.909603,37.735995 ],
    [ u"ru",u"Privodino",3140,61.075994,46.502381 ],
    [ u"ru",u"Privokzalnyy",3617,56.000107,35.921561 ],
    [ u"ru",u"Privokzalnyy",6116,58.879602,60.730923 ],
    [ u"ru",u"Privolnaya",6566,46.1389,38.6975 ],
    [ u"ru",u"Privolnyy",3554,45.593056,42.031389 ],
    [ u"ru",u"Privolzhskiy",4110,55.961346,48.415118 ],
    [ u"ru",u"Privolzhskiy",31849,51.409444,46.048333 ],
    [ u"ru",u"Privolzhsk",17865,57.386983,41.286655 ],
    [ u"ru",u"Privolzhye",7423,52.8558,48.5929 ],
    [ u"ru",u"Priyutnoye",5632,46.101111,43.507222 ],
    [ u"ru",u"Priyutovo",20847,53.9,53.933333 ],
    [ u"ru",u"Prochnookopskaya",4916,45.0666,41.1175 ],
    [ u"ru",u"Progress",12578,49.741,129.6824 ],
    [ u"ru",u"Prokhorovka",10136,51.037412,36.732524 ],
    [ u"ru",u"Prokopyevsk",215272,53.9059,86.719 ],
    [ u"ru",u"Prokudskoye",6043,55.0089,82.4574 ],
    [ u"ru",u"Proletariy",5240,58.434231,31.704619 ],
    [ u"ru",u"Proletarskiy",8786,50.7569,35.5194 ],
    [ u"ru",u"Proletarskiy",4069,55.022194,37.390193 ],
    [ u"ru",u"Proletarsk",19494,46.702886,41.727167 ],
    [ u"ru",u"Promyshlennaya",17216,54.9159,85.6385 ],
    [ u"ru",u"Promyshlennovskiy",6152,55.483333,86.2 ],
    [ u"ru",u"Promyshlennyy",1112,67.583333,63.916667 ],
    [ u"ru",u"Promysla",728,58.564167,59.152778 ],
    [ u"ru",u"Pronsk",4222,54.1048,39.6092 ],
    [ u"ru",u"Prosvet",2961,55.570278,65.0825 ],
    [ u"ru",u"Protvino",37330,54.868205,37.215835 ],
    [ u"ru",u"Provideniya",2536,64.383333,-173.3 ],
    [ u"ru",u"Prudy",3806,57.573804,46.27176 ],
    [ u"ru",u"Pryamitsyno",5120,51.6561,35.9314 ],
    [ u"ru",u"Pryazha",4156,61.692584,33.621586 ],
    [ u"ru",u"Przhevalskoye",2055,55.508745,31.848189 ],
    [ u"ru",u"Psebay",11174,44.1234,40.8107 ],
    [ u"ru",u"Psedakh",6964,43.467222,44.569167 ],
    [ u"ru",u"Pshekhskaya",4979,44.695966,39.79665 ],
    [ u"ru",u"Pskov",201992,57.8136,28.3496 ],
    [ u"ru",u"Psygansu",6885,43.419444,43.793611 ],
    [ u"ru",u"Psyzh",6840,44.233056,42.018333 ],
    [ u"ru",u"Ptichye",4680,45.525204,41.716017 ],
    [ u"ru",u"Puchezh",9881,56.978779,43.167615 ],
    [ u"ru",u"Pudem",2278,58.304399,52.167539 ],
    [ u"ru",u"Pudozh",10605,61.809882,36.534541 ],
    [ u"ru",u"Puksoozero",2086,62.5903,40.6066 ],
    [ u"ru",u"Purpe",9099,64.480278,76.689722 ],
    [ u"ru",u"Pushchino",20073,54.833727,37.611379 ],
    [ u"ru",u"Pushkino",71653,55.996111,37.901667 ],
    [ u"ru",u"Pushkino",2728,51.235,46.974167 ],
    [ u"ru",u"Pushkin",82417,59.722778,30.414167 ],
    [ u"ru",u"Pushkinskiye Gory",5920,57.020851,28.910296 ],
    [ u"ru",u"Pustoshka",5253,56.335474,29.369008 ],
    [ u"ru",u"Putëvka",3656,53.258333,34.287778 ],
    [ u"ru",u"Puteyets",1223,65.17157,57.091014 ],
    [ u"ru",u"Putyatino",3044,54.159976,41.116902 ],
    [ u"ru",u"Pyaozerskiy",2534,65.766361,31.100852 ],
    [ u"ru",u"Pyatigorskiy",4997,43.974167,43.258333 ],
    [ u"ru",u"Pyatigorsk",142868,44.048611,43.059444 ],
    [ u"ru",u"Pyatnitskoye",4855,50.4233,37.8273 ],
    [ u"ru",u"Pyatovskiy",2986,54.68908,36.056338 ],
    [ u"ru",u"Pychas",3183,56.503318,52.440877 ],
    [ u"ru",u"Pyra",1991,56.295273,43.35274 ],
    [ u"ru",u"Pyshchug",3226,58.887259,45.713413 ],
    [ u"ru",u"Pyshma",10094,56.952263,63.251291 ],
    [ u"ru",u"Pytalovo",6767,57.067905,27.913843 ],
    [ u"ru",u"Radchenko",2022,56.680271,36.371778 ],
    [ u"ru",u"Radishchevo",4845,52.854592,47.876437 ],
    [ u"ru",u"Raditsa-Krylovka",3443,53.317124,34.35742 ],
    [ u"ru",u"Radovitskiy",1887,55.128198,39.795601 ],
    [ u"ru",u"Raduzhnyy",9514,59.483333,49.65 ],
    [ u"ru",u"Rakhya",3140,60.091148,30.837778 ],
    [ u"ru",u"Rakitnoye",10596,50.8389,35.8515 ],
    [ u"ru",u"Ramasukha",553,52.738782,33.544128 ],
    [ u"ru",u"Ramenskoye",3830,55.566944,38.230278 ],
    [ u"ru",u"Rameshki",4110,57.343895,36.045346 ],
    [ u"ru",u"Ramon",7928,51.915695,39.336087 ],
    [ u"ru",u"Rasshevatskaya",5686,45.574802,41.034958 ],
    [ u"ru",u"Rasskazovo",45957,52.655986,41.88461 ],
    [ u"ru",u"Rassvet",3454,56.999,91.4724 ],
    [ u"ru",u"Rassvet",4765,46.7428,41.2342 ],
    [ u"ru",u"Raychikhinsk",23746,49.7838,129.4121 ],
    [ u"ru",u"Rayevskaya",8518,44.835714,37.555765 ],
    [ u"ru",u"Rayevskiy",20060,54.0658,54.9468 ],
    [ u"ru",u"Razdolinsk",2762,58.421111,94.665833 ],
    [ u"ru",u"Razdolnaya",3190,45.378276,39.556374 ],
    [ u"ru",u"Razdolnoye",7648,43.55,131.916667 ],
    [ u"ru",u"Razumnoye",15529,50.534392,36.68462 ],
    [ u"ru",u"Razvilka",8701,55.59209,37.740853 ],
    [ u"ru",u"Razvilnoye",5844,46.237791,41.295919 ],
    [ u"ru",u"Rebrikha",8858,53.009167,82.289722 ],
    [ u"ru",u"Rechitsy",3436,55.597537,38.471343 ],
    [ u"ru",u"Redkino",11507,56.647541,36.296737 ],
    [ u"ru",u"Reftinskiy",17673,57.090133,61.676919 ],
    [ u"ru",u"Remontnoye",7374,46.5614,43.6501 ],
    [ u"ru",u"Repino",1968,60.168833,29.870195 ],
    [ u"ru",u"Repnoye",3131,51.5921,43.1861 ],
    [ u"ru",u"Reshetikha",7356,56.215664,43.288021 ],
    [ u"ru",u"Reshetnikovo",3192,56.45,36.566667 ],
    [ u"ru",u"Rettikhovka",2712,44.168333,132.766944 ],
    [ u"ru",u"Reutov",78371,55.761111,37.8575 ],
    [ u"ru",u"Revda",9780,67.937101,34.561494 ],
    [ u"ru",u"Revda",61786,56.800968,59.930278 ],
    [ u"ru",u"Revyakino",3220,54.365167,37.662494 ],
    [ u"ru",u"Rezh",39217,57.3174,61.3355 ],
    [ u"ru",u"Rochegda",2362,62.8,43.25 ],
    [ u"ru",u"Rodino",9537,52.5,80.25 ],
    [ u"ru",u"Rodionovo-Nesvetayskaya",6188,47.610333,39.71212 ],
    [ u"ru",u"Rodniki",27681,57.105131,41.73048 ],
    [ u"ru",u"Rodniki",3710,55.652041,38.066846 ],
    [ u"ru",u"Rodnikovskaya",8925,44.764444,40.665556 ],
    [ u"ru",u"Rognedino",3287,53.801468,33.557597 ],
    [ u"ru",u"Rogovatoye",3062,51.23,38.3818 ],
    [ u"ru",u"Rogovskaya",8435,45.731166,38.739597 ],
    [ u"ru",u"Romanovka",5647,60.044301,30.713997 ],
    [ u"ru",u"Romanovka",7746,51.744271,42.752697 ],
    [ u"ru",u"Romanovo",6056,52.6182,81.2271 ],
    [ u"ru",u"Romanovskaya",6885,47.5426,42.0285 ],
    [ u"ru",u"Romny",3413,50.724984,129.289379 ],
    [ u"ru",u"Romodanovo",9646,54.42753,45.329622 ],
    [ u"ru",u"Roshal",21951,55.668534,39.874879 ],
    [ u"ru",u"Roshchino",5231,55.3093,61.2635 ],
    [ u"ru",u"Roshchino",9346,60.247426,29.613078 ],
    [ u"ru",u"Roshni-Chu",4253,43.089536,45.454349 ],
    [ u"ru",u"Roslavl",56972,53.952778,32.863889 ],
    [ u"ru",u"Roslyakovo",8921,69.04303,33.199061 ],
    [ u"ru",u"Rossosh",64324,51.1209,38.5116 ],
    [ u"ru",u"Rostovka",5423,55.3842,71.88913 ],
    [ u"ru",u"Rostov-na-Donu",1074495,47.23135,39.723284 ],
    [ u"ru",u"Rostov",33804,57.191402,39.41394 ],
    [ u"ru",u"Rovenki",9867,49.922268,38.891443 ],
    [ u"ru",u"Rovnoye",5228,50.776504,46.050855 ],
    [ u"ru",u"Roza",14491,54.9163,61.4586 ],
    [ u"ru",u"Rozhdestveno",3062,55.854436,37.049351 ],
    [ u"ru",u"Rozhdestveno",5004,53.237446,50.059706 ],
    [ u"ru",u"Rtishchevo",44014,52.260412,43.78745 ],
    [ u"ru",u"Rubtsovsk",161067,51.5,81.25 ],
    [ u"ru",u"Rudnaya Pristan",2332,44.3614,135.8116 ],
    [ u"ru",u"Rudnichnyy",4308,56.0837,86.2517 ],
    [ u"ru",u"Rudnichnyy",5555,59.617016,52.470326 ],
    [ u"ru",u"Rudnichnyy",4201,59.701183,60.288172 ],
    [ u"ru",u"Rudnichnyy",875,59.000819,57.648561 ],
    [ u"ru",u"Rudnogorsk",4441,57.2639,103.7519 ],
    [ u"ru",u"Rudnya",9615,54.946977,31.093395 ],
    [ u"ru",u"Rudnya",8062,50.798981,44.55856 ],
    [ u"ru",u"Rudnyy",2567,44.282778,134.959444 ],
    [ u"ru",u"Russkaya Polyana",6454,53.779444,73.880556 ],
    [ u"ru",u"Russkiy Aktash",4195,55.0384,52.1214 ],
    [ u"ru",u"Russkiy Kameshkir",5305,52.859548,46.088611 ],
    [ u"ru",u"Russkiy",5080,43.014722,131.864167 ],
    [ u"ru",u"Russko-Vysotskoye",4711,59.699634,29.944036 ],
    [ u"ru",u"Russkoye",4507,43.839722,44.615 ],
    [ u"ru",u"Rutul",4237,41.535663,47.423908 ],
    [ u"ru",u"Ruza",13480,55.698977,36.195219 ],
    [ u"ru",u"Ryabovo",3292,59.4,31.133333 ],
    [ u"ru",u"Ryazanovskiy",2305,55.133302,39.55141 ],
    [ u"ru",u"Ryazan",520177,54.6269,39.6916 ],
    [ u"ru",u"Ryazanskaya",5157,44.955279,39.588938 ],
    [ u"ru",u"Ryazhsk",22041,53.7038,40.1109 ],
    [ u"ru",u"Rybachiy",973,55.154559,20.851537 ],
    [ u"ru",u"Rybinsk",216726,58.044598,38.842594 ],
    [ u"ru",u"Rybnaya Sloboda",7190,55.461291,50.140899 ],
    [ u"ru",u"Rybnoye",19159,54.727742,39.517314 ],
    [ u"ru",u"Rylsk",17211,51.5655,34.6822 ],
    [ u"ru",u"Ryzdvyanyy",7602,45.2656,41.8389 ],
    [ u"ru",u"Rzhaksa",5692,52.133839,42.026402 ],
    [ u"ru",u"Rzhanitsa",5281,53.428443,33.922968 ],
    [ u"ru",u"Rzhavki",4084,56,37.23 ],
    [ u"ru",u"Rzhev",62247,56.262413,34.328168 ],
    [ u"ru",u"Sabnova",3598,42.076173,48.247956 ],
    [ u"ru",u"Sadon",754,42.852621,44.006496 ],
    [ u"ru",u"Sadovoye",6333,47.7772,44.5208 ],
    [ u"ru",u"Sadovoye",5011,51.531111,40.501944 ],
    [ u"ru",u"Sadovyy",2968,56.763744,60.549384 ],
    [ u"ru",u"Safakulevo",4189,54.9901,62.5442 ],
    [ u"ru",u"Safonovo",4578,69.060428,33.295228 ],
    [ u"ru",u"Safonovo",46638,55.110867,33.232917 ],
    [ u"ru",u"Sagopshi",11848,43.485146,44.590633 ],
    [ u"ru",u"Saint Petersburg",4039751,59.894444,30.264167 ],
    [ u"ru",u"Sakharovo",3790,56.899493,36.050153 ],
    [ u"ru",u"Sakmara",4594,51.984377,55.333799 ],
    [ u"ru",u"Salair",9096,54.2312,85.7972 ],
    [ u"ru",u"Salavat",159896,53.38365,55.907729 ],
    [ u"ru",u"Salekhard",38026,66.53,66.601944 ],
    [ u"ru",u"Salsk",61703,46.4455,41.6149 ],
    [ u"ru",u"Saltykovka",4573,55.766794,37.935327 ],
    [ u"ru",u"Salym",5605,60.0625,71.478889 ],
    [ u"ru",u"Samagaltay",3477,50.6022,95.0047 ],
    [ u"ru",u"Samara",1134742,53.1835,50.1182 ],
    [ u"ru",u"Samarskoye",10638,46.937,39.6881 ],
    [ u"ru",u"Samashki",10848,43.290556,45.301389 ],
    [ u"ru",u"Sambek",5278,47.743056,39.830833 ],
    [ u"ru",u"Samoded",1928,63.6083,40.5111 ],
    [ u"ru",u"Samoylovka",8584,51.184,43.7081 ],
    [ u"ru",u"Samur",3730,41.825267,48.485966 ],
    [ u"ru",u"Samus",5706,56.7475,84.699167 ],
    [ u"ru",u"Sanchursk",5544,56.941254,47.249874 ],
    [ u"ru",u"Sandata",4047,46.270809,41.758335 ],
    [ u"ru",u"Sandovo",3807,58.460224,36.412774 ],
    [ u"ru",u"Sangar",4633,63.924167,127.473889 ],
    [ u"ru",u"Sapernoye",3280,60.71673,29.950458 ],
    [ u"ru",u"Sapërnyy",1371,59.776111,30.661389 ],
    [ u"ru",u"Sapozhok",4283,53.941944,40.680556 ],
    [ u"ru",u"Sarai",6439,53.745766,41.021257 ],
    [ u"ru",u"Sarana",2640,56.47728,57.725865 ],
    [ u"ru",u"Saransk",303397,54.1838,45.1749 ],
    [ u"ru",u"Sarany",1224,58.533333,58.766667 ],
    [ u"ru",u"Sarapulka",878,56.8678,61.0552 ],
    [ u"ru",u"Sarapul",101346,56.470977,53.803603 ],
    [ u"ru",u"Saratov",863734,51.540556,46.008611 ],
    [ u"ru",u"Saratovskaya",6117,44.707521,39.221556 ],
    [ u"ru",u"Sargatskoye",8285,55.610065,73.497164 ],
    [ u"ru",u"Sarmakovo",9588,43.745556,43.200278 ],
    [ u"ru",u"Sarmanovo",6339,55.255285,52.589067 ],
    [ u"ru",u"Sars",5404,56.474884,57.117333 ],
    [ u"ru",u"Saryg-Sep",4582,51.5,95.6 ],
    [ u"ru",u"Sarylakh",189,64.416667,142.75 ],
    [ u"ru",u"Sary-Tyuz",3188,43.901811,41.895231 ],
    [ u"ru",u"Saskylakh",1920,71.916667,114.083333 ],
    [ u"ru",u"Sasovo",29859,54.353688,41.919859 ],
    [ u"ru",u"Sasykoli",4965,47.55153,46.996791 ],
    [ u"ru",u"Satinka",3599,52.379229,41.681918 ],
    [ u"ru",u"Satis",1867,55.022635,43.81543 ],
    [ u"ru",u"Satka",49384,55.0425,59.04 ],
    [ u"ru",u"Savasleyka",3261,55.4606,42.3207 ],
    [ u"ru",u"Savinka",3449,50.078484,47.099355 ],
    [ u"ru",u"Savino",6133,56.592849,41.21814 ],
    [ u"ru",u"Savinskiy",7587,62.93167,40.140661 ],
    [ u"ru",u"Sayanogorsk",49940,53.0875,91.399722 ],
    [ u"ru",u"Sayanskiy",3962,54.15,91.885 ],
    [ u"ru",u"Sayansk",45476,54.1088,102.1648 ],
    [ u"ru",u"Sazonovo",3509,59.0919,35.2268 ],
    [ u"ru",u"Schlüsselburg",12393,59.947299,31.038449 ],
    [ u"ru",u"Sebezh",6688,56.295463,28.46538 ],
    [ u"ru",u"Sebrovo",4496,50.0981,43.2976 ],
    [ u"ru",u"Sechenovo",5151,55.224444,45.890556 ],
    [ u"ru",u"Sedelnikovo",4994,56.946383,75.306594 ],
    [ u"ru",u"Sedkyrkeshch",1973,61.75,50.916667 ],
    [ u"ru",u"Segezha",33354,63.45,34.15 ],
    [ u"ru",u"Selenduma",2562,50.913056,106.240556 ],
    [ u"ru",u"Selenginsk",16028,52.006389,106.864722 ],
    [ u"ru",u"Selikhino",4722,50.367156,137.499575 ],
    [ u"ru",u"Selishche",1328,56.887937,33.26914 ],
    [ u"ru",u"Selizharovo",7096,56.851884,33.448694 ],
    [ u"ru",u"Seltso",18759,53.368308,34.103278 ],
    [ u"ru",u"Selty",5523,57.313201,52.134504 ],
    [ u"ru",u"Selyatino",12954,55.515141,36.977461 ],
    [ u"ru",u"Semibratovo",7511,57.304611,39.536875 ],
    [ u"ru",u"Semikarakorsk",23583,47.519429,40.811202 ],
    [ u"ru",u"Semiletka",4163,55.360278,54.615278 ],
    [ u"ru",u"Semiluki",26257,51.52115,39.155236 ],
    [ u"ru",u"Semkhoz",2838,56.283333,38.066667 ],
    [ u"ru",u"Sengiley",8018,53.962222,48.794444 ],
    [ u"ru",u"Sennoy",6979,52.150899,46.963092 ],
    [ u"ru",u"Sentyabrskiy",3071,45.266667,148.5 ],
    [ u"ru",u"Serafimovich",9847,49.5786,42.736 ],
    [ u"ru",u"Serafimovskiy",10360,54.424079,53.796396 ],
    [ u"ru",u"Serdobsk",36652,52.458607,44.216892 ],
    [ u"ru",u"Serebryanyy Bor",4302,56.8,124.8 ],
    [ u"ru",u"Seredeyskiy",1927,54.050713,35.231833 ],
    [ u"ru",u"Seredka",3724,58.15838,28.185757 ],
    [ u"ru",u"Sergach",22361,55.530786,45.466114 ],
    [ u"ru",u"Sergeyevka",3760,44.335,131.656111 ],
    [ u"ru",u"Sergiyev Posad",112921,56.3,38.133333 ],
    [ u"ru",u"Sergiyevsk",8218,53.945229,51.171415 ],
    [ u"ru",u"Sergokala",8165,42.454683,47.661195 ],
    [ u"ru",u"Sernovodskoye",9882,43.311723,45.159388 ],
    [ u"ru",u"Sernovodsk",3570,53.92293,51.257043 ],
    [ u"ru",u"Sernur",8921,56.933333,49.153611 ],
    [ u"ru",u"Serov",98440,59.483333,60.516667 ],
    [ u"ru",u"Serpukhov",128160,54.915785,37.411139 ],
    [ u"ru",u"Sertolovo",43626,60.144399,30.201649 ],
    [ u"ru",u"Seryshevo",11718,51.093333,128.378611 ],
    [ u"ru",u"Serzhen-Yurt",4773,43.122652,45.985826 ],
    [ u"ru",u"Seshcha",5038,53.718,33.3933 ],
    [ u"ru",u"Sestroretsk",41281,60.098015,29.963781 ],
    [ u"ru",u"Severka",3325,56.8688,60.3015 ],
    [ u"ru",u"Severnoye",5373,56.349121,78.361888 ],
    [ u"ru",u"Severnoye",4695,54.093467,52.54393 ],
    [ u"ru",u"Severnoye",3607,44.831944,42.858333 ],
    [ u"ru",u"Severnyy-Kospashskiy",2212,59.092543,57.800801 ],
    [ u"ru",u"Severnyy",7752,50.67704,36.553243 ],
    [ u"ru",u"Severnyy",11434,67.633333,64.1 ],
    [ u"ru",u"Severnyy",3796,56.733333,37.65 ],
    [ u"ru",u"Severnyy",74,66.333333,138.033333 ],
    [ u"ru",u"Severnyy",235,60.980278,60.392778 ],
    [ u"ru",u"Severobaykalsk",25587,55.65,109.316667 ],
    [ u"ru",u"Severodvinsk",194295,64.5635,39.8302 ],
    [ u"ru",u"Severo-Kurilsk",2286,50.678889,156.125 ],
    [ u"ru",u"Severomorsk",53921,69.068886,33.416218 ],
    [ u"ru",u"Severomuysk",3962,56.148056,113.426667 ],
    [ u"ru",u"Severouralsk",34317,60.153275,59.952054 ],
    [ u"ru",u"Severo-Yeniseyskiy",6564,60.3725,93.040833 ],
    [ u"ru",u"Severo-Zadonsk",16570,54.034809,38.401721 ],
    [ u"ru",u"Severskaya",22849,44.854072,38.676865 ],
    [ u"ru",u"Seversk",109846,56.600556,84.886389 ],
    [ u"ru",u"Sevsk",7594,52.1491,34.4926 ],
    [ u"ru",u"Seymchan",3455,62.883333,152.433333 ],
    [ u"ru",u"Shaami-Yurt",3209,43.226323,45.392033 ],
    [ u"ru",u"Shablykino",3848,52.856607,35.19637 ],
    [ u"ru",u"Shabrovskiy",3868,56.635966,60.580648 ],
    [ u"ru",u"Shadrinsk",79480,56.0852,63.6335 ],
    [ u"ru",u"Shafranovo",2611,53.966667,54.766667 ],
    [ u"ru",u"Shagonar",11415,51.533333,92.8 ],
    [ u"ru",u"Shakhovskaya",10353,56.031468,35.506965 ],
    [ u"ru",u"Shakhta",2767,59.092662,57.652985 ],
    [ u"ru",u"Shakhty",221315,47.709106,40.214434 ],
    [ u"ru",u"Shakhunya",21529,57.6599,46.5668 ],
    [ u"ru",u"Shalakusha",2684,62.224722,40.253889 ],
    [ u"ru",u"Shalazhi",5319,43.094757,45.358977 ],
    [ u"ru",u"Shalinskoye",4198,55.7194,93.7589 ],
    [ u"ru",u"Shalushka",11577,43.5325,43.566111 ],
    [ u"ru",u"Shalya",6689,57.2471,58.7298 ],
    [ u"ru",u"Shamary",3605,57.343398,58.219875 ],
    [ u"ru",u"Shamilkala",7563,42.685806,46.863929 ],
    [ u"ru",u"Shamkhal",8375,43.05958,47.33732 ],
    [ u"ru",u"Shamkhal-Termen",5774,43.03389,47.310526 ],
    [ u"ru",u"Sharanga",6273,57.177488,46.53956 ],
    [ u"ru",u"Sharan",5555,54.816667,54 ],
    [ u"ru",u"Sharkan",6523,57.298853,53.871224 ],
    [ u"ru",u"Sharlyk",8072,52.916667,54.75 ],
    [ u"ru",u"Sharoy",203,42.630085,45.806343 ],
    [ u"ru",u"Sharya",24395,58.369093,45.515582 ],
    [ u"ru",u"Shatalovo",4142,54.334,32.4465 ],
    [ u"ru",u"Shatki",9712,55.188745,44.124859 ],
    [ u"ru",u"Shatoy",1775,42.871431,45.688646 ],
    [ u"ru",u"Shatrovo",6295,56.516667,64.633333 ],
    [ u"ru",u"Shatsk",7434,54.025764,41.711907 ],
    [ u"ru",u"Shatura",30069,55.572529,39.536818 ],
    [ u"ru",u"Shaturtorf",3312,55.567108,39.421288 ],
    [ u"ru",u"Shaygino",1095,57.76751,46.861811 ],
    [ u"ru",u"Shcheglovo",3095,60.001399,30.783441 ],
    [ u"ru",u"Shchelkun",3044,56.303375,60.948313 ],
    [ u"ru",u"Shchelyayur",3376,65.326183,53.425646 ],
    [ u"ru",u"Shcherbinka",28066,55.435556,37.647778 ],
    [ u"ru",u"Shchigry",19198,51.875547,36.90432 ],
    [ u"ru",u"Shchuchye",10480,55.2075,62.748056 ],
    [ u"ru",u"Shebalino",4939,51.291667,85.677222 ],
    [ u"ru",u"Shebekino",45194,50.409671,36.913602 ],
    [ u"ru",u"Shebunino",1177,46.433889,141.860278 ],
    [ u"ru",u"Shedok",3142,44.2179,40.8487 ],
    [ u"ru",u"Sheksna",21197,59.209977,38.510664 ],
    [ u"ru",u"Shelabolikha",4298,53.4131,82.6167 ],
    [ u"ru",u"Shelekhov",47459,52.213889,104.1 ],
    [ u"ru",u"Shelkovskaya",9602,43.508038,46.340162 ],
    [ u"ru",u"Shelopugino",3416,51.6514,117.5599 ],
    [ u"ru",u"Sheltozero",1012,61.366667,35.366667 ],
    [ u"ru",u"Shemordan",5887,56.1856,50.3972 ],
    [ u"ru",u"Shemursha",3690,54.886629,47.518927 ],
    [ u"ru",u"Shemysheyka",6619,52.891961,45.392824 ],
    [ u"ru",u"Shenkursk",5893,62.109101,42.895947 ],
    [ u"ru",u"Shentala",6595,54.45,51.483333 ],
    [ u"ru",u"Shepsi",3151,44.0355,39.1474 ],
    [ u"ru",u"Sherbakul",7251,54.631585,72.396352 ],
    [ u"ru",u"Sheregesh",10114,52.9209,87.9869 ],
    [ u"ru",u"Sheremetyevskiy",6411,55.975833,37.494167 ],
    [ u"ru",u"Sherlovaya Gora",13989,50.566667,116.25 ],
    [ u"ru",u"Shestakovo",1084,56.483333,104.066667 ],
    [ u"ru",u"Shigony",5268,53.3318,48.6423 ],
    [ u"ru",u"Shikhany",6688,52.10379,47.153107 ],
    [ u"ru",u"Shikhazany",3060,55.5389,47.2923 ],
    [ u"ru",u"Shilka",14133,51.85,116.033333 ],
    [ u"ru",u"Shilovo",16159,54.3204,40.874 ],
    [ u"ru",u"Shilovo",6728,51.545833,39.089167 ],
    [ u"ru",u"Shimanovsk",21467,52,127.7 ],
    [ u"ru",u"Shimorskoye",3727,55.3281,42.0256 ],
    [ u"ru",u"Shimsk",3755,58.212006,30.712692 ],
    [ u"ru",u"Shipitsyno",3780,61.280556,46.520833 ],
    [ u"ru",u"Shipunovo",11431,52.1582,82.2173 ],
    [ u"ru",u"Shira",9358,54.491111,89.953056 ],
    [ u"ru",u"Shiringushi",2369,53.848505,42.767594 ],
    [ u"ru",u"Shirochanka",5853,46.649681,38.397825 ],
    [ u"ru",u"Shirokaya Rechka",1131,56.6694,60.4726 ],
    [ u"ru",u"Shirokiy",1519,49.758,129.523 ],
    [ u"ru",u"Shirokiy",543,63.116667,147.95 ],
    [ u"ru",u"Shirokovskiy",1823,58.842441,57.783226 ],
    [ u"ru",u"Shitkino",2363,56.3703,98.3543 ],
    [ u"ru",u"Shkotovo-22",8394,42.880278,132.3375 ],
    [ u"ru",u"Shkotovo-26",1106,42.861944,132.417222 ],
    [ u"ru",u"Shkotovo",5221,43.331944,132.3625 ],
    [ u"ru",u"Shkurinskaya",5005,46.5858,39.3599 ],
    [ u"ru",u"Sholokhovskiy",10062,48.280713,41.04592 ],
    [ u"ru",u"Shonguy",1122,68.752609,33.145954 ],
    [ u"ru",u"Shudayag",3446,63.526652,53.605822 ],
    [ u"ru",u"Shugurovo",2243,54.508283,52.132654 ],
    [ u"ru",u"Shumerlya",35221,55.500495,46.41288 ],
    [ u"ru",u"Shumikha",18500,55.226111,63.296111 ],
    [ u"ru",u"Shumikhinskiy",2192,58.744835,57.690496 ],
    [ u"ru",u"Shumskiy",3095,54.8318,99.1328 ],
    [ u"ru",u"Shumyachi",4607,53.858333,32.424167 ],
    [ u"ru",u"Shushary",15503,59.809167,30.381667 ],
    [ u"ru",u"Shushenskoye",18770,53.325,91.935556 ],
    [ u"ru",u"Shuya",60705,56.848649,41.38833 ],
    [ u"ru",u"Shuya",3261,61.916667,34.25 ],
    [ u"ru",u"Shuyskoye",2389,59.373557,41.030474 ],
    [ u"ru",u"Shvartsevskiy",5083,54.091737,37.990534 ],
    [ u"ru",u"Sibay",61591,52.718056,58.665833 ],
    [ u"ru",u"Sibirskiy",11952,53.5777,83.7577 ],
    [ u"ru",u"Sibirtsevo",9226,44.203611,132.448056 ],
    [ u"ru",u"Sigayevo",5780,56.421626,53.775657 ],
    [ u"ru",u"Silikatnyy",3614,53.989572,48.327495 ],
    [ u"ru",u"Sim",15632,54.993,57.6982 ],
    [ u"ru",u"Sindor",2880,62.86286,51.890512 ],
    [ u"ru",u"Sinegorskiy",6660,48.01389,40.84468 ],
    [ u"ru",u"Sinegorskiy",880,57.8941,59.5179 ],
    [ u"ru",u"Sinegorsk",2444,47.166667,142.5 ],
    [ u"ru",u"Sinegorye",3776,62.35,150.766667 ],
    [ u"ru",u"Sinyavino",3593,59.907813,31.071101 ],
    [ u"ru",u"Sinyavskoye",3715,47.277032,39.27888 ],
    [ u"ru",u"Sirtich",4185,41.833883,48.229007 ],
    [ u"ru",u"Sitniki",1321,56.455286,44.066577 ],
    [ u"ru",u"Siukh",3425,42.5999,46.544624 ],
    [ u"ru",u"Sivaki",2479,52.633333,126.75 ],
    [ u"ru",u"Siva",4744,58.382041,54.38037 ],
    [ u"ru",u"Siverskiy",12076,59.354444,30.078333 ],
    [ u"ru",u"Skalistyy",14225,69.255064,33.336161 ],
    [ u"ru",u"Skalnyy",2069,58.3605,57.9658 ],
    [ u"ru",u"Skhodnya",18898,55.948056,37.297778 ],
    [ u"ru",u"Skopin",24357,53.824856,39.550528 ],
    [ u"ru",u"Skorodnoye",3677,51.07101,37.227562 ],
    [ u"ru",u"Skoropuskovskiy",5434,56.366667,38.166667 ],
    [ u"ru",u"Skovorodino",10007,53.983333,123.916667 ],
    [ u"ru",u"Skuratovskiy",13325,54.101522,37.603843 ],
    [ u"ru",u"Sladkovo",3455,55.528348,70.338545 ],
    [ u"ru",u"Slantsy",36209,59.118169,28.091374 ],
    [ u"ru",u"Slavgorodskoye",3683,53.0214,78.6435 ],
    [ u"ru",u"Slavgorod",34141,52.9978,78.6449 ],
    [ u"ru",u"Slavsk",5248,55.042504,21.677044 ],
    [ u"ru",u"Slavyanka",14687,42.863333,131.384722 ],
    [ u"ru",u"Slavyansk-na-Kubani",65197,45.2558,38.1256 ],
    [ u"ru",u"Sloboda",3519,51.1421,40.3021 ],
    [ u"ru",u"Slobodskoy",32362,58.694722,50.231389 ],
    [ u"ru",u"Slyudyanka",18810,51.659444,103.706111 ],
    [ u"ru",u"Smidovich",5720,48.6,133.816667 ],
    [ u"ru",u"Smirnykh",7116,49.75,142.833333 ],
    [ u"ru",u"Smolenka",2933,52.135234,113.497398 ],
    [ u"ru",u"Smolenskaya",8130,44.788668,38.801814 ],
    [ u"ru",u"Smolenskoye",9431,52.304444,85.078056 ],
    [ u"ru",u"Smolensk",320994,54.7818,32.0401 ],
    [ u"ru",u"Smolino",2862,56.275256,43.091092 ],
    [ u"ru",u"Smolyaninovo",6294,43.295556,132.4675 ],
    [ u"ru",u"Smyshlyayevka",5908,53.239127,50.390723 ],
    [ u"ru",u"Snegiri",3465,55.888675,37.024213 ],
    [ u"ru",u"Snezhnogorsk",1286,68.093056,87.74 ],
    [ u"ru",u"Snezhnogorsk",12014,69.193333,33.253136 ],
    [ u"ru",u"Sobinka",20459,55.985531,40.011114 ],
    [ u"ru",u"Sobolevo",1787,54.298333,155.961111 ],
    [ u"ru",u"Sochi",327613,43.599167,39.725689 ],
    [ u"ru",u"Sofiysk",650,52.254444,133.986667 ],
    [ u"ru",u"Sofrino",15353,56.15,37.933333 ],
    [ u"ru",u"Sogdiondon",566,57.693889,112.16 ],
    [ u"ru",u"Sokolniki",10843,54.0246,38.4574 ],
    [ u"ru",u"Sokolovo-Kundryuchenskiy",9585,47.835362,39.947111 ],
    [ u"ru",u"Sokolovo",3281,52.5318,84.7896 ],
    [ u"ru",u"Sokolovskoye",3138,45.258333,40.679722 ],
    [ u"ru",u"Sokolovyy",6183,51.568568,45.833116 ],
    [ u"ru",u"Sokolskoye",6570,57.141219,43.158945 ],
    [ u"ru",u"Sokol",5928,51.800361,107.444373 ],
    [ u"ru",u"Sokol",4374,59.883333,150.916667 ],
    [ u"ru",u"Sokol",3228,47.233333,142.75 ],
    [ u"ru",u"Sokol",42174,59.461667,40.120556 ],
    [ u"ru",u"Sokur",5753,55.2092,83.2223 ],
    [ u"ru",u"Soldato-Aleksandrovskoye",11059,44.265278,43.756111 ],
    [ u"ru",u"Soldatskaya",4651,43.818056,43.815833 ],
    [ u"ru",u"Solginskiy",1802,61.05,41.342778 ],
    [ u"ru",u"Soligalich",6886,59.0796,42.285264 ],
    [ u"ru",u"Solikamsk",100814,59.619557,56.772889 ],
    [ u"ru",u"Sol-Iletsk",27420,51.163103,54.991756 ],
    [ u"ru",u"Solnechnogorsk",58892,56.183333,36.983333 ],
    [ u"ru",u"Solnechnoye",4024,43.276004,46.506968 ],
    [ u"ru",u"Solnechnoye",1136,60.149061,29.94279 ],
    [ u"ru",u"Solnechnyy",13993,50.583333,137.033333 ],
    [ u"ru",u"Solnechnyy",1230,60.416667,137.5 ],
    [ u"ru",u"Solnechnyy",2041,57.988056,33.873333 ],
    [ u"ru",u"Solntsevo",4374,51.398333,36.6625 ],
    [ u"ru",u"Solomenskoye",3096,44.216667,44.352778 ],
    [ u"ru",u"Soloneshnoye",4716,51.6544,84.3197 ],
    [ u"ru",u"Solotcha",2481,54.789701,39.833362 ],
    [ u"ru",u"Solovetskiy",919,65.027045,35.706812 ],
    [ u"ru",u"Solton",3122,52.8429,86.4787 ],
    [ u"ru",u"Soltsy",11093,58.123874,30.323771 ],
    [ u"ru",u"Soluno-Dmitriyevskoye",3270,44.4074,42.724 ],
    [ u"ru",u"Solvychegodsk",2647,61.330462,46.915589 ],
    [ u"ru",u"Solyanka",3173,46.388901,48.017547 ],
    [ u"ru",u"Somovo",13729,51.740984,39.366546 ],
    [ u"ru",u"Sonkovo",4431,57.778163,37.157074 ],
    [ u"ru",u"Sorochinsk",30731,52.4338,53.1583 ],
    [ u"ru",u"Sorokino",6203,53.75,84.916667 ],
    [ u"ru",u"Sorsk",13035,54.003333,90.246667 ],
    [ u"ru",u"Sortavala",20760,61.705323,30.691781 ],
    [ u"ru",u"Sosenskiy",12484,54.058991,35.962282 ],
    [ u"ru",u"Soskovo",2094,52.747523,35.382772 ],
    [ u"ru",u"Sosnogorsk",29343,63.602288,53.881751 ],
    [ u"ru",u"Sosnovka",3024,56.189328,47.219877 ],
    [ u"ru",u"Sosnovka",12355,56.254965,51.284191 ],
    [ u"ru",u"Sosnovka",3616,54.479403,43.286498 ],
    [ u"ru",u"Sosnovka",10475,53.235925,41.368593 ],
    [ u"ru",u"Sosnovoborsk",31633,56.1217,93.3385 ],
    [ u"ru",u"Sosnovoborsk",7299,53.290659,46.248489 ],
    [ u"ru",u"Sosnovo-Ozerskoye",5840,52.5249,111.5418 ],
    [ u"ru",u"Sosnovo",5923,60.551452,30.214411 ],
    [ u"ru",u"Sosnovskiy",3339,54.601011,73.165209 ],
    [ u"ru",u"Sosnovskoye",9052,55.805492,43.167909 ],
    [ u"ru",u"Sosva",10171,59.176621,61.855792 ],
    [ u"ru",u"Sotnikovo",4396,51.884462,107.479068 ],
    [ u"ru",u"Sotnikovskoye",5116,45.003889,43.777222 ],
    [ u"ru",u"Sovetskaya Gavan",29740,48.972303,140.28784 ],
    [ u"ru",u"Sovetskaya",10166,44.776944,41.172222 ],
    [ u"ru",u"Sovetskaya",2293,49.00912,42.121782 ],
    [ u"ru",u"Sovetskaya",7886,44.026667,44.05 ],
    [ u"ru",u"Sovetskiy",23685,61.361389,63.584167 ],
    [ u"ru",u"Sovetskiy",2415,67.483333,64.416667 ],
    [ u"ru",u"Sovetskiy",6574,60.539454,28.677558 ],
    [ u"ru",u"Sovetskiy",10674,56.758333,48.476111 ],
    [ u"ru",u"Sovetskoye",5441,52.286111,85.413056 ],
    [ u"ru",u"Sovetskoye",4203,42.444233,46.551722 ],
    [ u"ru",u"Sovetskoye",3490,51.442549,46.742399 ],
    [ u"ru",u"Sovetsk",43310,55.08392,21.878514 ],
    [ u"ru",u"Sovetsk",17869,57.5182,49.1222 ],
    [ u"ru",u"Sovetsk",8485,53.936015,37.62774 ],
    [ u"ru",u"Sovkhoznyy",3916,45.294623,38.113843 ],
    [ u"ru",u"Sovkhoznyy",3546,56.5599,61.426 ],
    [ u"ru",u"Sozimskiy",1968,59.741782,52.248214 ],
    [ u"ru",u"Spas-Demensk",5114,54.412222,34.022568 ],
    [ u"ru",u"Spas-Klepiki",5942,55.134717,40.176729 ],
    [ u"ru",u"Spassk-Dalniy",50186,44.597778,132.821111 ],
    [ u"ru",u"Spasskoye",4023,55.860477,45.696946 ],
    [ u"ru",u"Spasskoye",6038,44.610833,132.796944 ],
    [ u"ru",u"Spassk-Ryazanskiy",8655,54.404,40.3762 ],
    [ u"ru",u"Spassk",1556,52.747,87.7545 ],
    [ u"ru",u"Spiridonovka",4387,53.092483,50.646208 ],
    [ u"ru",u"Spirovo",6640,57.419051,34.976581 ],
    [ u"ru",u"Spitsevka",3374,45.123056,42.5125 ],
    [ u"ru",u"Spokoynaya",5291,44.2468,41.4015 ],
    [ u"ru",u"Spornoye",854,62.333333,151.05 ],
    [ u"ru",u"Srednebelaya",6148,50.659444,128.010556 ],
    [ u"ru",u"Srednekolymsk",3459,67.45,153.683333 ],
    [ u"ru",u"Sredneuralsk",19616,56.989211,60.466622 ],
    [ u"ru",u"Sredniye Achaluki",5643,43.370527,44.732658 ],
    [ u"ru",u"Sredniy Ikorets",3273,51.067492,39.758385 ],
    [ u"ru",u"Srednyaya Akhtuba",13887,48.709984,44.867238 ],
    [ u"ru",u"Srednyaya Yelyuzan",8279,53.0241,45.9529 ],
    [ u"ru",u"Sretensk",7698,52.2453,117.7093 ],
    [ u"ru",u"Srostki",3049,52.418889,85.702222 ],
    [ u"ru",u"Stalskoye",6535,43.187036,46.971335 ],
    [ u"ru",u"Stanovoye",5211,52.734686,38.326406 ],
    [ u"ru",u"Stantsionno-Oyashinskiy",4689,55.4664,83.8245 ],
    [ u"ru",u"Staraya Kulatka",6022,52.727783,47.617878 ],
    [ u"ru",u"Staraya Kupavna",21256,55.807994,38.180499 ],
    [ u"ru",u"Staraya Mayna",6927,54.604167,48.930556 ],
    [ u"ru",u"Staraya Poltavka",4068,50.477148,46.481443 ],
    [ u"ru",u"Staraya Russa",34303,57.994387,31.360811 ],
    [ u"ru",u"Staraya Stanitsa",7145,45.0098,41.1512 ],
    [ u"ru",u"Staraya Stanitsa",8284,48.336326,40.295881 ],
    [ u"ru",u"Staraya",4444,59.927488,30.627645 ],
    [ u"ru",u"Staraya Sunzha",7860,43.335421,45.743767 ],
    [ u"ru",u"Staraya Toropa",2232,56.280123,31.670178 ],
    [ u"ru",u"Staraya Vichuga",5599,57.268334,41.87873 ],
    [ u"ru",u"Starbeyevo",370,55.920017,37.477043 ],
    [ u"ru",u"Staritsa",9135,56.507516,34.935441 ],
    [ u"ru",u"Staroaleyskoye",5037,51.006111,82 ],
    [ u"ru",u"Starobachaty",4608,54.2425,86.2072 ],
    [ u"ru",u"Starobaltachevo",5612,56.001317,55.921311 ],
    [ u"ru",u"Staroderevyankovskaya",12918,46.1276,38.9674 ],
    [ u"ru",u"Starodubskoye",4104,44.563056,44.015278 ],
    [ u"ru",u"Starodub",18539,52.584444,32.763333 ],
    [ u"ru",u"Starodzhereliyevskaya",3106,45.475989,38.296798 ],
    [ u"ru",u"Starokamyshinsk",11158,55.0554,61.6031 ],
    [ u"ru",u"Starokorsunskaya",10915,45.057271,39.316109 ],
    [ u"ru",u"Starokucherganovka",5658,46.324758,47.955504 ],
    [ u"ru",u"Staroleushkovskaya",5733,45.986662,39.759867 ],
    [ u"ru",u"Staromaryevka",5869,45.093889,42.241667 ],
    [ u"ru",u"Starominskaya",30461,46.53,39.049722 ],
    [ u"ru",u"Staromyshastovskaya",10625,45.343286,39.076084 ],
    [ u"ru",u"Staronizhestebliyevskaya",10478,45.383146,38.443037 ],
    [ u"ru",u"Staropavlovskaya",3081,43.848889,43.632778 ],
    [ u"ru",u"Staropesterevo",3554,54.5001,86.4094 ],
    [ u"ru",u"Staropyshminsk",1679,56.938672,60.902947 ],
    [ u"ru",u"Staroshcherbinovskaya",18785,46.6311,38.6742 ],
    [ u"ru",u"Starosubkhangulovo",4351,53.1031,57.4423 ],
    [ u"ru",u"Starotimoshkino",4061,53.719076,47.531156 ],
    [ u"ru",u"Starotitarovskaya",12351,45.219383,37.154755 ],
    [ u"ru",u"Staroutkinsk",3188,57.230166,59.334826 ],
    [ u"ru",u"Starovelichkovskaya",13111,45.428836,38.732614 ],
    [ u"ru",u"Staroye Drozhzhanoye",3338,54.726575,47.567662 ],
    [ u"ru",u"Starozhilovo",5147,54.2254,39.916 ],
    [ u"ru",u"Star",4994,53.623617,34.151832 ],
    [ u"ru",u"Staryy Biser",690,58.413611,58.880278 ],
    [ u"ru",u"Staryy Cherek",6702,43.471389,43.846944 ],
    [ u"ru",u"Staryye Atagi",10183,43.086545,45.720351 ],
    [ u"ru",u"Staryye Atagi",10183,43.120278,45.740556 ],
    [ u"ru",u"Staryy Nadym",2766,65.666667,72.783333 ],
    [ u"ru",u"Staryy Oskol",226980,51.296667,37.841667 ],
    [ u"ru",u"Staryy Urukh",3848,43.340406,44.018683 ],
    [ u"ru",u"Stavropol",363069,45.0428,41.9734 ],
    [ u"ru",u"Stavrovo",7822,56.133107,40.012953 ],
    [ u"ru",u"Stekolnyy",2096,60.05,150.75 ],
    [ u"ru",u"Stepantsevo",2744,56.13143,41.703199 ],
    [ u"ru",u"Stepnoye",14035,51.379722,46.849167 ],
    [ u"ru",u"Stepnoye",6058,44.270833,44.585 ],
    [ u"ru",u"Sterlibashevo",5786,53.437548,55.257802 ],
    [ u"ru",u"Sterlitamak",267235,53.624619,55.950148 ],
    [ u"ru",u"Stodolishche",3198,54.185935,32.649245 ],
    [ u"ru",u"Stolbishche",3648,55.646786,49.215952 ],
    [ u"ru",u"Stolbovaya",5142,55.250215,37.492492 ],
    [ u"ru",u"Storozhevaya",7986,43.87886,41.451434 ],
    [ u"ru",u"Stoyba",895,52.8,131.7 ],
    [ u"ru",u"Streletskoye",5727,50.641016,36.469224 ],
    [ u"ru",u"Strelitsa",4761,51.6083,38.9102 ],
    [ u"ru",u"Strelka",5433,45.20633,37.286496 ],
    [ u"ru",u"Strelka",5677,58.072778,93.034444 ],
    [ u"ru",u"Strelna",12477,59.848333,30.026111 ],
    [ u"ru",u"Strezhevoy",44784,60.7333,77.5889 ],
    [ u"ru",u"Strizhi",3881,58.457577,49.286671 ],
    [ u"ru",u"Stroitel",18636,50.785427,36.483099 ],
    [ u"ru",u"Strunino",15484,56.383333,38.566667 ],
    [ u"ru",u"Stulovo",3488,58.7225,50.143889 ],
    [ u"ru",u"Stupino",61000,54.900833,38.070833 ],
    [ u"ru",u"Subkhankulovo",5674,54.557407,53.811526 ],
    [ u"ru",u"Suda",5582,59.152539,37.558202 ],
    [ u"ru",u"Sudislavl",5236,57.881746,41.708293 ],
    [ u"ru",u"Sudogda",13277,55.953936,40.862914 ],
    [ u"ru",u"Sudzha",6940,51.1976,35.2726 ],
    [ u"ru",u"Sug-Aksy",3051,51.4,91.283333 ],
    [ u"ru",u"Sukhaya Buyvola",3525,45.153333,42.995556 ],
    [ u"ru",u"Sukhinichi",16100,54.099894,35.342544 ],
    [ u"ru",u"Sukhobezvodnoye",6634,57.049127,44.889092 ],
    [ u"ru",u"Sukhobuzimskoye",4550,56.5,93.272778 ],
    [ u"ru",u"Sukhodol",14296,53.900627,51.211703 ],
    [ u"ru",u"Sukhoverkovo",706,56.626481,35.563482 ],
    [ u"ru",u"Sukhoy Log",36329,56.9094,62.0296 ],
    [ u"ru",u"Sukpak",3648,51.666667,94.633333 ],
    [ u"ru",u"Suksun",8284,57.1431,57.3949 ],
    [ u"ru",u"Suleya",2920,55.131667,58.88 ],
    [ u"ru",u"Sumkino",4186,58.110833,68.324444 ],
    [ u"ru",u"Suna",2400,57.833787,50.058839 ],
    [ u"ru",u"Suntar",8639,62.144444,117.631944 ],
    [ u"ru",u"Sunzha",11548,43.058616,44.82281 ],
    [ u"ru",u"Suoyarvi",10834,62.083333,32.35 ],
    [ u"ru",u"Suponevo",7845,53.204923,34.295966 ],
    [ u"ru",u"Sura",2275,53.887857,45.741917 ],
    [ u"ru",u"Surazh",11962,53.01747,32.391782 ],
    [ u"ru",u"Surgut",300371,61.25,73.416667 ],
    [ u"ru",u"Surgut",4699,53.924983,51.203476 ],
    [ u"ru",u"Surkhakhi",16215,43.1875,44.901944 ],
    [ u"ru",u"Surok",3126,56.446944,48.121389 ],
    [ u"ru",u"Surovatikha",4644,55.765158,43.898453 ],
    [ u"ru",u"Surovikino",20678,48.607344,42.846213 ],
    [ u"ru",u"Surskoye",7324,54.4821,46.7214 ],
    [ u"ru",u"Sursk",7623,53.075424,45.684613 ],
    [ u"ru",u"Susanino",3961,58.148813,41.594829 ],
    [ u"ru",u"Suslonger",3597,56.315556,48.253056 ],
    [ u"ru",u"Suslovo",2974,56.216667,88.116667 ],
    [ u"ru",u"Susuman",7366,62.783333,148.166667 ],
    [ u"ru",u"Suvorovskaya",17261,44.1901,42.6595 ],
    [ u"ru",u"Suvorov",21059,54.1223,36.496566 ],
    [ u"ru",u"Suzdal",11183,56.422736,40.446684 ],
    [ u"ru",u"Suzun",15365,53.7841,82.3116 ],
    [ u"ru",u"Svecha",4971,58.278494,47.516358 ],
    [ u"ru",u"Sven",3491,53.138105,34.364825 ],
    [ u"ru",u"Sverdlovskiy",5636,55.909684,38.149782 ],
    [ u"ru",u"Svetlaya",1109,46.538889,138.329722 ],
    [ u"ru",u"Svetlogorsk",1398,66.916667,88.35 ],
    [ u"ru",u"Svetlograd",39727,45.335278,42.854722 ],
    [ u"ru",u"Svetlopolyansk",3176,59.418358,52.360446 ],
    [ u"ru",u"Svetlyy",22119,54.67501,20.134733 ],
    [ u"ru",u"Svetlyy",8976,50.818333,60.851944 ],
    [ u"ru",u"Svetlyy",12222,51.670556,45.626667 ],
    [ u"ru",u"Svetlyy",7536,56.916667,85.966667 ],
    [ u"ru",u"Svetlyy Yar",13131,48.474801,44.780956 ],
    [ u"ru",u"Svetogorsk",15734,61.112134,28.863211 ],
    [ u"ru",u"Svirsk",14717,52.983333,103.397778 ],
    [ u"ru",u"Svirstroy",1039,60.801007,33.72378 ],
    [ u"ru",u"Svobodnyy",61018,51.381667,128.122222 ],
    [ u"ru",u"Svobodnyy",2275,52.330388,46.371221 ],
    [ u"ru",u"Svobody",17661,44.025556,43.050278 ],
    [ u"ru",u"Syamzha",3856,60.015772,41.061387 ],
    [ u"ru",u"Syasstroy",13170,60.136688,32.569061 ],
    [ u"ru",u"Syava",5339,58.014573,46.32216 ],
    [ u"ru",u"Sychëvka",8510,55.82515,34.273615 ],
    [ u"ru",u"Syktyvkar",230142,61.676422,50.809941 ],
    [ u"ru",u"Sylva",7655,58.034753,56.763464 ],
    [ u"ru",u"Syntul",1842,55.003266,41.297105 ],
    [ u"ru",u"Synya",1011,65.371849,58.038736 ],
    [ u"ru",u"Syrskoye",3454,52.574365,39.4966 ],
    [ u"ru",u"Sysert",21942,56.4412,60.3156 ],
    [ u"ru",u"Syumsi",5582,57.11108,51.614938 ],
    [ u"ru",u"Syzran",189341,53.1585,48.4681 ],
    [ u"ru",u"Tabory",2062,58.519819,64.549474 ],
    [ u"ru",u"Tabuny",3950,52.7773,78.7896 ],
    [ u"ru",u"Taganrog",279060,47.23617,38.896878 ],
    [ u"ru",u"Takhtamukay",5120,44.9215,38.995826 ],
    [ u"ru",u"Takhtamygda",1125,54.1,123.566667 ],
    [ u"ru",u"Taksimo",10359,56.344444,114.879444 ],
    [ u"ru",u"Talakan",6294,50.316667,130.366667 ],
    [ u"ru",u"Talaya",1054,61.116667,152.383333 ],
    [ u"ru",u"Taldan",3436,53.666667,124.8 ],
    [ u"ru",u"Taldom",13112,56.733333,37.533333 ],
    [ u"ru",u"Talitsa",18603,57.010946,63.732542 ],
    [ u"ru",u"Talitsy",6003,56.52801,42.332297 ],
    [ u"ru",u"Talmenka",19904,53.8183,83.5677 ],
    [ u"ru",u"Talnakh",59052,69.4865,88.3972 ],
    [ u"ru",u"Talovaya",13367,51.114444,40.73 ],
    [ u"ru",u"Talovyy",5909,47.807646,40.109431 ],
    [ u"ru",u"Tamala",7956,52.540973,43.25145 ],
    [ u"ru",u"Taman",9417,45.211696,36.716092 ],
    [ u"ru",u"Tambovka",7834,50.096944,128.048889 ],
    [ u"ru",u"Tambovka",3528,47.315283,47.37773 ],
    [ u"ru",u"Tambov",290936,52.731689,41.443262 ],
    [ u"ru",u"Tankhoy",1028,51.552778,105.130556 ],
    [ u"ru",u"Tarasovskiy",8949,48.727273,40.362669 ],
    [ u"ru",u"Tara",26986,56.894356,74.37096 ],
    [ u"ru",u"Tarbagatay",4175,51.48032,107.360199 ],
    [ u"ru",u"Tarbagatay",2412,51.1747,109.0931 ],
    [ u"ru",u"Taremskoye",3059,55.928894,43.044334 ],
    [ u"ru",u"Tarki",10554,42.944227,47.495271 ],
    [ u"ru",u"Tarko-Sale",18568,64.9225,77.785 ],
    [ u"ru",u"Tarnogskiy Gorodok",5432,60.499722,43.576111 ],
    [ u"ru",u"Tarskoye",4449,42.966986,44.771145 ],
    [ u"ru",u"Tarumovka",5245,44.076063,46.536134 ],
    [ u"ru",u"Tarusa",10181,54.724357,37.172719 ],
    [ u"ru",u"Taseyevo",8479,57.2112,94.8921 ],
    [ u"ru",u"Tashara",3364,55.5195,83.5094 ],
    [ u"ru",u"Tashla",6651,51.771569,52.742701 ],
    [ u"ru",u"Tashtagol",22779,52.7657,87.8894 ],
    [ u"ru",u"Tashtyp",6379,52.793889,89.898333 ],
    [ u"ru",u"Tatarka",6062,44.958895,41.951712 ],
    [ u"ru",u"Tatarskaya Kargala",3478,51.949524,55.173141 ],
    [ u"ru",u"Tatarskaya Pishlya",3150,54.060854,44.899781 ],
    [ u"ru",u"Tatarsk",25151,55.219035,75.982835 ],
    [ u"ru",u"Tatishchevo",7377,51.670278,45.595278 ],
    [ u"ru",u"Tatsinskaya",11258,48.19677,41.275583 ],
    [ u"ru",u"Tavatuy",559,57.070278,60.133611 ],
    [ u"ru",u"Tavda",39480,58.042537,65.272583 ],
    [ u"ru",u"Tavrichanka",8352,43.337778,131.863889 ],
    [ u"ru",u"Tavricheskoye",13063,54.58508,73.639498 ],
    [ u"ru",u"Tayga",24328,56.06,85.619722 ],
    [ u"ru",u"Tayginka",1413,55.6244,60.5076 ],
    [ u"ru",u"Tayshet",37767,55.9342,98.0044 ],
    [ u"ru",u"Taytsy",2631,59.664444,30.114722 ],
    [ u"ru",u"Tayturka",5100,52.869167,103.460833 ],
    [ u"ru",u"Tayzhina",5063,53.6679,87.4362 ],
    [ u"ru",u"Tazovskiy",5981,67.466667,78.7 ],
    [ u"ru",u"Tbilisskaya",24446,45.363333,40.19 ],
    [ u"ru",u"Teberda",7705,43.445653,41.744804 ],
    [ u"ru",u"Teeli",3732,51.033333,90.233333 ],
    [ u"ru",u"Teguldet",4801,57.306389,88.166667 ],
    [ u"ru",u"Tekstilshchik",7430,55.940833,37.844722 ],
    [ u"ru",u"Telma",4022,52.6704,103.7288 ],
    [ u"ru",u"Telnovskiy",207,49.4,142.1 ],
    [ u"ru",u"Temiraul",3331,43.253217,46.825402 ],
    [ u"ru",u"Temirgoyevskaya",8588,45.114137,40.280269 ],
    [ u"ru",u"Temirtau",4723,53.1377,87.4538 ],
    [ u"ru",u"Temizhbekskaya",6111,45.445556,40.845 ],
    [ u"ru",u"Temizhbekskiy",3811,45.450776,41.038657 ],
    [ u"ru",u"Temnikov",8252,54.630233,43.214833 ],
    [ u"ru",u"Tempy",458,56.633333,37.3 ],
    [ u"ru",u"Temryuk",36547,45.270547,37.387161 ],
    [ u"ru",u"Temyasovo",3524,52.993333,58.101389 ],
    [ u"ru",u"Tengushevo",4010,54.768611,42.718889 ],
    [ u"ru",u"Terbuny",6936,52.11484,38.469789 ],
    [ u"ru",u"Terekli-Mekteb",7799,44.167097,45.869749 ],
    [ u"ru",u"Terek",21180,43.483333,44.136111 ],
    [ u"ru",u"Terenga",5461,53.7168,48.3723 ],
    [ u"ru",u"Tereze",6335,43.936082,42.443401 ],
    [ u"ru",u"Terney",3876,45.050278,136.609167 ],
    [ u"ru",u"Ternovka",4703,51.678031,41.637503 ],
    [ u"ru",u"Ternovskaya",6643,45.8513,40.4125 ],
    [ u"ru",u"Terskaya",3069,43.723763,44.724422 ],
    [ u"ru",u"Tevriz",7270,57.509,72.4042 ],
    [ u"ru",u"Teya",1649,60.377778,92.626667 ],
    [ u"ru",u"Teykovo",36016,56.85796,40.536915 ],
    [ u"ru",u"Tigil",1993,57.8,158.666667 ],
    [ u"ru",u"Tikhmenevo",808,49.2,142.9 ],
    [ u"ru",u"Tikhoretsk",64388,45.854722,40.125278 ],
    [ u"ru",u"Tikhvin",62076,59.645107,33.529372 ],
    [ u"ru",u"Tiksi",5681,71.687222,128.869444 ],
    [ u"ru",u"Tilichiki",1968,60.466667,166.1 ],
    [ u"ru",u"Timiryazevskiy",3153,54.929167,60.7625 ],
    [ u"ru",u"Timiryazevskoye",6229,56.49,84.876944 ],
    [ u"ru",u"Tim",3673,51.622222,37.124444 ],
    [ u"ru",u"Tinskoy",4147,56.1513,96.9173 ],
    [ u"ru",u"Tirlyanskiy",5758,54.2109,58.5806 ],
    [ u"ru",u"Tishchenskoye",3437,45.460556,41.673818 ],
    [ u"ru",u"Tisul",9249,55.761111,88.312222 ],
    [ u"ru",u"Tlyarota",1898,42.104085,46.355901 ],
    [ u"ru",u"Tlyustenkhabl",4964,44.982781,39.096392 ],
    [ u"ru",u"Tobolsk",93651,58.2,68.266667 ],
    [ u"ru",u"Toguchin",21886,55.2075,84.379167 ],
    [ u"ru",u"Togul",4937,53.465,85.9128 ],
    [ u"ru",u"Togur",8442,58.3631,82.8265 ],
    [ u"ru",u"Toksovo",5863,60.153228,30.516463 ],
    [ u"ru",u"Tokur",1126,53.133333,132.9 ],
    [ u"ru",u"Tolbazy",10183,53.992812,55.908614 ],
    [ u"ru",u"Tolmachevo",3361,58.859731,29.910906 ],
    [ u"ru",u"Tolmachëvo",3921,54.9824,82.7363 ],
    [ u"ru",u"Tolstoy-Yurt",7772,43.445482,45.779012 ],
    [ u"ru",u"Tolyatti",718495,53.5303,49.3461 ],
    [ u"ru",u"Tomari",4910,47.765833,142.068333 ],
    [ u"ru",u"Tomarovka",7916,50.683376,36.233087 ],
    [ u"ru",u"Tomilino",28310,55.656195,37.947128 ],
    [ u"ru",u"Tommot",9034,58.956389,126.2925 ],
    [ u"ru",u"Tomsk",485523,56.494167,84.974167 ],
    [ u"ru",u"Tonkino",5406,57.372573,46.462938 ],
    [ u"ru",u"Tonnelnyy",433,56.281389,113.350556 ],
    [ u"ru",u"Tonshayevo",4357,57.735977,47.012646 ],
    [ u"ru",u"Toora-Khem",2214,52.4675,96.11 ],
    [ u"ru",u"Topchikha",9301,52.8192,83.1185 ],
    [ u"ru",u"Topolëvo",4117,48.499444,135.1975 ],
    [ u"ru",u"Torbeyevo",9138,54.079721,43.247318 ],
    [ u"ru",u"Torfyanoy",1775,58.4916,49.197862 ],
    [ u"ru",u"Torgo",94,58.454444,119.529444 ],
    [ u"ru",u"Toropets",14188,56.497793,31.63528 ],
    [ u"ru",u"Torzhok",48547,57.043595,34.962207 ],
    [ u"ru",u"Tosno",40198,59.54,30.8775 ],
    [ u"ru",u"Totma",10502,59.973749,42.764865 ],
    [ u"ru",u"Totskoye",7161,52.524783,52.762275 ],
    [ u"ru",u"Tovarkovo",14294,54.676172,35.938603 ],
    [ u"ru",u"Tovarkovskiy",7959,53.682168,38.209197 ],
    [ u"ru",u"Tpig",2823,41.78007,47.588963 ],
    [ u"ru",u"Tretiy Severnyy",2128,60.208611,59.961111 ],
    [ u"ru",u"Troitskaya",6479,45.134928,38.125441 ],
    [ u"ru",u"Troitskaya",23745,43.306641,44.983949 ],
    [ u"ru",u"Troitskiy",6236,51.3588,37.5253 ],
    [ u"ru",u"Troitskiy",11081,57.060277,63.748113 ],
    [ u"ru",u"Troitsko-Pechorsk",8414,62.708359,56.196426 ],
    [ u"ru",u"Troitskoye",10887,52.9821,84.6757 ],
    [ u"ru",u"Troitskoye",10025,46.4206,44.2591 ],
    [ u"ru",u"Troitskoye",5557,49.4405,136.5481 ],
    [ u"ru",u"Troitskoye",4548,55.3,38.533333 ],
    [ u"ru",u"Troitskoye",3911,55.701279,72.233694 ],
    [ u"ru",u"Troitskoye",3176,46.920574,142.636883 ],
    [ u"ru",u"Troitskoye",4007,43.762195,44.68415 ],
    [ u"ru",u"Troitsk",82339,54.0979,61.5773 ],
    [ u"ru",u"Troitsk",33785,55.48498,37.307359 ],
    [ u"ru",u"Trosna",2627,52.416667,36.383333 ],
    [ u"ru",u"Trudarmeyskiy",4711,54.132,86.4098 ],
    [ u"ru",u"Trudobelikovskiy",9013,45.268527,38.153763 ],
    [ u"ru",u"Trudovoye",18484,43.305833,132.081667 ],
    [ u"ru",u"Trud",664,57.609737,33.964103 ],
    [ u"ru",u"Trunovskoye",6459,45.487778,42.135833 ],
    [ u"ru",u"Tsagan Aman",5769,47.5639,46.7218 ],
    [ u"ru",u"Tselina",11075,46.53381,41.032841 ],
    [ u"ru",u"Tselinnoye",5836,53.083333,85.666667 ],
    [ u"ru",u"Tselinnoye",5711,54.501111,63.673611 ],
    [ u"ru",u"Tsementnozavodskiy",2135,67.616667,64.1 ],
    [ u"ru",u"Tsementnyy",5972,57.4693,60.1536 ],
    [ u"ru",u"Tsentoroy",5670,43.006581,46.222348 ],
    [ u"ru",u"Tsentralnyy-Kospashskiy",2806,59.043434,57.772436 ],
    [ u"ru",u"Tsentralnyy",773,55.2075,87.646944 ],
    [ u"ru",u"Tsentralnyy",3805,56.297,42.788695 ],
    [ u"ru",u"Tsentralnyy",1911,53.676898,39.625655 ],
    [ u"ru",u"Tsibanobalka",4548,44.980337,37.343841 ],
    [ u"ru",u"Tsilna",4128,54.595332,48.141405 ],
    [ u"ru",u"Tsimlyansk",15341,47.646111,42.101944 ],
    [ u"ru",u"Tsivilsk",13636,55.869736,47.478735 ],
    [ u"ru",u"Tsotsin-Yurt",15970,43.242058,46.000127 ],
    [ u"ru",u"Tsurib",1915,42.236799,46.830732 ],
    [ u"ru",u"Tuapse",64235,44.1053,39.0802 ],
    [ u"ru",u"Tubinskiy",1388,52.889167,58.2225 ],
    [ u"ru",u"Tuchkovo",16826,55.601111,36.468056 ],
    [ u"ru",u"Tugolesskiy Bor",2217,55.550507,39.82422 ],
    [ u"ru",u"Tugulym",6139,57.059063,64.642512 ],
    [ u"ru",u"Tuim",4669,54.341667,89.926111 ],
    [ u"ru",u"Tukan",1808,53.8409,57.4552 ],
    [ u"ru",u"Tula",468830,54.202133,37.644294 ],
    [ u"ru",u"Tulskiy",10508,44.513611,40.178889 ],
    [ u"ru",u"Tulun",51331,54.4837,100.7418 ],
    [ u"ru",u"Tumannyy",896,68.884722,35.694444 ],
    [ u"ru",u"Tuma",6432,55.147977,40.553742 ],
    [ u"ru",u"Tumbotino",7546,55.999258,43.023594 ],
    [ u"ru",u"Tungor",1322,53.380833,142.956389 ],
    [ u"ru",u"Tunoshna",3152,57.545891,40.125431 ],
    [ u"ru",u"Tupik",996,54.4253,119.9327 ],
    [ u"ru",u"Turan",5528,52.145278,93.919167 ],
    [ u"ru",u"Tura",5444,64.283333,100.25 ],
    [ u"ru",u"Turgenevo",5168,54.845545,46.329676 ],
    [ u"ru",u"Turgoyak",2275,55.065,59.9894 ],
    [ u"ru",u"Turinskaya Sloboda",6023,57.6232,64.385754 ],
    [ u"ru",u"Turinsk",18555,58.045751,63.696051 ],
    [ u"ru",u"Turka",1472,52.9492,108.2217 ],
    [ u"ru",u"Turki",6821,51.987032,43.273099 ],
    [ u"ru",u"Turochak",5514,52.2576,87.1224 ],
    [ u"ru",u"Turtas",5050,58.941667,69.1325 ],
    [ u"ru",u"Turukhansk",4774,65.816667,87.983333 ],
    [ u"ru",u"Tutayev",43828,57.885293,39.540597 ],
    [ u"ru",u"Tuymazy",68830,54.606657,53.709699 ],
    [ u"ru",u"Tuzha",5002,57.606149,47.935974 ],
    [ u"ru",u"Tver",400216,56.860491,35.876027 ],
    [ u"ru",u"Tyarlevo",1523,59.700556,30.456389 ],
    [ u"ru",u"Tyazhinskiy",13716,56.116,88.524 ],
    [ u"ru",u"Tygda",3510,53.116667,126.333333 ],
    [ u"ru",u"Tymovskoye",8030,50.845556,142.655 ],
    [ u"ru",u"Tynda",37336,55.166667,124.716667 ],
    [ u"ru",u"Tyret Pervaya",4082,53.670278,102.310556 ],
    [ u"ru",u"Tyrma",2445,50.083333,132.166667 ],
    [ u"ru",u"Tyube",6466,43.049261,47.307418 ],
    [ u"ru",u"Tyubuk",3573,56.055211,60.940501 ],
    [ u"ru",u"Tyukalinsk",11935,55.873209,72.196729 ],
    [ u"ru",u"Tyukhtet",5138,56.538889,89.301111 ],
    [ u"ru",u"Tyulgan",10105,52.340486,56.166043 ],
    [ u"ru",u"Tyulyachi",2949,55.891253,50.239925 ],
    [ u"ru",u"Tyumentsevo",5759,53.3224,81.498 ],
    [ u"ru",u"Tyumen",519124,57.152222,65.527222 ],
    [ u"ru",u"Ubinskoye",5882,55.306753,79.680163 ],
    [ u"ru",u"Uchaly",5260,54.2996,59.4521 ],
    [ u"ru",u"Uchkeken",15118,43.937778,42.511667 ],
    [ u"ru",u"Uchkent",3380,43.114272,47.082547 ],
    [ u"ru",u"Udachnyy",15266,66.416667,112.4 ],
    [ u"ru",u"Udarnyy",1142,44.349167,42.505278 ],
    [ u"ru",u"Udarnyy",3581,54.3409,42.8611 ],
    [ u"ru",u"Udarnyy",518,49.116667,142.15 ],
    [ u"ru",u"Udelnaya",13199,55.625356,38.002845 ],
    [ u"ru",u"Udimskiy",2594,61.141708,45.914425 ],
    [ u"ru",u"Udobnaya",5519,44.1932,41.5529 ],
    [ u"ru",u"Udomlya",32375,57.879444,34.9925 ],
    [ u"ru",u"Ufa",1033350,54.785167,56.045621 ],
    [ u"ru",u"Ufimskiy",3260,56.7084,58.0517 ],
    [ u"ru",u"Uglegorskiy",2485,48.242737,41.253105 ],
    [ u"ru",u"Uglegorsk",12669,49.083333,142.033333 ],
    [ u"ru",u"Uglekamensk",6461,43.217222,133.230278 ],
    [ u"ru",u"Uglerodovskiy",2986,48.147039,40.062067 ],
    [ u"ru",u"Ugleuralskiy",10169,58.953349,57.584631 ],
    [ u"ru",u"Uglezavodsk",1610,47.316667,142.616667 ],
    [ u"ru",u"Uglich",37733,57.5275,38.331667 ],
    [ u"ru",u"Uglovka",3472,58.239167,33.510833 ],
    [ u"ru",u"Uglovoye",12429,43.345,132.108333 ],
    [ u"ru",u"Uglovskoye",4744,51.3557,80.1942 ],
    [ u"ru",u"Uglyanets",3647,51.819079,39.59606 ],
    [ u"ru",u"Ugra",4721,54.777748,34.326742 ],
    [ u"ru",u"Uinskoye",4340,56.881741,56.581352 ],
    [ u"ru",u"Ukholovo",5558,53.7929,40.4892 ],
    [ u"ru",u"Ukhta",102188,63.567054,53.683478 ],
    [ u"ru",u"Uk",2342,55.079,98.8586 ],
    [ u"ru",u"Ulagan",2623,50.633333,87.966667 ],
    [ u"ru",u"Ulan-Ude",360281,51.826053,107.609794 ],
    [ u"ru",u"Ulëty",6075,51.3572,112.4849 ],
    [ u"ru",u"Ulkan",5701,57.242778,107.327778 ],
    [ u"ru",u"Ulluaya",5905,42.373774,47.374507 ],
    [ u"ru",u"Ullubiyaul",3665,42.59689,47.718245 ],
    [ u"ru",u"Ulukulevo",4546,54.4355,56.3221 ],
    [ u"ru",u"Ulu-Telyak",3287,54.9157,56.9827 ],
    [ u"ru",u"Ulyanovka",9197,59.639444,30.764722 ],
    [ u"ru",u"Ulyanovo",3051,53.723056,35.535 ],
    [ u"ru",u"Ulyanovo",3361,55.047992,44.399862 ],
    [ u"ru",u"Ulyanovsk",640685,54.328241,48.38657 ],
    [ u"ru",u"Umba",6128,66.687064,34.342915 ],
    [ u"ru",u"Undory",3376,54.60849,48.392756 ],
    [ u"ru",u"Unecha",29028,52.845911,32.673942 ],
    [ u"ru",u"Uni",4767,57.753511,51.492325 ],
    [ u"ru",u"Untsukul",5913,42.711488,46.786628 ],
    [ u"ru",u"Upornaya",3350,44.3914,41.0196 ],
    [ u"ru",u"Uporovo",5299,56.310934,66.269261 ],
    [ u"ru",u"Uptar",2144,59.75,150.916667 ],
    [ u"ru",u"Uralets",1551,57.6382,59.6296 ],
    [ u"ru",u"Uralskiy",2273,56.716667,58.966667 ],
    [ u"ru",u"Uralskiy",8707,57.939936,55.550948 ],
    [ u"ru",u"Ural",2057,55.9052,94.7537 ],
    [ u"ru",u"Uray",39879,60.124722,64.775833 ],
    [ u"ru",u"Urazovka",1884,55.401258,45.618601 ],
    [ u"ru",u"Urazovo",6966,50.0836,38.0395 ],
    [ u"ru",u"Urdoma",4460,61.753352,48.544195 ],
    [ u"ru",u"Urengoy",9355,65.966667,78.366667 ],
    [ u"ru",u"Uren",12311,57.455163,45.785218 ],
    [ u"ru",u"Urkarakh",5548,42.162973,47.63068 ],
    [ u"ru",u"Urman",2509,54.88314,56.874172 ],
    [ u"ru",u"Urmary",6256,55.678942,47.94396 ],
    [ u"ru",u"Urma",3515,42.538938,47.286386 ],
    [ u"ru",u"Urozhaynoye",4215,44.788333,44.922778 ],
    [ u"ru",u"Urshelskiy",4576,55.678325,40.216924 ],
    [ u"ru",u"Urukh",4360,43.293353,44.026472 ],
    [ u"ru",u"Urulga",3106,51.75,114.783333 ],
    [ u"ru",u"Urusha",4252,54.05,122.9 ],
    [ u"ru",u"Urus-Martan",41480,43.130527,45.537908 ],
    [ u"ru",u"Urussu",11279,54.598118,53.463126 ],
    [ u"ru",u"Urvan",5484,43.492222,43.760556 ],
    [ u"ru",u"Uryupinsk",41645,50.8047,42.0138 ],
    [ u"ru",u"Urzhum",11333,57.114119,49.999561 ],
    [ u"ru",u"Ushkovo",472,60.199332,29.619714 ],
    [ u"ru",u"Ushumun",2808,52.783333,126.533333 ],
    [ u"ru",u"Usinsk",44875,65.950714,57.46847 ],
    [ u"ru",u"Usisha",4442,42.251111,47.392778 ],
    [ u"ru",u"Usman",19910,52.046616,39.728796 ],
    [ u"ru",u"Usogorsk",5308,63.410636,48.687225 ],
    [ u"ru",u"Usolye-Sibirskoye",86903,52.751944,103.645278 ],
    [ u"ru",u"Usolye",4769,53.3912,49.0624 ],
    [ u"ru",u"Usolye",6002,59.426746,56.680811 ],
    [ u"ru",u"Uspenka",3217,56.801577,69.227024 ],
    [ u"ru",u"Uspenskaya",4682,45.764478,41.066963 ],
    [ u"ru",u"Uspenskoye",11843,44.8311,41.3927 ],
    [ u"ru",u"Ussuriysk",157071,43.8025,132.009444 ],
    [ u"ru",u"Ust-Abakan",14696,53.8525,91.374167 ],
    [ u"ru",u"Ust-Barguzin",7195,53.45,108.983333 ],
    [ u"ru",u"Ust-Bolsheretsk",2150,52.823333,156.278333 ],
    [ u"ru",u"Ust-Charyshskaya Pristan",5647,52.3934,83.6635 ],
    [ u"ru",u"Ust-Donetskiy",11357,47.641895,40.871819 ],
    [ u"ru",u"Ust-Dzheguta",34001,44.0834,41.9763 ],
    [ u"ru",u"Ust-Ilimsk",100272,58.000556,102.661944 ],
    [ u"ru",u"Ust-Ishim",4999,57.6935,71.1665 ],
    [ u"ru",u"Ust-Izhora",1127,59.811944,30.581389 ],
    [ u"ru",u"Ust-Kachka",3991,58.005979,55.672474 ],
    [ u"ru",u"Ust-Kalmanka",6659,52.1207,83.305 ],
    [ u"ru",u"Ust-Kamchatsk",4939,56.236667,162.518889 ],
    [ u"ru",u"Ust-Kan",3547,50.9276,84.761 ],
    [ u"ru",u"Ust-Karsk",1947,52.7011,118.8077 ],
    [ u"ru",u"Ust-Katav",25046,54.9366,58.1757 ],
    [ u"ru",u"Ust-Kishert",4413,57.3654,57.2495 ],
    [ u"ru",u"Ust-Koksa",4008,50.2696,85.6108 ],
    [ u"ru",u"Ust-Kulom",5205,61.686359,53.690205 ],
    [ u"ru",u"Ust-Kut",48203,56.7938,105.7672 ],
    [ u"ru",u"Ust-Kuyga",1517,70.016667,135.6 ],
    [ u"ru",u"Ust-Labinsk",44089,45.214355,39.690334 ],
    [ u"ru",u"Ust-Maya",3062,60.416667,134.533333 ],
    [ u"ru",u"Ust-Nera",9148,64.566667,143.2 ],
    [ u"ru",u"Ust-Omchug",4515,61.15,149.633333 ],
    [ u"ru",u"Ust-Ordynskiy",14538,52.805,104.751 ],
    [ u"ru",u"Ust-Shonosha",2252,61.1531,41.343 ],
    [ u"ru",u"Ust-Tarka",4325,55.567154,75.705003 ],
    [ u"ru",u"Ust-Tsilma",4830,65.441037,52.149783 ],
    [ u"ru",u"Ust-Uda",5169,54.1742,103.0304 ],
    [ u"ru",u"Ustye",3609,52.827778,40.466111 ],
    [ u"ru",u"Ustye",4068,59.614622,39.684037 ],
    [ u"ru",u"Ustyuzhna",10566,58.8394,36.4321 ],
    [ u"ru",u"Usukhchay",1966,41.422446,47.913179 ],
    [ u"ru",u"Usva",739,58.682316,57.645023 ],
    [ u"ru",u"Usvyaty",3060,55.745556,30.753333 ],
    [ u"ru",u"Utamysh",3714,42.40718,47.751093 ],
    [ u"ru",u"Utevka",4556,52.9035,50.9495 ],
    [ u"ru",u"Utsmiyurt",3464,43.53481,46.469518 ],
    [ u"ru",u"Uvarovka",3136,55.527778,35.606111 ],
    [ u"ru",u"Uvarovo",28771,51.984858,42.261474 ],
    [ u"ru",u"Uvat",4581,59.143333,68.895278 ],
    [ u"ru",u"Uva",19143,56.990807,52.185166 ],
    [ u"ru",u"Uvelskiy",10625,54.4446,61.3574 ],
    [ u"ru",u"Uyar",13167,55.8118,94.3247 ],
    [ u"ru",u"Uyemskiy",3593,64.4743,40.8524 ],
    [ u"ru",u"Uyskoye",7668,54.345278,60.018056 ],
    [ u"ru",u"Uzhur-4",10641,56.115833,92.925278 ],
    [ u"ru",u"Uzhur",15637,55.303611,89.833889 ],
    [ u"ru",u"Uzlovaya",58458,53.981789,38.17118 ],
    [ u"ru",u"Uzunovo",3371,54.538577,38.617338 ],
    [ u"ru",u"Vacha",6618,55.8035,42.7709 ],
    [ u"ru",u"Vachi",714,42.073808,47.214736 ],
    [ u"ru",u"Vadinsk",4708,53.691573,43.057437 ],
    [ u"ru",u"Vad",6645,55.530088,44.211366 ],
    [ u"ru",u"Vagay",4951,57.9375,69.021667 ],
    [ u"ru",u"Vakhrushevo",4152,55.2295,61.7487 ],
    [ u"ru",u"Vakhrushev",2884,48.983333,142.966667 ],
    [ u"ru",u"Vakhrushi",10330,58.67,50.070556 ],
    [ u"ru",u"Vakhtan",6529,57.965915,46.688857 ],
    [ u"ru",u"Valday",18549,57.974722,33.2525 ],
    [ u"ru",u"Valerianovsk",2152,58.760236,59.558986 ],
    [ u"ru",u"Valerik",6025,43.179722,45.408056 ],
    [ u"ru",u"Valuyki",35887,50.2035,38.1067 ],
    [ u"ru",u"Vanavara",3090,60.34,102.279722 ],
    [ u"ru",u"Vanino",18618,49.086856,140.254337 ],
    [ u"ru",u"Varenikovskaya",14409,45.120852,37.64171 ],
    [ u"ru",u"Vargashi",9728,55.355556,65.846667 ],
    [ u"ru",u"Varlamovo",3264,53.1897,48.4226 ],
    [ u"ru",u"Varna",9906,53.381944,60.974722 ],
    [ u"ru",u"Varnavino",3655,57.403507,45.091644 ],
    [ u"ru",u"Vasilkovo",4292,54.739929,20.634843 ],
    [ u"ru",u"Vasilsursk",1307,56.131395,46.015997 ],
    [ u"ru",u"Vasilyevo",16877,55.835955,48.658201 ],
    [ u"ru",u"Vasilyevskiy Mokh",2496,57.013162,35.918967 ],
    [ u"ru",u"Vasyurinskaya",12830,45.11809,39.423985 ],
    [ u"ru",u"Vatutinki",9502,55.4965,37.329875 ],
    [ u"ru",u"Vavozh",5569,56.775126,51.930977 ],
    [ u"ru",u"Vazhiny",2926,60.964444,34.022222 ],
    [ u"ru",u"Vedeno",1472,42.96892,46.09611 ],
    [ u"ru",u"Veletma",1178,55.334722,42.421389 ],
    [ u"ru",u"Velikent",4020,42.186258,48.062845 ],
    [ u"ru",u"Velikie Luki",103150,56.34,30.54517 ],
    [ u"ru",u"Velikiy Novgorod",215065,58.516667,31.283333 ],
    [ u"ru",u"Velikiy Ustyug",32642,60.761863,46.313519 ],
    [ u"ru",u"Velikodvorskiy",2218,55.249956,40.667797 ],
    [ u"ru",u"Velikooktyabrskiy",2574,57.433335,33.815954 ],
    [ u"ru",u"Velikovechnoye",5762,44.934018,39.754993 ],
    [ u"ru",u"Velizh",8147,55.605638,31.196732 ],
    [ u"ru",u"Velsk",26162,61.070057,42.0983 ],
    [ u"ru",u"Vengerovo",7073,55.684852,76.747066 ],
    [ u"ru",u"Ventsy",4193,45.376389,40.835833 ],
    [ u"ru",u"Verbilki",6708,56.533333,37.6 ],
    [ u"ru",u"Vereshchagino",22451,58.078945,54.655697 ],
    [ u"ru",u"Vereya",1973,55.773729,39.097662 ],
    [ u"ru",u"Verkh-Chebula",5224,56.0308,87.6218 ],
    [ u"ru",u"Verkhnebakanskiy",6746,44.842789,37.664118 ],
    [ u"ru",u"Verkhnechusovskiye Gorodki",2427,58.1671,57.1086 ],
    [ u"ru",u"Verkhnedneprovskiy",13903,54.981306,33.345734 ],
    [ u"ru",u"Verkhne-Katunskoye",3009,52.449444,85.431667 ],
    [ u"ru",u"Verkhnetulomskiy",1889,68.60727,31.79621 ],
    [ u"ru",u"Verkhneuralsk",9844,53.876944,59.210556 ],
    [ u"ru",u"Verkhnevilyuysk",6341,63.445278,120.316667 ],
    [ u"ru",u"Verkhneyarkeyevo",9357,55.450459,54.314551 ],
    [ u"ru",u"Verkhneye Dubrovo",4596,56.7528,61.0468 ],
    [ u"ru",u"Verkhneye Kazanishche",6444,42.735474,47.137804 ],
    [ u"ru",u"Verkh-Neyvinskiy",5156,57.269,60.1373 ],
    [ u"ru",u"Verkhniy At-Uryakh",57,62.65,150.116667 ],
    [ u"ru",u"Verkhniy Avzyan",2581,53.528889,57.537222 ],
    [ u"ru",u"Verkhniy Baskunchak",8745,48.225639,46.721695 ],
    [ u"ru",u"Verkhniye Achaluki",9393,43.346944,44.6975 ],
    [ u"ru",u"Verkhniye Kigi",6885,55.408333,58.604444 ],
    [ u"ru",u"Verkhniye Sergi",6520,56.646944,59.555556 ],
    [ u"ru",u"Verkhniye Tatyshly",6341,56.291174,55.857497 ],
    [ u"ru",u"Verkhniy Fiagdon",1102,42.833232,44.306569 ],
    [ u"ru",u"Verkhniy Kurkuzhin",3129,43.695556,43.274722 ],
    [ u"ru",u"Verkhniy Landekh",2009,56.839706,42.5973 ],
    [ u"ru",u"Verkhniy Lomov",4390,53.467778,43.551111 ],
    [ u"ru",u"Verkhniy Mamon",8278,50.1635,40.3832 ],
    [ u"ru",u"Verkhniy Naur",5036,43.61033,45.245416 ],
    [ u"ru",u"Verkhniy Tagil",12359,57.3733,59.9556 ],
    [ u"ru",u"Verkhniy Ufaley",33245,56.0556,60.2397 ],
    [ u"ru",u"Verkhniy Uslon",4265,55.7701,48.9823 ],
    [ u"ru",u"Verkhniy Zgid",208,42.870043,43.95937 ],
    [ u"ru",u"Verkhnyaya Balkariya",4076,43.12785,43.457322 ],
    [ u"ru",u"Verkhnyaya Inta",1975,66.083333,60.516667 ],
    [ u"ru",u"Verkhnyaya Khava",7870,51.840446,39.941341 ],
    [ u"ru",u"Verkhnyaya Maksakovka",3827,61.635039,50.967404 ],
    [ u"ru",u"Verkhnyaya Pyshma",59062,56.970468,60.582186 ],
    [ u"ru",u"Verkhnyaya Salda",48993,58.048742,60.559493 ],
    [ u"ru",u"Verkhnyaya Sinyachikha",10964,57.976045,61.667331 ],
    [ u"ru",u"Verkhnyaya Sysert",1115,56.44012,60.755635 ],
    [ u"ru",u"Verkhnyaya Tishanka",3602,51.323889,40.532778 ],
    [ u"ru",u"Verkhnyaya Toyma",3790,62.23487,44.998525 ],
    [ u"ru",u"Verkhnyaya Tura",10608,58.360833,59.806667 ],
    [ u"ru",u"Verkhoshizhemye",4382,58.01097,49.103841 ],
    [ u"ru",u"Verkhoturye",7566,58.862706,60.805363 ],
    [ u"ru",u"Verkhovazhye",5105,60.747174,42.046518 ],
    [ u"ru",u"Verkhovye",7964,52.811646,37.242146 ],
    [ u"ru",u"Verkhoyansk",1388,67.544722,133.385 ],
    [ u"ru",u"Verkhozim",1756,52.712213,45.418028 ],
    [ u"ru",u"Verkh-Suetka",2580,53.3,80.05 ],
    [ u"ru",u"Verkh-Tula",5625,54.8839,82.7762 ],
    [ u"ru",u"Verkh-Usugli",2573,52.683333,115.233333 ],
    [ u"ru",u"Vershino-Darasunskiy",6451,52.35,115.516667 ],
    [ u"ru",u"Vershino-Shakhtaminskiy",1633,51.3012,117.8868 ],
    [ u"ru",u"Vesëlovka",294,59.689084,59.993585 ],
    [ u"ru",u"Veseloyarsk",5230,51.283611,81.105556 ],
    [ u"ru",u"Veshenskaya",9303,49.630327,41.733402 ],
    [ u"ru",u"Veshkayma",7087,54.0472,47.13 ],
    [ u"ru",u"Vesyegonsk",8467,58.663982,37.260403 ],
    [ u"ru",u"Vetluga",9497,57.855741,45.781022 ],
    [ u"ru",u"Vetluzhskiy",13229,58.390162,45.465425 ],
    [ u"ru",u"Vetluzhskiy",5578,57.173548,45.122719 ],
    [ u"ru",u"Veydelevka",7280,50.1521,38.4492 ],
    [ u"ru",u"Vichuga",39072,57.212758,41.930117 ],
    [ u"ru",u"Vidim",1415,56.3816,103.1 ],
    [ u"ru",u"Vidnoye",51722,55.552387,37.709665 ],
    [ u"ru",u"Vidyayevo",5949,68.883333,33.016667 ],
    [ u"ru",u"Vikhorevka",24918,56.1201,101.1636 ],
    [ u"ru",u"Vikulovo",6952,56.816667,70.610691 ],
    [ u"ru",u"Vilya",3338,55.245556,42.208889 ],
    [ u"ru",u"Vilyuysk",9949,63.755278,121.624722 ],
    [ u"ru",u"Vinogradnyy",3250,45.056097,37.321252 ],
    [ u"ru",u"Vinsady",8949,44.080833,42.965278 ],
    [ u"ru",u"Vinzili",11219,56.959377,65.770796 ],
    [ u"ru",u"Vishnyakovskiye Dachi",1773,55.764705,38.133338 ],
    [ u"ru",u"Visimo-Utkinsk",843,57.6843,59.3585 ],
    [ u"ru",u"Visim",1699,57.6488,59.5014 ],
    [ u"ru",u"Vitimskiy",885,58.218333,113.27 ],
    [ u"ru",u"Vitim",3843,59.451111,112.557778 ],
    [ u"ru",u"Vityazevo",6104,45.001299,37.282115 ],
    [ u"ru",u"Vizimyary",2358,56.438047,46.938364 ],
    [ u"ru",u"Vizinga",6788,61.074927,50.103114 ],
    [ u"ru",u"Vkhodnoy",7819,54.951809,73.171077 ],
    [ u"ru",u"Vladikavkaz",317372,43.036667,44.667778 ],
    [ u"ru",u"Vladimiro-Aleksandrovskoye",5444,42.894444,133.077778 ],
    [ u"ru",u"Vladimirskaya",7278,44.5455,40.7933 ],
    [ u"ru",u"Vladimir",310027,56.136547,40.396576 ],
    [ u"ru",u"Vladivostok",587029,43.128056,131.901111 ],
    [ u"ru",u"Vlasikha",4687,53.297222,83.574167 ],
    [ u"ru",u"Vnukovo",20592,55.646145,37.265867 ],
    [ u"ru",u"Vnukovo",20592,55.609936,37.293187 ],
    [ u"ru",u"Vodnyy",6307,63.50464,53.409466 ],
    [ u"ru",u"Vodstroy",4173,48.841651,44.557926 ],
    [ u"ru",u"Vokhma",4663,58.930305,46.758593 ],
    [ u"ru",u"Vokhtoga",7107,58.769705,41.074091 ],
    [ u"ru",u"Volchanets",4013,42.913056,132.746944 ],
    [ u"ru",u"Volchansk",10403,59.9378,60.081 ],
    [ u"ru",u"Volchikha",11212,52.033333,80.383333 ],
    [ u"ru",u"Volga",3469,57.95157,38.387846 ],
    [ u"ru",u"Volginskiy",6151,55.966667,39.233333 ],
    [ u"ru",u"Volgodonsk",167734,47.5026,42.235 ],
    [ u"ru",u"Volgograd",1010331,48.71939,44.501835 ],
    [ u"ru",u"Volgo-Kaspiyskiy",2662,46.203064,47.918691 ],
    [ u"ru",u"Volgorechensk",17700,57.439307,41.155532 ],
    [ u"ru",u"Volkhovskiy",2975,58.579997,31.316411 ],
    [ u"ru",u"Volkhov",45673,59.819014,32.367159 ],
    [ u"ru",u"Volno-Nadezhdinskoye",6604,43.383333,131.991667 ],
    [ u"ru",u"Volnoye",3670,44.6232,40.7034 ],
    [ u"ru",u"Volnoye",3495,44.954722,41.206389 ],
    [ u"ru",u"Volodarskiy",9509,46.401342,48.54093 ],
    [ u"ru",u"Volodarsk",10862,56.231051,43.187671 ],
    [ u"ru",u"Vologda",294892,59.2187,39.8886 ],
    [ u"ru",u"Volokolamsk",16277,56.038968,35.957021 ],
    [ u"ru",u"Volokonovka",12413,50.4827,37.8563 ],
    [ u"ru",u"Voloshka",1562,61.331389,40.085833 ],
    [ u"ru",u"Volosovo",12096,59.44802,29.491394 ],
    [ u"ru",u"Volot",2276,57.938155,30.685802 ],
    [ u"ru",u"Volovo",4089,53.55932,38.002061 ],
    [ u"ru",u"Volovo",4036,52.02659,37.885403 ],
    [ u"ru",u"Volovo",4089,53.558311,38.002848 ],
    [ u"ru",u"Volsk",71717,51.986272,47.243375 ],
    [ u"ru",u"Volya",7869,51.765096,39.540396 ],
    [ u"ru",u"Volzhskiy",7040,53.430578,50.119003 ],
    [ u"ru",u"Volzhskiy",323298,48.785832,44.77973 ],
    [ u"ru",u"Volzhsk",58608,55.866383,48.359404 ],
    [ u"ru",u"Vorgashor",18158,67.583333,63.95 ],
    [ u"ru",u"Vorkuta",80040,67.5,64 ],
    [ u"ru",u"Vorobyevka",4420,50.6417,40.927 ],
    [ u"ru",u"Voronezhskaya",8026,45.211305,39.567058 ],
    [ u"ru",u"Voronezh",840590,51.672035,39.184301 ],
    [ u"ru",u"Vorontsovka",983,59.657958,60.237883 ],
    [ u"ru",u"Vorontsovka",5067,50.6132,40.3549 ],
    [ u"ru",u"Voroshnëvo",3244,51.652778,36.017222 ],
    [ u"ru",u"Vorotynets",6606,56.060279,45.8633 ],
    [ u"ru",u"Vorotynsk",10977,54.428279,36.04646 ],
    [ u"ru",u"Vorsma",12362,55.990622,43.272485 ],
    [ u"ru",u"Voskresenskoye",1992,52.797073,56.36564 ],
    [ u"ru",u"Voskresenskoye",6255,56.838056,45.431667 ],
    [ u"ru",u"Voskresenskoye",3211,51.824785,46.935077 ],
    [ u"ru",u"Voskresensk",77088,55.317331,38.652642 ],
    [ u"ru",u"Vostochnyy",7622,58.788108,52.245134 ],
    [ u"ru",u"Vostochnyy",13011,55.816667,37.866667 ],
    [ u"ru",u"Vostochnyy",936,48.283333,142.616667 ],
    [ u"ru",u"Vostochnyy",5635,58.799909,61.813906 ],
    [ u"ru",u"Vostok",3452,46.485556,135.883333 ],
    [ u"ru",u"Vostok",2779,48.916667,148.9 ],
    [ u"ru",u"Vostryakovo",16509,55.399335,37.808291 ],
    [ u"ru",u"Votkinsk",98635,57.048651,53.987169 ],
    [ u"ru",u"Voyskovitsy",3896,59.528668,29.963963 ],
    [ u"ru",u"Voyvozh",3727,62.891983,54.963462 ],
    [ u"ru",u"Vozdvizhenka",7102,43.9,131.95 ],
    [ u"ru",u"Vozhd Proletariata",594,55.437968,39.304187 ],
    [ u"ru",u"Vozhega",6703,60.472457,40.221342 ],
    [ u"ru",u"Voznesenskaya",7009,44.5527,41.0318 ],
    [ u"ru",u"Voznesenskaya",6972,43.543787,44.746137 ],
    [ u"ru",u"Voznesenskoye",7204,54.89,42.756944 ],
    [ u"ru",u"Voznesenye",2803,61.010599,35.478127 ],
    [ u"ru",u"Vozrozhdeniye",2738,52.6901,48.1879 ],
    [ u"ru",u"Vrangel",14981,42.729722,133.083889 ],
    [ u"ru",u"Vsevolodo-Vilva",3539,59.218435,57.433798 ],
    [ u"ru",u"Vsevolozhsk",48224,60.020433,30.63716 ],
    [ u"ru",u"Vstrechnyy",12,67.95,165.6 ],
    [ u"ru",u"Vuktyl",13694,63.856667,57.309444 ],
    [ u"ru",u"Vurnary",10825,55.490444,46.96479 ],
    [ u"ru",u"Vvedenskoye",3895,55.4275,65.119722 ],
    [ u"ru",u"Vyartsilya",3145,62.17645,30.69296 ],
    [ u"ru",u"Vyatskiye Polyany",39535,56.226018,51.065573 ],
    [ u"ru",u"Vyazemskiy",15248,47.537778,134.7525 ],
    [ u"ru",u"Vyazma",57192,55.210391,34.295076 ],
    [ u"ru",u"Vyazniki",39244,56.240566,42.155629 ],
    [ u"ru",u"Vyazovaya",2101,54.905,58.356111 ],
    [ u"ru",u"Vyborg",78634,60.707631,28.752826 ],
    [ u"ru",u"Vychegodskiy",12923,61.247016,46.898418 ],
    [ u"ru",u"Vydrino",5211,51.4892,104.8429 ],
    [ u"ru",u"Vygonichi",5086,53.098549,34.067284 ],
    [ u"ru",u"Vyksa",61665,55.3175,42.174444 ],
    [ u"ru",u"Vylgort",9707,61.622833,50.7573 ],
    [ u"ru",u"Vypolzovo",1982,57.876667,33.698611 ],
    [ u"ru",u"Vyritsa",11107,59.407778,30.348056 ],
    [ u"ru",u"Vyselki",18746,45.581282,39.664093 ],
    [ u"ru",u"Vysha",1061,53.847675,42.377658 ],
    [ u"ru",u"Vyshestebliyevskaya",4312,45.1968,37.0036 ],
    [ u"ru",u"Vyshkov",2881,52.4764,31.6873 ],
    [ u"ru",u"Vysokaya Gora",8013,55.912778,49.301667 ],
    [ u"ru",u"Vysokogornyy",3926,50.116667,139.15 ],
    [ u"ru",u"Vysokogorsk",463,44.405833,135.401389 ],
    [ u"ru",u"Vysokovsk",10772,56.316667,36.55 ],
    [ u"ru",u"Vysokoye",3090,43.463041,39.967011 ],
    [ u"ru",u"Vysotskoye",3078,45.025,42.906389 ],
    [ u"ru",u"Vysotsk",1873,60.628793,28.570476 ],
    [ u"ru",u"Vytegra",11100,61.006364,36.448111 ],
    [ u"ru",u"Vyyezdnoye",7857,55.381539,43.786381 ],
    [ u"ru",u"Vzmorye",758,47.849444,142.520556 ],
    [ u"ru",u"Yablochnyy",2062,47.166111,142.066111 ],
    [ u"ru",u"Yablonovo",799,51.8424,112.7625 ],
    [ u"ru",u"Yablonovskiy",25078,44.989009,38.943244 ],
    [ u"ru",u"Yadrin",10735,55.940518,46.206224 ],
    [ u"ru",u"Yagodnoye",4685,62.55,149.666667 ],
    [ u"ru",u"Yagunovskiy",8199,55.2828,85.978 ],
    [ u"ru",u"Yakhroma",12667,56.3,37.483333 ],
    [ u"ru",u"Yakovlevka",4996,44.425,133.477222 ],
    [ u"ru",u"Yakovlevo",2629,50.860329,36.44784 ],
    [ u"ru",u"Yakovlevskoye",4330,55.441944,37.948056 ],
    [ u"ru",u"Yaksatovo",3376,46.243425,48.015141 ],
    [ u"ru",u"Yakshur-Bodya",6867,57.183996,53.161174 ],
    [ u"ru",u"Yalchiki",2706,55.163151,48.001405 ],
    [ u"ru",u"Yalkhoy-Mokhk",4058,43.105282,46.190446 ],
    [ u"ru",u"Yalutorovsk",35892,56.653582,66.300575 ],
    [ u"ru",u"Yam",3244,55.487848,37.744579 ],
    [ u"ru",u"Yanaul",27963,56.271899,54.930862 ],
    [ u"ru",u"Yanchukan",529,56.249722,112.811389 ],
    [ u"ru",u"Yandyki",3411,45.769133,47.125766 ],
    [ u"ru",u"Yandyrka",11730,43.275,44.912778 ],
    [ u"ru",u"Yanino",4263,59.935495,30.61534 ],
    [ u"ru",u"Yantal",2383,56.8471,105.2542 ],
    [ u"ru",u"Yantarnyy",5527,54.871023,19.940157 ],
    [ u"ru",u"Yantikovo",3331,55.521033,47.779272 ],
    [ u"ru",u"Yaransk",19558,57.303313,47.886113 ],
    [ u"ru",u"Yarega",8092,63.435434,53.576505 ],
    [ u"ru",u"Yarensk",3929,62.167548,49.091617 ],
    [ u"ru",u"Yarkovo",5149,54.8056,82.5989 ],
    [ u"ru",u"Yarkovo",6925,57.402778,67.078611 ],
    [ u"ru",u"Yaroslavl",606735,57.61977,39.85536 ],
    [ u"ru",u"Yaroslavskaya",5458,44.610556,40.464167 ],
    [ u"ru",u"Yaroslavskiy",10010,44.168333,132.207222 ],
    [ u"ru",u"Yarovoye",21195,52.9273,78.58 ],
    [ u"ru",u"Yar-Sale",4885,66.833333,70.833333 ],
    [ u"ru",u"Yartsevo",52706,55.066667,32.696389 ],
    [ u"ru",u"Yar",7122,58.24898,52.102576 ],
    [ u"ru",u"Yasenskaya",4855,46.3592,38.269 ],
    [ u"ru",u"Yashalta",4723,46.3395,42.2762 ],
    [ u"ru",u"Yashkino",15197,55.8736,85.4265 ],
    [ u"ru",u"Yashkul",7203,46.1711,45.3435 ],
    [ u"ru",u"Yasnaya Polyana",5064,44.0225,42.7539 ],
    [ u"ru",u"Yasnogorsk",18023,54.480819,37.698542 ],
    [ u"ru",u"Yasnyy",17360,51.0333,59.8742 ],
    [ u"ru",u"Yavas",7783,54.3902,42.6626 ],
    [ u"ru",u"Yaya",13238,56.206,86.44 ],
    [ u"ru",u"Yayva",10615,59.330333,57.264079 ],
    [ u"ru",u"Yazykovo",5929,55.219884,56.135322 ],
    [ u"ru",u"Yazykovo",4918,54.2922,47.3891 ],
    [ u"ru",u"Yefimovskiy",3917,59.496389,34.672222 ],
    [ u"ru",u"Yefremov",45498,53.14806,38.099235 ],
    [ u"ru",u"Yegorlykskaya",17978,46.553123,40.682604 ],
    [ u"ru",u"Yekaterinburg",1287586,56.8519,60.6122 ],
    [ u"ru",u"Yekaterinogradskaya",3841,43.763333,44.230556 ],
    [ u"ru",u"Yekaterinoslavka",10178,50.373365,129.11386 ],
    [ u"ru",u"Yekaterinovka",3555,42.925,133.047222 ],
    [ u"ru",u"Yekaterinovka",6435,52.050827,44.345146 ],
    [ u"ru",u"Yekimovichi",1534,54.11285,33.296483 ],
    [ u"ru",u"Yelabuga",72644,55.761274,52.064931 ],
    [ u"ru",u"Yelan-Kolenovskiy",4112,51.054444,41.281667 ],
    [ u"ru",u"Yelan-Koleno",5270,51.1523,41.2306 ],
    [ u"ru",u"Yelanskiy",8653,56.8419,62.5014 ],
    [ u"ru",u"Yelan",15181,50.949005,43.737812 ],
    [ u"ru",u"Yelatma",3902,54.9675,41.750833 ],
    [ u"ru",u"Yeletskiy",742,67.05,64.2 ],
    [ u"ru",u"Yelets",115690,52.623659,38.501686 ],
    [ u"ru",u"Yelizavetino",3037,59.491574,29.793763 ],
    [ u"ru",u"Yelizavetinskaya",19306,45.044462,38.795803 ],
    [ u"ru",u"Yelizavetinskoye",3316,45.007222,43.349444 ],
    [ u"ru",u"Yelizovo",40692,53.1873,158.3805 ],
    [ u"ru",u"Yelkhovka",3142,53.866675,50.283193 ],
    [ u"ru",u"Yelniki",5549,54.623476,43.873091 ],
    [ u"ru",u"Yelnya",10947,54.578643,33.183727 ],
    [ u"ru",u"Yelovo",5570,57.053811,54.920704 ],
    [ u"ru",u"Yeltsovka",3311,51.916667,82.416667 ],
    [ u"ru",u"Yemanzhelinka",4117,54.754722,61.320833 ],
    [ u"ru",u"Yemanzhelinsk",29849,54.754722,61.320833 ],
    [ u"ru",u"Yemelyanovo",11734,56.168056,92.676667 ],
    [ u"ru",u"Yemtsa",1441,63.073369,40.332851 ],
    [ u"ru",u"Yeniseysk",19920,58.449722,92.170278 ],
    [ u"ru",u"Yenotayevka",7985,47.245594,47.02814 ],
    [ u"ru",u"Yepifan",2310,53.825262,38.551806 ],
    [ u"ru",u"Yerbogachën",2019,61.276667,108.010833 ],
    [ u"ru",u"Yermakovskoye",8910,53.283056,92.400278 ],
    [ u"ru",u"Yermekeyevo",4214,54.076144,53.671253 ],
    [ u"ru",u"Yermish",4598,54.767778,42.271111 ],
    [ u"ru",u"Yermolayevo",6354,52.716667,55.8 ],
    [ u"ru",u"Yermolino",9350,55.194888,36.595133 ],
    [ u"ru",u"Yerofey Pavlovich",5409,53.966667,121.966667 ],
    [ u"ru",u"Yershichi",3239,53.6725,32.754167 ],
    [ u"ru",u"Yershov",23682,51.3513,48.2766 ],
    [ u"ru",u"Yertarskiy",1612,56.790156,64.299516 ],
    [ u"ru",u"Yertsevo",3860,60.7966,40.086 ],
    [ u"ru",u"Yessentuki",81016,44.044444,42.860556 ],
    [ u"ru",u"Yessentukskaya",19956,44.0328,42.8813 ],
    [ u"ru",u"Yetkul",6163,54.8221,61.588 ],
    [ u"ru",u"Yevsino",5036,54.4136,83.322 ],
    [ u"ru",u"Yeysk",87815,46.7055,38.2739 ],
    [ u"ru",u"Yllymakh",484,58.577222,126.696111 ],
    [ u"ru",u"Ynykchan",379,60.25,137.716667 ],
    [ u"ru",u"Yubileynyy",1656,58.781024,57.777818 ],
    [ u"ru",u"Yuganets",2991,56.250798,43.230686 ],
    [ u"ru",u"Yugo-Kamskiy",7779,57.703977,55.594265 ],
    [ u"ru",u"Yugorsk",30878,61.313333,63.331944 ],
    [ u"ru",u"Yukamenskoye",4278,57.886542,52.241574 ],
    [ u"ru",u"Yukhnov",7934,54.744444,35.229722 ],
    [ u"ru",u"Yumaguzino",5353,52.904119,56.393289 ],
    [ u"ru",u"Yurgamysh",7888,55.371389,64.465556 ],
    [ u"ru",u"Yurga",84222,55.723056,84.886111 ],
    [ u"ru",u"Yurginskoye",4606,56.818883,67.392114 ],
    [ u"ru",u"Yurino",4199,56.294169,46.303917 ],
    [ u"ru",u"Yurla",4058,59.325887,54.322337 ],
    [ u"ru",u"Yurovka",3510,45.114698,37.418823 ],
    [ u"ru",u"Yurty",5902,56.0498,97.6348 ],
    [ u"ru",u"Yurya",5982,59.043,49.2687 ],
    [ u"ru",u"Yuryevets",11921,57.320073,43.1041 ],
    [ u"ru",u"Yuryevets",11352,56.101384,40.269814 ],
    [ u"ru",u"Yuryev-Polskiy",19414,56.503387,39.679111 ],
    [ u"ru",u"Yuryuzan",13424,54.815,58.459167 ],
    [ u"ru",u"Yushala",4169,57.076113,64.260115 ],
    [ u"ru",u"Yusva",4556,58.963123,54.960359 ],
    [ u"ru",u"Yutsa",8702,43.943056,42.971111 ],
    [ u"ru",u"Yuzha",14678,56.583056,42.012222 ],
    [ u"ru",u"Yuzhno-Kurilsk",5413,44.030556,145.855556 ],
    [ u"ru",u"Yuzhno-Sukhokumsk",9913,44.658113,45.643596 ],
    [ u"ru",u"Yuzhnouralsk",38745,54.4418,61.2536 ],
    [ u"ru",u"Yuzhno-Yeniseyskiy",807,58.795833,94.706389 ],
    [ u"ru",u"Yuzhnyy-Kospashskiy",2275,58.969478,57.754785 ],
    [ u"ru",u"Yuzhnyy",19515,53.254167,83.693611 ],
    [ u"ru",u"Yuzhnyy",2143,53.526944,60.077778 ],
    [ u"ru",u"Yuzhnyy",3111,54.548374,20.598432 ],
    [ u"ru",u"Yuzhnyy",3320,44.721107,39.879184 ],
    [ u"ru",u"Zabaykalsk",9767,49.633333,117.316667 ],
    [ u"ru",u"Zabolotovka",3308,50.273679,39.314696 ],
    [ u"ru",u"Zadonsk",10326,52.3904,38.9261 ],
    [ u"ru",u"Zadonye",1410,54.005542,38.395322 ],
    [ u"ru",u"Zagoryanskiy",7514,55.9325,37.958056 ],
    [ u"ru",u"Zaigrayevo",5512,51.8336,108.2703 ],
    [ u"ru",u"Zainsk",42045,55.2827,52.0007 ],
    [ u"ru",u"Zakamensk",12250,50.3741,103.2863 ],
    [ u"ru",u"Zakan-Yurt",4939,43.259722,45.420556 ],
    [ u"ru",u"Zakharovo",2882,54.366,39.2792 ],
    [ u"ru",u"Zalari",9781,53.5584,102.5065 ],
    [ u"ru",u"Zalegoshch",5925,52.898898,36.890927 ],
    [ u"ru",u"Zalesovo",7936,53.993889,84.743056 ],
    [ u"ru",u"Zalukokoazhe",9554,43.903889,43.215556 ],
    [ u"ru",u"Zandak",3549,43.057105,46.455656 ],
    [ u"ru",u"Zaokskiy",6480,54.732274,37.405386 ],
    [ u"ru",u"Zapadnaya Dvina",9963,56.259014,32.074541 ],
    [ u"ru",u"Zaplavnoye",3693,48.7048,45.0229 ],
    [ u"ru",u"Zaplyusye",1354,58.437795,29.73356 ],
    [ u"ru",u"Zapolyarnyy",4476,67.483333,63.75 ],
    [ u"ru",u"Zapolyarnyy",17790,69.415408,30.813551 ],
    [ u"ru",u"Zaprudnya",12517,56.566667,37.433333 ],
    [ u"ru",u"Zaraysk",24638,54.760504,38.878407 ],
    [ u"ru",u"Zarechnyy",9806,51.851388,107.514449 ],
    [ u"ru",u"Zarechnyy",1335,57.469313,42.284308 ],
    [ u"ru",u"Zarechnyy",62139,53.133333,46.583333 ],
    [ u"ru",u"Zarechnyy",3069,53.730596,39.594373 ],
    [ u"ru",u"Zarechnyy",27759,56.7878,61.3633 ],
    [ u"ru",u"Zarinsk",52210,53.7074,84.9493 ],
    [ u"ru",u"Zarubino",1612,58.735,33.475556 ],
    [ u"ru",u"Zarubino",3438,42.63,131.092222 ],
    [ u"ru",u"Zarya",1194,60.0077,48.029571 ],
    [ u"ru",u"Zasechnoye",4733,53.109201,45.079356 ],
    [ u"ru",u"Zasheyek",983,67.419523,32.536585 ],
    [ u"ru",u"Zasosna",4287,50.6307,38.3965 ],
    [ u"ru",u"Zaterechnyy",7835,44.793056,45.209722 ],
    [ u"ru",u"Zaton",3157,53.293611,83.807222 ],
    [ u"ru",u"Zauralskiy",7777,54.7855,61.2421 ],
    [ u"ru",u"Zavetnoye",6711,47.119444,43.890278 ],
    [ u"ru",u"Zavetnoye",3932,44.7492,41.5995 ],
    [ u"ru",u"Zavetnyy",4486,44.9316,41.1373 ],
    [ u"ru",u"Zavety Ilicha",9153,49.029421,140.249375 ],
    [ u"ru",u"Zavety Ilicha",5758,56.05,37.85 ],
    [ u"ru",u"Zavitinsk",13198,50.111789,129.443761 ],
    [ u"ru",u"Zavodoukovsk",25683,56.504205,66.551531 ],
    [ u"ru",u"Zavodouspenskoye",1441,56.862565,65.015533 ],
    [ u"ru",u"Zavodskoy",14865,43.442778,132.253333 ],
    [ u"ru",u"Zavodskoy",8948,48.403722,40.260644 ],
    [ u"ru",u"Zavodskoy",14833,42.983502,44.687646 ],
    [ u"ru",u"Zavolzhsk",12847,57.482297,42.137786 ],
    [ u"ru",u"Zavolzhye",43700,56.640511,43.394458 ],
    [ u"ru",u"Zavoronezhskoye",5645,52.8801,40.5526 ],
    [ u"ru",u"Zavyalovo",7393,52.833333,80.866667 ],
    [ u"ru",u"Zavyalovo",7374,56.791958,53.376118 ],
    [ u"ru",u"Zaykovo",4731,57.5613,62.756809 ],
    [ u"ru",u"Zaymishche",4942,52.7264,32.2334 ],
    [ u"ru",u"Zayukovo",10559,43.616111,43.333889 ],
    [ u"ru",u"Zdvinsk",5539,54.702059,78.661053 ],
    [ u"ru",u"Zelenchukskaya",21117,43.85804,41.5894 ],
    [ u"ru",u"Zelenets",3040,61.884849,50.748925 ],
    [ u"ru",u"Zelenoborskiy",7207,66.845,32.362222 ],
    [ u"ru",u"Zelenoborsk",2252,61.466944,64.033333 ],
    [ u"ru",u"Zelenodolsk",101131,55.84376,48.517837 ],
    [ u"ru",u"Zelenogorskiy",5249,55.033333,87 ],
    [ u"ru",u"Zelenogorsk",11867,60.199679,29.701834 ],
    [ u"ru",u"Zelenogradskiy",2155,56.1,37.916667 ],
    [ u"ru",u"Zelenogradsk",12846,54.958926,20.476684 ],
    [ u"ru",u"Zelenograd",228298,56.001111,37.209167 ],
    [ u"ru",u"Zelenokumsk",41307,44.406944,43.880556 ],
    [ u"ru",u"Zelënyy Bor",2604,53.666667,91.666667 ],
    [ u"ru",u"Zemetchino",11928,53.497296,42.616319 ],
    [ u"ru",u"Zemlyansk",3111,51.9041,38.7334 ],
    [ u"ru",u"Zenzeli",3147,45.924067,47.047386 ],
    [ u"ru",u"Zernograd",29268,46.845176,40.308342 ],
    [ u"ru",u"Zeya",26999,53.75,127.266667 ],
    [ u"ru",u"Zhadovka",2098,53.574644,46.949846 ],
    [ u"ru",u"Zharkovskiy",4833,55.849,32.2697 ],
    [ u"ru",u"Zhatay",8131,62.159444,129.829444 ],
    [ u"ru",u"Zhavoronki",2899,55.649425,37.101007 ],
    [ u"ru",u"Zhdankovskiy",3046,53.753208,38.179514 ],
    [ u"ru",u"Zheleznodorozhnyy",7337,55.1024,61.4867 ],
    [ u"ru",u"Zheleznodorozhnyy",7629,57.912222,102.765278 ],
    [ u"ru",u"Zheleznodorozhnyy",2984,54.363258,21.305698 ],
    [ u"ru",u"Zheleznodorozhnyy",16404,62.589988,50.859388 ],
    [ u"ru",u"Zheleznogorsk-Ilimskiy",28456,56.5768,104.1217 ],
    [ u"ru",u"Zheleznogorsk",97902,52.331,35.3711 ],
    [ u"ru",u"Zheleznovodsk",24632,44.139444,43.019722 ],
    [ u"ru",u"Zhelnino",684,56.202298,43.365068 ],
    [ u"ru",u"Zhemchuzhnyy",802,54.494167,90.148056 ],
    [ u"ru",u"Zhemtala",3266,43.284076,43.655855 ],
    [ u"ru",u"Zherdevka",16019,51.84687,41.458318 ],
    [ u"ru",u"Zheshart",9534,62.07314,49.573348 ],
    [ u"ru",u"Zhigalovo",5272,54.809722,105.157778 ],
    [ u"ru",u"Zhigansk",3237,66.769722,123.371111 ],
    [ u"ru",u"Zhiletovo",2998,54.692161,36.022248 ],
    [ u"ru",u"Zhireken",3766,52.8249,117.3076 ],
    [ u"ru",u"Zhirnovsk",17887,50.984482,44.773474 ],
    [ u"ru",u"Zhirnov",6069,48.170886,41.126082 ],
    [ u"ru",u"Zhiryatino",2324,53.2228,33.7306 ],
    [ u"ru",u"Zhitnevo",3193,55.342327,37.914637 ],
    [ u"ru",u"Zhizdra",5737,53.745961,34.739506 ],
    [ u"ru",u"Zhukovka",19691,53.533946,33.727979 ],
    [ u"ru",u"Zhukovo",12170,55.031783,36.744017 ],
    [ u"ru",u"Zhukovskiy",101253,55.595278,38.120278 ],
    [ u"ru",u"Zilair",5872,52.2332,57.4392 ],
    [ u"ru",u"Zima",33324,53.885556,102.046389 ],
    [ u"ru",u"Zimovniki",17678,47.1474,42.4721 ],
    [ u"ru",u"Zirgan",4083,53.2222,55.9185 ],
    [ u"ru",u"Zlatoustovsk",823,52.963889,133.596667 ],
    [ u"ru",u"Zlatoust",191369,55.171111,59.650833 ],
    [ u"ru",u"Zlynka",5261,52.4267,31.7378 ],
    [ u"ru",u"Zmeinogorsk",11514,51.156667,82.195 ],
    [ u"ru",u"Zmeyskaya",6533,43.336168,44.15733 ],
    [ u"ru",u"Zmievka",6288,52.666972,36.374258 ],
    [ u"ru",u"Znamenka",11938,52.897887,35.977032 ],
    [ u"ru",u"Znamenka",8940,52.4167,41.431079 ],
    [ u"ru",u"Znamenskoye",9641,43.678975,45.128674 ],
    [ u"ru",u"Znamenskoye",5391,57.128056,73.828214 ],
    [ u"ru",u"Znamenskoye",1950,53.278691,35.690549 ],
    [ u"ru",u"Znamensk",4359,54.609481,21.208036 ],
    [ u"ru",u"Zolnoye",1797,53.4421,49.7978 ],
    [ u"ru",u"Zolotinka",548,56.1813,124.8724 ],
    [ u"ru",u"Zolotkovo",3655,55.5113,41.0811 ],
    [ u"ru",u"Zolotukhino",4886,52.084204,36.377766 ],
    [ u"ru",u"Zolskaya",8865,43.908611,43.301111 ],
    [ u"ru",u"Zonalnaya Stantsiya",5050,56.430278,85.012778 ],
    [ u"ru",u"Zonalnoye",3500,52.6665,84.9331 ],
    [ u"ru",u"Zubova Polyana",10119,54.0771,42.8372 ],
    [ u"ru",u"Zubtsov",7397,56.175335,34.589349 ],
    [ u"ru",u"Zubutli-Miatli",4918,43.198859,46.812413 ],
    [ u"ru",u"Zudilovo",3144,53.4927,83.8937 ],
    [ u"ru",u"Zvenigorod",11628,55.734015,36.859182 ],
    [ u"ru",u"Zvenigovo",12484,55.9468,48.0841 ],
    [ u"ru",u"Zverevo",24979,48.021083,40.122815 ],
    [ u"ru",u"Zverinogolovskoye",4400,54.458611,64.854167 ],
    [ u"ru",u"Zykovo",5365,55.9533,93.1507 ],
    [ u"ru",u"Zykovo",1059,54.068526,45.086329 ],
    [ u"ru",u"Zyryanka",3627,65.75,150.85 ],
    [ u"ru",u"Zyryanovskiy",896,57.733333,61.7 ],
    [ u"ru",u"Zyryanskoye",6285,56.8306,86.6258 ],
    [ u"ru",u"Zyukayka",4556,58.204156,54.707839 ],
    [ u"ru",u"Zyuzelskiy",1311,56.4856,60.1331 ],
    [ u"rw",u"Butare",89709,-2.5966667,29.7394444 ],
    [ u"rw",u"Byumba",70586,-1.5775,30.0625 ],
    [ u"rw",u"Cyangugu",63883,-2.4833333,28.8966667 ],
    [ u"rw",u"Gikongoro",33832,-2.4688889,29.5675 ],
    [ u"rw",u"Gisenyi",83718,-1.7027778,29.2563889 ],
    [ u"rw",u"Gitarama",87613,-2.0744444,29.7566667 ],
    [ u"rw",u"Kibungo",46235,-2.1644444,30.5419444 ],
    [ u"rw",u"Kibuye",48024,-2.0555556,29.3497222 ],
    [ u"rw",u"Kigali",745526,-1.9536111,30.0605556 ],
    [ u"rw",u"Nyanza",56679,-2.5833333,29.7166667 ],
    [ u"rw",u"Nyanza",56679,-2.3580556,29.7386111 ],
    [ u"rw",u"Ruhengeri",86737,-1.4833333,29.6166667 ],
    [ u"rw",u"Rwamagana",50076,-1.9525,30.4377778 ],
    [ u"sa",u"Abha",142255,18.216389,42.505278 ],
    [ u"sa",u"Buqayq",37696,25.937103,49.677613 ],
    [ u"sa",u"Buraydah",341981,26.325986,43.974966 ],
    [ u"sa",u"Jiddah",2545728,21.516944,39.219167 ],
    [ u"sa",u"Jizan",79946,16.889167,42.551111 ],
    [ u"sa",u"Mecca",1199659,21.426667,39.826111 ],
    [ u"sa",u"Najran",125637,17.466667,44.1 ],
    [ u"sa",u"Riyadh",3469290,24.653664,46.71522 ],
    [ u"sa",u"Sabya",49398,17.149496,42.625368 ],
    [ u"sa",u"Safwah",43946,26.649862,49.952228 ],
    [ u"sa",u"Sakakah",93282,29.969742,40.206414 ],
    [ u"sa",u"Sayhat",68425,26.48522,50.040455 ],
    [ u"sa",u"Tabuk",355469,28.399804,36.571505 ],
    [ u"sa",u"Tarut",44849,26.573316,50.036936 ],
    [ u"sa",u"Turayf",32654,31.672516,38.663735 ],
    [ u"sa",u"Umm Lajj",31468,25.021264,37.268502 ],
    [ u"sb",u"Auki",4336,-8.7666667,160.7 ],
    [ u"sb",u"Buala",2689,-8.1333333,159.5833333 ],
    [ u"sb",u"Gizo",6155,-8.1,156.85 ],
    [ u"sb",u"Honiara",56312,-9.4333333,159.95 ],
    [ u"sb",u"Kirakira",1122,-10.45,161.9166667 ],
    [ u"sb",u"Lata",539,-10.7166667,165.8333333 ],
    [ u"sb",u"Tulagi",1472,-9.1,160.15 ],
    [ u"sc",u"Victoria",26361,-4.6166667,55.45 ],
    [ u"sd",u"Abu Jubayhah",21791,11.45,31.2333333 ],
    [ u"sd",u"Abu Zabad",15304,12.35,29.25 ],
    [ u"sd",u"Babanusah",29637,11.3333333,27.8 ],
    [ u"sd",u"Bara",16969,13.7,30.3666667 ],
    [ u"sd",u"Barbar",22395,18.0166667,33.9833333 ],
    [ u"sd",u"Bentiu",7653,9.2333333,29.8333333 ],
    [ u"sd",u"Doka",19821,13.5166667,35.7666667 ],
    [ u"sd",u"Galgani",9472,12.45,34.1833333 ],
    [ u"sd",u"Gogrial",38572,8.5333333,28.1166667 ],
    [ u"sd",u"Juba",163455,4.85,31.6166667 ],
    [ u"sd",u"Kaduqli",87677,11.0166667,29.7166667 ],
    [ u"sd",u"Kapoeta",7042,4.7716667,33.5902778 ],
    [ u"sd",u"Kassala",401514,15.4558333,36.3988889 ],
    [ u"sd",u"Khartoum",1974780,15.5880556,32.5341667 ],
    [ u"sd",u"Kinanah",26233,14.0333333,33.1666667 ],
    [ u"sd",u"Kusti",345102,13.1666667,32.6666667 ],
    [ u"sd",u"Kutum",9849,14.2,24.6666667 ],
    [ u"sd",u"Ler",10486,8.3,30.1333333 ],
    [ u"sd",u"Malakal",160893,9.5369444,31.6561111 ],
    [ u"sd",u"Marabba",12108,12.35,32.1833333 ],
    [ u"sd",u"Marawi",10234,18.4833333,31.8166667 ],
    [ u"sd",u"Maridi",14224,4.9147222,29.4769444 ],
    [ u"sd",u"Rabak",135389,13.15,32.7333333 ],
    [ u"sd",u"Raga",3700,8.4666667,25.6833333 ],
    [ u"sd",u"Sawakin",28570,19.1038889,37.33 ],
    [ u"sd",u"Sinjah",44626,13.15,33.9333333 ],
    [ u"sd",u"Sinkat",12547,18.8372222,36.8327778 ],
    [ u"sd",u"Sinnar",130138,13.55,33.6333333 ],
    [ u"sd",u"Tabat",10976,14.6666667,33.0833333 ],
    [ u"sd",u"Talawdi",13188,10.6363889,30.3797222 ],
    [ u"sd",u"Tambul",10489,14.9333333,33.4 ],
    [ u"sd",u"Tambura",9484,5.6,27.4666667 ],
    [ u"sd",u"Tandalti",27275,13.0166667,31.8666667 ],
    [ u"sd",u"Tawkar",22251,18.4333333,37.7333333 ],
    [ u"sd",u"Tonj",17338,7.2733333,28.6838889 ],
    [ u"sd",u"Torit",20048,4.4133333,32.5677778 ],
    [ u"sd",u"Umm Durman",2810328,15.6361111,32.4372222 ],
    [ u"sd",u"Umm Jarr",9038,13.8166667,32.4 ],
    [ u"sd",u"Umm Kaddadah",10979,13.6,26.7 ],
    [ u"sd",u"Umm Ruwabah",55742,12.9,31.2166667 ],
    [ u"sd",u"Uwayl",38745,8.7666667,27.4 ],
    [ u"sd",u"Wad Madani",332752,14.4,33.5333333 ],
    [ u"sd",u"Wad Rawah",10348,15.1602778,33.1397222 ],
    [ u"sd",u"Wagar",11950,16.1527778,36.2041667 ],
    [ u"sd",u"Waw",127400,7.7,28.0 ],
    [ u"sd",u"Yambio",40382,4.5705556,28.4163889 ],
    [ u"sd",u"Yei",40382,4.0913889,30.6786111 ],
    [ u"sd",u"Yirol",11646,6.5566667,30.5036111 ],
    [ u"se",u"Åkersberga",26785,59.483333,18.3 ],
    [ u"se",u"Alingsås",22788,57.933333,12.516667 ],
    [ u"se",u"Ängelholm",22385,56.25,12.866667 ],
    [ u"se",u"Arvika",13666,59.666667,12.566667 ],
    [ u"se",u"Avesta",14110,60.15,16.2 ],
    [ u"se",u"Bålsta",13495,59.583333,17.5 ],
    [ u"se",u"Boden",18225,65.833333,21.7 ],
    [ u"se",u"Bollnäs",12145,61.35,16.366667 ],
    [ u"se",u"Boo",21761,59.333333,18.283333 ],
    [ u"se",u"Borås",63223,57.716667,12.916667 ],
    [ u"se",u"Borlänge",38757,60.483333,15.416667 ],
    [ u"se",u"Enköping",19733,59.633333,17.066667 ],
    [ u"se",u"Eskilstuna",59016,59.366667,16.5 ],
    [ u"se",u"Eslöv",15898,55.833333,13.333333 ],
    [ u"se",u"Fagersta",10432,60,15.783333 ],
    [ u"se",u"Falkenberg",18407,56.898056,12.501944 ],
    [ u"se",u"Falköping",15054,58.166667,13.55 ],
    [ u"se",u"Falun",35385,60.6,15.633333 ],
    [ u"se",u"Finspång",11989,58.716667,15.783333 ],
    [ u"se",u"Gävle",68635,60.666667,17.166667 ],
    [ u"se",u"Göteborg",515253,57.716667,11.966667 ],
    [ u"se",u"Halmstad",55658,56.671389,12.855556 ],
    [ u"se",u"Härnösand",17016,62.636111,17.941111 ],
    [ u"se",u"Hässleholm",17050,56.15,13.766667 ],
    [ u"se",u"Helsingborg",91025,56.05,12.7 ],
    [ u"se",u"Höganäs",13461,56.2,12.55 ],
    [ u"se",u"Hudiksvall",14621,61.733333,17.1125 ],
    [ u"se",u"Jönköping",83202,57.783333,14.183333 ],
    [ u"se",u"Kalmar",34745,56.666667,16.366667 ],
    [ u"se",u"Karlshamn",18161,56.166667,14.85 ],
    [ u"se",u"Karlskoga",26949,59.333333,14.516667 ],
    [ u"se",u"Karlskrona",32309,56.166667,15.583333 ],
    [ u"se",u"Karlstad",57779,59.366667,13.5 ],
    [ u"se",u"Katrineholm",21108,59,16.2 ],
    [ u"se",u"Kinna",14211,57.5,12.683333 ],
    [ u"se",u"Kiruna",17806,67.85,20.216667 ],
    [ u"se",u"Köping",16617,59.516667,16 ],
    [ u"se",u"Kristianstad",32188,56.033333,14.133333 ],
    [ u"se",u"Kristinehamn",17000,59.333333,14.116667 ],
    [ u"se",u"Kumla",12756,59.133333,15.133333 ],
    [ u"se",u"Kungälv",21262,57.866667,11.966667 ],
    [ u"se",u"Kungsbacka",18698,57.483333,12.066667 ],
    [ u"se",u"Landskrona",27889,55.866667,12.833333 ],
    [ u"se",u"Lerum",15949,57.766667,12.266667 ],
    [ u"se",u"Lidingö",30930,59.366667,18.133333 ],
    [ u"se",u"Lidköping",24586,58.5,13.166667 ],
    [ u"se",u"Lindome",10942,57.566667,12.083333 ],
    [ u"se",u"Linköping",96732,58.416667,15.616667 ],
    [ u"se",u"Ljungby",14272,56.833333,13.933333 ],
    [ u"se",u"Ludvika",13638,60.15,15.183333 ],
    [ u"se",u"Luleå",45551,65.583333,22.15 ],
    [ u"se",u"Lund",76263,55.7,13.183333 ],
    [ u"se",u"Malmö",261549,55.6,13 ],
    [ u"se",u"Mariestad",14891,58.7,13.816667 ],
    [ u"se",u"Märsta",23194,59.616667,17.85 ],
    [ u"se",u"Mjölby",11560,58.316667,15.133333 ],
    [ u"se",u"Mölnlycke",14653,57.65,12.133333 ],
    [ u"se",u"Motala",29715,58.55,15.05 ],
    [ u"se",u"Nässjö",15954,57.65,14.683333 ],
    [ u"se",u"Norrköping",82903,58.6,16.183333 ],
    [ u"se",u"Norrtälje",16914,59.766667,18.7 ],
    [ u"se",u"Nybro",12059,56.75,15.9 ],
    [ u"se",u"Nyköping",27582,58.75,17 ],
    [ u"se",u"Nynäshamn",13616,58.904444,17.946389 ],
    [ u"se",u"Örebro",98573,59.283333,15.216667 ],
    [ u"se",u"Örnsköldsvik",27749,63.3,18.716667 ],
    [ u"se",u"Oskarshamn",16613,57.266667,16.433333 ],
    [ u"se",u"Östersund",42940,63.183333,14.65 ],
    [ u"se",u"Oxelösund",10690,58.666667,17.1 ],
    [ u"se",u"Piteå",22044,65.333333,21.5 ],
    [ u"se",u"Ronneby",11618,56.2,15.3 ],
    [ u"se",u"Sala",12015,59.916667,16.6 ],
    [ u"se",u"Sandviken",22111,60.616667,16.766667 ],
    [ u"se",u"Skara",10608,58.366667,13.416667 ],
    [ u"se",u"Skellefteå",30839,64.766667,20.95 ],
    [ u"se",u"Skoghall",12845,59.333333,13.433333 ],
    [ u"se",u"Skövde",32639,58.4,13.85 ],
    [ u"se",u"Söderhamn",12022,61.3,17.05 ],
    [ u"se",u"Södertälje",59977,59.2,17.616667 ],
    [ u"se",u"Solna",59098,59.366667,18.016667 ],
    [ u"se",u"Staffanstorp",14192,55.633333,13.216667 ],
    [ u"se",u"Stockholm",1253309,59.333333,18.05 ],
    [ u"se",u"Strängnäs",12555,59.383333,17.033333 ],
    [ u"se",u"Sundsvall",48463,62.383333,17.3 ],
    [ u"se",u"Täby",58123,59.5,18.05 ],
    [ u"se",u"Timrå",10168,62.477778,17.306944 ],
    [ u"se",u"Tranås",13765,58.05,14.983333 ],
    [ u"se",u"Trelleborg",25494,55.366667,13.166667 ],
    [ u"se",u"Trollhättan",44522,58.266667,12.3 ],
    [ u"se",u"Tumba",35780,59.2,17.816667 ],
    [ u"se",u"Uddevalla",30283,58.366667,11.933333 ],
    [ u"se",u"Umeå",74005,63.833333,20.25 ],
    [ u"se",u"Upplands-Väsby",36535,59.516667,17.9 ],
    [ u"se",u"Uppsala",127734,59.85,17.633333 ],
    [ u"se",u"Uppsala",127734,59.866667,17.633333 ],
    [ u"se",u"Vallentuna",26733,59.533333,18.083333 ],
    [ u"se",u"Vänersborg",21836,58.366667,12.316667 ],
    [ u"se",u"Varberg",25816,57.1,12.25 ],
    [ u"se",u"Värnamo",17950,57.183333,14.033333 ],
    [ u"se",u"Västerås",107194,59.616667,16.55 ],
    [ u"se",u"Västerhaninge",14620,59.116667,18.1 ],
    [ u"se",u"Västervik",19860,57.75,16.633333 ],
    [ u"se",u"Växjö",53607,56.883333,14.816667 ],
    [ u"se",u"Vetlanda",12068,57.433333,15.066667 ],
    [ u"se",u"Visby",21970,57.633333,18.3 ],
    [ u"se",u"Ystad",17266,55.416667,13.816667 ],
    [ u"sg",u"Singapore",3547809,1.2930556,103.8558333 ],
    [ u"sh",u"Edinburgh",271,-37.05,-12.3 ],
    [ u"sh",u"Georgetown",538,-7.9333333,-14.4166667 ],
    [ u"sh",u"Jamestown",637,-15.9333333,-5.7166667 ],
    [ u"si",u"Ajdovscina",6527,45.8875,13.9111111 ],
    [ u"si",u"Ankaran",2895,45.5786111,13.7361111 ],
    [ u"si",u"Beltinci",2258,46.6052778,16.2405556 ],
    [ u"si",u"Bled",5205,46.3691667,14.1136111 ],
    [ u"si",u"Borovnica",2115,45.9158333,14.3630556 ],
    [ u"si",u"Brezice",6298,45.9033333,15.5911111 ],
    [ u"si",u"Brezovica pri Ljubljani",2345,46.0333333,14.4 ],
    [ u"si",u"Celje",37115,46.2361111,15.2675 ],
    [ u"si",u"Cerknica",3531,45.7930556,14.3625 ],
    [ u"si",u"Crna na Koroskem",2346,46.4666667,15.85 ],
    [ u"si",u"Crnomelj",5840,45.5711111,15.1888889 ],
    [ u"si",u"Domzale",11647,46.1380556,14.5977778 ],
    [ u"si",u"Dravograd",3381,46.5880556,15.0191667 ],
    [ u"si",u"Gornja Radgona",3194,46.6733333,15.9922222 ],
    [ u"si",u"Grosuplje",6256,45.9555556,14.6588889 ],
    [ u"si",u"Hrastnik",5800,46.1461111,15.0813889 ],
    [ u"si",u"Idrija",5784,46.0027778,14.0305556 ],
    [ u"si",u"Ig",2078,45.9602778,14.5288889 ],
    [ u"si",u"Ilirska Bistrica",4846,45.5697222,14.2408333 ],
    [ u"si",u"Izola",10355,45.5369444,13.6619444 ],
    [ u"si",u"Jagodje",2143,45.5322222,13.655 ],
    [ u"si",u"Jesenice",12511,46.4305556,14.0669444 ],
    [ u"si",u"Kamnik",12584,46.2197222,14.6094444 ],
    [ u"si",u"Kocevje",8841,45.6433333,14.8633333 ],
    [ u"si",u"Koper",23273,45.5469444,13.7294444 ],
    [ u"si",u"Kranj",34950,46.2411111,14.3616667 ],
    [ u"si",u"Kranjska Gora",1414,46.4838889,13.7894444 ],
    [ u"si",u"Kromberk",1813,45.9608333,13.6655556 ],
    [ u"si",u"Krsko",6926,45.9530556,15.4894444 ],
    [ u"si",u"Lasko",3389,46.1519444,15.2363889 ],
    [ u"si",u"Lenart",2567,46.5761111,15.8313889 ],
    [ u"si",u"Lendava",3377,46.5613889,16.4505556 ],
    [ u"si",u"Lesce",2788,46.3611111,14.1577778 ],
    [ u"si",u"Limbus",1983,46.5536111,15.5836111 ],
    [ u"si",u"Litija",6459,46.0586111,14.8225 ],
    [ u"si",u"Ljubljana",255115,46.0552778,14.5144444 ],
    [ u"si",u"Ljutomer",3387,46.5208333,16.1975 ],
    [ u"si",u"Logatec",8014,45.9144444,14.2258333 ],
    [ u"si",u"Lovrenc na Pohorju",2003,46.5405556,15.3930556 ],
    [ u"si",u"Lucija",6036,45.4963889,13.6136111 ],
    [ u"si",u"Maribor",89056,46.5547222,15.6466667 ],
    [ u"si",u"Medvode",4954,46.1333333,14.4333333 ],
    [ u"si",u"Menges",5742,46.1669444,14.575 ],
    [ u"si",u"Metlika",3237,45.6472222,15.3141667 ],
    [ u"si",u"Mezica",3445,46.5213889,14.8544444 ],
    [ u"si",u"Miklavz na Dravskem Polju",3799,46.5058333,15.6972222 ],
    [ u"si",u"Mislinja",1852,46.4411111,15.1955556 ],
    [ u"si",u"Mozirje",1957,46.3394444,14.9633333 ],
    [ u"si",u"Murska Sobota",12412,46.6625,16.1663889 ],
    [ u"si",u"Muta",2410,46.6113889,15.1661111 ],
    [ u"si",u"Nova Gorica",12748,45.9613889,13.6436111 ],
    [ u"si",u"Novo Mesto",22417,45.7925,15.1647222 ],
    [ u"si",u"Ormoz",2198,46.4113889,16.1544444 ],
    [ u"si",u"Pesnica pri Mariboru",813,46.6069444,15.6766667 ],
    [ u"si",u"Piran",4032,45.5277778,13.5705556 ],
    [ u"si",u"Pivka",2051,45.6794444,14.1966667 ],
    [ u"si",u"Polzela",2363,46.2833333,15.0666667 ],
    [ u"si",u"Portoroz",2769,45.5161111,13.5883333 ],
    [ u"si",u"Postojna",8626,45.7769444,14.2166667 ],
    [ u"si",u"Prevalje",4469,46.5469444,14.9208333 ],
    [ u"si",u"Ptuj",18141,46.4213889,15.8697222 ],
    [ u"si",u"Race",2246,46.4519444,15.6813889 ],
    [ u"si",u"Radece",2291,46.0680556,15.1838889 ],
    [ u"si",u"Radenci",2149,46.6472222,16.0441667 ],
    [ u"si",u"Radlje ob Dravi",2661,46.6141667,15.2263889 ],
    [ u"si",u"Radovljica",5978,46.3444444,14.1744444 ],
    [ u"si",u"Rakek",1966,45.8133333,14.3111111 ],
    [ u"si",u"Ravne",7671,45.9625,15.0127778 ],
    [ u"si",u"Rence",1836,45.89,13.6686111 ],
    [ u"si",u"Ribnica",3482,45.7386111,14.7275 ],
    [ u"si",u"Rogaska Slatina",4724,46.2375,15.6397222 ],
    [ u"si",u"Ruse",4497,46.5394444,15.5158333 ],
    [ u"si",u"Sempeter",3886,45.9275,13.6411111 ],
    [ u"si",u"Sempeter",1901,46.2563889,15.1219444 ],
    [ u"si",u"Sencur",2745,46.2455556,14.4197222 ],
    [ u"si",u"Senovo",2404,46.0236111,15.4769444 ],
    [ u"si",u"Sentjur",4710,46.2172222,15.3975 ],
    [ u"si",u"Sevnica",4836,46.0077778,15.3155556 ],
    [ u"si",u"Sezana",4797,45.7069444,13.8722222 ],
    [ u"si",u"Skofja Loka",12013,46.1672222,14.3088889 ],
    [ u"si",u"Skofljica",1972,45.9833333,14.5766667 ],
    [ u"si",u"Slovenj Gradec",7933,46.5102778,15.0805556 ],
    [ u"si",u"Slovenska Bistrica",6561,46.3927778,15.5744444 ],
    [ u"si",u"Slovenske Konjice",4830,46.3366667,15.4258333 ],
    [ u"si",u"Solkan",3252,45.9713889,13.6494444 ],
    [ u"si",u"Sostanj",2776,46.38,15.0486111 ],
    [ u"si",u"Spodnja Idrija",1853,46.0319444,14.0272222 ],
    [ u"si",u"Spodnje Hoce",2107,46.5,15.65 ],
    [ u"si",u"Store",1872,46.2208333,15.3138889 ],
    [ u"si",u"Straza",1978,45.78,15.0727778 ],
    [ u"si",u"Tolmin",3684,46.1863889,13.7361111 ],
    [ u"si",u"Trbovlje",15993,46.155,15.0533333 ],
    [ u"si",u"Trebnje",3162,45.9041667,15.0216667 ],
    [ u"si",u"Trzic",3925,46.3666667,14.3166667 ],
    [ u"si",u"Trzin",3420,46.1333333,14.5666667 ],
    [ u"si",u"Velenje",26426,46.3591667,15.1102778 ],
    [ u"si",u"Verd",1846,45.9566667,14.3058333 ],
    [ u"si",u"Vir",3102,45.9525,14.8177778 ],
    [ u"si",u"Vnanje Gorice",1837,46.0072222,14.4219444 ],
    [ u"si",u"Vojnik",1964,46.2933333,15.3033333 ],
    [ u"si",u"Vrhnika",7623,45.9661111,14.2955556 ],
    [ u"si",u"Vrtojba",2385,45.9125,13.6341667 ],
    [ u"si",u"Zagorje ob Savi",6799,46.1341667,15.0013889 ],
    [ u"si",u"Zalec",4859,46.2536111,15.1675 ],
    [ u"si",u"Zelezniki",3175,46.2333333,14.1666667 ],
    [ u"si",u"Ziri",3587,46.0422222,14.1072222 ],
    [ u"si",u"Zrece",2874,46.3822222,15.3791667 ],
    [ u"sj",u"Barentsburg",576,78.0666667,14.2333333 ],
    [ u"sj",u"Longyearbyen",1232,78.2166667,15.6333333 ],
    [ u"sj",u"Ny-Ålesund",40,78.9333333,11.95 ],
    [ u"sk",u"Banovce",21328,48.7166667,18.2666667 ],
    [ u"sk",u"Banská Bystrica",82336,48.7333333,19.15 ],
    [ u"sk",u"Banska Stiavnica",10874,48.45,18.9 ],
    [ u"sk",u"Bardejov",34209,49.2833333,21.2833333 ],
    [ u"sk",u"Bojnice",5006,48.7833333,18.5833333 ],
    [ u"sk",u"Bratislava",423737,48.15,17.1166667 ],
    [ u"sk",u"Brezno",23055,48.8166667,19.65 ],
    [ u"sk",u"Brezová pod Bradlom",5567,48.6666667,17.5333333 ],
    [ u"sk",u"Bytca",11550,49.2166667,18.5666667 ],
    [ u"sk",u"Cadca",27281,49.4333333,18.7833333 ],
    [ u"sk",u"Cierna nad Tisou",4645,48.4333333,22.1 ],
    [ u"sk",u"Detva",15122,48.5666667,19.4166667 ],
    [ u"sk",u"Dobsina",4896,48.8166667,20.3666667 ],
    [ u"sk",u"Dolný Kubín",20401,49.2,19.3 ],
    [ u"sk",u"Dunajská Streda",23639,47.9833333,17.6166667 ],
    [ u"sk",u"Galanta",16365,48.2,17.7166667 ],
    [ u"sk",u"Gbely",5223,48.7166667,17.1333333 ],
    [ u"sk",u"Gelnica",6404,48.85,20.9333333 ],
    [ u"sk",u"Giraltovce",4189,49.1166667,21.5166667 ],
    [ u"sk",u"Handlová",18018,48.7333333,18.7666667 ],
    [ u"sk",u"Hlohovec",23930,48.4333333,17.8 ],
    [ u"sk",u"Holic",11416,48.8,17.1666667 ],
    [ u"sk",u"Hrinova",8289,48.5833333,19.5333333 ],
    [ u"sk",u"Humenné",35367,48.9333333,21.9166667 ],
    [ u"sk",u"Hurbanovo",8153,47.8666667,18.2 ],
    [ u"sk",u"Ilava",5411,49.0,18.2333333 ],
    [ u"sk",u"Kezmarok",21391,49.1333333,20.4333333 ],
    [ u"sk",u"Kolárovo",10823,47.9166667,18.0 ],
    [ u"sk",u"Komárno",37365,47.7666667,18.1333333 ],
    [ u"sk",u"Kosice",236563,48.7166667,21.25 ],
    [ u"sk",u"Kremnica",5822,48.7,18.9166667 ],
    [ u"sk",u"Krompachy",8812,48.9166667,20.8666667 ],
    [ u"sk",u"Krupina",7991,48.35,19.0666667 ],
    [ u"sk",u"Kysucké Nové Mesto",16558,49.3,18.7833333 ],
    [ u"sk",u"Leopoldov",3999,48.45,17.7666667 ],
    [ u"sk",u"Levice",37574,48.2166667,18.6 ],
    [ u"sk",u"Lipany",6130,49.15,20.9666667 ],
    [ u"sk",u"Liptovský Hrádok",8232,49.0333333,19.7333333 ],
    [ u"sk",u"Liptovsky Mikulas",33509,49.0833333,19.6166667 ],
    [ u"sk",u"Lucenec",28159,48.3333333,19.6666667 ],
    [ u"sk",u"Malacky",17773,48.4333333,17.0166667 ],
    [ u"sk",u"Martin",60817,49.0666667,18.9333333 ],
    [ u"sk",u"Medzev",3667,48.7,20.9 ],
    [ u"sk",u"Medzilaborce",6741,49.2666667,21.9166667 ],
    [ u"sk",u"Michalovce",40360,48.75,21.9333333 ],
    [ u"sk",u"Modra",8536,48.3333333,17.3166667 ],
    [ u"sk",u"Moldava nad Bodvou",9525,48.6166667,21.0 ],
    [ u"sk",u"Myjava",13142,48.75,17.5666667 ],
    [ u"sk",u"Námestovo",8135,49.4,19.5 ],
    [ u"sk",u"Nemsova",6136,48.9666667,18.1166667 ],
    [ u"sk",u"Nitra",86329,48.3166667,18.0833333 ],
    [ u"sk",u"Nova Bana",7505,48.4333333,18.65 ],
    [ u"sk",u"Nová Dubnica",12358,48.95,18.15 ],
    [ u"sk",u"Nováky",4402,48.7166667,18.55 ],
    [ u"sk",u"Nové Zámky",42044,47.9833333,18.1666667 ],
    [ u"sk",u"Partizánske",24370,48.6333333,18.3833333 ],
    [ u"sk",u"Pezinok",21343,48.2833333,17.2666667 ],
    [ u"sk",u"Podolínec",3173,49.2666667,20.5333333 ],
    [ u"sk",u"Poltár",6099,48.4333333,19.8 ],
    [ u"sk",u"Poprad",57431,49.05,20.3 ],
    [ u"sk",u"Povazska Bystrica",43936,49.1166667,18.45 ],
    [ u"sk",u"Presov",94718,49.0,21.25 ],
    [ u"sk",u"Prievidza",52987,48.7666667,18.6333333 ],
    [ u"sk",u"Púchov",18833,49.1333333,18.3333333 ],
    [ u"sk",u"Rajec",6400,49.0833333,18.6333333 ],
    [ u"sk",u"Revúca",13466,48.6833333,20.1166667 ],
    [ u"sk",u"Rimavská Sobota",25235,48.3833333,20.0333333 ],
    [ u"sk",u"Roznava",19261,48.6666667,20.5333333 ],
    [ u"sk",u"Ruzomberok",30806,49.0833333,19.3166667 ],
    [ u"sk",u"Sabinov",12290,49.1,21.1 ],
    [ u"sk",u"Sahy",8061,48.0666667,18.9666667 ],
    [ u"sk",u"Samorin",12143,48.0333333,17.3166667 ],
    [ u"sk",u"Secovce",7819,48.7,21.65 ],
    [ u"sk",u"Senec",14673,48.2166667,17.4 ],
    [ u"sk",u"Senica",21741,48.6833333,17.3666667 ],
    [ u"sk",u"Skalica",15013,48.85,17.2333333 ],
    [ u"sk",u"Sladkovicovo",6078,48.2,17.65 ],
    [ u"sk",u"Sliac",4667,48.6166667,19.1833333 ],
    [ u"sk",u"Snina",22221,48.9833333,22.15 ],
    [ u"sk",u"Sobrance",6262,48.75,22.1833333 ],
    [ u"sk",u"Spisska Bela",6136,49.1833333,20.4666667 ],
    [ u"sk",u"Spisska Nova Ves",39195,48.95,20.5666667 ],
    [ u"sk",u"Spisske Podhradie",3780,49.0,20.75 ],
    [ u"sk",u"Stará Turá",10291,48.7833333,17.7 ],
    [ u"sk",u"Strazske",4474,48.8666667,21.8333333 ],
    [ u"sk",u"Stropkov",10874,49.2,21.65 ],
    [ u"sk",u"Stupava",8063,48.2833333,17.0333333 ],
    [ u"sk",u"Sturovo",11708,47.8,18.7333333 ],
    [ u"sk",u"Surany",10491,48.0833333,18.1833333 ],
    [ u"sk",u"Svätý Jur",4614,48.25,17.2166667 ],
    [ u"sk",u"Svidník",12428,49.3,21.5666667 ],
    [ u"sk",u"Svit",7445,49.0666667,20.2 ],
    [ u"sk",u"Svodín",2649,47.9166667,18.5 ],
    [ u"sk",u"Tisovec",4215,48.6833333,19.95 ],
    [ u"sk",u"Tlmace",4305,48.2833333,18.5333333 ],
    [ u"sk",u"Trebisov",22947,48.6333333,21.7166667 ],
    [ u"sk",u"Trencianske Teplice",4438,48.9166667,18.1666667 ],
    [ u"sk",u"Trencin",58278,48.9,18.0333333 ],
    [ u"sk",u"Trnava",69785,48.3666667,17.6 ],
    [ u"sk",u"Trstená",7461,49.3666667,19.6166667 ],
    [ u"sk",u"Turcianske Teplice",7031,48.8666667,18.8666667 ],
    [ u"sk",u"Turzovka",7854,49.4,18.6333333 ],
    [ u"sk",u"Tvrdosin",9544,49.3333333,19.5666667 ],
    [ u"sk",u"Vráble",9493,48.25,18.3166667 ],
    [ u"sk",u"Vranov",23246,48.9,21.6833333 ],
    [ u"sk",u"Vrbové",6249,48.6333333,17.7333333 ],
    [ u"sk",u"Vrútky",7298,49.1166667,18.9166667 ],
    [ u"sk",u"Zarnovica",6596,48.4833333,18.7333333 ],
    [ u"sk",u"Zeliezovce",7522,48.05,18.6666667 ],
    [ u"sk",u"Zilina",85985,49.2166667,18.7333333 ],
    [ u"sk",u"Zlaté Moravce",15618,48.3833333,18.4 ],
    [ u"sk",u"Zvolen",44502,48.5833333,19.1333333 ],
    [ u"sl",u"Alikalia",3279,9.1666667,-11.4 ],
    [ u"sl",u"Baiima",2826,7.8333333,-11.6166667 ],
    [ u"sl",u"Baoma",4836,7.7058333,-11.2033333 ],
    [ u"sl",u"Baoma",4836,8.1,-11.35 ],
    [ u"sl",u"Barma",6921,8.35,-11.3333333 ],
    [ u"sl",u"Bindi",3331,9.9166667,-11.45 ],
    [ u"sl",u"Blama",7488,7.8736111,-11.3433333 ],
    [ u"sl",u"Boajibu",6787,8.1833333,-11.3333333 ],
    [ u"sl",u"Bo",80506,7.9647222,-11.7383333 ],
    [ u"sl",u"Bomi",3583,7.2461111,-11.5258333 ],
    [ u"sl",u"Bonthe",9712,7.5263889,-12.505 ],
    [ u"sl",u"Buedu",4686,8.2802778,-10.3719444 ],
    [ u"sl",u"Bumbuna",3010,9.05,-11.7333333 ],
    [ u"sl",u"Bunumbu",6368,8.1666667,-10.8666667 ],
    [ u"sl",u"Daru",5159,7.9919444,-10.8405556 ],
    [ u"sl",u"Foindu",3848,7.4108333,-11.5422222 ],
    [ u"sl",u"Freetown",1190761,8.49,-13.2341667 ],
    [ u"sl",u"Gandorhun",7003,7.1786111,-11.7841667 ],
    [ u"sl",u"Gberia Fotombu",3171,9.8833333,-11.1666667 ],
    [ u"sl",u"Giehun",3368,7.8666667,-11.0 ],
    [ u"sl",u"Goderich",14794,8.4319444,-13.2897222 ],
    [ u"sl",u"Gorahun",3758,7.4661111,-11.2375 ],
    [ u"sl",u"Hangha",4603,7.9411111,-11.14 ],
    [ u"sl",u"Hastings",5502,8.3797222,-13.1386111 ],
    [ u"sl",u"Jojoima",2715,7.8791667,-10.7877778 ],
    [ u"sl",u"Kabala",18754,9.5833333,-11.55 ],
    [ u"sl",u"Kailahun",12195,8.2833333,-10.5666667 ],
    [ u"sl",u"Kamakwie",8468,9.5,-12.2333333 ],
    [ u"sl",u"Kambia",10279,9.1166667,-12.9166667 ],
    [ u"sl",u"Kasiri",4605,8.9372222,-13.1244444 ],
    [ u"sl",u"Kenema",70680,7.8766667,-11.1875 ],
    [ u"sl",u"Koidu",111090,8.4166667,-10.8333333 ],
    [ u"sl",u"Koindu",11096,8.2025,-10.3730556 ],
    [ u"sl",u"Kukuna",6849,9.4,-12.6666667 ],
    [ u"sl",u"Largo",4484,8.2666667,-12.15 ],
    [ u"sl",u"Lungi",7165,8.6408333,-13.2219444 ],
    [ u"sl",u"Lunsar",21650,8.6833333,-12.5333333 ],
    [ u"sl",u"Magburaka",13937,8.7166667,-11.95 ],
    [ u"sl",u"Makali",3318,8.4666667,-11.8833333 ],
    [ u"sl",u"Makeni",53930,8.5666667,-11.9666667 ],
    [ u"sl",u"Mambolo",5911,8.9230556,-13.0444444 ],
    [ u"sl",u"Mamboma",3898,7.8416667,-11.6569444 ],
    [ u"sl",u"Mange",2980,8.9166667,-12.85 ],
    [ u"sl",u"Manowa",3991,8.1666667,-10.75 ],
    [ u"sl",u"Masingbi",5902,8.7833333,-11.95 ],
    [ u"sl",u"Masoyila",3526,8.6097222,-13.19 ],
    [ u"sl",u"Mattru",7818,7.2641667,-12.1225 ],
    [ u"sl",u"Mobai",2980,7.9944444,-10.7511111 ],
    [ u"sl",u"Motema",8502,8.4333333,-11.2333333 ],
    [ u"sl",u"Moyamba",8732,8.1666667,-12.4333333 ],
    [ u"sl",u"Panguma",7321,8.1833333,-11.1333333 ],
    [ u"sl",u"Pendembu",7602,7.95,-10.9333333 ],
    [ u"sl",u"Pepel",4301,8.5816667,-13.0627778 ],
    [ u"sl",u"Peyima",4201,8.7,-11.0333333 ],
    [ u"sl",u"Port Loko",20539,8.7666667,-12.7833333 ],
    [ u"sl",u"Potoru",3238,7.5072222,-11.4786111 ],
    [ u"sl",u"Pujehun",5198,7.3505556,-11.7180556 ],
    [ u"sl",u"Rokupr",11157,8.6716667,-12.395 ],
    [ u"sl",u"Rotifunk",6331,8.2333333,-12.6833333 ],
    [ u"sl",u"Sawkta",3327,8.6319444,-13.2019444 ],
    [ u"sl",u"Segbwema",11135,8.0,-10.95 ],
    [ u"sl",u"Seidu",3483,9.0166667,-10.6 ],
    [ u"sl",u"Serabu",3194,7.7958333,-12.0536111 ],
    [ u"sl",u"Simbakoro",3905,8.6,-11.0166667 ],
    [ u"sl",u"Sumbuya",5302,7.6466667,-11.9611111 ],
    [ u"sl",u"Waterloo",21222,8.3383333,-13.0719444 ],
    [ u"sl",u"Yamandu",5524,8.1833333,-11.8 ],
    [ u"sl",u"Yele",3155,8.4166667,-11.8333333 ],
    [ u"sl",u"Yengema",17427,8.6166667,-11.05 ],
    [ u"sl",u"Yonibana",3354,8.4447222,-12.245 ],
    [ u"sl",u"Zimmi",3145,7.3152778,-11.3061111 ],
    [ u"sm",u"Acquaviva",1530,43.95,12.4166667 ],
    [ u"sm",u"Chiesanuova",952,43.9166667,12.4166667 ],
    [ u"sm",u"San Marino",4598,43.9333333,12.45 ],
    [ u"sm",u"Serravalle",9258,43.95,12.5 ],
    [ u"sn",u"Bakel",10202,14.9,-12.45 ],
    [ u"sn",u"Bambey",32874,14.7,-16.4666667 ],
    [ u"sn",u"Bignona",45918,12.8102778,-16.2263889 ],
    [ u"sn",u"Dagana",31310,16.5166667,-15.5 ],
    [ u"sn",u"Dahra",17656,15.35,-15.4833333 ],
    [ u"sn",u"Dakar",2702820,14.6708333,-17.4380556 ],
    [ u"sn",u"Diofior",6407,14.1833333,-16.6666667 ],
    [ u"sn",u"Diourbel",126400,14.6666667,-16.25 ],
    [ u"sn",u"Fatick",62987,14.3333333,-16.4166667 ],
    [ u"sn",u"Foundiougne",4718,14.1333333,-16.4666667 ],
    [ u"sn",u"Gandiaye",5984,14.2333333,-16.2666667 ],
    [ u"sn",u"Golléré",2684,16.25,-14.1 ],
    [ u"sn",u"Gossas",10244,14.5,-16.0666667 ],
    [ u"sn",u"Goudomp",10098,12.5777778,-15.8722222 ],
    [ u"sn",u"Guinguinéo",15201,14.2666667,-15.95 ],
    [ u"sn",u"Kaffrine",33572,14.1,-15.55 ],
    [ u"sn",u"Kahone",2825,14.15,-16.0333333 ],
    [ u"sn",u"Kanel",5138,15.4833333,-13.1666667 ],
    [ u"sn",u"Kaolack",289633,14.15,-16.0666667 ],
    [ u"sn",u"Kébémèr",21409,15.3666667,-16.45 ],
    [ u"sn",u"Kédougou",16612,12.4833333,-11.95 ],
    [ u"sn",u"Khombole",14762,14.7666667,-16.7 ],
    [ u"sn",u"Kolda",80632,12.8833333,-14.95 ],
    [ u"sn",u"Koungheul",14786,13.9833333,-14.8 ],
    [ u"sn",u"Linguère",10228,15.4,-15.1166667 ],
    [ u"sn",u"Louga",117333,15.6166667,-16.2166667 ],
    [ u"sn",u"Marsassoum",9116,12.8275,-15.9805556 ],
    [ u"sn",u"Matam",12277,15.6666667,-13.25 ],
    [ u"sn",u"Mbacké",78635,14.8,-15.9166667 ],
    [ u"sn",u"Mbour",194682,14.4,-16.9666667 ],
    [ u"sn",u"Mékhé",20207,15.1166667,-16.6333333 ],
    [ u"sn",u"Ndioum",5304,16.5166667,-14.65 ],
    [ u"sn",u"Nioro",21846,13.75,-15.8 ],
    [ u"sn",u"Ourossogui",9741,15.6,-13.3166667 ],
    [ u"sn",u"Oussouye",7107,12.485,-16.5469444 ],
    [ u"sn",u"Passi",4521,13.9833333,-16.2666667 ],
    [ u"sn",u"Podor",6984,16.6666667,-14.95 ],
    [ u"sn",u"Pout",29387,14.7738889,-17.0602778 ],
    [ u"sn",u"Richard Toll",91500,16.4666667,-15.6833333 ],
    [ u"sn",u"Saint-Louis",176048,16.0188889,-16.4952778 ],
    [ u"sn",u"Sédhiou",20756,12.7080556,-15.5569444 ],
    [ u"sn",u"Semmé",3717,15.2,-12.95 ],
    [ u"sn",u"Sokone",15460,13.8833333,-16.3666667 ],
    [ u"sn",u"Tambacounda",83467,13.7833333,-13.6666667 ],
    [ u"sn",u"Thiadiaye",7495,14.4166667,-16.7 ],
    [ u"sn",u"Thiès",320721,14.8,-16.9333333 ],
    [ u"sn",u"Thilogne",4968,15.9666667,-13.6 ],
    [ u"sn",u"Tivaouane",56828,14.95,-16.8166667 ],
    [ u"sn",u"Vélingara",27566,13.15,-14.1166667 ],
    [ u"sn",u"Waoundé",13688,15.2666667,-12.8666667 ],
    [ u"sn",u"Ziguinchor",255391,12.5833333,-16.2719444 ],
    [ u"so",u"Afgoye",65461,2.15,45.1166667 ],
    [ u"so",u"Afmadu",11939,0.5172222,42.0711111 ],
    [ u"so",u"Bandarbeyla",13753,9.4833333,50.8166667 ],
    [ u"so",u"Barawe",27067,1.1,44.05 ],
    [ u"so",u"Bargal",6798,11.2833333,51.0833333 ],
    [ u"so",u"Berbera",242363,10.4355556,45.0163889 ],
    [ u"so",u"Bereda",11262,11.85,51.05 ],
    [ u"so",u"Borama",38075,9.9333333,43.1833333 ],
    [ u"so",u"Bosaso",74287,11.2847222,49.1825 ],
    [ u"so",u"Bur Gabo",3096,-1.2166667,41.85 ],
    [ u"so",u"Dinsor",16149,2.4,42.9833333 ],
    [ u"so",u"Dujuma",2432,1.2533333,42.5708333 ],
    [ u"so",u"Eyl",18904,7.9666667,49.8166667 ],
    [ u"so",u"Garowe",49913,8.4,48.5 ],
    [ u"so",u"Hargeysa",478283,9.5833333,44.0666667 ],
    [ u"so",u"Hobyo",12564,5.3513889,48.5255556 ],
    [ u"so",u"Jamame",185270,0.0722222,42.7505556 ],
    [ u"so",u"Jawhar",47086,2.7666667,45.5166667 ],
    [ u"so",u"Jilib",43694,0.4958333,42.7727778 ],
    [ u"so",u"Kismayo",234884,-0.3666667,42.5333333 ],
    [ u"so",u"Mahadday Weyne",8273,2.9666667,45.5333333 ],
    [ u"so",u"Mogadishu",2590180,2.0666667,45.3666667 ],
    [ u"so",u"Odweyne",5491,9.4,45.0666667 ],
    [ u"so",u"Qandala",15923,11.4711111,49.8738889 ],
    [ u"so",u"Wajid",6666,3.8,43.25 ],
    [ u"so",u"Wanlaweyn",22022,2.6166667,44.9 ],
    [ u"so",u"Xuddur",13303,4.1166667,43.9 ],
    [ u"sr",u"Albina",4138,5.5,-54.05 ],
    [ u"sr",u"Brokopondo",2072,5.0666667,-54.9666667 ],
    [ u"sr",u"Groningen",3112,5.8,-55.4666667 ],
    [ u"sr",u"Lelydorp",17735,5.7,-55.2333333 ],
    [ u"sr",u"Mariënburg",4463,5.8833333,-55.05 ],
    [ u"sr",u"Meerzorg",6591,5.8166667,-55.15 ],
    [ u"sr",u"Moengo",7345,5.6166667,-54.4 ],
    [ u"sr",u"Nieuw Amsterdam",4935,5.8833333,-55.0833333 ],
    [ u"sr",u"Nieuw Nickerie",13410,5.95,-56.9833333 ],
    [ u"sr",u"Onverwacht",2009,5.5833333,-55.1833333 ],
    [ u"sr",u"Paramaribo",220306,5.8333333,-55.1666667 ],
    [ u"sr",u"Totness",1800,5.8833333,-56.3166667 ],
    [ u"sr",u"Wageningen",4229,5.7666667,-56.6833333 ],
    [ u"sv",u"Acajutla",22764,13.5927778,-89.8275 ],
    [ u"sv",u"Aguilares",21445,13.9572222,-89.1897222 ],
    [ u"sv",u"Ahuachapán",34104,13.9213889,-89.845 ],
    [ u"sv",u"Anamorós",2655,13.7405556,-87.8736111 ],
    [ u"sv",u"Antiguo Cuscatlán",33767,13.6730556,-89.2408333 ],
    [ u"sv",u"Apastepeque",5785,13.6666667,-88.7833333 ],
    [ u"sv",u"Apopa",112157,13.8072222,-89.1791667 ],
    [ u"sv",u"Armenia",14997,13.7436111,-89.4988889 ],
    [ u"sv",u"Atiquizaya",9477,13.9769444,-89.7525 ],
    [ u"sv",u"Ayutuxtepeque",25426,13.7455556,-89.2063889 ],
    [ u"sv",u"Berlín",11313,13.5,-88.5333333 ],
    [ u"sv",u"Cacaopera",2528,13.7666667,-88.0833333 ],
    [ u"sv",u"Chalatenango",19366,14.0333333,-88.9333333 ],
    [ u"sv",u"Chalchuapa",32282,13.9866667,-89.6811111 ],
    [ u"sv",u"Chapeltique",3159,13.6333333,-88.2666667 ],
    [ u"sv",u"Chinameca",8646,13.5,-88.35 ],
    [ u"sv",u"Chirilagua",6393,13.2202778,-88.1386111 ],
    [ u"sv",u"Ciudad Arce",10095,13.8402778,-89.4472222 ],
    [ u"sv",u"Ciudad Barrios",8491,13.7666667,-88.2666667 ],
    [ u"sv",u"Coatepeque",5773,13.9286111,-89.5041667 ],
    [ u"sv",u"Cojutepeque",48414,13.7166667,-88.9333333 ],
    [ u"sv",u"Colón",1895,13.55,-88.5666667 ],
    [ u"sv",u"Concepción Batres",3286,13.35,-88.3666667 ],
    [ u"sv",u"Concepción de Ataco",7797,13.8702778,-89.8486111 ],
    [ u"sv",u"Conchagua",3034,13.3077778,-87.8647222 ],
    [ u"sv",u"Corinto",3160,13.8108333,-87.9713889 ],
    [ u"sv",u"Cuscatancingo",44368,13.7361111,-89.1813889 ],
    [ u"sv",u"Delgado",71593,13.7241667,-89.1702778 ],
    [ u"sv",u"El Congo",8906,13.9088889,-89.4958333 ],
    [ u"sv",u"El Paisnal",1641,13.9736111,-89.2186111 ],
    [ u"sv",u"El Rosario",5620,13.4977778,-89.0297222 ],
    [ u"sv",u"El Tránsito",9486,13.35,-88.35 ],
    [ u"sv",u"Gotera",16154,13.7,-88.1 ],
    [ u"sv",u"Guatajiagua",5273,13.6666667,-88.2 ],
    [ u"sv",u"Guaymango",1517,13.7502778,-89.8422222 ],
    [ u"sv",u"Guazapa",9217,13.8769444,-89.1730556 ],
    [ u"sv",u"Ilopango",38889,13.7016667,-89.1094444 ],
    [ u"sv",u"Intipucá",3540,13.1969444,-88.0544444 ],
    [ u"sv",u"Izalco",19198,13.7447222,-89.6730556 ],
    [ u"sv",u"Jiquilisco",9129,13.3166667,-88.5833333 ],
    [ u"sv",u"Jocoro",4298,13.6166667,-88.0166667 ],
    [ u"sv",u"Juayúa",9936,13.8413889,-89.7455556 ],
    [ u"sv",u"Jucuapa",10601,13.5166667,-88.3833333 ],
    [ u"sv",u"Jucuarán",1643,13.2538889,-88.2477778 ],
    [ u"sv",u"Jujutla",2022,13.7869444,-89.8572222 ],
    [ u"sv",u"La Libertad",16855,13.4883333,-89.3222222 ],
    [ u"sv",u"La Unión",26809,13.3369444,-87.8438889 ],
    [ u"sv",u"Lolotique",2654,13.55,-88.35 ],
    [ u"sv",u"Mejicanos",160319,13.7402778,-89.2130556 ],
    [ u"sv",u"Metapán",19143,14.3333333,-89.45 ],
    [ u"sv",u"Moncagua",2148,13.5333333,-88.25 ],
    [ u"sv",u"Nahuizalco",7358,13.7775,-89.7366667 ],
    [ u"sv",u"Nejapa",5390,13.8919444,-89.2727778 ],
    [ u"sv",u"Nejapa",5390,13.8147222,-89.2313889 ],
    [ u"sv",u"Nueva Concepción",9990,14.1333333,-89.3 ],
    [ u"sv",u"Nueva Esparta",2528,13.7836111,-87.8386111 ],
    [ u"sv",u"Nueva Guadalupe",5798,13.5333333,-88.35 ],
    [ u"sv",u"Nueva San Salvador",124702,13.6769444,-89.2797222 ],
    [ u"sv",u"Nuevo Cuscatlán",6469,13.6486111,-89.2652778 ],
    [ u"sv",u"Olocuilta",6324,13.5697222,-89.1172222 ],
    [ u"sv",u"Opico",7127,13.8761111,-89.3597222 ],
    [ u"sv",u"Ozatlán",4171,13.3833333,-88.5 ],
    [ u"sv",u"Panchimalco",6764,13.6127778,-89.18 ],
    [ u"sv",u"Pasaquina",2149,13.5844444,-87.8411111 ],
    [ u"sv",u"Puerto El Triunfo",19074,13.2833333,-88.55 ],
    [ u"sv",u"Quezaltepeque",28886,13.835,-89.2744444 ],
    [ u"sv",u"Rosario de Mora",5178,13.5752778,-89.2088889 ],
    [ u"sv",u"San Agustín",2149,13.4333333,-88.6 ],
    [ u"sv",u"San Alejo",5149,13.4313889,-87.9630556 ],
    [ u"sv",u"San Antonio del Monte",9136,13.7163889,-89.7383333 ],
    [ u"sv",u"San Francisco Menéndez",1264,13.8430556,-90.0158333 ],
    [ u"sv",u"San Francisco Morazán",506,14.1833333,-89.05 ],
    [ u"sv",u"San Marcos",54614,13.6588889,-89.1830556 ],
    [ u"sv",u"San Martín",39360,13.7833333,-88.9166667 ],
    [ u"sv",u"San Martín",39360,13.7416667,-89.0563889 ],
    [ u"sv",u"San Pablo Tacachico",3033,13.9755556,-89.34 ],
    [ u"sv",u"San Pedro Masahuat",2654,13.5436111,-89.0386111 ],
    [ u"sv",u"San Salvador",526013,13.7086111,-89.2030556 ],
    [ u"sv",u"San Sebastián",7333,13.7333333,-88.8333333 ],
    [ u"sv",u"Santa Ana",176671,13.9941667,-89.5597222 ],
    [ u"sv",u"Santa Elena",5887,13.3833333,-88.4166667 ],
    [ u"sv",u"Santa Rosa de Lima",13249,13.6247222,-87.8936111 ],
    [ u"sv",u"Santiago de María",15033,13.4833333,-88.4666667 ],
    [ u"sv",u"Santiago Nonualco",9490,13.5166667,-88.95 ],
    [ u"sv",u"Santo Tomás",14581,13.6408333,-89.1333333 ],
    [ u"sv",u"San Vicente",37328,13.6333333,-88.8 ],
    [ u"sv",u"Sensuntepeque",20387,13.8666667,-88.6333333 ],
    [ u"sv",u"Sesori",1390,13.7166667,-88.3666667 ],
    [ u"sv",u"Sociedad",1770,13.7,-88.0166667 ],
    [ u"sv",u"Sonsonate",59473,13.7188889,-89.7241667 ],
    [ u"sv",u"Sonzacate",15446,13.7341667,-89.7147222 ],
    [ u"sv",u"Soyapango",329704,13.7347222,-89.1513889 ],
    [ u"sv",u"Suchitoto",5735,13.9380556,-89.0277778 ],
    [ u"sv",u"Tacuba",5055,13.9011111,-89.9297222 ],
    [ u"sv",u"Tecoluca",2781,13.7891667,-89.0052778 ],
    [ u"sv",u"Tenancingo",1011,13.8333333,-88.9833333 ],
    [ u"sv",u"Texistepeque",2401,14.1333333,-89.5 ],
    [ u"sv",u"Tonacatepeque",6245,13.7811111,-89.1186111 ],
    [ u"sv",u"Usulután",51914,13.35,-88.45 ],
    [ u"sv",u"Victoria",2023,13.95,-88.6333333 ],
    [ u"sv",u"Zacatecoluca",39616,13.5,-88.8666667 ],
    [ u"sv",u"Zaragoza",11749,13.5894444,-89.2888889 ],
    [ u"sy",u"Abu Kamal",62491,34.45,40.9186111 ],
    [ u"sy",u"Aleppo",2139878,36.2027778,37.1586111 ],
    [ u"sy",u"Baniyas",39718,35.1833333,35.95 ],
    [ u"sy",u"Damascus",1576843,33.5,36.3 ],
    [ u"sy",u"Darayya",51760,33.45,36.25 ],
    [ u"sy",u"Duma",111709,33.5833333,36.4 ],
    [ u"sy",u"Idlib",110503,35.9297222,36.6316667 ],
    [ u"sy",u"Jablah",52309,35.35,35.9166667 ],
    [ u"sy",u"Jaramana",189888,33.4833333,36.35 ],
    [ u"sy",u"Manbij",105420,36.5266667,37.9563889 ],
    [ u"sy",u"Masyaf",33001,35.05,36.35 ],
    [ u"sy",u"Nawá",50821,32.8833333,36.05 ],
    [ u"sy",u"Qatana",27254,33.4333333,36.0833333 ],
    [ u"sy",u"Safita",20394,34.8166667,36.1166667 ],
    [ u"sy",u"Salamiyah",91318,35.0166667,37.05 ],
    [ u"sy",u"Tartus",107081,34.8833333,35.8833333 ],
    [ u"sy",u"Yabrud",25941,33.9666667,36.6666667 ],
    [ u"sz",u"Bhunya",3050,-26.55,31.0166667 ],
    [ u"sz",u"Big Bend",10344,-26.8166667,31.9333333 ],
    [ u"sz",u"Bulembu",2263,-25.9666667,31.1333333 ],
    [ u"sz",u"Hlatikulu",2748,-26.9666667,31.3166667 ],
    [ u"sz",u"Hluti",6763,-27.2166667,31.6166667 ],
    [ u"sz",u"Kubuta",2038,-26.8833333,31.4833333 ],
    [ u"sz",u"Kwaluseni",3395,-26.4833333,31.3333333 ],
    [ u"sz",u"Lavumisa",1300,-27.3166667,31.9 ],
    [ u"sz",u"Lobamba",4557,-26.4666667,31.2 ],
    [ u"sz",u"Malkerns",9726,-26.5666667,31.1833333 ],
    [ u"sz",u"Manzini",110543,-26.4833333,31.3666667 ],
    [ u"sz",u"Mbabane",76223,-26.3166667,31.1333333 ],
    [ u"sz",u"Mhlambanyatsi",2886,-26.45,31.0166667 ],
    [ u"sz",u"Mhlume",8654,-26.0333333,31.85 ],
    [ u"sz",u"Nhlangano",9017,-27.1166667,31.2 ],
    [ u"sz",u"Nsoko",1180,-27.0333333,31.95 ],
    [ u"sz",u"Sidvokodvo",1747,-26.6166667,31.45 ],
    [ u"sz",u"Siteki",6153,-26.45,31.95 ],
    [ u"tc",u"Cockburn Harbour",1744,21.4833333,-71.5333333 ],
    [ u"tc",u"Cockburn Town",5525,21.4666667,-71.1333333 ],
    [ u"td",u"Abéché",74188,13.8166667,20.8166667 ],
    [ u"td",u"Adré",11928,13.4666667,22.2 ],
    [ u"td",u"Am Timan",28885,11.0333333,20.2833333 ],
    [ u"td",u"Ati",24074,13.2166667,18.3333333 ],
    [ u"td",u"Béboto",5432,8.2666667,16.9333333 ],
    [ u"td",u"Beinamar",7445,8.5666667,15.4333333 ],
    [ u"td",u"Bénoy",15717,8.9833333,16.3166667 ],
    [ u"td",u"Béré",14666,9.3333333,16.15 ],
    [ u"td",u"Biltine",11000,14.5333333,20.9166667 ],
    [ u"td",u"Bitkine",18495,11.9816667,18.2127778 ],
    [ u"td",u"Bokoro",14723,12.3766667,17.0580556 ],
    [ u"td",u"Bol",10551,7.6666667,15.9166667 ],
    [ u"td",u"Bongor",27770,10.2805556,15.3722222 ],
    [ u"td",u"Bousso",13555,10.4825,16.7161111 ],
    [ u"td",u"Doba",24336,8.65,16.85 ],
    [ u"td",u"Dourbali",17682,11.8094444,15.8611111 ],
    [ u"td",u"Faya",13400,17.9166667,19.1166667 ],
    [ u"td",u"Fianga",13441,9.9152778,15.1375 ],
    [ u"td",u"Goundi",10052,9.3666667,17.3666667 ],
    [ u"td",u"Guélengdeng",11379,10.9333333,15.5333333 ],
    [ u"td",u"Kélo",42533,9.3166667,15.8 ],
    [ u"td",u"Koumra",36263,8.9166667,17.55 ],
    [ u"td",u"Kyabé",16177,9.45,18.95 ],
    [ u"td",u"Laï",19382,9.4,16.3 ],
    [ u"td",u"Mao",18031,14.1194444,15.3133333 ],
    [ u"td",u"Massaguet",17906,12.4741667,15.4427778 ],
    [ u"td",u"Massakory",15406,12.9980556,15.7375 ],
    [ u"td",u"Melfi",5784,11.0597222,17.9330556 ],
    [ u"td",u"Moïssala",11264,8.35,17.7666667 ],
    [ u"td",u"Mongo",27763,12.1833333,18.7 ],
    [ u"td",u"Moundou",135167,8.5666667,16.0833333 ],
    [ u"td",u"Moussoro",15190,13.6425,16.4888889 ],
    [ u"td",u"Ngama",12438,11.7833333,17.1666667 ],
    [ u"td",u"Oum Hadjer",19271,13.3,19.6833333 ],
    [ u"td",u"Pala",35466,9.35,14.9666667 ],
    [ u"td",u"Sarh",102528,9.15,18.3833333 ],
    [ u"tf",u"Port-aux-Français",45,-49.35,70.2166667 ],
    [ u"tg",u"Amlamé",10931,7.4666667,0.9 ],
    [ u"tg",u"Aného",47174,6.2333333,1.6 ],
    [ u"tg",u"Atakpamé",92976,7.5333333,1.1333333 ],
    [ u"tg",u"Badou",22182,7.5833333,0.6 ],
    [ u"tg",u"Bafilo",20870,9.35,1.2666667 ],
    [ u"tg",u"Bassar",55901,9.25,0.7833333 ],
    [ u"tg",u"Dapaong",31315,10.8638889,0.205 ],
    [ u"tg",u"Kandé",10615,9.9577778,1.0447222 ],
    [ u"tg",u"Kara",94044,9.5511111,1.1861111 ],
    [ u"tg",u"Kpagouda",7116,9.7525,1.3277778 ],
    [ u"tg",u"Kpalimé",110541,6.9,0.6333333 ],
    [ u"tg",u"Mango",34791,10.3591667,0.4708333 ],
    [ u"tg",u"Niamtougou",21534,9.7680556,1.1052778 ],
    [ u"tg",u"Notsé",24383,6.95,1.1666667 ],
    [ u"tg",u"Sokodé",108373,8.9833333,1.1333333 ],
    [ u"tg",u"Sotouboua",19742,8.5666667,0.9833333 ],
    [ u"tg",u"Tabligbo",13625,6.5833333,1.5 ],
    [ u"tg",u"Tchamba",24069,9.0333333,1.4166667 ],
    [ u"tg",u"Tsévié",55302,6.4261111,1.2133333 ],
    [ u"tg",u"Vogan",20386,6.3333333,1.5333333 ],
    [ u"th",u"Amnat Charoen",34769,15.858511,104.628834 ],
    [ u"th",u"Ang Thong",14430,14.588389,100.452834 ],
    [ u"th",u"Ao Luk",13263,8.378028,98.721167 ],
    [ u"th",u"Ayutthaya",81962,14.351667,100.577389 ],
    [ u"th",u"Bamnet Narong",14890,15.499167,101.689722 ],
    [ u"th",u"Ban Bung",26113,12.866298,100.970249 ],
    [ u"th",u"Ban Chang",28204,12.725428,101.055305 ],
    [ u"th",u"Ban Dung",19479,17.698999,103.259567 ],
    [ u"th",u"Bang Ban",16588,14.373945,100.485278 ],
    [ u"th",u"Bang Bo",28376,13.574278,100.835333 ],
    [ u"th",u"Bang Khla",13528,13.721442,101.208136 ],
    [ u"th",u"Bangkok",5104475,13.753979,100.501444 ],
    [ u"th",u"Bang Krathum",18874,16.578312,100.300336 ],
    [ u"th",u"Bang Kruai",78305,13.805,100.472833 ],
    [ u"th",u"Bang Lamung",39620,12.976278,100.914056 ],
    [ u"th",u"Bang Len",17914,14.021885,100.171827 ],
    [ u"th",u"Bang Mun Nak",15616,16.027806,100.379167 ],
    [ u"th",u"Bang Pakong",25620,13.498139,100.991861 ],
    [ u"th",u"Bang Phae",29548,13.691568,99.929816 ],
    [ u"th",u"Bang Racham",15313,14.892,100.317278 ],
    [ u"th",u"Bang Rakam",16841,16.758472,100.117417 ],
    [ u"th",u"Bang Sai",13611,14.212395,100.496566 ],
    [ u"th",u"Bang Sao Thong",31153,13.595,100.830417 ],
    [ u"th",u"Bang Saphan",15134,11.213152,99.507648 ],
    [ u"th",u"Bang Yai",14012,13.805,100.472833 ],
    [ u"th",u"Ban Mo",15959,14.615445,100.727306 ],
    [ u"th",u"Ban Phaeo",41904,13.590724,100.107483 ],
    [ u"th",u"Ban Phai",35583,16.059972,102.730972 ],
    [ u"th",u"Ban Pong",57559,13.816292,99.877392 ],
    [ u"th",u"Ban Tak",18384,17.04325,99.081278 ],
    [ u"th",u"Betong",29604,5.774337,101.072312 ],
    [ u"th",u"Bo Phloi",16786,14.323611,99.516111 ],
    [ u"th",u"Bo Rai",13620,12.572834,102.537139 ],
    [ u"th",u"Bua Yai",16832,15.55,102.433333 ],
    [ u"th",u"Chachoengsao",49741,13.688195,101.071556 ],
    [ u"th",u"Chai Badan",25196,15.206139,101.136834 ],
    [ u"th",u"Chai Nat",15469,15.186361,100.123528 ],
    [ u"th",u"Chaiya",12223,9.386245,99.198612 ],
    [ u"th",u"Chaiyaphum",58350,15.81047,102.028812 ],
    [ u"th",u"Chaiyo",13255,14.648778,100.478778 ],
    [ u"th",u"Chanthaburi",99819,12.609611,102.104472 ],
    [ u"th",u"Chiang Kham",14092,19.523306,100.3 ],
    [ u"th",u"Chiang Khong",14505,20.261248,100.404613 ],
    [ u"th",u"Chiang Klang",13244,19.293778,100.861695 ],
    [ u"th",u"Chiang Mai",200952,18.790376,98.984683 ],
    [ u"th",u"Chiang Rai",78756,19.908584,99.8325 ],
    [ u"th",u"Chok Chai",23337,14.728444,102.165239 ],
    [ u"th",u"Chom Bung",15143,13.620003,99.591688 ],
    [ u"th",u"Chon Buri",219190,13.362199,100.983454 ],
    [ u"th",u"Chon Daen",17567,16.189528,100.859584 ],
    [ u"th",u"Chum Phae",46335,16.544296,102.099243 ],
    [ u"th",u"Chumphon",55835,10.5,99.166667 ],
    [ u"th",u"Damnoen Saduak",23296,13.518245,99.954687 ],
    [ u"th",u"Dan Khun Thot",15580,15.208499,101.771381 ],
    [ u"th",u"Den Chai",17019,17.983722,100.052167 ],
    [ u"th",u"Det Udom",35669,14.905978,105.078364 ],
    [ u"th",u"Doembang Nangbuat",14671,14.854278,100.097722 ],
    [ u"th",u"Dok Kham Tai",23824,19.162417,99.993417 ],
    [ u"th",u"Don Sak",12422,9.316763,99.691836 ],
    [ u"th",u"Hat Yai",191696,7.008359,100.476682 ],
    [ u"th",u"Hua Hin",50456,12.530722,99.880861 ],
    [ u"th",u"Huai Mek",12352,16.58975,103.235472 ],
    [ u"th",u"Huai Thalaeng",15352,14.997007,102.647463 ],
    [ u"th",u"Huai Yot",16586,7.789334,99.634778 ],
    [ u"th",u"Kabin Buri",20212,13.95114,101.717687 ],
    [ u"th",u"Kaeng Khlo",29056,16.108639,102.258084 ],
    [ u"th",u"Kaeng Khoi",30332,14.583333,101.016667 ],
    [ u"th",u"Kalasin",55102,16.432806,103.506584 ],
    [ u"th",u"Kamalasai",23393,16.338389,103.575639 ],
    [ u"th",u"Kamphaeng Phet",58787,16.483442,99.521534 ],
    [ u"th",u"Kanchanaburi",63699,14.003195,99.550056 ],
    [ u"th",u"Kantang",14156,7.405417,99.515611 ],
    [ u"th",u"Kaset Sombun",16996,16.280528,101.954222 ],
    [ u"th",u"Kathu",34835,7.909028,98.333195 ],
    [ u"th",u"Khanu Woralaksaburi",21889,16.061695,99.860584 ],
    [ u"th",u"Khao Wong",15184,16.700084,104.090195 ],
    [ u"th",u"Khao Yoi",18506,13.216667,99.833333 ],
    [ u"th",u"Khiri Mat",11272,16.833333,99.766667 ],
    [ u"th",u"Khlong Luang",118551,14.064667,100.645778 ],
    [ u"th",u"Khlung",13286,12.454667,102.221417 ],
    [ u"th",u"Khon Buri",18596,14.525407,102.245908 ],
    [ u"th",u"Khon Kaen",147579,16.446711,102.832999 ],
    [ u"th",u"Klaeng",55619,12.779722,101.648309 ],
    [ u"th",u"Ko Samui",39681,9.535671,99.935669 ],
    [ u"th",u"Kosum Phisai",10672,16.248584,103.067389 ],
    [ u"th",u"Krabi",31219,8.072574,98.910516 ],
    [ u"th",u"Kranuan",13475,16.706722,103.078778 ],
    [ u"th",u"Krathum Baen",72819,13.653298,100.259717 ],
    [ u"th",u"Kuchinarai",20532,16.541001,104.050041 ],
    [ u"th",u"Kui Buri",19046,12.082834,99.854306 ],
    [ u"th",u"Kumphawapi",29211,17.108751,103.014874 ],
    [ u"th",u"Kut Chap",24696,17.425695,102.566917 ],
    [ u"th",u"Laem Sing",16066,12.481639,102.07375 ],
    [ u"th",u"Lam Luk Ka",60700,13.932261,100.74937 ],
    [ u"th",u"Lampang",156139,18.292318,99.49277 ],
    [ u"th",u"Lamphun",41791,18.580537,99.007446 ],
    [ u"th",u"Lang Suan",16142,9.945611,99.078472 ],
    [ u"th",u"Lat Yao",17506,15.751,99.78925 ],
    [ u"th",u"Loei",35273,17.490518,101.727488 ],
    [ u"th",u"Lom Sak",17309,16.779834,101.24225 ],
    [ u"th",u"Long",11802,18.076056,99.832556 ],
    [ u"th",u"Lop Buri",57761,14.798084,100.653972 ],
    [ u"th",u"Mae Chan",37672,20.14675,99.852556 ],
    [ u"th",u"Mae Hong Son",9109,19.308543,97.965302 ],
    [ u"th",u"Mae Ramat",17316,16.984032,98.516646 ],
    [ u"th",u"Mae Sai",27520,20.433528,99.876167 ],
    [ u"th",u"Mae Sot",44563,16.716667,98.566667 ],
    [ u"th",u"Mae Tha",10048,18.464564,99.140258 ],
    [ u"th",u"Maha Sarakham",51584,16.184834,103.300667 ],
    [ u"th",u"Mukdahan",40480,16.545311,104.723512 ],
    [ u"th",u"Nakhon Luang",15008,14.462807,100.608315 ],
    [ u"th",u"Nakhon Nayok",21309,14.204631,101.212948 ],
    [ u"th",u"Nakhon Pathom",117927,13.819602,100.044274 ],
    [ u"th",u"Nakhon Phanom",34595,17.410806,104.778556 ],
    [ u"th",u"Nakhon Ratchasima",208781,14.971596,102.08255 ],
    [ u"th",u"Nakhon Sawan",99176,15.704722,100.137167 ],
    [ u"th",u"Nakhon Si Thammarat",120836,8.433333,99.966667 ],
    [ u"th",u"Nakhon Thai",12345,17.100556,100.837389 ],
    [ u"th",u"Na Klang",31024,17.307195,102.188861 ],
    [ u"th",u"Nam Phong",15759,16.702278,102.855695 ],
    [ u"th",u"Nam Som",19324,17.770361,102.189472 ],
    [ u"th",u"Nang Rong",21961,14.637704,102.791383 ],
    [ u"th",u"Nan",24670,18.792917,100.729722 ],
    [ u"th",u"Narathiwat",47771,6.426389,101.823084 ],
    [ u"th",u"Na Wa",12989,17.489695,104.100556 ],
    [ u"th",u"Nong Bua",14160,15.864584,100.585806 ],
    [ u"th",u"Nong Chik",11385,6.843556,101.178028 ],
    [ u"th",u"Nong Han",26120,17.360834,103.105334 ],
    [ u"th",u"Nong Khae",41067,14.340618,100.867331 ],
    [ u"th",u"Nong Khai",63609,17.878472,102.742 ],
    [ u"th",u"Nong Ki",13592,14.686794,102.538002 ],
    [ u"th",u"Nong Kung Si",17001,16.655926,103.297233 ],
    [ u"th",u"Nong Phai",27756,15.99025,101.061834 ],
    [ u"th",u"Non Sang",11819,16.868696,102.566422 ],
    [ u"th",u"Non Sung",18399,15.180139,102.256945 ],
    [ u"th",u"Nonthaburi",375826,13.862167,100.513417 ],
    [ u"th",u"Non Thai",11959,15.195798,102.07145 ],
    [ u"th",u"Pa Daet",13624,19.50489,99.992415 ],
    [ u"th",u"Pak Chong",48999,14.708023,101.416142 ],
    [ u"th",u"Pak Kret",182926,13.913014,100.498828 ],
    [ u"th",u"Pak Phanang",25014,8.35109,100.201952 ],
    [ u"th",u"Pak Thong Chai",23412,14.722603,102.025121 ],
    [ u"th",u"Pa Sang",15607,18.526167,98.939361 ],
    [ u"th",u"Pathum Thani",27911,14.013461,100.530488 ],
    [ u"th",u"Pattani",49084,6.8749,101.254851 ],
    [ u"th",u"Pattaya",97296,12.933333,100.883333 ],
    [ u"th",u"Phak Hai",19386,14.457361,100.369889 ],
    [ u"th",u"Phanat Nikhom",21924,13.445813,101.184447 ],
    [ u"th",u"Phangnga",9676,8.450905,98.52985 ],
    [ u"th",u"Phanom Sarakham",16057,13.747873,101.3553 ],
    [ u"th",u"Phanom Thuan",12469,14.130306,99.698584 ],
    [ u"th",u"Phan Thong",18708,13.46804,101.095322 ],
    [ u"th",u"Phatthalung",43522,7.617861,100.077917 ],
    [ u"th",u"Phayakkhaphum Phisai",10212,15.516306,103.193667 ],
    [ u"th",u"Phayao",21058,19.192028,99.878834 ],
    [ u"th",u"Phayuha Khiri",12271,15.45525,100.135334 ],
    [ u"th",u"Phetchabun",50656,16.443306,101.147528 ],
    [ u"th",u"Phetchaburi",46601,13.111889,99.944667 ],
    [ u"th",u"Phibun Mangsahan",19883,15.244667,105.229084 ],
    [ u"th",u"Phichit",35760,16.441842,100.348793 ],
    [ u"th",u"Phimai",13084,15.223235,102.494725 ],
    [ u"th",u"Phitsanulok",103427,16.824806,100.258584 ],
    [ u"th",u"Pho Chai",13671,16.328269,103.770328 ],
    [ u"th",u"Phon",14596,15.816,102.599806 ],
    [ u"th",u"Phon Thong",13317,16.0385,103.746472 ],
    [ u"th",u"Photharam",36248,13.692336,99.849692 ],
    [ u"th",u"Pho Thong",12200,14.667306,100.408778 ],
    [ u"th",u"Phrae",38538,18.145889,100.141028 ],
    [ u"th",u"Phrai Bung",11494,14.748334,104.362611 ],
    [ u"th",u"Phra Phutthabat",57008,14.725264,100.79536 ],
    [ u"th",u"Phra Pradaeng",171333,13.658545,100.533618 ],
    [ u"th",u"Phuket",89072,7.833333,98.383333 ],
    [ u"th",u"Phu Khieo",17122,16.3765,102.128528 ],
    [ u"th",u"Phun Phin",25810,9.110722,99.232084 ],
    [ u"th",u"Plaeng Yao",13139,13.584667,101.284028 ],
    [ u"th",u"Pong",14392,19.149306,100.275222 ],
    [ u"th",u"Prachin Buri",32600,14.049917,101.368639 ],
    [ u"th",u"Prachuap Khiri Khan",33520,11.808584,99.796667 ],
    [ u"th",u"Pran Buri",47293,12.384665,99.909829 ],
    [ u"th",u"Ranong",24560,9.965834,98.634761 ],
    [ u"th",u"Ranot",19780,7.777677,100.321344 ],
    [ u"th",u"Ratchaburi",92448,13.536711,99.817117 ],
    [ u"th",u"Rayong",119080,12.668462,101.275503 ],
    [ u"th",u"Roi Et",39328,16.053306,103.653861 ],
    [ u"th",u"Rong Kwang",12087,18.339028,100.317361 ],
    [ u"th",u"Ron Phibun",26621,8.179111,99.85425 ],
    [ u"th",u"Sadao",46236,6.638833,100.423417 ],
    [ u"th",u"Sai Buri",14356,6.701306,101.61675 ],
    [ u"th",u"Sa Kaeo",28497,13.814111,102.072222 ],
    [ u"th",u"Sakhon Nakhon",76237,17.161157,104.147254 ],
    [ u"th",u"Sam Chuk",13438,14.757626,100.089925 ],
    [ u"th",u"Sam Phran",37115,13.726983,100.215264 ],
    [ u"th",u"Sam Roi Yot",19709,12.270806,99.872028 ],
    [ u"th",u"Samut Prakan",388921,13.600417,100.596778 ],
    [ u"th",u"Samut Sakhon",63498,13.54753,100.273622 ],
    [ u"th",u"Samut Songkhram",35065,13.414556,100.002639 ],
    [ u"th",u"Sansai",37491,18.83075,99.003806 ],
    [ u"th",u"Sattahip",65444,12.666438,100.900727 ],
    [ u"th",u"Satuk",11680,15.297028,103.291917 ],
    [ u"th",u"Satun",34544,6.623142,100.066758 ],
    [ u"th",u"Sawang Daen Din",16825,17.475306,103.457528 ],
    [ u"th",u"Sawankhalok",19805,17.315972,99.831861 ],
    [ u"th",u"Seka",16493,17.928511,103.955192 ],
    [ u"th",u"Selaphum",17412,16.029923,103.938262 ],
    [ u"th",u"Si Bun Ruang",12842,16.966667,102.283333 ],
    [ u"th",u"Si Chiang Mai",14068,17.956389,102.586667 ],
    [ u"th",u"Sing Buri",20046,14.887861,100.404639 ],
    [ u"th",u"Si Racha",178916,13.173722,100.931111 ],
    [ u"th",u"Si Sa Ket",44751,15.114806,104.32938 ],
    [ u"th",u"Si Satchanalai",25942,17.520342,99.763962 ],
    [ u"th",u"Soeng Sang",14138,14.426417,102.460584 ],
    [ u"th",u"Songkhla",86899,7.198822,100.595098 ],
    [ u"th",u"Song Phi Nong",19839,14.216667,100.05 ],
    [ u"th",u"Sukhothai",40174,17.007778,99.823 ],
    [ u"th",u"Sungai Kolok",42776,6.029774,101.965855 ],
    [ u"th",u"Sungai Padi",14274,6.072389,101.871722 ],
    [ u"th",u"Sung Noen",14365,14.899195,101.82075 ],
    [ u"th",u"Suphan Buri",53399,14.474178,100.122178 ],
    [ u"th",u"Surat Thani",127201,9.140109,99.333114 ],
    [ u"th",u"Surin",46673,14.881806,103.493639 ],
    [ u"th",u"Suwannaphum",12221,15.60348,103.802067 ],
    [ u"th",u"Tak Bai",17241,6.259472,102.054611 ],
    [ u"th",u"Takhli",41745,15.263361,100.343778 ],
    [ u"th",u"Tak",24149,16.869684,99.128979 ],
    [ u"th",u"Taphan Hin",21895,16.220945,100.419778 ],
    [ u"th",u"Tha Bo",35292,17.850028,102.581389 ],
    [ u"th",u"Tha Chang",9547,9.264179,99.192181 ],
    [ u"th",u"Tha Mai",22445,12.621369,102.004805 ],
    [ u"th",u"Tha Maka",52907,13.920806,99.765528 ],
    [ u"th",u"Tha Muang",26746,13.961179,99.641223 ],
    [ u"th",u"Thanyaburi",123382,14.021139,100.734334 ],
    [ u"th",u"Thap Khlo",15528,16.160028,100.596556 ],
    [ u"th",u"Thap Than",16615,15.460632,99.891657 ],
    [ u"th",u"Tha Rua",19116,14.567387,100.725979 ],
    [ u"th",u"That Phanom",14424,16.936361,104.710389 ],
    [ u"th",u"Thoen",18459,17.612894,99.216116 ],
    [ u"th",u"Thung Song",28223,8.164528,99.680389 ],
    [ u"th",u"Trang",66713,7.558167,99.610528 ],
    [ u"th",u"Trat",21590,12.241028,102.515472 ],
    [ u"th",u"Ubon Ratchathani",122533,15.23844,104.848659 ],
    [ u"th",u"Udon Thani",247232,17.415667,102.785889 ],
    [ u"th",u"Uthai Thani",22219,15.379389,100.0245 ],
    [ u"th",u"U Thong",13753,14.328889,99.868333 ],
    [ u"th",u"Uttaradit",58313,17.625572,100.094209 ],
    [ u"th",u"Wang Noi",15865,14.226889,100.7155 ],
    [ u"th",u"Wang Saphung",15747,17.300972,101.7685 ],
    [ u"th",u"Wapi Pathum",10198,15.845229,103.376785 ],
    [ u"th",u"Warin Chamrap",43102,15.193187,104.862805 ],
    [ u"th",u"Wiang Sa",11933,8.635849,99.366595 ],
    [ u"th",u"Wichian Buri",39272,15.657778,101.106028 ],
    [ u"th",u"Wiset Chai Chan",19129,14.5945,100.33825 ],
    [ u"th",u"Yala",93558,6.539946,101.281284 ],
    [ u"th",u"Yang Talat",13360,16.399815,103.367846 ],
    [ u"th",u"Yaring",31111,6.866167,101.368945 ],
    [ u"th",u"Yasothon",21643,15.794079,104.145104 ],
    [ u"tj",u"Adrasmon",13372,40.6486111,69.9855556 ],
    [ u"tj",u"Altyn-Topkan",4823,40.645,69.5966667 ],
    [ u"tj",u"Asht",11705,40.6666667,70.3333333 ],
    [ u"tj",u"Ayni",2128,39.3975,68.5405556 ],
    [ u"tj",u"Boshkengash",23696,38.4647222,68.8036111 ],
    [ u"tj",u"Buston",13043,40.5216667,69.3308333 ],
    [ u"tj",u"Bustonkala",4068,37.8666667,68.8333333 ],
    [ u"tj",u"Chkalovsk",21555,40.1986111,69.81 ],
    [ u"tj",u"Chorbog",4237,37.4166667,68.2 ],
    [ u"tj",u"Dangara",22824,38.0963889,69.3355556 ],
    [ u"tj",u"Dushanbe",543105,38.56,68.7738889 ],
    [ u"tj",u"Dusti",8700,37.3486111,68.6733333 ],
    [ u"tj",u"Farkhor",21736,37.4922222,69.4016667 ],
    [ u"tj",u"Gafurov",14482,40.2177778,69.725 ],
    [ u"tj",u"Garavuti",8474,37.5602778,68.4525 ],
    [ u"tj",u"Garm",10771,39.0241667,70.3794444 ],
    [ u"tj",u"Hisor",23981,38.4819444,68.5969444 ],
    [ u"tj",u"Isfara",37742,40.1166667,70.6333333 ],
    [ u"tj",u"Jilikul",5434,37.4936111,68.5311111 ],
    [ u"tj",u"Kansay",5042,40.4927778,69.7025 ],
    [ u"tj",u"Karakendzha",2899,39.2422222,71.5261111 ],
    [ u"tj",u"Khujand",144874,40.28,69.6316667 ],
    [ u"tj",u"Kim",2411,40.2,70.4666667 ],
    [ u"tj",u"Kirovskiy",7696,37.8166667,68.85 ],
    [ u"tj",u"Kofarnihon",42909,38.5530556,69.0197222 ],
    [ u"tj",u"Konibodom",50364,40.2833333,70.4166667 ],
    [ u"tj",u"Kulob",78794,37.9091667,69.7819444 ],
    [ u"tj",u"Kuruksay",3288,40.5786111,69.3777778 ],
    [ u"tj",u"Leningradskiy",11955,38.1077778,70.0308333 ],
    [ u"tj",u"Matcha",14897,40.3680556,69.3252778 ],
    [ u"tj",u"Moskovskiy",19563,37.6127778,69.7061111 ],
    [ u"tj",u"Naugarzan",877,40.9333333,70.55 ],
    [ u"tj",u"Nau",13833,40.1538889,69.3730556 ],
    [ u"tj",u"Navabad",5352,39.0077778,70.1555556 ],
    [ u"tj",u"Nefteabad",4603,40.2,70.5666667 ],
    [ u"tj",u"Obigarm",10035,38.72,69.7094444 ],
    [ u"tj",u"Orzu",5988,37.6,68.8166667 ],
    [ u"tj",u"Pakhtakoron",8220,40.1666667,68.75 ],
    [ u"tj",u"Palas",3288,40.3136111,69.7444444 ],
    [ u"tj",u"Panjakent",35089,39.5030556,67.615 ],
    [ u"tj",u"Proletarsk",16441,40.1686111,69.5083333 ],
    [ u"tj",u"Rogun",7732,38.7811111,69.8719444 ],
    [ u"tj",u"Shaartuz",13042,37.2594444,68.1347222 ],
    [ u"tj",u"Shakhrinau",5385,38.5736111,68.3330556 ],
    [ u"tj",u"Shurob",3988,40.05,70.55 ],
    [ u"tj",u"Sovetskiy",8694,38.0458333,69.5880556 ],
    [ u"tj",u"Taboshar",11588,40.5688889,69.6402778 ],
    [ u"tj",u"Takob",2565,38.8411111,68.9302778 ],
    [ u"tj",u"Tartki",2342,37.5833333,68.1333333 ],
    [ u"tj",u"Tugalan",18476,37.5894444,68.6608333 ],
    [ u"tj",u"Tursunzoda",37999,38.5108333,68.2302778 ],
    [ u"tj",u"Uroteppa",52856,39.9108333,69.0063889 ],
    [ u"tj",u"Vakhsh",15215,37.7108333,68.8311111 ],
    [ u"tj",u"Varzob",2154,38.7758333,68.8308333 ],
    [ u"tj",u"Vorukh",3836,39.8533333,70.5769444 ],
    [ u"tj",u"Yovon",17480,38.3130556,69.0430556 ],
    [ u"tm",u"Akdepe",14177,42.05,59.4 ],
    [ u"tm",u"Annau",27527,37.8883333,58.5280556 ],
    [ u"tm",u"Asgabat",797900,37.95,58.3833333 ],
    [ u"tm",u"Bäherden",22991,38.4302778,57.4369444 ],
    [ u"tm",u"Balkanabat",87830,39.5119444,54.365 ],
    [ u"tm",u"Boldumsaz",21160,42.1333333,59.6666667 ],
    [ u"tm",u"Büzmeýin",39485,38.0516667,58.21 ],
    [ u"tm",u"Dasoguz",199514,41.8333333,59.9666667 ],
    [ u"tm",u"Farap",14502,39.1713889,63.6030556 ],
    [ u"tm",u"Gazanjyk",21090,39.2430556,55.5169444 ],
    [ u"tm",u"Gazojak",21020,41.1833333,61.4 ],
    [ u"tm",u"Gumdag",24312,39.2061111,54.5905556 ],
    [ u"tm",u"Kaka",18545,37.35,59.6 ],
    [ u"tm",u"Kerki",33241,37.8344444,65.2097222 ],
    [ u"tm",u"Murgab",13199,37.5,61.9666667 ],
    [ u"tm",u"Saýat",17761,38.7811111,63.8866667 ],
    [ u"tm",u"Seydi",17761,39.4166667,62.9 ],
    [ u"tm",u"Türkmenabat",234828,39.1013889,63.575 ],
    [ u"tn",u"Akkudah",20027,35.869104,10.565302 ],
    [ u"tn",u"Aryanah",237401,36.860117,10.193371 ],
    [ u"tn",u"Bajah",57211,36.725638,9.181692 ],
    [ u"tn",u"Bardaw",74027,36.809167,10.140556 ],
    [ u"tn",u"Bin Qirdan",13364,33.13783,11.219649 ],
    [ u"tn",u"Bu Salim",20310,36.607323,8.96981 ],
    [ u"tn",u"Duz",28127,33.466324,9.020302 ],
    [ u"tn",u"Harqalah",6942,36.030273,10.509044 ],
    [ u"tn",u"Jabinyanah",7349,35.034999,10.90809 ],
    [ u"tn",u"Jammal",39990,35.622311,10.75696 ],
    [ u"tn",u"Jamnah",6254,33.577778,9.014722 ],
    [ u"tn",u"Jarjis",79334,33.503981,11.112155 ],
    [ u"tn",u"Jilmah",5647,35.273111,9.423849 ],
    [ u"tn",u"Jundubah",51419,36.501136,8.780239 ],
    [ u"tn",u"Kasra",2598,35.813635,9.36434 ],
    [ u"tn",u"Lamtah",5382,35.666667,10.883333 ],
    [ u"tn",u"Manubah",24948,36.808029,10.097205 ],
    [ u"tn",u"Manzil Bu Ruqaybah",46257,37.153684,9.785945 ],
    [ u"tn",u"Manzil Bu Zalafah",16232,36.683123,10.584312 ],
    [ u"tn",u"Manzil Jamil",21542,37.23618,9.91448 ],
    [ u"tn",u"Manzil Kamil",8314,35.624767,10.667268 ],
    [ u"tn",u"Manzil Salim",2856,35.856732,8.476536 ],
    [ u"tn",u"Manzil Tamim",34768,36.782222,10.9875 ],
    [ u"tn",u"Maqrin",31290,36.769167,10.236389 ],
    [ u"tn",u"Masakin",64563,35.729173,10.58082 ],
    [ u"tn",u"Matir",31005,37.040448,9.665574 ],
    [ u"tn",u"Nabul",60207,36.456058,10.73763 ],
    [ u"tn",u"Naftah",21720,33.873094,7.877652 ],
    [ u"tn",u"Nibbar",3393,36.294109,8.766568 ],
    [ u"tn",u"Qabis",111070,33.881457,10.098196 ],
    [ u"tn",u"Qafsah",81236,34.425,8.784167 ],
    [ u"tn",u"Qasr Hallal",39792,35.647731,10.890461 ],
    [ u"tn",u"Qibili",19880,33.704387,8.969034 ],
    [ u"tn",u"Quballat",3353,36.541781,9.663341 ],
    [ u"tn",u"Qurbah",33589,36.578611,10.858611 ],
    [ u"tn",u"Qurbus",3581,36.816682,10.568654 ],
    [ u"tn",u"Qurunbaliyah",18965,36.598941,10.500316 ],
    [ u"tn",u"Radis",44298,36.768056,10.275278 ],
    [ u"tn",u"Rafraf",9255,37.19043,10.183648 ],
    [ u"tn",u"Sabibah",6291,35.543318,9.073696 ],
    [ u"tn",u"Safaqis",276293,34.740556,10.760278 ],
    [ u"tn",u"Sajanan",5009,37.057222,9.238056 ],
    [ u"tn",u"Sidi Bin Nur",4042,35.533333,10.916667 ],
    [ u"tn",u"Sidi Bu Zayd",42109,35.038234,9.484935 ],
    [ u"tn",u"Silyanah",26965,36.084966,9.370818 ],
    [ u"tn",u"Subaytilah",21539,35.231513,9.123213 ],
    [ u"tn",u"Sulayman",25634,36.696389,10.491667 ],
    [ u"tn",u"Susah",163704,35.825388,10.636991 ],
    [ u"tn",u"Tabarqah",13712,36.954423,8.75801 ],
    [ u"tn",u"Tabulbah",31709,35.640179,10.96731 ],
    [ u"tn",u"Taburbah",26012,36.829326,9.839346 ],
    [ u"tn",u"Tabursuq",12727,36.456924,9.247507 ],
    [ u"tn",u"Taklisah",20659,36.783333,10.633333 ],
    [ u"tn",u"Talah",16068,35.572436,8.670313 ],
    [ u"tn",u"Tastur",13708,36.551301,9.443073 ],
    [ u"tn",u"Tatawin",62588,32.929674,10.451767 ],
    [ u"tn",u"Tawzar",34949,33.919683,8.13352 ],
    [ u"tn",u"Tazirkah",7280,36.553669,10.838684 ],
    [ u"tn",u"Tinjah",18551,37.15964,9.760601 ],
    [ u"tn",u"Tunis",692816,36.806112,10.171078 ],
    [ u"tn",u"Tuzah",6085,35.635435,10.827316 ],
    [ u"tn",u"Wadi Maliz",2148,36.468127,8.549507 ],
    [ u"tn",u"Zawiyat Susah",8789,35.785531,10.627246 ],
    [ u"to",u"Hihifo",815,-15.95,-173.75 ],
    [ u"to",u"Neiafu",4320,-18.65,-173.9833333 ],
    [ u"to",u"Pangai",1737,-19.8,-174.35 ],
    [ u"to",u"Vaini",2976,-21.2,-175.2 ],
    [ u"tr",u"Adana",1249680,37.001667,35.328889 ],
    [ u"tr",u"Adilcevaz",52794,38.803893,42.734218 ],
    [ u"tr",u"Afsin",39633,38.247693,36.91399 ],
    [ u"tr",u"Afyonkarahisar",146211,38.756667,30.543333 ],
    [ u"tr",u"Agva",3492,41.138056,29.856667 ],
    [ u"tr",u"Ahlat",64725,38.751775,42.481353 ],
    [ u"tr",u"Akçaabat",45129,41.021205,39.571457 ],
    [ u"tr",u"Akçakoca",35167,41.086627,31.116226 ],
    [ u"tr",u"Akdagmadeni",23060,39.660278,35.883611 ],
    [ u"tr",u"Akhisar",84702,38.918524,27.840065 ],
    [ u"tr",u"Aksaray",152281,38.37255,34.02537 ],
    [ u"tr",u"Aksehir",64478,38.3575,31.416389 ],
    [ u"tr",u"Alaca",27032,40.168333,34.8425 ],
    [ u"tr",u"Alanya",113027,36.543747,31.999817 ],
    [ u"tr",u"Alasehir",40755,38.350833,28.517175 ],
    [ u"tr",u"Aliaga",44906,38.79975,26.972026 ],
    [ u"tr",u"Amasya",82939,40.653333,35.833056 ],
    [ u"tr",u"Anamur",57157,36.075081,32.836907 ],
    [ u"tr",u"Ankara",3519177,39.911652,32.840305 ],
    [ u"tr",u"Antakya",154881,36.206551,36.157225 ],
    [ u"tr",u"Antalya",758603,36.908118,30.695565 ],
    [ u"tr",u"Ardahan",21020,41.108711,42.702222 ],
    [ u"tr",u"Ardesen",67990,41.191111,40.9875 ],
    [ u"tr",u"Artvin",24278,41.182222,41.819444 ],
    [ u"tr",u"Babaeski",26737,41.4325,27.093056 ],
    [ u"tr",u"Bafra",92991,41.567778,35.906944 ],
    [ u"tr",u"Bahçe",19575,37.200225,36.576171 ],
    [ u"tr",u"Batman",302204,37.887378,41.132208 ],
    [ u"tr",u"Bayburt",31274,40.258889,40.227778 ],
    [ u"tr",u"Belen",20123,36.489114,36.223314 ],
    [ u"tr",u"Bergama",57229,39.119323,27.179971 ],
    [ u"tr",u"Besikduzu",37003,41.051992,39.228445 ],
    [ u"tr",u"Beysehir",44483,37.677348,31.724577 ],
    [ u"tr",u"Biga",30869,40.228056,27.242222 ],
    [ u"tr",u"Bilecik",40306,40.141924,29.979319 ],
    [ u"tr",u"Bingöl",80592,38.884722,40.493889 ],
    [ u"tr",u"Birecik",44307,37.029444,37.990278 ],
    [ u"tr",u"Bismil",74530,37.848611,40.665833 ],
    [ u"tr",u"Bitlis",48258,38.401146,42.107845 ],
    [ u"tr",u"Bodrum",39337,37.038333,27.429167 ],
    [ u"tr",u"Bolu",96680,40.735833,31.606111 ],
    [ u"tr",u"Bor",32452,37.890556,34.558889 ],
    [ u"tr",u"Boyabat",27711,41.468889,34.766667 ],
    [ u"tr",u"Bozova",21513,37.3625,38.526667 ],
    [ u"tr",u"Bozüyük",55393,39.907778,30.036667 ],
    [ u"tr",u"Bucak",29248,37.459167,30.595 ],
    [ u"tr",u"Bulancak",36882,40.937172,38.229067 ],
    [ u"tr",u"Burdur",66192,37.720278,30.290833 ],
    [ u"tr",u"Burhaniye",38102,39.500407,26.972693 ],
    [ u"tr",u"Bursa",1413485,40.191667,29.061111 ],
    [ u"tr",u"Buyukcavuslu",3843,41.242273,28.064625 ],
    [ u"tr",u"Çanakkale",87836,40.145556,26.406389 ],
    [ u"tr",u"Çan",26216,40.033282,27.052357 ],
    [ u"tr",u"Çanta",5473,41.118137,28.080345 ],
    [ u"tr",u"Carsamba",50488,41.198889,36.721944 ],
    [ u"tr",u"Çatalca",19328,41.142019,28.463817 ],
    [ u"tr",u"Çay",34225,38.591667,31.028611 ],
    [ u"tr",u"Çayeli",24571,41.092275,40.729235 ],
    [ u"tr",u"Celâliye",7793,41.045682,28.432325 ],
    [ u"tr",u"Çerkezköy",67117,41.285,28.000278 ],
    [ u"tr",u"Çermik",20987,38.13613,39.449294 ],
    [ u"tr",u"Cesme",21329,38.322778,26.306389 ],
    [ u"tr",u"Ceyhan",96358,37.024722,35.8175 ],
    [ u"tr",u"Çine",21339,37.611667,28.061389 ],
    [ u"tr",u"Cizre",81039,37.327222,42.190278 ],
    [ u"tr",u"Çorlu",202659,41.159167,27.8 ],
    [ u"tr",u"Çorum",183513,40.548889,34.953333 ],
    [ u"tr",u"Çubuk",62616,40.238611,33.032223 ],
    [ u"tr",u"Çumra",45681,37.573197,32.774461 ],
    [ u"tr",u"Degirmen",5902,41.098794,28.009861 ],
    [ u"tr",u"Demirci",21389,39.046072,28.65889 ],
    [ u"tr",u"Denizli",313402,37.774167,29.0875 ],
    [ u"tr",u"Develi",35886,38.390556,35.492222 ],
    [ u"tr",u"Devrek",24571,41.219167,31.955833 ],
    [ u"tr",u"Dinar",35376,38.065001,30.165569 ],
    [ u"tr",u"Dörtyol",56542,36.861583,36.228846 ],
    [ u"tr",u"Durusu",2784,41.305278,28.676667 ],
    [ u"tr",u"Düzce",57769,40.838889,31.163889 ],
    [ u"tr",u"Düziçi",50850,37.242164,36.454844 ],
    [ u"tr",u"Edirne",126535,41.675745,26.558665 ],
    [ u"tr",u"Edremit",40797,39.596111,27.024444 ],
    [ u"tr",u"Elbistan",80496,38.205909,37.198295 ],
    [ u"tr",u"Elmadag",25407,39.920833,33.230833 ],
    [ u"tr",u"Emet",23824,39.342995,29.258469 ],
    [ u"tr",u"Emirdag",20073,39.019722,31.15 ],
    [ u"tr",u"Erbaa",52213,40.668889,36.5675 ],
    [ u"tr",u"Ercis",91962,39.028688,43.358636 ],
    [ u"tr",u"Erdemli",46595,36.604981,34.308359 ],
    [ u"tr",u"Eregli",92166,37.512691,34.048189 ],
    [ u"tr",u"Eregli",88894,41.282615,31.418056 ],
    [ u"tr",u"Ergani",52710,38.265328,39.762118 ],
    [ u"tr",u"Erzincan",114087,39.752222,39.492778 ],
    [ u"tr",u"Erzurum",420919,39.908611,41.276944 ],
    [ u"tr",u"Esenyurt",211443,41.033333,28.675278 ],
    [ u"tr",u"Eskil",27061,38.401667,33.413056 ],
    [ u"tr",u"Eskisehir",515155,39.776667,30.520556 ],
    [ u"tr",u"Fatsa",82203,41.027778,37.501389 ],
    [ u"tr",u"Fethiye",60469,36.621667,29.116389 ],
    [ u"tr",u"Gaziantep",1066561,37.059444,37.3825 ],
    [ u"tr",u"Gebze",281585,40.802758,29.430684 ],
    [ u"tr",u"Gediz",22069,39.041667,29.41 ],
    [ u"tr",u"Gelibolu",25191,40.410278,26.670833 ],
    [ u"tr",u"Gemlik",71099,40.430937,29.159694 ],
    [ u"tr",u"Genç",22504,38.75071,40.560354 ],
    [ u"tr",u"Gerede",28596,40.800833,32.196944 ],
    [ u"tr",u"Giresun",98916,40.91698,38.387406 ],
    [ u"tr",u"Göksun",34260,38.020959,36.497303 ],
    [ u"tr",u"Gölcük",56201,40.716667,29.828611 ],
    [ u"tr",u"Gölköy",27418,40.6875,37.617778 ],
    [ u"tr",u"Gönen",40785,40.104901,27.653991 ],
    [ u"tr",u"Görele",30396,41.030833,39.003056 ],
    [ u"tr",u"Gumushane",32266,40.460278,39.481389 ],
    [ u"tr",u"Gumusyaka",6244,41.047222,28.042778 ],
    [ u"tr",u"Gürgentepe",18780,40.788333,37.601667 ],
    [ u"tr",u"Gürsu",24523,40.218757,29.194872 ],
    [ u"tr",u"Hadimkoy",11842,41.155889,28.617697 ],
    [ u"tr",u"Hakkari",77739,37.574444,43.740833 ],
    [ u"tr",u"Hayrabolu",19803,41.213112,27.106876 ],
    [ u"tr",u"Hendek",35275,40.799444,30.748056 ],
    [ u"tr",u"Horasan",17076,40.045833,42.172778 ],
    [ u"tr",u"Idil",22972,37.341138,41.889499 ],
    [ u"tr",u"Igdir",72597,39.923708,44.044999 ],
    [ u"tr",u"Imamoglu",31932,37.265061,35.657166 ],
    [ u"tr",u"Inegol",134030,40.078056,29.513333 ],
    [ u"tr",u"Iskenderun",160046,36.587185,36.173468 ],
    [ u"tr",u"Iskilip",19840,40.735278,34.473889 ],
    [ u"tr",u"Islahiye",40783,37.025,36.630556 ],
    [ u"tr",u"Isparta",172424,37.764444,30.552222 ],
    [ u"tr",u"Istanbul",9797536,41.018611,28.964722 ],
    [ u"tr",u"Izmir",2501895,38.412726,27.138376 ],
    [ u"tr",u"Izmit",196672,40.766944,29.916944 ],
    [ u"tr",u"Iznik",22242,40.428611,29.721111 ],
    [ u"tr",u"Kadirli",70283,37.373889,36.096111 ],
    [ u"tr",u"Kahramanmaras",376247,37.584705,36.926405 ],
    [ u"tr",u"Kâhta",73142,37.785525,38.623697 ],
    [ u"tr",u"Kaman",28619,39.3575,33.723889 ],
    [ u"tr",u"Karabük",97531,41.204884,32.62768 ],
    [ u"tr",u"Karacabey",44279,40.215251,28.403778 ],
    [ u"tr",u"Karacaköy",3107,41.402864,28.383381 ],
    [ u"tr",u"Karaköse",92069,39.719444,43.051389 ],
    [ u"tr",u"Karaman",120464,37.181111,33.215 ],
    [ u"tr",u"Karamürsel",30541,40.691437,29.615681 ],
    [ u"tr",u"Kars",77525,40.601992,43.094947 ],
    [ u"tr",u"Kastamonu",70438,41.378052,33.775275 ],
    [ u"tr",u"Kavakli",50532,41.093298,28.33328 ],
    [ u"tr",u"Kayseri",593164,38.732222,35.485278 ],
    [ u"tr",u"Kemalpasa",30427,38.426206,27.41731 ],
    [ u"tr",u"Kesan",44668,40.855833,26.630278 ],
    [ u"tr",u"Keskin",49701,39.673056,33.613611 ],
    [ u"tr",u"Kestel",36204,40.198283,29.212369 ],
    [ u"tr",u"Kilis",82304,36.716111,37.115 ],
    [ u"tr",u"Kirac",27970,41.037222,28.643333 ],
    [ u"tr",u"Konya",876004,37.871354,32.484636 ],
    [ u"tr",u"Körfez",90626,40.776667,29.729722 ],
    [ u"tr",u"Kozan",88160,37.455167,35.81573 ],
    [ u"tr",u"Kozluk",29517,38.193828,41.488526 ],
    [ u"tr",u"Kula",31116,38.547261,28.649761 ],
    [ u"tr",u"Kulu",47061,39.095135,33.079893 ],
    [ u"tr",u"Kumburgaz",11956,41.02107,28.477154 ],
    [ u"tr",u"Kumluca",30355,36.370278,30.286944 ],
    [ u"tr",u"Kurtalan",32131,37.927174,41.702816 ],
    [ u"tr",u"Kütahya",185104,39.424167,29.983333 ],
    [ u"tr",u"Luleburgaz",90947,41.403848,27.359181 ],
    [ u"tr",u"Malatya",442046,38.350183,38.316669 ],
    [ u"tr",u"Malazgirt",26121,39.14265,42.540077 ],
    [ u"tr",u"Malkara",27441,40.89,26.901111 ],
    [ u"tr",u"Manavgat",96102,36.786667,31.443056 ],
    [ u"tr",u"Manisa",244095,38.612018,27.426465 ],
    [ u"tr",u"Mardin",71409,37.313092,40.743569 ],
    [ u"tr",u"Marmaris",33749,36.855,28.274167 ],
    [ u"tr",u"Menemen",53518,38.607536,27.069382 ],
    [ u"tr",u"Mersin",612540,36.732778,34.644167 ],
    [ u"tr",u"Merzifon",50685,40.873333,35.463056 ],
    [ u"tr",u"Midyat",76307,37.424704,41.339335 ],
    [ u"tr",u"Milas",43215,37.316389,27.783889 ],
    [ u"tr",u"Mimarsinan",31021,41.003154,28.537681 ],
    [ u"tr",u"Mudanya",23174,40.375278,28.882222 ],
    [ u"tr",u"Mugla",48208,37.218066,28.366497 ],
    [ u"tr",u"Muratbey",2166,41.094985,28.49403 ],
    [ u"tr",u"Mus",82578,38.74525,41.506929 ],
    [ u"tr",u"Mustafakemalpasa",54519,40.035278,28.411667 ],
    [ u"tr",u"Mut",49423,36.643887,33.438847 ],
    [ u"tr",u"Nazilli",119430,37.916309,28.322249 ],
    [ u"tr",u"Nevsehir",75565,38.625,34.712222 ],
    [ u"tr",u"Nigde",91086,37.965834,34.679352 ],
    [ u"tr",u"Niksar",49890,40.591667,36.951667 ],
    [ u"tr",u"Nizip",82351,37.009722,37.794167 ],
    [ u"tr",u"Nusaybin",89022,37.077795,41.217797 ],
    [ u"tr",u"Odemis",67187,38.227805,27.969551 ],
    [ u"tr",u"Of",31968,40.944575,40.267465 ],
    [ u"tr",u"Oltu",23516,40.549831,42.001258 ],
    [ u"tr",u"Ordu",116846,40.984722,37.878889 ],
    [ u"tr",u"Orhangazi",51818,40.489167,29.308889 ],
    [ u"tr",u"Ortaköy",3837,41.101604,28.375869 ],
    [ u"tr",u"Ortaköy",31159,38.737281,34.038658 ],
    [ u"tr",u"Osmaniye",202944,37.074167,36.247778 ],
    [ u"tr",u"Pasinler",24565,39.980307,41.676353 ],
    [ u"tr",u"Patnos",87490,39.233614,42.863436 ],
    [ u"tr",u"Rize",92820,41.020833,40.521944 ],
    [ u"tr",u"Safranbolu",35259,41.250833,32.694167 ],
    [ u"tr",u"Salihli",88950,38.482581,28.147737 ],
    [ u"tr",u"Samandag",38434,36.084187,35.977139 ],
    [ u"tr",u"Samsun",394261,41.286667,36.33 ],
    [ u"tr",u"Sarkikaraagac",32785,38.079444,31.366389 ],
    [ u"tr",u"Sebinkarahisar",47384,40.288333,38.423611 ],
    [ u"tr",u"Selçuk",29116,37.948564,27.372747 ],
    [ u"tr",u"Selimpasa",10569,41.055838,28.378949 ],
    [ u"tr",u"Sereflikochisar",44124,38.945099,33.542998 ],
    [ u"tr",u"Serik",36945,36.916944,31.098889 ],
    [ u"tr",u"Seydisehir",51114,37.419256,31.845269 ],
    [ u"tr",u"Siirt",114094,37.932624,41.940247 ],
    [ u"tr",u"Sile",11602,41.175403,29.61333 ],
    [ u"tr",u"Silifke",75353,36.377778,33.934444 ],
    [ u"tr",u"Silivri",53196,41.080217,28.226051 ],
    [ u"tr",u"Silopi",74833,37.249722,42.469444 ],
    [ u"tr",u"Silvan",65990,38.141944,41.008056 ],
    [ u"tr",u"Simav",34924,39.088204,28.977673 ],
    [ u"tr",u"Sinop",34827,42.026829,35.162525 ],
    [ u"tr",u"Sirnak",72439,37.522778,42.459444 ],
    [ u"tr",u"Sivas",264163,39.748333,37.016111 ],
    [ u"tr",u"Siverek",175432,37.755025,39.316667 ],
    [ u"tr",u"Söke",68265,37.7482,27.40614 ],
    [ u"tr",u"Solhan",15311,38.963375,41.029307 ],
    [ u"tr",u"Soma",65967,39.185535,27.609449 ],
    [ u"tr",u"Sorgun",62894,39.810125,35.185959 ],
    [ u"tr",u"Suhut",13849,38.531111,30.545833 ],
    [ u"tr",u"Suluova",47596,40.831285,35.647882 ],
    [ u"tr",u"Sungurlu",37544,40.1675,34.373889 ],
    [ u"tr",u"Suruç",46718,36.976137,38.424954 ],
    [ u"tr",u"Susehri",25832,40.164444,38.086667 ],
    [ u"tr",u"Susurluk",24829,39.913611,28.157778 ],
    [ u"tr",u"Talas",36908,38.690805,35.553801 ],
    [ u"tr",u"Tarsus",256617,36.91876,34.878404 ],
    [ u"tr",u"Tatvan",73259,38.506667,42.281667 ],
    [ u"tr",u"Tekirdag",122350,40.978012,27.508524 ],
    [ u"tr",u"Tepecik",21711,41.029311,28.549785 ],
    [ u"tr",u"Terme",28411,41.209167,36.973889 ],
    [ u"tr",u"Tire",47245,38.088769,27.73508 ],
    [ u"tr",u"Tokat",129768,40.313889,36.554444 ],
    [ u"tr",u"Tosya",24025,41.015447,34.040126 ],
    [ u"tr",u"Trabzon",244209,41.005,39.726944 ],
    [ u"tr",u"Tunceli",29042,39.108288,39.547112 ],
    [ u"tr",u"Turgutlu",103346,38.495332,27.699697 ],
    [ u"tr",u"Turhal",110941,40.3875,36.081111 ],
    [ u"tr",u"Ünye",77626,41.131389,37.2825 ],
    [ u"tr",u"Urfa",449785,37.16708,38.793919 ],
    [ u"tr",u"Urla",45222,38.322919,26.76403 ],
    [ u"tr",u"Usak",152943,38.673511,29.405799 ],
    [ u"tr",u"Üzümlü",39609,39.710107,39.702129 ],
    [ u"tr",u"Uzunköprü",36488,41.265975,26.688496 ],
    [ u"tr",u"Van",371911,38.492393,43.38311 ],
    [ u"tr",u"Vezirköprü",25168,41.143611,35.454722 ],
    [ u"tr",u"Viransehir",154244,37.235278,39.763056 ],
    [ u"tr",u"Yakuplu",28828,40.983333,28.65 ],
    [ u"tr",u"Yalova",71327,40.655015,29.276933 ],
    [ u"tr",u"Yalvaç",39165,38.295556,31.177778 ],
    [ u"tr",u"Yenisehir",28671,40.264444,29.653056 ],
    [ u"tr",u"Yerköy",35312,39.638056,34.467222 ],
    [ u"tr",u"Yozgat",87926,39.82,34.804444 ],
    [ u"tr",u"Yüksekova",71763,37.313813,44.166061 ],
    [ u"tr",u"Zile",55708,40.303056,35.886389 ],
    [ u"tr",u"Zonguldak",100281,41.451392,31.793053 ],
    [ u"tt",u"Arima",34996,10.6333333,-61.2833333 ],
    [ u"tt",u"Arouca",12054,10.6333333,-61.3333333 ],
    [ u"tt",u"Chaguanas",72158,10.5166667,-61.4166667 ],
    [ u"tt",u"Couva",5178,10.4166667,-61.45 ],
    [ u"tt",u"Débé",3127,10.2,-61.45 ],
    [ u"tt",u"Marabella",26700,10.3,-61.45 ],
    [ u"tt",u"Mucurapo",4342,10.6666667,-61.5333333 ],
    [ u"tt",u"Peñal",4899,10.1666667,-61.4666667 ],
    [ u"tt",u"Point Fortin",18918,10.1833333,-61.6833333 ],
    [ u"tt",u"Princes Town",11000,10.2666667,-61.3833333 ],
    [ u"tt",u"Rio Claro",2808,10.3,-61.1833333 ],
    [ u"tt",u"San Fernando",56379,10.2833333,-61.4666667 ],
    [ u"tt",u"Sangre Grande",15968,10.5666667,-61.1333333 ],
    [ u"tt",u"Scarborough",4595,11.1833333,-60.7333333 ],
    [ u"tt",u"Siparia",8568,10.1333333,-61.5 ],
    [ u"tt",u"Tabaquite",3314,10.3833333,-61.3 ],
    [ u"tt",u"Tacarigua",15067,10.6333333,-61.3666667 ],
    [ u"tt",u"Tunapuna",17758,10.6333333,-61.3833333 ],
    [ u"tv",u"Asau",628,-7.5,178.6666667 ],
    [ u"tv",u"Lolua",628,-5.6666667,176.1333333 ],
    [ u"tv",u"Tanrake",381,-7.25,177.15 ],
    [ u"tv",u"Tonga",376,-6.2833333,176.3166667 ],
    [ u"tw",u"Chaochou",58795,22.55,120.5388889 ],
    [ u"tw",u"Chengkung",18621,24.2,120.8333333 ],
    [ u"tw",u"Chiali",58438,23.16,120.1777778 ],
    [ u"tw",u"Chichi",11284,23.8275,120.7902778 ],
    [ u"tw",u"Chihu",56733,23.9605556,120.48 ],
    [ u"tw",u"Chingshui",82843,24.2688889,120.5761111 ],
    [ u"tw",u"Chishan",41137,22.8888889,120.4822222 ],
    [ u"tw",u"Cholan",18806,24.3113889,120.8266667 ],
    [ u"tw",u"Chunan",71204,24.6852778,120.8788889 ],
    [ u"tw",u"Chungho",378389,24.9944444,121.4727778 ],
    [ u"tw",u"Chupei",106065,24.8333333,121.0 ],
    [ u"tw",u"Chushan",59640,23.7563889,120.6827778 ],
    [ u"tw",u"Chutung",92669,24.7333333,121.0833333 ],
    [ u"tw",u"Erhlin",55234,23.9005556,120.3686111 ],
    [ u"tw",u"Fengshan",334443,22.6333333,120.35 ],
    [ u"tw",u"Homei",88185,24.1122222,120.4977778 ],
    [ u"tw",u"Houlung",41120,24.6141667,120.7877778 ],
    [ u"tw",u"Hsichih",213899,25.0691667,121.6505556 ],
    [ u"tw",u"Hsilo",48180,23.8008333,120.4613889 ],
    [ u"tw",u"Hsinchu",413683,24.8047222,120.9713889 ],
    [ u"tw",u"Hsinhua",47816,23.0377778,120.3075 ],
    [ u"tw",u"Hsinpu",35417,24.8333333,121.0666667 ],
    [ u"tw",u"Hsintien",275698,24.95,121.5333333 ],
    [ u"tw",u"Hsinying",77207,23.3052778,120.315 ],
    [ u"tw",u"Huwei",63693,23.7083333,120.435 ],
    [ u"tw",u"Ilan",92920,24.7666667,121.75 ],
    [ u"tw",u"Juifang",44657,25.1097222,121.8041667 ],
    [ u"tw",u"Kangshan",97102,22.7958333,120.2941667 ],
    [ u"tw",u"Kaohsiung",1512832,22.6177778,120.3013889 ],
    [ u"tw",u"Kaohsiung",1512832,22.6333333,120.35 ],
    [ u"tw",u"Keelung",397516,25.1313889,121.7375 ],
    [ u"tw",u"Kuanhsi",34720,24.8,121.1666667 ],
    [ u"tw",u"Kuanshan",10245,23.05,121.15 ],
    [ u"tw",u"Lotung",70627,24.6833333,121.7666667 ],
    [ u"tw",u"Luchou",203059,25.0830556,121.47 ],
    [ u"tw",u"Lukang",83071,24.055,120.4338889 ],
    [ u"tw",u"Makung",51043,23.5666667,119.5666667 ],
    [ u"tw",u"Matou",46728,23.1858333,120.2463889 ],
    [ u"tw",u"Meinung",43005,22.9008333,120.5433333 ],
    [ u"tw",u"Miaoli",88945,24.5588889,120.8219444 ],
    [ u"tw",u"Nantou",107219,23.9088889,120.6847222 ],
    [ u"tw",u"Paiho",32064,23.3513889,120.4152778 ],
    [ u"tw",u"Panchiao",491891,25.0391667,121.525 ],
    [ u"tw",u"Pate",176909,24.9333333,121.2833333 ],
    [ u"tw",u"Peikang",43945,23.5733333,120.3013889 ],
    [ u"tw",u"Peitou",34466,23.8744444,120.5219444 ],
    [ u"tw",u"Pingchen",219163,24.95,121.2 ],
    [ u"tw",u"Pingtung",208920,22.6725,120.4883333 ],
    [ u"tw",u"Potzu",42268,23.4675,120.2433333 ],
    [ u"tw",u"Puli",87642,23.9647222,120.9672222 ],
    [ u"tw",u"Putai",30975,23.3783333,120.1583333 ],
    [ u"tw",u"Sanchung",360829,25.0630556,121.4638889 ],
    [ u"tw",u"Sanhsia",100698,24.9333333,121.3666667 ],
    [ u"tw",u"Shalu",72263,24.2358333,120.5597222 ],
    [ u"tw",u"Shulin",179136,25.0,121.4166667 ],
    [ u"tw",u"Suao",43156,24.6,121.8333333 ],
    [ u"tw",u"Tachia",78670,24.3461111,120.6263889 ],
    [ u"tw",u"Tachi",84552,24.8833333,121.2833333 ],
    [ u"tw",u"Taichung",1083582,24.1433333,120.6813889 ],
    [ u"tw",u"Tainan",734314,22.9933333,120.2036111 ],
    [ u"tw",u"Taipao",34737,23.4647222,120.3319444 ],
    [ u"tw",u"Taipei",2514794,25.0391667,121.525 ],
    [ u"tw",u"Taitung",109353,22.75,121.15 ],
    [ u"tw",u"Talin",34975,23.6061111,120.4533333 ],
    [ u"tw",u"Tali",190564,24.1,120.6666667 ],
    [ u"tw",u"Tanshui",133001,25.1777778,121.4433333 ],
    [ u"tw",u"Taoyüan",375366,24.9869444,121.3055556 ],
    [ u"tw",u"Tienchung",46310,23.8602778,120.5852778 ],
    [ u"tw",u"Toucheng",31414,24.8666667,121.8166667 ],
    [ u"tw",u"Toufen",92557,24.6861111,120.9083333 ],
    [ u"tw",u"Touliu",104726,23.7091667,120.5422222 ],
    [ u"tw",u"Tounan",48112,23.6786111,120.4777778 ],
    [ u"tw",u"Tsaotun",99423,23.9816667,120.6852778 ],
    [ u"tw",u"Tucheng",332405,24.9833333,121.4333333 ],
    [ u"tw",u"Tuku",31038,23.6794444,120.3919444 ],
    [ u"tw",u"Tunghsiao",39058,24.4894444,120.6797222 ],
    [ u"tw",u"Tungkang",51500,22.4647222,120.4494444 ],
    [ u"tw",u"Wuchi",53919,24.2544444,120.5297222 ],
    [ u"tw",u"Yangmei",149768,24.9166667,121.1333333 ],
    [ u"tw",u"Yingko",86237,24.95,121.35 ],
    [ u"tw",u"Yüanlin",127650,23.9575,120.5733333 ],
    [ u"tw",u"Yüanli",49231,24.4427778,120.6533333 ],
    [ u"tw",u"Yüli",30038,23.3333333,121.3 ],
    [ u"tw",u"Yungho",207852,25.0,121.4961111 ],
    [ u"tw",u"Yungkang",240214,22.9333333,121.1 ],
    [ u"tz",u"Arusha",341155,-3.3666667,36.6833333 ],
    [ u"tz",u"Babati",34292,-4.2166667,35.75 ],
    [ u"tz",u"Bagamoyo",82578,-6.4333333,38.9 ],
    [ u"tz",u"Bariadi",33865,-2.8,33.9833333 ],
    [ u"tz",u"Biharamulo",34038,-2.6319444,31.3088889 ],
    [ u"tz",u"Bugarama",32494,-2.8705556,30.5280556 ],
    [ u"tz",u"Bugene",10609,-1.5911111,31.1402778 ],
    [ u"tz",u"Bukene",7444,-4.2333333,32.8833333 ],
    [ u"tz",u"Bukoba",70630,-1.3316667,31.8122222 ],
    [ u"tz",u"Bunda",50949,-2.05,33.8666667 ],
    [ u"tz",u"Bungu",27873,-7.6333333,39.05 ],
    [ u"tz",u"Buseresere",52870,-3.0236111,31.8747222 ],
    [ u"tz",u"Butiama",16376,-1.7666667,33.9666667 ],
    [ u"tz",u"Bwanga",20929,-3.0322222,31.7636111 ],
    [ u"tz",u"Chake Chake",21687,-5.25,39.7666667 ],
    [ u"tz",u"Chala",22624,-7.5833333,31.2666667 ],
    [ u"tz",u"Chalinze",34335,-6.6,38.35 ],
    [ u"tz",u"Chanika",30905,-5.4166667,38.0166667 ],
    [ u"tz",u"Chato",27776,-2.6377778,31.7669444 ],
    [ u"tz",u"Chimala",24817,-8.85,34.0166667 ],
    [ u"tz",u"Chiungutwa",12764,-10.8833333,38.9833333 ],
    [ u"tz",u"Dareda",19876,-4.2166667,35.55 ],
    [ u"tz",u"Dar es Salaam",2698651,-6.8,39.2833333 ],
    [ u"tz",u"Dodoma",180551,-6.1833333,35.75 ],
    [ u"tz",u"Dongobesh",18864,-4.0666667,35.3833333 ],
    [ u"tz",u"Dunda",14080,-8.1166667,34.25 ],
    [ u"tz",u"Gairo",37909,-6.15,36.8666667 ],
    [ u"tz",u"Gamba",3644,-5.9,39.3 ],
    [ u"tz",u"Hedaru",20231,-4.5,37.9 ],
    [ u"tz",u"Ifakara",49532,-8.1333333,36.6833333 ],
    [ u"tz",u"Iguguno",22810,-4.5666667,34.6333333 ],
    [ u"tz",u"Igunga",35644,-4.2833333,33.8833333 ],
    [ u"tz",u"Igurubi",10083,-4.0,33.7 ],
    [ u"tz",u"Igurusi",24895,-8.85,33.85 ],
    [ u"tz",u"Ikungi",19692,-5.1333333,34.7666667 ],
    [ u"tz",u"Ikwiriri",13071,-7.9833333,39.0166667 ],
    [ u"tz",u"Ilembo",2607,-9.25,33.3833333 ],
    [ u"tz",u"Ilembula",18870,-8.9,34.5833333 ],
    [ u"tz",u"Ilongero",17342,-4.6666667,34.8666667 ],
    [ u"tz",u"Ilula",29193,-7.6833333,36.0333333 ],
    [ u"tz",u"Inyonga",11790,-6.7166667,32.0666667 ],
    [ u"tz",u"Ipinda",17775,-9.4833333,33.9 ],
    [ u"tz",u"Iringa",111831,-7.7666667,35.7 ],
    [ u"tz",u"Isaka",21094,-3.9,32.9333333 ],
    [ u"tz",u"Issenye",7778,-2.0,34.3333333 ],
    [ u"tz",u"Itigi",19711,-5.7,34.4833333 ],
    [ u"tz",u"Itumba",13438,-9.4,33.1833333 ],
    [ u"tz",u"Izazi",18010,-7.2,35.7333333 ],
    [ u"tz",u"Kabanga",19421,-2.625,30.4819444 ],
    [ u"tz",u"Kahama",36016,-3.8333333,32.6 ],
    [ u"tz",u"Kakonko",24688,-3.2827778,30.9641667 ],
    [ u"tz",u"Kaliua",12362,-5.0605556,31.7936111 ],
    [ u"tz",u"Kamachumu",15701,-1.6186111,31.62 ],
    [ u"tz",u"Kandete",10318,-9.15,33.8 ],
    [ u"tz",u"Karatu",19803,-3.3333333,35.6666667 ],
    [ u"tz",u"Karema",12630,-6.8166667,30.4333333 ],
    [ u"tz",u"Kasamwa",27681,-2.85,32.4333333 ],
    [ u"tz",u"Kasulu",37347,-4.5766667,30.1025 ],
    [ u"tz",u"Katerero",18430,-1.4,31.7333333 ],
    [ u"tz",u"Katesh",4943,-4.5166667,35.3833333 ],
    [ u"tz",u"Katoro",11925,-1.3997222,31.5002778 ],
    [ u"tz",u"Katumba",108558,-9.2333333,33.6166667 ],
    [ u"tz",u"Kayanga",12407,-1.2166667,31.65 ],
    [ u"tz",u"Kibaha",23653,-6.7666667,38.9166667 ],
    [ u"tz",u"Kibakwe",19526,-6.7166667,36.3666667 ],
    [ u"tz",u"Kibara",17211,-2.15,33.45 ],
    [ u"tz",u"Kibaya",5028,-5.3,36.5666667 ],
    [ u"tz",u"Kibiti",30165,-7.7333333,38.95 ],
    [ u"tz",u"Kibondo",28666,-3.5863889,30.7202778 ],
    [ u"tz",u"Kidodi",35953,-7.6,36.9833333 ],
    [ u"tz",u"Kigoma",164261,-4.8769444,29.6266667 ],
    [ u"tz",u"Kigonsera",22155,-10.8,35.05 ],
    [ u"tz",u"Kihurio",8377,-4.4666667,38.0666667 ],
    [ u"tz",u"Kijini",3720,-5.85,39.3166667 ],
    [ u"tz",u"Kilimatinde",5975,-5.85,34.95 ],
    [ u"tz",u"Kilindoni",12409,-7.9166667,39.65 ],
    [ u"tz",u"Kilosa",91889,-6.8333333,36.9833333 ],
    [ u"tz",u"Kimamba",11235,-6.7833333,37.1333333 ],
    [ u"tz",u"Kingori",22840,-3.2833333,36.9833333 ],
    [ u"tz",u"Kintinku",7906,-5.8833333,35.2333333 ],
    [ u"tz",u"Kiomboi",23519,-4.2666667,34.3666667 ],
    [ u"tz",u"Kirando",33111,-7.4166667,30.6 ],
    [ u"tz",u"Kisanga",10977,-7.4333333,37.7 ],
    [ u"tz",u"Kisarawe",12507,-6.9,39.0666667 ],
    [ u"tz",u"Kisesa",29804,-3.0833333,34.15 ],
    [ u"tz",u"Kishapu",16371,-3.6166667,33.8666667 ],
    [ u"tz",u"Kisiwani",7126,-4.1333333,37.95 ],
    [ u"tz",u"Kitama",16232,-10.7166667,39.7333333 ],
    [ u"tz",u"Kitangari",10956,-10.65,39.3333333 ],
    [ u"tz",u"Kiwira",21342,-9.1666667,33.5333333 ],
    [ u"tz",u"Koani",2311,-6.1333333,39.2833333 ],
    [ u"tz",u"Konde",9530,-4.95,39.75 ],
    [ u"tz",u"Kondoa",23520,-4.9,35.7833333 ],
    [ u"tz",u"Kongwa",11840,-6.2,36.4166667 ],
    [ u"tz",u"Korogwe",33919,-5.15,38.4833333 ],
    [ u"tz",u"Kwakoa",7514,-3.7666667,37.7166667 ],
    [ u"tz",u"Kyaka",13809,-1.2522222,31.4202778 ],
    [ u"tz",u"Kyela",30684,-9.5833333,33.85 ],
    [ u"tz",u"Laela",19185,-8.5666667,32.05 ],
    [ u"tz",u"Lembeni",16008,-3.7833333,37.6166667 ],
    [ u"tz",u"Lindi",41915,-10.0,39.7166667 ],
    [ u"tz",u"Liuli",13119,-11.0833333,34.6333333 ],
    [ u"tz",u"Liwale",19296,-9.7666667,37.9333333 ],
    [ u"tz",u"Longido",9403,-2.7333333,36.6833333 ],
    [ u"tz",u"Luchingu",25145,-10.9,39.3333333 ],
    [ u"tz",u"Lugoba",16902,-6.45,38.3333333 ],
    [ u"tz",u"Lukuledi",29699,-10.5666667,38.8 ],
    [ u"tz",u"Lulindi",7807,-10.8166667,39.1333333 ],
    [ u"tz",u"Lupiro",11430,-8.3833333,36.6666667 ],
    [ u"tz",u"Lushoto",24197,-4.7833333,38.2833333 ],
    [ u"tz",u"Mabama",15320,-5.1333333,32.5333333 ],
    [ u"tz",u"Mabamba",14140,-3.5983333,30.5019444 ],
    [ u"tz",u"Madimba",12507,-10.4,40.3333333 ],
    [ u"tz",u"Mafinga",34958,-7.25,35.0666667 ],
    [ u"tz",u"Magole",18753,-6.3666667,37.3666667 ],
    [ u"tz",u"Magomeni",8944,-5.2333333,38.1166667 ],
    [ u"tz",u"Magomeni",19086,-6.8,39.25 ],
    [ u"tz",u"Magugu",26132,-4.0166667,35.7666667 ],
    [ u"tz",u"Mahanje",15009,-9.9333333,35.3333333 ],
    [ u"tz",u"Mahenge",7768,-8.6833333,36.7166667 ],
    [ u"tz",u"Mahonda",5569,-6.45,39.4666667 ],
    [ u"tz",u"Mahuta",13548,-10.8666667,39.45 ],
    [ u"tz",u"Majengo",9874,-5.15,38.9833333 ],
    [ u"tz",u"Makambako",53003,-8.85,34.8333333 ],
    [ u"tz",u"Makanya",9505,-4.3333333,37.85 ],
    [ u"tz",u"Makungu",10291,-8.7333333,35.2833333 ],
    [ u"tz",u"Makuyuni",15516,-4.7333333,38.1 ],
    [ u"tz",u"Malampaka",16916,-3.1333333,33.5333333 ],
    [ u"tz",u"Malangali",7112,-8.5666667,34.85 ],
    [ u"tz",u"Malinyi",27041,-8.9333333,36.1333333 ],
    [ u"tz",u"Malya",12627,-2.9833333,33.5166667 ],
    [ u"tz",u"Maneromango",9402,-7.2,38.7833333 ],
    [ u"tz",u"Manyoni",25532,-5.75,34.8333333 ],
    [ u"tz",u"Maposeni",19472,-10.5833333,35.4 ],
    [ u"tz",u"Maramba",26531,-5.05,38.6166667 ],
    [ u"tz",u"Masasi",36034,-10.7166667,38.8 ],
    [ u"tz",u"Masoko",12720,-9.3333333,33.75 ],
    [ u"tz",u"Masuguru",7946,-11.3666667,38.4166667 ],
    [ u"tz",u"Masumbwe",34780,-3.6333333,32.1833333 ],
    [ u"tz",u"Maswa",22025,-2.6833333,33.9833333 ],
    [ u"tz",u"Matai",24070,-8.3,31.5166667 ],
    [ u"tz",u"Matamba",10642,-8.9833333,33.9666667 ],
    [ u"tz",u"Matiri",18830,-10.75,34.9 ],
    [ u"tz",u"Matongo",11828,-2.3833333,34.0833333 ],
    [ u"tz",u"Matui",20242,-4.8,38.25 ],
    [ u"tz",u"Mazinde",20534,-4.8,38.2166667 ],
    [ u"tz",u"Mbamba",8997,-11.2833333,34.7666667 ],
    [ u"tz",u"Mbekenyera",11794,-10.0,38.9833333 ],
    [ u"tz",u"Mbeya",291672,-8.9,33.45 ],
    [ u"tz",u"Mbinga",25192,-10.9333333,35.0166667 ],
    [ u"tz",u"Mbuguni",16442,-3.5666667,36.95 ],
    [ u"tz",u"Mbulu",13430,-3.85,35.5333333 ],
    [ u"tz",u"Mbumi",4305,-7.9,39.2 ],
    [ u"tz",u"Mgandu",23718,-5.95,34.1333333 ],
    [ u"tz",u"Mhango",21553,-3.2833333,32.85 ],
    [ u"tz",u"Micheweni",9838,-4.9666667,39.8333333 ],
    [ u"tz",u"Mikumi",16780,-7.4,36.9833333 ],
    [ u"tz",u"Mingoyo",10480,-10.1,39.6333333 ],
    [ u"tz",u"Misasi",14170,-3.0,33.0833333 ],
    [ u"tz",u"Missungwi",35530,-2.85,33.0833333 ],
    [ u"tz",u"Mkokotoni",2572,-5.8666667,39.25 ],
    [ u"tz",u"Mkuranga",28037,-7.1166667,39.2 ],
    [ u"tz",u"Mlalo",15576,-4.9333333,38.9333333 ],
    [ u"tz",u"Mlandizi",29394,-6.7,38.7333333 ],
    [ u"tz",u"Mlimba",34969,-8.8,35.8166667 ],
    [ u"tz",u"Mlowo",18737,-9.0,32.9833333 ],
    [ u"tz",u"Monduli",5694,-3.3,36.45 ],
    [ u"tz",u"Morogoro",250914,-6.8166667,37.6666667 ],
    [ u"tz",u"Moshi",156970,-3.35,37.3333333 ],
    [ u"tz",u"Mpanda",73338,-6.3666667,31.0333333 ],
    [ u"tz",u"Mpwapwa",19806,-6.35,36.4833333 ],
    [ u"tz",u"Msanga",5527,-6.05,36.0333333 ],
    [ u"tz",u"Msowero",17861,-6.5333333,37.2 ],
    [ u"tz",u"Mtama",11928,-10.3,39.3666667 ],
    [ u"tz",u"Mtambile",6797,-5.3833333,39.7 ],
    [ u"tz",u"Mtimbira",11122,-8.7833333,36.35 ],
    [ u"tz",u"Mtinko",26725,-4.55,34.85 ],
    [ u"tz",u"Mto wa Mbu",17755,-3.35,35.85 ],
    [ u"tz",u"Mtwango",19040,-9.0166667,34.8 ],
    [ u"tz",u"Mtwara",96606,-10.2666667,40.1833333 ],
    [ u"tz",u"Mugango",10550,-1.6833333,33.7 ],
    [ u"tz",u"Mugumu",18431,-1.85,34.7 ],
    [ u"tz",u"Muheza",17000,-5.1666667,38.7833333 ],
    [ u"tz",u"Muleba",11555,-1.8397222,31.6544444 ],
    [ u"tz",u"Mungaa",16715,-4.9666667,34.8833333 ],
    [ u"tz",u"Muriti",20254,-1.9833333,32.9166667 ],
    [ u"tz",u"Musoma",121125,-1.5,33.8 ],
    [ u"tz",u"Mvomero",31324,-6.25,38.6666667 ],
    [ u"tz",u"Mwadui",23298,-3.55,33.6 ],
    [ u"tz",u"Mwandiga",16822,-4.83,29.6580556 ],
    [ u"tz",u"Mwanga",12846,-4.8,38.2 ],
    [ u"tz",u"Mwanza",436811,-2.5166667,32.9 ],
    [ u"tz",u"Mwaya",7558,-9.55,33.95 ],
    [ u"tz",u"Mwembe",9032,-4.15,37.85 ],
    [ u"tz",u"Naberera",13500,-4.2,36.9333333 ],
    [ u"tz",u"Nachingwea",18058,-10.3833333,38.7666667 ],
    [ u"tz",u"Nakatunguru",6064,-2.1166667,33.0666667 ],
    [ u"tz",u"Namalenga",11204,-10.95,39.1 ],
    [ u"tz",u"Namanga",12049,-2.55,36.7666667 ],
    [ u"tz",u"Namanyere",28218,-7.5166667,31.05 ],
    [ u"tz",u"Namikupa",11733,-10.8166667,39.65 ],
    [ u"tz",u"Nanganga",17468,-10.3833333,39.15 ],
    [ u"tz",u"Nangomba",23028,-10.9,38.5 ],
    [ u"tz",u"Nangwa",18595,-4.4666667,35.45 ],
    [ u"tz",u"Nanhyanga",13519,-10.8,39.55 ],
    [ u"tz",u"Nansio",6437,-2.1333333,33.05 ],
    [ u"tz",u"Nanyamba",19555,-10.6833333,39.8333333 ],
    [ u"tz",u"Ndago",13012,-4.6,34.35 ],
    [ u"tz",u"Ndungu",14545,-4.3666667,38.05 ],
    [ u"tz",u"Newala",38164,-10.9333333,39.3 ],
    [ u"tz",u"Ngara",16890,-2.5122222,30.6558333 ],
    [ u"tz",u"Ngerengere",17181,-6.75,38.1166667 ],
    [ u"tz",u"Ngorongoro",10836,-3.25,35.5166667 ],
    [ u"tz",u"Ngudu",22658,-2.9666667,33.3333333 ],
    [ u"tz",u"Nguruka",39135,-5.1091667,31.0419444 ],
    [ u"tz",u"Njombe",46731,-9.3333333,34.7666667 ],
    [ u"tz",u"Nkoaranga",14738,-3.3333333,36.8 ],
    [ u"tz",u"Nshamba",19815,-1.7983333,31.5511111 ],
    [ u"tz",u"Nsunga",20049,-1.1438889,31.3947222 ],
    [ u"tz",u"Nyakabindi",18427,-2.6333333,33.9833333 ],
    [ u"tz",u"Nyakahanga",14611,-1.6033333,31.1413889 ],
    [ u"tz",u"Nyalikungu",24648,-3.1833333,33.7833333 ],
    [ u"tz",u"Nyamuswa",16507,-1.9,34.0166667 ],
    [ u"tz",u"Nyangao",16343,-10.3333333,39.2833333 ],
    [ u"tz",u"Nyanguge",10746,-2.55,33.2 ],
    [ u"tz",u"Nzega",26584,-4.2166667,33.1833333 ],
    [ u"tz",u"Old Shinyanga",23746,-3.55,33.4 ],
    [ u"tz",u"Pangani",8343,-5.4333333,38.9666667 ],
    [ u"tz",u"Poli",9568,-3.3333333,36.8 ],
    [ u"tz",u"Puma",17092,-5.0,34.7333333 ],
    [ u"tz",u"Ruangwa",11095,-10.0666667,38.9333333 ],
    [ u"tz",u"Rujewa",29228,-8.7,34.3833333 ],
    [ u"tz",u"Rulenge",22069,-2.7175,30.6325 ],
    [ u"tz",u"Same",17455,-4.0666667,37.7333333 ],
    [ u"tz",u"Sepuka",25657,-4.75,34.5333333 ],
    [ u"tz",u"Shelui",24817,-4.3666667,34.2 ],
    [ u"tz",u"Shinyanga",107365,-3.6666667,33.4333333 ],
    [ u"tz",u"Sikonge",27113,-5.6333333,32.7666667 ],
    [ u"tz",u"Singida",62436,-4.8166667,34.75 ],
    [ u"tz",u"Sirari",24317,-1.2333333,34.4333333 ],
    [ u"tz",u"Sokoni",25822,-6.4333333,39.55 ],
    [ u"tz",u"Somanda",33932,-3.3666667,33.95 ],
    [ u"tz",u"Songea",126499,-10.6833333,35.65 ],
    [ u"tz",u"Songwa",23618,-3.5166667,33.5166667 ],
    [ u"tz",u"Soni",12402,-4.85,38.3666667 ],
    [ u"tz",u"Sumbawanga",89169,-7.9666667,31.6166667 ],
    [ u"tz",u"Tabora",145291,-5.0166667,32.8 ],
    [ u"tz",u"Tandahimba",17041,-10.75,39.6333333 ],
    [ u"tz",u"Tanga",224891,-5.0666667,39.1 ],
    [ u"tz",u"Tarime",33097,-1.35,34.3666667 ],
    [ u"tz",u"Tinde",22082,-3.8833333,33.2 ],
    [ u"tz",u"Tingi",16315,-11.3,35.0333333 ],
    [ u"tz",u"Tukuyu",28398,-9.25,33.65 ],
    [ u"tz",u"Tumbi",32900,-5.0666667,32.7333333 ],
    [ u"tz",u"Tunduma",36556,-9.3,32.7666667 ],
    [ u"tz",u"Tunduru",36796,-11.0666667,37.35 ],
    [ u"tz",u"Ulenje",12219,-8.9333333,33.6833333 ],
    [ u"tz",u"Urambo",23723,-5.0666667,32.05 ],
    [ u"tz",u"Usagara",15514,-2.6833333,33.0 ],
    [ u"tz",u"Usa River",18726,-3.3666667,36.85 ],
    [ u"tz",u"Usevya",17742,-7.1,31.2333333 ],
    [ u"tz",u"Ushirombo",95052,-3.4919444,31.9638889 ],
    [ u"tz",u"Usoke",7295,-5.1,32.3333333 ],
    [ u"tz",u"Utete",11889,-7.9833333,38.7833333 ],
    [ u"tz",u"Uvinza",24650,-5.1036111,30.3911111 ],
    [ u"tz",u"Uyovu",60849,-3.2833333,31.5258333 ],
    [ u"tz",u"Vikindu",23307,-6.9833333,39.2833333 ],
    [ u"tz",u"Vwawa",40144,-9.1166667,32.9333333 ],
    [ u"tz",u"Wete",26452,-5.0666667,39.7166667 ],
    [ u"tz",u"Zanzibar",403670,-6.1666667,39.1833333 ],
    [ u"ua",u"Adzhamka",3859,48.542445,32.535419 ],
    [ u"ua",u"Ahrarne",3326,45.015958,34.057246 ],
    [ u"ua",u"Aleksandriya",91206,48.669614,33.115934 ],
    [ u"ua",u"Alushta",30271,44.676307,34.407785 ],
    [ u"ua",u"Amvrosiyivka",21307,47.793485,38.47768 ],
    [ u"ua",u"Andrushivka",9522,50.022878,29.020226 ],
    [ u"ua",u"Antoniny",2592,49.809743,26.877143 ],
    [ u"ua",u"Apostolove",15828,47.660028,33.713686 ],
    [ u"ua",u"Arbuzynka",7140,47.909719,31.31963 ],
    [ u"ua",u"Artëmovsk",80655,48.595594,37.999871 ],
    [ u"ua",u"Artsyz",15761,45.991936,29.418236 ],
    [ u"ua",u"Auly",4167,48.527081,34.494931 ],
    [ u"ua",u"Avdiyivka",35826,48.139892,37.742549 ],
    [ u"ua",u"Babanka",2460,48.709706,30.448267 ],
    [ u"ua",u"Baherove",4382,45.374174,36.297047 ],
    [ u"ua",u"Bakhchysaray",26525,44.755246,33.857819 ],
    [ u"ua",u"Bakhmach",2970,51.180763,32.756943 ],
    [ u"ua",u"Balakliya",31156,49.462699,36.859508 ],
    [ u"ua",u"Balky",5717,47.383365,34.94396 ],
    [ u"ua",u"Balta",19220,47.935476,29.619822 ],
    [ u"ua",u"Banyliv",3748,48.366125,25.345488 ],
    [ u"ua",u"Bar",16641,49.07717,27.682559 ],
    [ u"ua",u"Barvinkove",12344,48.909696,37.020511 ],
    [ u"ua",u"Baryshivka",10762,50.36098,31.32173 ],
    [ u"ua",u"Bashtanka",12657,47.407188,32.438682 ],
    [ u"ua",u"Baturyn",2964,51.345668,32.877943 ],
    [ u"ua",u"Bazaliya",2035,49.712668,26.473313 ],
    [ u"ua",u"Bekhtery",2909,46.250993,32.292672 ],
    [ u"ua",u"Beloye",6775,48.495229,39.050513 ],
    [ u"ua",u"Belz",2386,50.382261,24.006416 ],
    [ u"ua",u"Berdychiv",86250,49.899285,28.602346 ],
    [ u"ua",u"Berehomet",8227,48.17882,25.348548 ],
    [ u"ua",u"Berehove",500,44.901477,33.621587 ],
    [ u"ua",u"Berehove",25741,48.20555,22.644176 ],
    [ u"ua",u"Berestechko",1830,50.357486,25.115859 ],
    [ u"ua",u"Berezanka",4090,46.852615,31.388025 ],
    [ u"ua",u"Berezhany",16962,49.442315,24.932315 ],
    [ u"ua",u"Berezivka",1618,49.44107,35.711669 ],
    [ u"ua",u"Berezna",5172,51.571605,31.784558 ],
    [ u"ua",u"Bereznehuvate",7506,47.30783,32.84993 ],
    [ u"ua",u"Bereznyky",3055,48.514065,23.219822 ],
    [ u"ua",u"Berezovo",2885,48.309431,23.474004 ],
    [ u"ua",u"Berezyne",3658,46.22968,29.204362 ],
    [ u"ua",u"Beryslav",14880,46.841522,33.42838 ],
    [ u"ua",u"Bezlyudivka",9294,49.87185,36.295161 ],
    [ u"ua",u"Bila",3728,49.029004,25.770586 ],
    [ u"ua",u"Bila Krynytsya",1029,50.639818,29.470409 ],
    [ u"ua",u"Bila Tserkva",199161,49.809386,30.112086 ],
    [ u"ua",u"Bili Oslavy",4351,48.487218,24.700775 ],
    [ u"ua",u"Bilky",7778,48.315033,23.13248 ],
    [ u"ua",u"Bilokurakyne",7712,49.534099,38.73067 ],
    [ u"ua",u"Bilopillya",17824,51.15016,34.312866 ],
    [ u"ua",u"Bilozerka",9348,46.624798,32.442509 ],
    [ u"ua",u"Bilyayivka",13762,46.483191,30.216779 ],
    [ u"ua",u"Biryukove",4250,47.956306,39.738426 ],
    [ u"ua",u"Blagodatnoye",1263,47.700134,37.418978 ],
    [ u"ua",u"Blahodatne",3512,47.879282,38.484917 ],
    [ u"ua",u"Blyznyuky",4824,48.857747,36.555046 ],
    [ u"ua",u"Bobrovytsya",11544,50.746927,31.394802 ],
    [ u"ua",u"Bohdan",3155,48.041221,24.352224 ],
    [ u"ua",u"Bohodukhiv",17817,50.164661,35.527652 ],
    [ u"ua",u"Bohorodchany",7328,48.806996,24.538342 ],
    [ u"ua",u"Bohuslav",16498,49.549391,30.874396 ],
    [ u"ua",u"Bolekhiv",10238,49.066073,23.864351 ],
    [ u"ua",u"Bolhrad",16708,45.682621,28.614872 ],
    [ u"ua",u"Borivka",3483,48.505422,28.260741 ],
    [ u"ua",u"Borodino",1758,46.3025,29.241667 ],
    [ u"ua",u"Borodyanka",12069,50.644842,29.920103 ],
    [ u"ua",u"Boromlya",4070,50.618385,34.970415 ],
    [ u"ua",u"Borova",6589,49.377695,37.621363 ],
    [ u"ua",u"Borova",7315,50.176253,30.104292 ],
    [ u"ua",u"Borshchiv",10959,48.803322,26.043466 ],
    [ u"ua",u"Boryslav",36704,49.28672,23.43238 ],
    [ u"ua",u"Borzna",11363,51.254645,32.426901 ],
    [ u"ua",u"Boyany",4260,48.270773,26.126237 ],
    [ u"ua",u"Boyarka",34631,50.319105,30.297278 ],
    [ u"ua",u"Bratslav",5819,48.822572,28.940701 ],
    [ u"ua",u"Brody",22375,50.087911,25.150269 ],
    [ u"ua",u"Broska",3586,45.373275,28.783 ],
    [ u"ua",u"Brovary",88505,50.518094,30.806712 ],
    [ u"ua",u"Brusyliv",5242,50.284486,29.526264 ],
    [ u"ua",u"Bryanka",51920,48.510998,38.672218 ],
    [ u"ua",u"Brylivka",4305,46.424758,33.14721 ],
    [ u"ua",u"Bryukhovychi",5590,49.904669,23.959695 ],
    [ u"ua",u"Buchach",12082,49.062539,25.387981 ],
    [ u"ua",u"Buchmany",792,51.068786,28.042206 ],
    [ u"ua",u"Budy",6742,49.893366,36.022429 ],
    [ u"ua",u"Burshtyn",14729,49.258665,24.627765 ],
    [ u"ua",u"Bushtyno",8236,48.05121,23.485786 ],
    [ u"ua",u"Bykivka",1911,50.292848,27.983142 ],
    [ u"ua",u"Bytkiv",4112,48.629684,24.473978 ],
    [ u"ua",u"Chapayeve",2800,49.366249,35.874856 ],
    [ u"ua",u"Chapayevka",3042,49.381787,30.451366 ],
    [ u"ua",u"Chapayevka",3502,47.471138,36.345066 ],
    [ u"ua",u"Chaplynka",10224,46.365071,33.540274 ],
    [ u"ua",u"Cherkasy",297566,49.428536,32.06207 ],
    [ u"ua",u"Chernelytsya",1809,48.812068,25.424771 ],
    [ u"ua",u"Chernihiv",307683,51.505507,31.284875 ],
    [ u"ua",u"Chernivtsi",236249,48.291488,25.940341 ],
    [ u"ua",u"Cherniyiv",3801,48.856584,24.713884 ],
    [ u"ua",u"Chernyakhiv",10082,50.456524,28.67018 ],
    [ u"ua",u"Chernyatyn",3046,48.660343,25.448315 ],
    [ u"ua",u"Chervona Sloboda",9333,49.378902,32.146432 ],
    [ u"ua",u"Chervone",1800,51.770056,34.067288 ],
    [ u"ua",u"Chervone",2880,49.956429,28.864534 ],
    [ u"ua",u"Chervonohryhorivka",6444,47.622976,34.538874 ],
    [ u"ua",u"Chop",8587,48.431982,22.205549 ],
    [ u"ua",u"Chopovychi",2183,50.833253,28.953344 ],
    [ u"ua",u"Chornobay",8053,49.670791,32.32387 ],
    [ u"ua",u"Chornobayivka",8954,46.694115,32.55371 ],
    [ u"ua",u"Chornoliztsi",2965,48.830336,24.89576 ],
    [ u"ua",u"Chornukhy",3075,50.267317,32.941964 ],
    [ u"ua",u"Chornyanka",3363,46.652217,33.35904 ],
    [ u"ua",u"Chortkiv",27977,49.017087,25.798045 ],
    [ u"ua",u"Chortomlyk",1275,47.623153,34.141977 ],
    [ u"ua",u"Chudey",5058,48.052468,25.62208 ],
    [ u"ua",u"Chudniv",6314,50.052037,28.11745 ],
    [ u"ua",u"Chuhuyiv",36519,49.835884,36.688028 ],
    [ u"ua",u"Chulakivka",2938,46.357626,32.351401 ],
    [ u"ua",u"Chutove",6274,49.710416,35.160255 ],
    [ u"ua",u"Chyhyryn",11515,49.07018,32.678563 ],
    [ u"ua",u"Chynadiyovo",6564,48.481788,22.821701 ],
    [ u"ua",u"Davydivka",2981,48.120993,25.564612 ],
    [ u"ua",u"Delyatyn",7980,48.523545,24.624658 ],
    [ u"ua",u"Derazhnya",10058,49.269198,27.433817 ],
    [ u"ua",u"Dergachi",19321,50.106586,36.121116 ],
    [ u"ua",u"Desna",6906,50.927313,30.760476 ],
    [ u"ua",u"Dibrova",187,51.155557,27.978999 ],
    [ u"ua",u"Dmytrivka",3170,47.936113,38.936607 ],
    [ u"ua",u"Dmytrivka",4070,48.796903,32.716452 ],
    [ u"ua",u"Dmytrivka",4536,45.971667,28.986389 ],
    [ u"ua",u"Dniprorudne",20271,47.38169,34.976522 ],
    [ u"ua",u"Dniprovka",3873,47.429446,34.618052 ],
    [ u"ua",u"Dnipryany",4537,46.746307,33.272879 ],
    [ u"ua",u"Dobroye",3327,44.866321,34.226609 ],
    [ u"ua",u"Dobryanka",3250,52.063136,31.185669 ],
    [ u"ua",u"Domanivka",6517,47.631923,30.988515 ],
    [ u"ua",u"Dovbysh",4559,50.373316,27.987421 ],
    [ u"ua",u"Dovhe",6541,48.36527,23.279045 ],
    [ u"ua",u"Drabiv",7011,49.963019,32.152913 ],
    [ u"ua",u"Drahovo",4262,48.235726,23.54914 ],
    [ u"ua",u"Druzhba",793,50.801555,32.357688 ],
    [ u"ua",u"Druzhba",5220,52.045448,33.945169 ],
    [ u"ua",u"Druzhba",1586,49.042506,25.450549 ],
    [ u"ua",u"Druzhba",531,51.187679,27.974032 ],
    [ u"ua",u"Dublyany",2086,49.498324,23.387184 ],
    [ u"ua",u"Dubno",37690,50.416937,25.734325 ],
    [ u"ua",u"Dubove",8902,48.17205,23.889545 ],
    [ u"ua",u"Dubrovytsya",9285,51.57438,26.565034 ],
    [ u"ua",u"Duliby",3533,49.231341,23.815321 ],
    [ u"ua",u"Dunayivtsi",15836,48.889087,26.856362 ],
    [ u"ua",u"Dvorichna",4322,49.849629,37.68568 ],
    [ u"ua",u"Dymer",5653,50.786469,30.302597 ],
    [ u"ua",u"Dymytrove",5410,48.607672,32.983473 ],
    [ u"ua",u"Dzerzhinsk",41758,48.398694,37.847873 ],
    [ u"ua",u"Dzhankoy",41731,45.711677,34.392739 ],
    [ u"ua",u"Dzhuryn",3648,48.679661,28.286305 ],
    [ u"ua",u"Dzyhivka",3973,48.359065,28.320828 ],
    [ u"ua",u"Eskhar",5349,49.798663,36.588307 ],
    [ u"ua",u"Fastiv",51142,50.0767,29.917704 ],
    [ u"ua",u"Feodosiya",72051,45.036772,35.377892 ],
    [ u"ua",u"Fontanka",6027,46.56255,30.860714 ],
    [ u"ua",u"Frunze",2958,45.026878,33.629563 ],
    [ u"ua",u"Frunze",3605,48.66863,38.754441 ],
    [ u"ua",u"Frunzivka",5007,47.33232,29.759027 ],
    [ u"ua",u"Gornyak",4012,48.055696,37.373087 ],
    [ u"ua",u"Haysyn",24687,48.811429,29.389766 ],
    [ u"ua",u"Hayvoron",15526,48.339579,29.867911 ],
    [ u"ua",u"Hlobyne",12544,49.387837,33.259587 ],
    [ u"ua",u"Hlukhiv",35387,51.678221,33.916204 ],
    [ u"ua",u"Hlyboka",8942,48.089711,25.929333 ],
    [ u"ua",u"Holoby",4203,51.08651,25.007671 ],
    [ u"ua",u"Holovyne",1891,50.471184,28.825302 ],
    [ u"ua",u"Horinchovo",2959,48.270757,23.434747 ],
    [ u"ua",u"Horlivka",278548,48.346981,38.054189 ],
    [ u"ua",u"Hornostayivka",6762,47.007771,33.72899 ],
    [ u"ua",u"Horodenka",9430,48.672738,25.50163 ],
    [ u"ua",u"Horodkivka",6188,48.37753,28.693467 ],
    [ u"ua",u"Horodnya",13601,51.890853,31.597414 ],
    [ u"ua",u"Horodnye",4901,45.890833,28.848333 ],
    [ u"ua",u"Horodnytsya",5238,50.806966,27.316759 ],
    [ u"ua",u"Horodok",17086,49.163739,26.58394 ],
    [ u"ua",u"Horodyshche",15063,49.284887,31.445134 ],
    [ u"ua",u"Horodyshche",3757,50.639653,26.365734 ],
    [ u"ua",u"Hoshcha",5084,50.600295,26.674347 ],
    [ u"ua",u"Hrebinka",11017,50.117116,32.436098 ],
    [ u"ua",u"Hrymayliv",2051,49.332082,26.011119 ],
    [ u"ua",u"Hryshkivtsi",4427,49.935285,28.60383 ],
    [ u"ua",u"Hulyaypole",16442,47.663893,36.256326 ],
    [ u"ua",u"Hurzuf",8810,44.546244,34.278406 ],
    [ u"ua",u"Husyatyn",6481,49.072627,26.2141 ],
    [ u"ua",u"Huty",1978,50.13322,35.343936 ],
    [ u"ua",u"Hvizd",3311,48.685169,24.550551 ],
    [ u"ua",u"Ichnya",12417,50.862576,32.394253 ],
    [ u"ua",u"Illintsi",10770,49.104791,29.217732 ],
    [ u"ua",u"Irshava",9161,48.31667,23.038459 ],
    [ u"ua",u"Ispas",4278,48.297342,25.274064 ],
    [ u"ua",u"Ivanivka",5036,46.72082,34.552982 ],
    [ u"ua",u"Ivanivka",3028,46.975687,30.469983 ],
    [ u"ua",u"Ivankiv",3299,50.938645,29.894255 ],
    [ u"ua",u"Iza",5015,48.215249,23.328665 ],
    [ u"ua",u"Izmayil",82485,45.349286,28.840794 ],
    [ u"ua",u"Izyaslav",17758,50.119467,26.821254 ],
    [ u"ua",u"Izyum",53778,49.208754,37.248485 ],
    [ u"ua",u"Kadubivtsi",3161,48.583372,25.76871 ],
    [ u"ua",u"Kaharlyk",13245,49.862333,30.82815 ],
    [ u"ua",u"Kakhovka",36816,46.813706,33.486977 ],
    [ u"ua",u"Kalanchak",10673,46.256228,33.2907 ],
    [ u"ua",u"Kalcheva",3388,45.737374,28.814053 ],
    [ u"ua",u"Kalush",67697,49.011872,24.373077 ],
    [ u"ua",u"Kalynivka",19315,49.453887,28.526081 ],
    [ u"ua",u"Kalyny",5627,48.140783,23.873795 ],
    [ u"ua",u"Kaniv",25666,49.751825,31.460044 ],
    [ u"ua",u"Kapitanivka",2945,48.917194,31.716706 ],
    [ u"ua",u"Karapyshi",2960,49.642374,30.790024 ],
    [ u"ua",u"Karlivka",17226,49.456677,35.129469 ],
    [ u"ua",u"Katsiveli",631,44.396308,33.973035 ],
    [ u"ua",u"Katyuzhanka",4046,50.805947,30.137635 ],
    [ u"ua",u"Kayiry",3364,46.945372,33.705915 ],
    [ u"ua",u"Kazanka",8010,47.846249,32.821771 ],
    [ u"ua",u"Kehychivka",6404,49.289436,35.763621 ],
    [ u"ua",u"Keramik",469,48.253028,37.681573 ],
    [ u"ua",u"Kerch",152194,45.360696,36.470597 ],
    [ u"ua",u"Kherson",320476,46.655814,32.6178 ],
    [ u"ua",u"Kholmy",3146,51.870957,32.600632 ],
    [ u"ua",u"Khorol",14117,49.783671,33.278331 ],
    [ u"ua",u"Khorosheve",4432,49.852789,36.219476 ],
    [ u"ua",u"Khorostkiv",7034,49.211141,25.921648 ],
    [ u"ua",u"Khotiv",4569,50.330685,30.468357 ],
    [ u"ua",u"Khotyn",10799,48.506933,26.491214 ],
    [ u"ua",u"Khrystynivka",2839,48.824883,29.968055 ],
    [ u"ua",u"Khust",27999,48.1793,23.299091 ],
    [ u"ua",u"Khymchyn",3124,48.386391,25.14803 ],
    [ u"ua",u"Khyriv",4419,49.533316,22.852363 ],
    [ u"ua",u"Kiev",2514227,50.433333,30.516667 ],
    [ u"ua",u"Kiliya",21754,45.455181,29.263672 ],
    [ u"ua",u"Kirove",3291,47.653107,35.69512 ],
    [ u"ua",u"Kirovohrad",249453,48.513199,32.259702 ],
    [ u"ua",u"Kivertsi",16509,50.834248,25.45821 ],
    [ u"ua",u"Kivsharivka",19738,49.621247,37.70357 ],
    [ u"ua",u"Klembivka",3692,48.390372,28.410923 ],
    [ u"ua",u"Klenovyy",2259,48.119341,39.458797 ],
    [ u"ua",u"Klishkivtsi",6272,48.431607,26.262311 ],
    [ u"ua",u"Kobelyaky",11691,49.148924,34.196526 ],
    [ u"ua",u"Kobyzhcha",4332,50.828545,31.504393 ],
    [ u"ua",u"Kochetok",3481,49.880047,36.737232 ],
    [ u"ua",u"Kodra",1685,50.594882,29.558735 ],
    [ u"ua",u"Kodyma",9276,48.09875,29.12463 ],
    [ u"ua",u"Kolochava",4839,48.42851,23.695902 ],
    [ u"ua",u"Kolodenka",3052,50.585608,26.316012 ],
    [ u"ua",u"Kolomak",3712,49.839865,35.304415 ],
    [ u"ua",u"Kolomyya",61780,48.531152,25.036487 ],
    [ u"ua",u"Komarno",3845,49.627392,23.699516 ],
    [ u"ua",u"Kompaniyivka",4934,48.251149,32.207949 ],
    [ u"ua",u"Komsomolskoye",12337,47.6639,38.077532 ],
    [ u"ua",u"Komyshany",6978,46.637161,32.50719 ],
    [ u"ua",u"Komyshnya",2539,50.185869,33.68401 ],
    [ u"ua",u"Komyshuvakha",5231,47.717578,35.528816 ],
    [ u"ua",u"Konotop",91797,51.240317,33.202633 ],
    [ u"ua",u"Kopashnovo",3010,48.2197,23.484566 ],
    [ u"ua",u"Kopayhorod",1437,48.859171,27.796901 ],
    [ u"ua",u"Kopychyntsi",6774,49.104411,25.910256 ],
    [ u"ua",u"Korolevo",7844,48.152472,23.136593 ],
    [ u"ua",u"Korop",5478,51.566383,32.958609 ],
    [ u"ua",u"Korostyshiv",25099,50.31723,29.056298 ],
    [ u"ua",u"Korotych",4889,49.945519,36.040573 ],
    [ u"ua",u"Koryukivka",14214,51.768772,32.24813 ],
    [ u"ua",u"Kosiv",7992,48.310708,25.095752 ],
    [ u"ua",u"Kosmach",5822,48.329906,24.820519 ],
    [ u"ua",u"Kostryzhivka",2768,48.654551,25.713164 ],
    [ u"ua",u"Kostyantynivka",91258,48.527701,37.706905 ],
    [ u"ua",u"Kostyantynivka",2705,47.826599,31.135509 ],
    [ u"ua",u"Kostyantynivka",11540,46.816729,35.422869 ],
    [ u"ua",u"Kozachi Laheri",3587,46.703721,32.977603 ],
    [ u"ua",u"Kozhanka",2584,49.979327,29.738057 ],
    [ u"ua",u"Kozova",9019,49.435442,25.15086 ],
    [ u"ua",u"Kozyatyn",25645,49.714312,28.833848 ],
    [ u"ua",u"Krasna",3096,48.575706,24.700269 ],
    [ u"ua",u"Krasne",2898,46.130884,32.769098 ],
    [ u"ua",u"Krasne",6250,49.914471,24.6134 ],
    [ u"ua",u"Krasni Okny",5461,47.540443,29.460013 ],
    [ u"ua",u"Krasnoarmeysk",68263,48.281976,37.175847 ],
    [ u"ua",u"Krasnodon",49351,48.292289,39.737292 ],
    [ u"ua",u"Krasnohrad",21426,49.381405,35.440206 ],
    [ u"ua",u"Krasnopavlivka",7495,49.136434,36.31911 ],
    [ u"ua",u"Krasnopillya",8603,50.774583,35.259646 ],
    [ u"ua",u"Krasnosilka",4406,46.622577,30.774206 ],
    [ u"ua",u"Krasnotorka",3061,48.682039,37.532662 ],
    [ u"ua",u"Krasnyy Kut",2983,48.201376,38.79765 ],
    [ u"ua",u"Krasnyy Luch",90004,48.139542,38.93715 ],
    [ u"ua",u"Krasnyy Oktyabr",979,48.25,38.2 ],
    [ u"ua",u"Krasyliv",19815,49.65186,26.972525 ],
    [ u"ua",u"Kremenchuk",232741,49.072005,33.427482 ],
    [ u"ua",u"Kreminna",23538,49.049499,38.21792 ],
    [ u"ua",u"Krynychky",4557,48.375511,34.46701 ],
    [ u"ua",u"Kryva",2911,48.172339,23.236473 ],
    [ u"ua",u"Kryve Ozero",8258,47.952417,30.349282 ],
    [ u"ua",u"Kryvyy Rih",652376,47.909659,33.380438 ],
    [ u"ua",u"Kryzhanivka",3076,46.561672,30.794873 ],
    [ u"ua",u"Kuchurhan",3183,47.163018,29.789375 ],
    [ u"ua",u"Kulevcha",3882,46.030338,29.936137 ],
    [ u"ua",u"Kulykivka",5739,51.37345,31.646606 ],
    [ u"ua",u"Kulykiv",3763,50.314244,24.817569 ],
    [ u"ua",u"Kulynychi",2981,49.982273,36.384183 ],
    [ u"ua",u"Kurpaty",399,44.444493,34.130592 ],
    [ u"ua",u"Kushnytsya",4508,48.439878,23.258162 ],
    [ u"ua",u"Kushuhum",7475,47.712783,35.209172 ],
    [ u"ua",u"Kuteynykove",2076,47.812269,38.288219 ],
    [ u"ua",u"Kuty",4160,48.258677,25.179463 ],
    [ u"ua",u"Kuybysheve",2344,44.629004,33.86895 ],
    [ u"ua",u"Kuybysheve",7832,47.358002,36.649075 ],
    [ u"ua",u"Kynashiv",2989,48.671773,28.899413 ],
    [ u"ua",u"Kyrnasivka",5322,48.596011,28.975928 ],
    [ u"ua",u"Kyrylivka",1422,46.375917,35.367528 ],
    [ u"ua",u"Ladan",6719,50.519588,32.581779 ],
    [ u"ua",u"Ladyzhyn",21393,48.684962,29.236785 ],
    [ u"ua",u"Lanchyn",7718,48.557807,24.756215 ],
    [ u"ua",u"Lanivtsi",8357,49.863275,26.09082 ],
    [ u"ua",u"Lazeshchyna",4008,48.268516,24.420099 ],
    [ u"ua",u"Lazurne",3127,46.084001,32.529554 ],
    [ u"ua",u"Lazy",3660,48.066667,24.233333 ],
    [ u"ua",u"Lebedyn",4402,48.962419,31.526956 ],
    [ u"ua",u"Lebedyn",27695,50.585182,34.484896 ],
    [ u"ua",u"Lenina",1228,48.429444,39.145556 ],
    [ u"ua",u"Lenine",8297,45.298571,35.777083 ],
    [ u"ua",u"Lesnoye",166,48.098585,38.132934 ],
    [ u"ua",u"Letychiv",10669,49.382631,27.630511 ],
    [ u"ua",u"Lityn",6804,49.32509,28.080942 ],
    [ u"ua",u"Livadiya",1560,44.474813,34.144374 ],
    [ u"ua",u"Lokachi",4056,50.736995,24.649436 ],
    [ u"ua",u"Lokhvytsya",11950,50.367757,33.260244 ],
    [ u"ua",u"Lopatyn",3418,50.220216,24.848311 ],
    [ u"ua",u"Lopukhiv",3199,48.365265,23.963819 ],
    [ u"ua",u"Lozova",62311,48.889369,36.317546 ],
    [ u"ua",u"Lozuvatka",6412,48.057099,33.285811 ],
    [ u"ua",u"Luhyny",4561,51.082025,28.40057 ],
    [ u"ua",u"Lukiv",3043,51.0521,25.400592 ],
    [ u"ua",u"Luzhany",4520,48.364923,25.77173 ],
    [ u"ua",u"Lvov",830000,49.840661,24.030451 ],
    [ u"ua",u"Lykhivka",2382,48.687347,33.922791 ],
    [ u"ua",u"Lyman",4008,49.594803,36.467111 ],
    [ u"ua",u"Lypcha",3640,48.261075,23.383364 ],
    [ u"ua",u"Lypnyazhka",4272,48.446944,31.076111 ],
    [ u"ua",u"Lypova Dolyna",5199,50.564281,33.797934 ],
    [ u"ua",u"Lysa Hora",4312,48.170591,31.10994 ],
    [ u"ua",u"Lysyanka",7954,49.25229,30.829463 ],
    [ u"ua",u"Lysychovo",3068,48.496768,23.289924 ],
    [ u"ua",u"Lyubar",2351,49.92045,27.75918 ],
    [ u"ua",u"Lyubashivka",9426,47.837157,30.259763 ],
    [ u"ua",u"Lyubech",2550,51.702604,30.656918 ],
    [ u"ua",u"Lyubeshiv",5812,51.765346,25.5142 ],
    [ u"ua",u"Lyubotyn",22545,49.945435,35.932904 ],
    [ u"ua",u"Lyubymivka",5786,46.810627,33.568619 ],
    [ u"ua",u"Mahdalynivka",6567,48.921016,34.915577 ],
    [ u"ua",u"Makariv",11594,50.464077,29.811277 ],
    [ u"ua",u"Makiyivka",376607,48.047816,37.925764 ],
    [ u"ua",u"Makoshyne",2596,51.459598,32.346357 ],
    [ u"ua",u"Mala Bilozerka",5717,47.247366,34.934574 ],
    [ u"ua",u"Mala Danylivka",7211,50.063542,36.165641 ],
    [ u"ua",u"Mala Tokmachka",2912,47.535633,35.89293 ],
    [ u"ua",u"Mala Vyska",12644,48.64308,31.636574 ],
    [ u"ua",u"Malokakhovka",2862,46.781425,33.447898 ],
    [ u"ua",u"Malokaterynivka",3174,47.655501,35.256489 ],
    [ u"ua",u"Malynivka",7502,49.798345,36.714171 ],
    [ u"ua",u"Malyn",27068,50.772332,29.238328 ],
    [ u"ua",u"Manchenky",1147,49.980461,35.854233 ],
    [ u"ua",u"Manhush",8153,47.055817,37.310677 ],
    [ u"ua",u"Manyava",3333,48.655411,24.375374 ],
    [ u"ua",u"Markivka",7087,49.522896,39.570548 ],
    [ u"ua",u"Markova",2896,48.675764,24.413824 ],
    [ u"ua",u"Masandra",6966,44.518921,34.185931 ],
    [ u"ua",u"Mashivka",3999,49.443077,34.866875 ],
    [ u"ua",u"Matviyivka",3716,47.074725,35.144439 ],
    [ u"ua",u"Mayaky",5716,47.440827,29.559855 ],
    [ u"ua",u"Mazurivka",3259,48.536384,28.14428 ],
    [ u"ua",u"Medenychi",3219,49.430551,23.750729 ],
    [ u"ua",u"Mena",12766,51.521697,32.215683 ],
    [ u"ua",u"Merefa",23679,49.823023,36.050686 ],
    [ u"ua",u"Mezhgorye",9297,48.52458,23.505627 ],
    [ u"ua",u"Mezhova",7817,48.253177,36.734685 ],
    [ u"ua",u"Milove",5418,49.375278,40.132222 ],
    [ u"ua",u"Mizoch",3553,50.4,26.15 ],
    [ u"ua",u"Mlyniv",8228,50.508996,25.616753 ],
    [ u"ua",u"Molodiya",3691,48.223257,26.021392 ],
    [ u"ua",u"Molodizhne",1541,48.177322,32.660154 ],
    [ u"ua",u"Monastyryshche",9111,48.990902,29.8047 ],
    [ u"ua",u"Morshyn",6241,49.156519,23.872323 ],
    [ u"ua",u"Moshny",4629,49.524209,31.743376 ],
    [ u"ua",u"Mospyne",11300,47.890806,38.063951 ],
    [ u"ua",u"Mukacheve",81632,48.439187,22.717792 ],
    [ u"ua",u"Murovane",4251,49.52143,22.936695 ],
    [ u"ua",u"Murovani Kurylivtsi",5994,48.723477,27.518919 ],
    [ u"ua",u"Myhove",3546,48.157492,25.379038 ],
    [ u"ua",u"Mykhaylivka",3352,45.286688,36.2627 ],
    [ u"ua",u"Mykhaylivka",13216,47.272347,35.222352 ],
    [ u"ua",u"Mykolayivka",2573,44.969203,33.608596 ],
    [ u"ua",u"Mykolayivka",3629,47.541348,30.756146 ],
    [ u"ua",u"Mykolayiv",14251,49.523723,23.985219 ],
    [ u"ua",u"Mynay",2973,48.588796,22.275017 ],
    [ u"ua",u"Myrhorod",41376,49.968545,33.60886 ],
    [ u"ua",u"Myronivka",12871,49.660074,30.982246 ],
    [ u"ua",u"Nadvirna",20154,48.634799,24.569364 ],
    [ u"ua",u"Narkevychi",1631,49.517173,26.641782 ],
    [ u"ua",u"Narodychi",2521,51.202858,29.082281 ],
    [ u"ua",u"Nebyliv",3282,48.815265,24.21657 ],
    [ u"ua",u"Nedryhayliv",6031,50.83398,33.876256 ],
    [ u"ua",u"Nelipyno",3403,48.561008,23.031459 ],
    [ u"ua",u"Nemyriv",11633,48.970761,28.837793 ],
    [ u"ua",u"Neresnytsya",3617,48.118145,23.765878 ],
    [ u"ua",u"Netishyn",33063,50.340041,26.641707 ],
    [ u"ua",u"Nikita",2291,44.515635,34.238397 ],
    [ u"ua",u"Nizhyn",75498,51.048014,31.886882 ],
    [ u"ua",u"Nosivka",15164,50.931518,31.582825 ],
    [ u"ua",u"Nova Borova",5494,50.69296,28.63446 ],
    [ u"ua",u"Nova Kakhovka",50672,46.75451,33.348636 ],
    [ u"ua",u"Nova Mayachka",7238,46.599956,33.22707 ],
    [ u"ua",u"Nova Odesa",13547,47.307783,31.785063 ],
    [ u"ua",u"Nova Praha",7513,48.568214,32.902726 ],
    [ u"ua",u"Nova Ushytsya",4548,48.837157,27.274337 ],
    [ u"ua",u"Nova Vodolaha",13112,49.718496,35.870775 ],
    [ u"ua",u"Nove Davydkovo",3853,48.441334,22.621638 ],
    [ u"ua",u"Novhorodka",6405,48.365061,32.657846 ],
    [ u"ua",u"Novi Bilokorovychi",3251,51.115477,28.05463 ],
    [ u"ua",u"Novi Sanzhary",8020,49.343954,34.310839 ],
    [ u"ua",u"Novi Troyany",3992,45.942752,28.856281 ],
    [ u"ua",u"Novobohdanivka",3506,47.08524,35.329447 ],
    [ u"ua",u"Novomykolayivka",3860,48.556246,34.373991 ],
    [ u"ua",u"Novomykolayivka",5568,47.978099,35.910195 ],
    [ u"ua",u"Novomyrhorod",12728,48.781047,31.642042 ],
    [ u"ua",u"Novooleksiyivka",9852,46.224718,34.64031 ],
    [ u"ua",u"Novopokrovka",2092,48.05918,34.606193 ],
    [ u"ua",u"Novopokrovka",4841,49.842522,36.547733 ],
    [ u"ua",u"Novopskov",9739,49.546402,39.089867 ],
    [ u"ua",u"Novoselytsya",8088,48.219314,26.26531 ],
    [ u"ua",u"Novoselytsya",3185,50.070303,27.519552 ],
    [ u"ua",u"Novoukrayinka",18633,48.326353,31.528521 ],
    [ u"ua",u"Novovasylivka",2724,46.831498,35.753621 ],
    [ u"ua",u"Novovorontsovka",6847,47.500353,33.917485 ],
    [ u"ua",u"Novytsya",3564,48.963447,24.335423 ],
    [ u"ua",u"Novyy Buh",15646,47.693084,32.521601 ],
    [ u"ua",u"Novyy Starodub",4777,48.515801,33.173293 ],
    [ u"ua",u"Novyy Svit",9488,47.805909,38.021118 ],
    [ u"ua",u"Novyy Svit",1017,45.477545,36.297373 ],
    [ u"ua",u"Novyy Yarychiv",2841,49.904438,24.30523 ],
    [ u"ua",u"Nyzhni Petrivtsi",2887,48.028469,25.723272 ],
    [ u"ua",u"Nyzhni Sirohozy",5797,46.848415,34.380442 ],
    [ u"ua",u"Nyzhnya Duvanka",2353,49.584639,38.17429 ],
    [ u"ua",u"Nyzhnya Krynka",14253,48.113497,38.160636 ],
    [ u"ua",u"Nyzy",2819,50.782812,34.784411 ],
    [ u"ua",u"Obertyn",3264,48.700325,25.170116 ],
    [ u"ua",u"Obodivka",3378,48.40514,29.247748 ],
    [ u"ua",u"Obukhiv",31557,50.10997,30.62272 ],
    [ u"ua",u"Ochakiv",16300,46.612829,31.549822 ],
    [ u"ua",u"Odesa",1001553,46.463934,30.738551 ],
    [ u"ua",u"Okhtyrka",49818,50.310359,34.898787 ],
    [ u"ua",u"Oleksandrivka",10687,48.963361,32.234925 ],
    [ u"ua",u"Oleksandrivka",5653,46.838258,32.761155 ],
    [ u"ua",u"Oleksandrivka",4990,46.328932,30.634808 ],
    [ u"ua",u"Olyka",3074,50.718554,25.812507 ],
    [ u"ua",u"Onufriyivka",4298,48.907156,33.448686 ],
    [ u"ua",u"Orativ",3170,49.188893,29.526971 ],
    [ u"ua",u"Ordzhonikidze",43167,47.667625,34.059574 ],
    [ u"ua",u"Ordzhonikidze",2773,44.965749,35.356219 ],
    [ u"ua",u"Oreanda",858,44.457138,34.140632 ],
    [ u"ua",u"Orikhiv",17287,47.567311,35.785748 ],
    [ u"ua",u"Orikhove",3000,45.129439,33.631799 ],
    [ u"ua",u"Orzhytsya",3898,49.791821,32.701217 ],
    [ u"ua",u"Ostër",6794,50.950602,30.882291 ],
    [ u"ua",u"Ostroh",14251,50.329419,26.514252 ],
    [ u"ua",u"Osypenko",4477,46.913598,36.825303 ],
    [ u"ua",u"Otyniya",5205,48.737668,24.861109 ],
    [ u"ua",u"Ovruch",16398,51.324595,28.803514 ],
    [ u"ua",u"Ozerna",3451,49.628909,25.328947 ],
    [ u"ua",u"Ozerne",5162,45.402996,28.675461 ],
    [ u"ua",u"Ozerne",5646,50.178163,28.733838 ],
    [ u"ua",u"Pantayivka",2918,48.673998,32.884102 ],
    [ u"ua",u"Panyutyne",7038,48.936916,36.275628 ],
    [ u"ua",u"Parkove",463,44.408922,33.907839 ],
    [ u"ua",u"Partenit",6021,44.576448,34.344509 ],
    [ u"ua",u"Partyzany",3738,46.333829,34.753138 ],
    [ u"ua",u"Pasichna",4530,48.571524,24.43003 ],
    [ u"ua",u"Pavlivka",1135,49.608638,38.70917 ],
    [ u"ua",u"Pavlivka",3635,49.441431,28.45956 ],
    [ u"ua",u"Pavlohrad",115931,48.53341,35.870499 ],
    [ u"ua",u"Pavlysh",4693,48.917617,33.356914 ],
    [ u"ua",u"Pechenizhyn",5126,48.515514,24.894231 ],
    [ u"ua",u"Perehonivka",3354,48.535523,30.519226 ],
    [ u"ua",u"Peremyshlyany",7284,49.665229,24.558457 ],
    [ u"ua",u"Peresichna",6894,50.024132,35.98259 ],
    [ u"ua",u"Perove",3746,44.930162,34.056087 ],
    [ u"ua",u"Pershotravneve",2523,51.392871,28.868373 ],
    [ u"ua",u"Pervomayskoye",9014,45.45,33.7 ],
    [ u"ua",u"Pervomaysk",41480,48.629882,38.548056 ],
    [ u"ua",u"Pervomaysk",67306,48.044331,30.850729 ],
    [ u"ua",u"Petranka",2929,48.902455,24.303467 ],
    [ u"ua",u"Petrivka",6467,45.497756,34.288165 ],
    [ u"ua",u"Petrivka",4535,46.96951,30.959142 ],
    [ u"ua",u"Petropavlivka",8912,48.456429,36.436699 ],
    [ u"ua",u"Petrove",8252,48.324674,33.256166 ],
    [ u"ua",u"Petrykivka",4896,48.729784,34.635134 ],
    [ u"ua",u"Petrykiv",3033,49.531218,25.579009 ],
    [ u"ua",u"Pidhaytsi",3158,49.268535,25.133412 ],
    [ u"ua",u"Pidhorodna",2481,48.107044,30.889529 ],
    [ u"ua",u"Pidhorodne",17103,48.575277,35.106804 ],
    [ u"ua",u"Pidvynohradiv",4206,48.139468,22.971938 ],
    [ u"ua",u"Pishchanka",5484,48.207267,28.886068 ],
    [ u"ua",u"Piskivka",6889,50.693777,29.619339 ],
    [ u"ua",u"Pivdenne",8053,49.885511,36.066751 ],
    [ u"ua",u"Plakhtiyivka",5038,46.100596,29.721687 ],
    [ u"ua",u"Pniv",4443,48.617829,24.528723 ],
    [ u"ua",u"Pohrebyshche",10354,49.486387,29.263613 ],
    [ u"ua",u"Pokotylivka",9962,49.913431,36.175111 ],
    [ u"ua",u"Polohy",21380,47.484444,36.253611 ],
    [ u"ua",u"Polonne",22348,50.124238,27.510874 ],
    [ u"ua",u"Poltava",317845,49.593727,34.540733 ],
    [ u"ua",u"Polyanka",1693,50.258358,27.688087 ],
    [ u"ua",u"Pomichna",10539,48.242222,31.415833 ],
    [ u"ua",u"Pomoryany",1449,49.640924,24.9307 ],
    [ u"ua",u"Poninka",7642,50.184922,27.536289 ],
    [ u"ua",u"Ponyzivka",348,44.397104,33.939115 ],
    [ u"ua",u"Porohy",3004,48.687554,24.263219 ],
    [ u"ua",u"Poroshkovo",3645,48.668316,22.753276 ],
    [ u"ua",u"Poshtove",2882,44.836068,33.961929 ],
    [ u"ua",u"Preobrazhenka",3550,47.571938,35.816666 ],
    [ u"ua",u"Prosyana",5432,47.636455,34.813868 ],
    [ u"ua",u"Prudyanka",1924,50.236057,36.168352 ],
    [ u"ua",u"Prykolotne",2499,50.160423,37.347441 ],
    [ u"ua",u"Pryluky",62822,50.593235,32.387614 ],
    [ u"ua",u"Pryozerne",3013,45.269764,36.330252 ],
    [ u"ua",u"Pryshyb",3365,47.259267,35.319529 ],
    [ u"ua",u"Pryvillya",8669,49.015013,38.304575 ],
    [ u"ua",u"Pryyutivka",3238,48.720938,33.070778 ],
    [ u"ua",u"Pustomyty",9434,49.715321,23.912951 ],
    [ u"ua",u"Pyryatyn",16089,50.244501,32.510733 ],
    [ u"ua",u"Radcha",2927,48.850231,24.655025 ],
    [ u"ua",u"Radyvyliv",9928,50.129938,25.255764 ],
    [ u"ua",u"Rakhiv",14674,48.0526,24.200889 ],
    [ u"ua",u"Rakitnoye",13277,49.686653,30.473838 ],
    [ u"ua",u"Rakiv Lis",2958,51.621741,24.924269 ],
    [ u"ua",u"Rakoshyno",3145,48.467126,22.596872 ],
    [ u"ua",u"Ralivka",3926,49.500527,23.240578 ],
    [ u"ua",u"Ratne",9081,51.668301,24.530296 ],
    [ u"ua",u"Razdolnoye",7871,45.770828,33.487769 ],
    [ u"ua",u"Reni",19719,45.457273,28.293171 ],
    [ u"ua",u"Reshetylivka",9336,49.565011,34.078154 ],
    [ u"ua",u"Ripky",7708,51.801046,31.083827 ],
    [ u"ua",u"Rivne",5296,48.247424,31.754318 ],
    [ u"ua",u"Rivne",255104,50.623079,26.22743 ],
    [ u"ua",u"Rodnykove",3058,45.042961,33.954074 ],
    [ u"ua",u"Rohatyn",8287,49.409003,24.609265 ],
    [ u"ua",u"Rokosovo",4544,48.210178,23.176242 ],
    [ u"ua",u"Rokytne",7028,51.279599,27.214004 ],
    [ u"ua",u"Romny",48570,50.751038,33.474713 ],
    [ u"ua",u"Ropcha",3189,48.11988,25.774214 ],
    [ u"ua",u"Rozhniv",5351,48.365971,25.225795 ],
    [ u"ua",u"Rozhnyativ",3983,48.935755,24.163792 ],
    [ u"ua",u"Rozhyshche",13280,50.915425,25.269055 ],
    [ u"ua",u"Rozivka",4197,46.938458,35.772388 ],
    [ u"ua",u"Rozkishne",6205,48.50743,39.30036 ],
    [ u"ua",u"Rozsypne",4911,48.149659,38.576185 ],
    [ u"ua",u"Rozvadiv",3098,49.5,23.616667 ],
    [ u"ua",u"Rubizhne",62992,49.012286,38.379672 ],
    [ u"ua",u"Rudno",6016,49.849527,23.887734 ],
    [ u"ua",u"Rudnytsya",1228,48.255422,28.935745 ],
    [ u"ua",u"Russkaya Polyana",7780,49.420948,31.922065 ],
    [ u"ua",u"Ruzhyn",4993,49.722804,29.204548 ],
    [ u"ua",u"Rykhtychi",3115,49.385107,23.556618 ],
    [ u"ua",u"Rzhyshchiv",7993,49.968864,31.046282 ],
    [ u"ua",u"Sadove",3104,45.310367,34.652596 ],
    [ u"ua",u"Sad",461,48.426635,35.24787 ],
    [ u"ua",u"Sadzhavka",3278,48.566033,24.788195 ],
    [ u"ua",u"Sakhnovshchyna",8188,49.151664,35.871978 ],
    [ u"ua",u"Saky",28322,45.134243,33.599965 ],
    [ u"ua",u"Sambir",35197,49.518301,23.197525 ],
    [ u"ua",u"Sarata",5035,46.019661,29.66567 ],
    [ u"ua",u"Sarny",27097,51.337949,26.601913 ],
    [ u"ua",u"Sartana",10543,47.174357,37.692661 ],
    [ u"ua",u"Savyntsi",5326,49.402566,37.062658 ],
    [ u"ua",u"Sedniv",1301,51.644725,31.564965 ],
    [ u"ua",u"Semenivka",9320,52.178273,32.581827 ],
    [ u"ua",u"Semenivka",7305,49.590311,33.180486 ],
    [ u"ua",u"Semypolky",2939,50.726267,30.93441 ],
    [ u"ua",u"Sencha",2953,50.2,33.45 ],
    [ u"ua",u"Serebriya",2906,48.455928,27.719226 ],
    [ u"ua",u"Serednye Vodyane",5465,47.981593,23.910408 ],
    [ u"ua",u"Serpneve",1768,46.30094,29.019579 ],
    [ u"ua",u"Shabo",6886,46.132618,30.385947 ],
    [ u"ua",u"Shakhtne",975,47.983648,38.282073 ],
    [ u"ua",u"Shalyhyne",3031,51.571675,34.121666 ],
    [ u"ua",u"Sharhorod",6895,48.738346,28.084969 ],
    [ u"ua",u"Shchebetovka",3213,44.938212,35.158002 ],
    [ u"ua",u"Shcherbynivka",3868,48.39489,37.791021 ],
    [ u"ua",u"Shcholkine",11264,45.427187,35.813346 ],
    [ u"ua",u"Shchors",11857,51.818646,31.94504 ],
    [ u"ua",u"Shepetivka",46419,50.185447,27.063647 ],
    [ u"ua",u"Shevchenko",2023,48.655323,37.992514 ],
    [ u"ua",u"Shevchenkove",7090,49.695853,37.173484 ],
    [ u"ua",u"Shevchenkove",3031,46.862889,32.203872 ],
    [ u"ua",u"Shevchenkove",5362,45.556035,29.33357 ],
    [ u"ua",u"Shklo",5164,49.956751,23.544085 ],
    [ u"ua",u"Sholokhove",3097,47.694529,34.031194 ],
    [ u"ua",u"Shostka",85431,51.862956,33.469804 ],
    [ u"ua",u"Shpykiv",3638,48.78868,28.565746 ],
    [ u"ua",u"Shypyntsi",2937,48.376769,25.746637 ],
    [ u"ua",u"Shyroke",10920,47.69173,33.257145 ],
    [ u"ua",u"Shyroke",1001,47.957114,38.231602 ],
    [ u"ua",u"Shyryayeve",7018,47.380518,30.196385 ],
    [ u"ua",u"Simeykyne",2493,48.326434,39.533659 ],
    [ u"ua",u"Skalat",3886,49.427322,25.978689 ],
    [ u"ua",u"Skole",6491,49.037169,23.513457 ],
    [ u"ua",u"Skvyra",17452,49.731771,29.665694 ],
    [ u"ua",u"Slatyne",6544,50.210413,36.153765 ],
    [ u"ua",u"Slavuta",33080,50.301552,26.865061 ],
    [ u"ua",u"Slavutych",27832,51.521486,30.753224 ],
    [ u"ua",u"Slobidka",2530,47.886944,29.346111 ],
    [ u"ua",u"Sloboda",2949,51.198056,33.606953 ],
    [ u"ua",u"Smila",67530,49.22242,31.887138 ],
    [ u"ua",u"Snihurivka",14873,47.07579,32.805164 ],
    [ u"ua",u"Snizhne",55587,48.026118,38.772251 ],
    [ u"ua",u"Snyatyn",10089,48.446922,25.569371 ],
    [ u"ua",u"Sobolivka",3605,49.336044,28.650964 ],
    [ u"ua",u"Sofiyivka",8017,48.049273,33.874621 ],
    [ u"ua",u"Sokyryany",9877,48.447466,27.416781 ],
    [ u"ua",u"Soledar",12662,48.679346,38.089019 ],
    [ u"ua",u"Solone",7304,48.20805,34.872076 ],
    [ u"ua",u"Solonytsivka",12378,49.998472,36.042736 ],
    [ u"ua",u"Solotvyno",8931,47.946041,23.870347 ],
    [ u"ua",u"Solotvyn",3803,48.702122,24.42212 ],
    [ u"ua",u"Sosnytsya",7825,51.523873,32.499849 ],
    [ u"ua",u"Spasskoye",3017,48.659833,35.052423 ],
    [ u"ua",u"Spas",2976,48.889925,24.062929 ],
    [ u"ua",u"Sribne",3534,50.663844,32.918668 ],
    [ u"ua",u"Stakhanov",84425,48.568178,38.643517 ],
    [ u"ua",u"Stanislav",4726,46.569094,32.147766 ],
    [ u"ua",u"Stara Synyava",5771,49.603177,27.619091 ],
    [ u"ua",u"Stara Vyzhivka",5466,51.437625,24.439971 ],
    [ u"ua",u"Stari Bohorodchany",3426,48.833607,24.524297 ],
    [ u"ua",u"Stari Kuty",5068,48.270933,25.172933 ],
    [ u"ua",u"Starobesheve",6917,47.750378,38.030512 ],
    [ u"ua",u"Starokostyantyniv",33897,49.757637,27.20342 ],
    [ u"ua",u"Starokozache",5108,46.337222,29.985278 ],
    [ u"ua",u"Starychi",3293,49.980011,23.558481 ],
    [ u"ua",u"Staryy Krym",5977,47.161463,37.489339 ],
    [ u"ua",u"Staryy Krym",9725,45.028874,35.091738 ],
    [ u"ua",u"Staryy Merchyk",1709,49.97489,35.770176 ],
    [ u"ua",u"Staryy Saltiv",3776,50.08268,36.793926 ],
    [ u"ua",u"Stavyshche",7634,50.400512,29.527961 ],
    [ u"ua",u"Stebnyk",20087,49.294164,23.563574 ],
    [ u"ua",u"Stetseva",3076,48.527669,25.575722 ],
    [ u"ua",u"Strabychovo",3255,48.392468,22.543082 ],
    [ u"ua",u"Strohonivka",3447,44.943094,34.197274 ],
    [ u"ua",u"Stryy",61404,49.262228,23.856087 ],
    [ u"ua",u"Subottsi",3095,48.655452,32.520929 ],
    [ u"ua",u"Sudak",13956,44.849241,34.974713 ],
    [ u"ua",u"Sudova Vyshnya",6420,49.788915,23.37218 ],
    [ u"ua",u"Sukhovolya",3612,49.824261,23.837695 ],
    [ u"ua",u"Sumy",294454,50.921597,34.800294 ],
    [ u"ua",u"Sutysky",6111,49.042448,28.417325 ],
    [ u"ua",u"Svalyava",16507,48.548533,22.995782 ],
    [ u"ua",u"Svarychiv",4845,48.962196,24.196585 ],
    [ u"ua",u"Svatove",18770,49.410287,38.15035 ],
    [ u"ua",u"Syedove",2667,47.076781,38.156021 ],
    [ u"ua",u"Synevyr",4623,48.487448,23.62575 ],
    [ u"ua",u"Talalayivka",5054,50.957826,31.92085 ],
    [ u"ua",u"Tarashcha",12952,49.558316,30.492592 ],
    [ u"ua",u"Tarutyne",5988,46.186356,29.15203 ],
    [ u"ua",u"Tatarbunary",10396,45.837308,29.614243 ],
    [ u"ua",u"Tayirove",1849,46.363134,30.64891 ],
    [ u"ua",u"Teplodar",8502,46.505846,30.325205 ],
    [ u"ua",u"Teplyk",6604,48.665658,29.745035 ],
    [ u"ua",u"Terebovlya",13153,49.301873,25.709974 ],
    [ u"ua",u"Ternova",2968,50.192259,36.67477 ],
    [ u"ua",u"Ternuvate",1510,47.830492,36.127609 ],
    [ u"ua",u"Tërny",3661,50.989163,33.970697 ],
    [ u"ua",u"Terpinnya",4656,46.96971,35.419715 ],
    [ u"ua",u"Tetiyiv",14388,49.376698,29.664738 ],
    [ u"ua",u"Tokmak",34926,47.255218,35.71238 ],
    [ u"ua",u"Tomakivka",8006,47.815692,34.741368 ],
    [ u"ua",u"Torez",68037,48.038762,38.596854 ],
    [ u"ua",u"Toshkivka",4926,48.77914,38.579031 ],
    [ u"ua",u"Tovste",3382,48.846625,25.726208 ],
    [ u"ua",u"Trebukhiv",6207,50.484316,30.903041 ],
    [ u"ua",u"Trybukhivtsi",4134,49.042506,25.450549 ],
    [ u"ua",u"Tsarychanka",7638,48.936973,34.478596 ],
    [ u"ua",u"Tsybli",3512,49.994843,31.562813 ],
    [ u"ua",u"Tsybuliv",3751,49.079072,29.847265 ],
    [ u"ua",u"Turbiv",6740,49.347878,28.721174 ],
    [ u"ua",u"Turka",7395,49.154109,23.029673 ],
    [ u"ua",u"Tyachiv",9422,48.011795,23.570611 ],
    [ u"ua",u"Tymoshivka",2975,47.184182,35.108812 ],
    [ u"ua",u"Tynne",4123,50.601453,26.184864 ],
    [ u"ua",u"Tyshkivka",3368,48.496649,30.942293 ],
    [ u"ua",u"Tysmenychany",2944,48.771685,24.666264 ],
    [ u"ua",u"Tysmenytsya",9426,48.90219,24.844815 ],
    [ u"ua",u"Uhlove",3283,44.82146,33.604516 ],
    [ u"ua",u"Uhryniv",3090,48.955196,24.692924 ],
    [ u"ua",u"Ukrayinka",13636,50.143174,30.746119 ],
    [ u"ua",u"Ulychne",3671,49.233846,23.65111 ],
    [ u"ua",u"Urozhayne",3404,45.045222,34.135113 ],
    [ u"ua",u"Usatove",7732,46.532957,30.659602 ],
    [ u"ua",u"Uspenka",9400,48.390278,39.161944 ],
    [ u"ua",u"Ustynivka",4003,47.95507,32.536738 ],
    [ u"ua",u"Utkivka",1272,49.785833,36.075278 ],
    [ u"ua",u"Uyutne",3710,45.197689,33.297956 ],
    [ u"ua",u"Uzhhorod",117877,48.616667,22.3 ],
    [ u"ua",u"Uzyn",12726,49.826188,30.414874 ],
    [ u"ua",u"Valky",10099,49.838683,35.620724 ],
    [ u"ua",u"Vapnyarka",8443,48.534789,28.743578 ],
    [ u"ua",u"Varva",8549,50.495034,32.719684 ],
    [ u"ua",u"Vary",2998,48.122067,22.712811 ],
    [ u"ua",u"Vashkivtsi",5764,48.384915,25.510231 ],
    [ u"ua",u"Vasylivka",15012,47.436944,35.274167 ],
    [ u"ua",u"Vasyshcheve",5862,49.828521,36.326909 ],
    [ u"ua",u"Vatutine",19407,49.015017,31.062109 ],
    [ u"ua",u"Velyka Bahachka",5707,49.791162,33.72258 ],
    [ u"ua",u"Velyka Bilozerka",3511,47.277556,34.706158 ],
    [ u"ua",u"Velyka Kisnytsya",3088,48.135947,28.443357 ],
    [ u"ua",u"Velyka Lepetykha",9511,47.175719,33.943625 ],
    [ u"ua",u"Velyka Mykhaylivka",5777,47.079711,29.857533 ],
    [ u"ua",u"Velyka Oleksandrivka",7281,47.319691,33.303734 ],
    [ u"ua",u"Velyka Pysarivka",5235,50.425867,35.485015 ],
    [ u"ua",u"Velykoploske",3192,47.012538,29.671707 ],
    [ u"ua",u"Velykyy Burluk",4821,50.037866,37.398713 ],
    [ u"ua",u"Velykyy Klyuchiv",3290,48.470917,24.946775 ],
    [ u"ua",u"Vendychany",4182,48.61176,27.793241 ],
    [ u"ua",u"Verbivka",3377,49.416667,35.533333 ],
    [ u"ua",u"Verenchanka",3560,48.546529,25.745331 ],
    [ u"ua",u"Verkhniy Rohachyk",6557,47.250535,34.337973 ],
    [ u"ua",u"Verkhnyachka",4130,48.828488,30.039566 ],
    [ u"ua",u"Verkhnya Syrovatka",3669,50.82902,34.958613 ],
    [ u"ua",u"Verkhovyna",5290,48.15571,24.791124 ],
    [ u"ua",u"Vesele",10683,47.014791,34.915036 ],
    [ u"ua",u"Veselynove",6997,47.356659,31.234882 ],
    [ u"ua",u"Viline",6649,44.845596,33.671607 ],
    [ u"ua",u"Vinnitsa",332400,49.232776,28.480968 ],
    [ u"ua",u"Vinnytsya",352113,49.232776,28.480968 ],
    [ u"ua",u"Viytivka",4245,48.426031,29.542914 ],
    [ u"ua",u"Vladyslavivka",3326,45.168284,35.376581 ],
    [ u"ua",u"Vodyane",5685,47.48746,34.492351 ],
    [ u"ua",u"Volchansk",19485,50.290785,36.94108 ],
    [ u"ua",u"Volnovakha",23731,47.601034,37.496744 ],
    [ u"ua",u"Volodarka",7355,49.524836,29.912219 ],
    [ u"ua",u"Voloka",2915,48.192252,25.930736 ],
    [ u"ua",u"Vorokhta",3853,48.284589,24.565364 ],
    [ u"ua",u"Voronovytsya",6389,49.109541,28.680782 ],
    [ u"ua",u"Vorozhba",7915,51.17334,34.219171 ],
    [ u"ua",u"Voskhod",462,44.517259,34.216942 ],
    [ u"ua",u"Voyinka",4221,45.869899,33.991381 ],
    [ u"ua",u"Voykove",59,47.968256,38.213067 ],
    [ u"ua",u"Voykove",4100,45.382613,36.437242 ],
    [ u"ua",u"Voznesenka",4917,46.87165,35.464579 ],
    [ u"ua",u"Vradiyivka",9578,47.861948,30.591953 ],
    [ u"ua",u"Vvedenka",2628,49.824409,36.507474 ],
    [ u"ua",u"Vylkove",8916,45.40214,29.585946 ],
    [ u"ua",u"Vylok",3292,48.109153,22.83865 ],
    [ u"ua",u"Vynohradivka",3110,45.681189,28.571385 ],
    [ u"ua",u"Vynohradove",4422,46.36957,32.939803 ],
    [ u"ua",u"Vyshchetarasivka",3651,47.568505,34.880964 ],
    [ u"ua",u"Vyshhorod",22080,50.584758,30.489799 ],
    [ u"ua",u"Vyshkovo",7838,48.049112,23.421128 ],
    [ u"ua",u"Vyshneve",2467,48.436607,33.916181 ],
    [ u"ua",u"Vyshneve",33183,50.389133,30.370497 ],
    [ u"ua",u"Vysoke",553,47.944067,38.058044 ],
    [ u"ua",u"Vysokopillya",4542,47.491873,33.530611 ],
    [ u"ua",u"Vysokyy",10988,49.889198,36.132098 ],
    [ u"ua",u"Vyzhnytsya",4834,48.248007,25.194524 ],
    [ u"ua",u"Yabluniv",1798,48.404178,24.93874 ],
    [ u"ua",u"Yahotyn",22779,50.279751,31.762461 ],
    [ u"ua",u"Yakymivka",12353,46.699719,35.159156 ],
    [ u"ua",u"Yalta",5519,46.962787,37.273654 ],
    [ u"ua",u"Yalta",79509,44.500129,34.161481 ],
    [ u"ua",u"Yamnytsya",3223,48.989722,24.7075 ],
    [ u"ua",u"Yaremche",7558,48.451569,24.554362 ],
    [ u"ua",u"Yarke Pole",4739,45.21493,35.206131 ],
    [ u"ua",u"Yarmolyntsi",8583,49.192363,26.837252 ],
    [ u"ua",u"Yasinya",7708,48.279373,24.360425 ],
    [ u"ua",u"Yavoriv",13008,49.938639,23.382543 ],
    [ u"ua",u"Yelyzavethradka",1673,48.803812,32.404595 ],
    [ u"ua",u"Yerky",4159,48.990617,30.988184 ],
    [ u"ua",u"Yevpatoriya",105222,45.200908,33.366546 ],
    [ u"ua",u"Yizhivtsi",3240,48.039618,25.66232 ],
    [ u"ua",u"Yurkivka",2887,49.012564,31.10125 ],
    [ u"ua",u"Yuzhne",23085,46.624487,31.10226 ],
    [ u"ua",u"Zabolotiv",4029,48.470539,25.285713 ],
    [ u"ua",u"Zabolottya",4267,51.632053,24.253923 ],
    [ u"ua",u"Zachepylivka",4217,49.193846,35.239433 ],
    [ u"ua",u"Zahnitkiv",2893,48.048062,28.888454 ],
    [ u"ua",u"Zahvizdya",3546,48.918361,24.652751 ],
    [ u"ua",u"Zakupne",1398,49.11944,26.337564 ],
    [ u"ua",u"Zalishchyky",9749,48.643314,25.737944 ],
    [ u"ua",u"Zaliznychne",3343,45.7489,28.61466 ],
    [ u"ua",u"Zaliznychne",1206,47.652378,36.16524 ],
    [ u"ua",u"Zaliztsi",2612,49.79188,25.372974 ],
    [ u"ua",u"Zamhlay",1878,51.815047,31.159815 ],
    [ u"ua",u"Zaozerne",4396,45.158156,33.278663 ],
    [ u"ua",u"Zaporizhzhya",796213,47.822892,35.190314 ],
    [ u"ua",u"Zarechye",3832,48.52144,24.64857 ],
    [ u"ua",u"Zarichne",6671,51.812603,26.129022 ],
    [ u"ua",u"Zastavna",8536,48.523071,25.843686 ],
    [ u"ua",u"Zatoka",1391,46.072512,30.465384 ],
    [ u"ua",u"Zatyshshya",3327,47.333514,29.873268 ],
    [ u"ua",u"Zavallya",5010,48.213542,30.015579 ],
    [ u"ua",u"Zbarazh",12736,49.663574,25.776162 ],
    [ u"ua",u"Zboriv",7159,49.664839,25.140965 ],
    [ u"ua",u"Zdolbuniv",23697,50.520599,26.242513 ],
    [ u"ua",u"Zhashkiv",15264,49.245446,30.110204 ],
    [ u"ua",u"Zhelyabovka",2930,45.398773,34.75776 ],
    [ u"ua",u"Zhmerynka",35960,49.03705,28.112013 ],
    [ u"ua",u"Zhovkva",12973,50.05825,23.972596 ],
    [ u"ua",u"Zhovti Vody",51559,48.347309,33.500338 ],
    [ u"ua",u"Zhovtneve",4652,50.663646,24.249178 ],
    [ u"ua",u"Zhovtneve",609,49.987839,29.531292 ],
    [ u"ua",u"Zhuravka",2900,50.481081,32.594903 ],
    [ u"ua",u"Zhuravky",3068,45.129125,35.214509 ],
    [ u"ua",u"Zhurivka",6369,50.502756,31.784917 ],
    [ u"ua",u"Zhytomyr",282190,50.264868,28.676691 ],
    [ u"ua",u"Zlynka",4981,48.485215,31.539061 ],
    [ u"ua",u"Zmiyiv",16095,49.696638,36.361089 ],
    [ u"ua",u"Zolochiv",11160,50.279848,35.981785 ],
    [ u"ua",u"Zolochiv",22608,49.805974,24.894357 ],
    [ u"ua",u"Zolotonosha",27722,49.668865,32.037726 ],
    [ u"ua",u"Zolotyy Potik",2343,48.909504,25.33926 ],
    [ u"ua",u"Zorya",5243,45.990796,29.696721 ],
    [ u"ua",u"Zuhres",19121,48.011401,38.264437 ],
    [ u"ua",u"Zuya",6677,45.0531,34.31542 ],
    [ u"ua",u"Zvenyhorodka",19161,49.078664,30.967545 ],
    [ u"ug",u"Adjumani",26774,3.3613889,31.8097222 ],
    [ u"ug",u"Amudat",1873,1.95,34.95 ],
    [ u"ug",u"Apac",11775,1.9755556,32.5386111 ],
    [ u"ug",u"Arua",55583,3.0191667,30.9308333 ],
    [ u"ug",u"Bombo",12752,0.5663889,32.5155556 ],
    [ u"ug",u"Bugembe",11598,0.4797222,33.2344444 ],
    [ u"ug",u"Bugiri",24154,-0.85,29.6666667 ],
    [ u"ug",u"Bundibugyo",16920,0.7413889,30.0416667 ],
    [ u"ug",u"Busembatia",15889,0.7697222,33.6130556 ],
    [ u"ug",u"Bushenyi",24810,-0.5852778,30.2113889 ],
    [ u"ug",u"Busia",42596,0.4544444,34.0758333 ],
    [ u"ug",u"Buwenge",15130,0.6422222,33.1744444 ],
    [ u"ug",u"Bweyogerere",11473,0.3558333,32.6672222 ],
    [ u"ug",u"Entebbe",62971,0.0644444,32.4469444 ],
    [ u"ug",u"Fort Portal",42671,0.6938889,30.2663889 ],
    [ u"ug",u"Gulu",146832,2.7666667,32.3055556 ],
    [ u"ug",u"Hima",14678,0.3488889,30.1622222 ],
    [ u"ug",u"Hoima",39644,1.4355556,31.3436111 ],
    [ u"ug",u"Ibanda",24704,-0.1538889,30.5319444 ],
    [ u"ug",u"Iganga",45023,0.6091667,33.4686111 ],
    [ u"ug",u"Jinja",93060,0.4244444,33.2041667 ],
    [ u"ug",u"Kaabong",9806,3.4836111,34.1491667 ],
    [ u"ug",u"Kabale",50871,-1.3261111,30.0038889 ],
    [ u"ug",u"Kaberamaido",27789,1.7388889,33.1594444 ],
    [ u"ug",u"Kagadi",2097,0.9605556,30.7966667 ],
    [ u"ug",u"Kajansi",7530,0.2080556,32.5222222 ],
    [ u"ug",u"Kalangala",3731,-0.3088889,32.225 ],
    [ u"ug",u"Kampala",1353236,0.3155556,32.5655556 ],
    [ u"ug",u"Kamuli",12763,0.9472222,33.1197222 ],
    [ u"ug",u"Kamwenge",17177,0.2111111,30.4208333 ],
    [ u"ug",u"Kanungu",12886,-0.9575,29.7897222 ],
    [ u"ug",u"Kapchorwa",10416,1.3827778,34.5244444 ],
    [ u"ug",u"Kasese",67279,0.23,29.9883333 ],
    [ u"ug",u"Katakwi",8702,1.8911111,33.9661111 ],
    [ u"ug",u"Kayunga",21706,0.7025,32.8886111 ],
    [ u"ug",u"Kiboga",14512,0.9161111,31.7741667 ],
    [ u"ug",u"Kigorobya",5420,1.62,31.3108333 ],
    [ u"ug",u"Kilembe",7914,0.2,30.0 ],
    [ u"ug",u"Kireka",17947,0.3475,32.6491667 ],
    [ u"ug",u"Kisoro",11554,-1.3538889,29.6983333 ],
    [ u"ug",u"Kitgum",56881,3.2783333,32.8866667 ],
    [ u"ug",u"Koboko",39609,3.4113889,30.9866667 ],
    [ u"ug",u"Kotido",17336,2.9805556,34.1330556 ],
    [ u"ug",u"Kumi",8827,1.4608333,33.9361111 ],
    [ u"ug",u"Kyenjojo",19123,0.6327778,30.6213889 ],
    [ u"ug",u"Kyotera",8472,-0.6155556,31.5175 ],
    [ u"ug",u"Lira",119302,2.235,32.9097222 ],
    [ u"ug",u"Lugazi",35038,0.3772222,32.9197222 ],
    [ u"ug",u"Lukaya",17576,-0.1130556,31.8538889 ],
    [ u"ug",u"Luwero",28340,0.8491667,32.4730556 ],
    [ u"ug",u"Lyantonde",8039,-0.4030556,31.1572222 ],
    [ u"ug",u"Masaka",65376,-0.3127778,31.7130556 ],
    [ u"ug",u"Masindi",31488,1.6744444,31.715 ],
    [ u"ug",u"Mayuge",11501,0.4597222,33.4802778 ],
    [ u"ug",u"Mbale",76492,1.0644444,34.1794444 ],
    [ u"ug",u"Mbarara",79159,-0.6583333,30.6758333 ],
    [ u"ug",u"Mityana",41146,0.4175,32.0227778 ],
    [ u"ug",u"Moroto",8490,2.4958333,34.6694444 ],
    [ u"ug",u"Moyo",14377,3.6280556,31.7536111 ],
    [ u"ug",u"Mpigi",11082,0.225,32.3136111 ],
    [ u"ug",u"Mubende",18937,0.5891667,31.36 ],
    [ u"ug",u"Muhororo",1567,0.9380556,30.7594444 ],
    [ u"ug",u"Mukono",67303,0.3533333,32.7552778 ],
    [ u"ug",u"Nakapiripirit",1800,1.8144444,34.7136111 ],
    [ u"ug",u"Nakasongola",6922,1.3088889,32.4563889 ],
    [ u"ug",u"Namasuba",22507,0.6894444,32.4213889 ],
    [ u"ug",u"Nebbi",30347,2.4758333,31.1025 ],
    [ u"ug",u"Ngora",9193,1.4313889,33.7772222 ],
    [ u"ug",u"Njeru",61975,0.4186111,33.1730556 ],
    [ u"ug",u"Ntungamo",16922,-0.8833333,29.65 ],
    [ u"ug",u"Paidha",28346,2.4166667,30.9833333 ],
    [ u"ug",u"Pakwach",23890,2.4536111,31.5025 ],
    [ u"ug",u"Pallisa",30740,1.145,33.7094444 ],
    [ u"ug",u"Rakai",7613,-0.72,31.4838889 ],
    [ u"ug",u"Sembabule",4320,-0.0772222,31.4566667 ],
    [ u"ug",u"Sironko",14698,1.2075,34.2522222 ],
    [ u"ug",u"Soroti",43312,1.6855556,33.6163889 ],
    [ u"ug",u"Tororo",47729,0.6847222,34.1811111 ],
    [ u"ug",u"Wakiso",20543,0.4044444,32.4594444 ],
    [ u"ug",u"Wobulenzi",24425,0.7283333,32.5122222 ],
    [ u"ug",u"Yumbe",17178,3.4463889,31.2702778 ],
    [ u"us",u"Alabaster",26738,33.2441667,-86.8163889 ],
    [ u"us",u"Albertville",18368,34.2675000,-86.2088889 ],
    [ u"us",u"Alexander City",14993,32.9438889,-85.9538889 ],
    [ u"us",u"Anniston",23423,33.6597222,-85.8316667 ],
    [ u"us",u"Athens",20470,34.8027778,-86.9716667 ],
    [ u"us",u"Auburn",49833,32.6097222,-85.4808333 ],
    [ u"us",u"Bessemer",28628,33.4016667,-86.9544444 ],
    [ u"us",u"Birmingham",231621,33.5205556,-86.8025000 ],
    [ u"us",u"Cullman",14796,34.1747222,-86.8436111 ],
    [ u"us",u"Daphne",18581,30.6033333,-87.9036111 ],
    [ u"us",u"Decatur",54621,34.6058333,-86.9833333 ],
    [ u"us",u"Dothan",61741,31.2230556,-85.3905556 ],
    [ u"us",u"Enterprise",22572,31.3150000,-85.8552778 ],
    [ u"us",u"Eufaula",13453,31.8911111,-85.1455556 ],
    [ u"us",u"Fairfield",11641,33.4858333,-86.9119444 ],
    [ u"us",u"Fairhope",15419,30.5227778,-87.9033333 ],
    [ u"us",u"Florence",35733,34.7997222,-87.6772222 ],
    [ u"us",u"Fort Payne",13586,34.4441667,-85.7197222 ],
    [ u"us",u"Gadsden",36821,34.0141667,-86.0066667 ],
    [ u"us",u"Gardendale",12370,33.6600000,-86.8127778 ],
    [ u"us",u"Hartselle",13089,34.4433333,-86.9352778 ],
    [ u"us",u"Helena",13119,33.2961111,-86.8436111 ],
    [ u"us",u"Homewood",23815,33.4716667,-86.8008333 ],
    [ u"us",u"Hoover",66752,33.4052778,-86.8113889 ],
    [ u"us",u"Hueytown",15308,33.4511111,-86.9966667 ],
    [ u"us",u"Huntsville",167528,34.7302778,-86.5861111 ],
    [ u"us",u"Irondale",9652,33.5380556,-86.7072222 ],
    [ u"us",u"Jacksonville",8603,33.8136111,-85.7613889 ],
    [ u"us",u"Jasper",13831,33.8311111,-87.2775000 ],
    [ u"us",u"Leeds",11167,33.5480556,-86.5444444 ],
    [ u"us",u"Madison",37652,34.6991667,-86.7483333 ],
    [ u"us",u"Millbrook",14308,32.4797222,-86.3619444 ],
    [ u"us",u"Mobile",190274,30.6941667,-88.0430556 ],
    [ u"us",u"Montgomery",198325,32.3666667,-86.3000000 ],
    [ u"us",u"Mountain Brook",19509,33.5008333,-86.7522222 ],
    [ u"us",u"Muscle Shoals",12314,34.7447222,-87.6675000 ],
    [ u"us",u"Northport",20574,33.2288889,-87.5772222 ],
    [ u"us",u"Opelika",23625,32.6452778,-85.3783333 ],
    [ u"us",u"Oxford",16058,33.6141667,-85.8350000 ],
    [ u"us",u"Ozark",14967,31.4588889,-85.6405556 ],
    [ u"us",u"Pelham",19438,33.2855556,-86.8100000 ],
    [ u"us",u"Pell City",10773,33.5861111,-86.2861111 ],
    [ u"us",u"Phenix City",28427,32.4708333,-85.0008333 ],
    [ u"us",u"Pleasant Grove",10440,33.4908333,-86.9702778 ],
    [ u"us",u"Prattville",28265,32.4638889,-86.4597222 ],
    [ u"us",u"Prichard",27505,30.7386111,-88.0788889 ],
    [ u"us",u"Saraland",12660,30.8205556,-88.0705556 ],
    [ u"us",u"Scottsboro",14737,34.6722222,-86.0341667 ],
    [ u"us",u"Selma",18980,32.4072222,-87.0211111 ],
    [ u"us",u"Sheffield",9041,34.7650000,-87.6986111 ],
    [ u"us",u"Sylacauga",12543,33.1730556,-86.2516667 ],
    [ u"us",u"Talladega",19408,33.4358333,-86.1058333 ],
    [ u"us",u"Troy",13337,31.8086111,-85.9700000 ],
    [ u"us",u"Trussville",15903,33.6197222,-86.6088889 ],
    [ u"us",u"Tuscaloosa",79816,33.2097222,-87.5691667 ],
    [ u"us",u"Tuskegee",11423,32.4238889,-85.6916667 ],
    [ u"us",u"Valley",8663,32.8186111,-85.1794444 ],
    [ u"us",u"Vestavia Hills",37988,33.4486111,-86.7877778 ],
    [ u"us",u"Anchorage",276263,61.2180556,-149.9002778 ],
    [ u"us",u"Barrow",4336,71.2905556,-156.7886111 ],
    [ u"us",u"Bethel",6228,60.7922222,-161.7558333 ],
    [ u"us",u"College",11413,64.8569444,-147.8027778 ],
    [ u"us",u"Fairbanks",31351,64.8377778,-147.7163889 ],
    [ u"us",u"Homer",6560,59.6425000,-151.5483333 ],
    [ u"us",u"Juneau",31796,58.3019444,-134.4197222 ],
    [ u"us",u"Kenai",7610,60.5544444,-151.2583333 ],
    [ u"us",u"Ketchikan",7172,55.3422222,-131.6461111 ],
    [ u"us",u"Kodiak",6148,57.7900000,-152.4072222 ],
    [ u"us",u"Nome",3485,64.5011111,-165.4063889 ],
    [ u"us",u"Palmer",6585,61.5997222,-149.1127778 ],
    [ u"us",u"Sitka",8931,57.0530556,-135.3300000 ],
    [ u"us",u"Soldotna",4136,60.4877778,-151.0583333 ],
    [ u"us",u"Sterling",5173,60.5372222,-150.7647222 ],
    [ u"us",u"Wasilla",8521,61.5813889,-149.4394444 ],
    [ u"us",u"Apache Junction",34904,33.4150000,-111.5488889 ],
    [ u"us",u"Avondale",69679,33.4355556,-112.3488889 ],
    [ u"us",u"Buckeye",9039,33.3702778,-112.5830556 ],
    [ u"us",u"Bullhead City",37989,35.1477778,-114.5675000 ],
    [ u"us",u"Camp Verde",10298,34.5636111,-111.8536111 ],
    [ u"us",u"Casa Grande",32138,32.8794444,-111.7566667 ],
    [ u"us",u"Casas Adobes",77904,32.3233333,-110.9944444 ],
    [ u"us",u"Catalina Foothills",71589,32.2977778,-110.9180556 ],
    [ u"us",u"Chandler",234297,33.3061111,-111.8405556 ],
    [ u"us",u"Chino Valley",9233,34.7575000,-112.4530556 ],
    [ u"us",u"Coolidge",8487,32.9777778,-111.5169444 ],
    [ u"us",u"Cottonwood",10681,34.7391667,-112.0091667 ],
    [ u"us",u"Douglas",16692,31.3444444,-109.5447222 ],
    [ u"us",u"Drexel Heights",35743,32.1411111,-111.0277778 ],
    [ u"us",u"El Mirage",32308,33.6130556,-112.3238889 ],
    [ u"us",u"Eloy",11019,32.7558333,-111.5541667 ],
    [ u"us",u"Flagstaff",57566,35.1980556,-111.6505556 ],
    [ u"us",u"Florence",15482,33.0313889,-111.3866667 ],
    [ u"us",u"Flowing Wells",15339,32.2938889,-111.0091667 ],
    [ u"us",u"Fortuna Foothills",30680,32.6577778,-114.4111111 ],
    [ u"us",u"Fountain Hills",23116,33.6116667,-111.7166667 ],
    [ u"us",u"Gilbert",170829,33.3527778,-111.7883333 ],
    [ u"us",u"Glendale",240112,33.5386111,-112.1852778 ],
    [ u"us",u"Goodyear",42738,33.4352778,-112.3575000 ],
    [ u"us",u"Green Valley",19310,31.8541667,-110.9930556 ],
    [ u"us",u"Kingman",24431,35.1894444,-114.0522222 ],
    [ u"us",u"Lake Havasu City",54752,34.4838889,-114.3216667 ],
    [ u"us",u"Marana",25553,32.4366667,-111.2247222 ],
    [ u"us",u"Mesa",449878,33.4222222,-111.8219444 ],
    [ u"us",u"Nogales",20707,31.3402778,-110.9336111 ],
    [ u"us",u"Oro Valley",37221,32.3908333,-110.9658333 ],
    [ u"us",u"Paradise Valley",14400,33.5311111,-111.9419444 ],
    [ u"us",u"Payson",14737,34.2308333,-111.3244444 ],
    [ u"us",u"Peoria",139368,33.5805556,-112.2366667 ],
    [ u"us",u"Phoenix",1428509,33.4483333,-112.0733333 ],
    [ u"us",u"Prescott",40136,34.5400000,-112.4677778 ],
    [ u"us",u"Prescott Valley",32415,34.6100000,-112.3150000 ],
    [ u"us",u"Safford",8825,32.8338889,-109.7069444 ],
    [ u"us",u"San Luis",21793,32.4869444,-114.7813889 ],
    [ u"us",u"Scottsdale",225796,33.5091667,-111.8983333 ],
    [ u"us",u"Sedona",11299,34.8697222,-111.7602778 ],
    [ u"us",u"Show Low",9564,34.2541667,-110.0291667 ],
    [ u"us",u"Sierra Vista",41378,31.5544444,-110.3030556 ],
    [ u"us",u"Somerton",9466,32.5963889,-114.7088889 ],
    [ u"us",u"Sun City",41078,33.5975000,-112.2711111 ],
    [ u"us",u"Sun City West",32813,33.6619444,-112.3405556 ],
    [ u"us",u"Surprise",65450,33.6305556,-112.3325000 ],
    [ u"us",u"Tempe",158368,33.4147222,-111.9086111 ],
    [ u"us",u"Tucson",518907,32.2216667,-110.9258333 ],
    [ u"us",u"Winslow",10003,35.0241667,-110.6966667 ],
    [ u"us",u"Yuma",84316,32.7252778,-114.6236111 ],
    [ u"us",u"Arkadelphia",11062,34.1208333,-93.0536111 ],
    [ u"us",u"Batesville",9438,35.7697222,-91.6408333 ],
    [ u"us",u"Bella Vista",21436,36.4813889,-94.2730556 ],
    [ u"us",u"Benton",24689,34.5644444,-92.5866667 ],
    [ u"us",u"Bentonville",31470,36.3727778,-94.2086111 ],
    [ u"us",u"Blytheville",16315,35.9272222,-89.9188889 ],
    [ u"us",u"Bryant",15065,34.5958333,-92.4888889 ],
    [ u"us",u"Cabot",20555,34.9744444,-92.0163889 ],
    [ u"us",u"Camden",12218,33.5844444,-92.8341667 ],
    [ u"us",u"Conway",51524,35.0886111,-92.4419444 ],
    [ u"us",u"El Dorado",20353,33.2075000,-92.6661111 ],
    [ u"us",u"Fayetteville",64864,36.0625000,-94.1572222 ],
    [ u"us",u"Forrest City",14084,35.0080556,-90.7897222 ],
    [ u"us",u"Fort Smith",81985,35.3858333,-94.3983333 ],
    [ u"us",u"Harrison",12468,36.2297222,-93.1075000 ],
    [ u"us",u"Hope",10382,33.6669444,-93.5913889 ],
    [ u"us",u"Hot Springs",37470,34.5036111,-93.0550000 ],
    [ u"us",u"Jacksonville",30520,34.8661111,-92.1100000 ],
    [ u"us",u"Jonesboro",58619,35.8422222,-90.7041667 ],
    [ u"us",u"Little Rock",184217,34.7463889,-92.2894444 ],
    [ u"us",u"Magnolia",10300,33.2669444,-93.2391667 ],
    [ u"us",u"Malvern",8965,34.3622222,-92.8127778 ],
    [ u"us",u"Marion",9227,35.2144444,-90.1963889 ],
    [ u"us",u"Maumelle",13822,34.8666667,-92.4041667 ],
    [ u"us",u"Monticello",8954,33.6288889,-91.7908333 ],
    [ u"us",u"Mountain Home",11798,36.3352778,-92.3850000 ],
    [ u"us",u"North Little Rock",59078,34.7694444,-92.2669444 ],
    [ u"us",u"Paragould",23450,36.0583333,-90.4972222 ],
    [ u"us",u"Pine Bluff",53217,34.2283333,-92.0030556 ],
    [ u"us",u"Rogers",45524,36.3319444,-94.1183333 ],
    [ u"us",u"Russellville",24972,35.2783333,-93.1336111 ],
    [ u"us",u"Searcy",20154,35.2505556,-91.7361111 ],
    [ u"us",u"Sherwood",22495,34.8150000,-92.2241667 ],
    [ u"us",u"Siloam Springs",14634,36.1880556,-94.5402778 ],
    [ u"us",u"Springdale",56402,36.1866667,-94.1286111 ],
    [ u"us",u"Stuttgart",9181,34.5002778,-91.5525000 ],
    [ u"us",u"Texarkana",35315,33.4416667,-94.0375000 ],
    [ u"us",u"Van Buren",20932,35.4366667,-94.3480556 ],
    [ u"us",u"West Helena",7679,34.5505556,-90.6416667 ],
    [ u"us",u"West Memphis",28065,35.1463889,-90.1844444 ],
    [ u"us",u"Adelanto",21955,34.5827778,-117.4083333 ],
    [ u"us",u"Agoura Hills",22222,34.1363889,-118.7736111 ],
    [ u"us",u"Alameda",70443,37.7652778,-122.2405556 ],
    [ u"us",u"Alamo",17764,37.8502778,-122.0311111 ],
    [ u"us",u"Albany",16144,37.8869444,-122.2966667 ],
    [ u"us",u"Alhambra",88386,34.0952778,-118.1261111 ],
    [ u"us",u"Aliso Viejo",41314,33.6083333,-117.7444444 ],
    [ u"us",u"Alondra Park",8028,33.8894444,-118.3300000 ],
    [ u"us",u"Alpine",15391,32.8350000,-116.7655556 ],
    [ u"us",u"Altadena",43226,34.1897222,-118.1302778 ],
    [ u"us",u"American Canyon",15513,38.1750000,-122.2597222 ],
    [ u"us",u"Anaheim",333689,33.8352778,-117.9136111 ],
    [ u"us",u"Anderson",10684,40.4483333,-122.2966667 ],
    [ u"us",u"Antioch",106038,38.0050000,-121.8047222 ],
    [ u"us",u"Apple Valley",64271,34.5008333,-117.1850000 ],
    [ u"us",u"Aptos",9701,36.9772222,-121.8983333 ],
    [ u"us",u"Arcadia",56716,34.1397222,-118.0344444 ],
    [ u"us",u"Arcata",17199,40.8666667,-124.0816667 ],
    [ u"us",u"Arroyo Grande",16613,35.1186111,-120.5897222 ],
    [ u"us",u"Artesia",16992,33.8658333,-118.0822222 ],
    [ u"us",u"Arvin",14744,35.2091667,-118.8275000 ],
    [ u"us",u"Ashland",23467,37.6947222,-122.1127778 ],
    [ u"us",u"Atascadero",27308,35.4894444,-120.6697222 ],
    [ u"us",u"Atwater",29686,37.3477778,-120.6080556 ],
    [ u"us",u"Auburn",12523,38.8966667,-121.0758333 ],
    [ u"us",u"Avenal",16727,36.0041667,-120.1280556 ],
    [ u"us",u"Avocado Heights",15832,34.0361111,-117.9902778 ],
    [ u"us",u"Azusa",48297,34.1336111,-117.9066667 ],
    [ u"us",u"Bakersfield",291389,35.3733333,-119.0177778 ],
    [ u"us",u"Baldwin Park",80566,34.0852778,-117.9600000 ],
    [ u"us",u"Banning",30411,33.9255556,-116.8755556 ],
    [ u"us",u"Barstow",24202,34.8986111,-117.0219444 ],
    [ u"us",u"Bay Point",24125,38.0291667,-121.9605556 ],
    [ u"us",u"Beaumont",18593,33.9294444,-116.9763889 ],
    [ u"us",u"Bell",38335,33.9775000,-118.1861111 ],
    [ u"us",u"Bell Gardens",46119,33.9652778,-118.1505556 ],
    [ u"us",u"Bellflower",75847,33.8816667,-118.1161111 ],
    [ u"us",u"Belmont",23998,37.5202778,-122.2747222 ],
    [ u"us",u"Benicia",26742,38.0494444,-122.1575000 ],
    [ u"us",u"Berkeley",100158,37.8716667,-122.2716667 ],
    [ u"us",u"Beverly Hills",35355,34.0736111,-118.3994444 ],
    [ u"us",u"Bloomington",22003,34.0702778,-117.3950000 ],
    [ u"us",u"Blythe",22483,33.6102778,-114.5955556 ],
    [ u"us",u"Bonita",12520,32.6577778,-117.0291667 ],
    [ u"us",u"Bostonia",16168,32.8075000,-116.9355556 ],
    [ u"us",u"Brawley",22185,32.9786111,-115.5294444 ],
    [ u"us",u"Brea",39542,33.9166667,-117.8991667 ],
    [ u"us",u"Brentwood",46669,37.9319444,-121.6947222 ],
    [ u"us",u"Buena Park",79157,33.8675000,-117.9972222 ],
    [ u"us",u"Burbank",104690,34.1808333,-118.3080556 ],
    [ u"us",u"Burlingame",26777,37.5841667,-122.3650000 ],
    [ u"us",u"Calabasas",21368,34.1577778,-118.6375000 ],
    [ u"us",u"Calexico",36389,32.6788889,-115.4980556 ],
    [ u"us",u"California City",14780,35.1258333,-117.9850000 ],
    [ u"us",u"Camarillo",62500,34.2163889,-119.0366667 ],
    [ u"us",u"Cameron Park",16232,38.6688889,-120.9861111 ],
    [ u"us",u"Campbell",36529,37.2872222,-121.9488889 ],
    [ u"us",u"Canyon Lake",11582,33.6850000,-117.2722222 ],
    [ u"us",u"Capitola",9573,36.9752778,-121.9522222 ],
    [ u"us",u"Carlsbad",91070,33.1580556,-117.3497222 ],
    [ u"us",u"Carmichael",50992,38.6172222,-121.3272222 ],
    [ u"us",u"Carpinteria",13786,34.3988889,-119.5175000 ],
    [ u"us",u"Carson",95767,33.8313889,-118.2811111 ],
    [ u"us",u"Castro Valley",62813,37.6941667,-122.0852778 ],
    [ u"us",u"Cathedral City",52991,33.7797222,-116.4644444 ],
    [ u"us",u"Ceres",40082,37.5950000,-120.9566667 ],
    [ u"us",u"Cerritos",53305,33.8583333,-118.0638889 ],
    [ u"us",u"Charter Oak",9244,34.1030556,-117.8450000 ],
    [ u"us",u"Cherryland",15585,37.6794444,-122.1022222 ],
    [ u"us",u"Chico",70565,39.7286111,-121.8363889 ],
    [ u"us",u"Chino",75494,34.0122222,-117.6880556 ],
    [ u"us",u"Chino Hills",78211,33.8936111,-117.7263889 ],
    [ u"us",u"Chowchilla",14898,37.1230556,-120.2591667 ],
    [ u"us",u"Chula Vista",213032,32.6400000,-117.0833333 ],
    [ u"us",u"Citrus",11308,34.1150000,-117.8908333 ],
    [ u"us",u"Citrus Heights",89430,38.7072222,-121.2800000 ],
    [ u"us",u"Claremont",35368,34.0966667,-117.7188889 ],
    [ u"us",u"Clayton",11161,37.9411111,-121.9347222 ],
    [ u"us",u"Clearlake",14825,38.9583333,-122.6252778 ],
    [ u"us",u"Clovis",86324,36.8252778,-119.7019444 ],
    [ u"us",u"Coachella",30755,33.6802778,-116.1730556 ],
    [ u"us",u"Coalinga",16331,36.1397222,-120.3591667 ],
    [ u"us",u"Colton",52335,34.0738889,-117.3127778 ],
    [ u"us",u"Commerce",13684,34.0005556,-118.1588889 ],
    [ u"us",u"Compton",96749,33.8958333,-118.2191667 ],
    [ u"us",u"Concord",125626,37.9780556,-122.0300000 ],
    [ u"us",u"Corcoran",22587,36.0980556,-119.5594444 ],
    [ u"us",u"Corona",152954,33.8752778,-117.5655556 ],
    [ u"us",u"Coronado",23571,32.6858333,-117.1822222 ],
    [ u"us",u"Corte Madera",9154,37.9255556,-122.5263889 ],
    [ u"us",u"Costa Mesa",109250,33.6411111,-117.9177778 ],
    [ u"us",u"Country Club",9670,37.9688889,-121.3397222 ],
    [ u"us",u"Covina",48688,34.0900000,-117.8894444 ],
    [ u"us",u"Crestline",11250,34.2419444,-117.2847222 ],
    [ u"us",u"Cudahy",25606,33.9605556,-118.1844444 ],
    [ u"us",u"Culver City",40129,34.0211111,-118.3955556 ],
    [ u"us",u"Cupertino",50934,37.3230556,-122.0311111 ],
    [ u"us",u"Cypress",47371,33.8169444,-118.0363889 ],
    [ u"us",u"Daly City",98959,37.7058333,-122.4608333 ],
    [ u"us",u"Dana Point",35870,33.4669444,-117.6972222 ],
    [ u"us",u"Danville",42852,37.8216667,-121.9988889 ],
    [ u"us",u"Davis",65806,38.5450000,-121.7394444 ],
    [ u"us",u"Delano",44757,35.7688889,-119.2461111 ],
    [ u"us",u"Desert Hot Springs",18991,33.9611111,-116.5008333 ],
    [ u"us",u"Diamond Bar",58935,34.0286111,-117.8094444 ],
    [ u"us",u"Dinuba",18511,36.5433333,-119.3861111 ],
    [ u"us",u"Dixon",16244,38.4455556,-121.8222222 ],
    [ u"us",u"Downey",111862,33.9400000,-118.1316667 ],
    [ u"us",u"Duarte",22521,34.1394444,-117.9763889 ],
    [ u"us",u"Dublin",38805,37.7022222,-121.9347222 ],
    [ u"us",u"East Foothills",8141,37.3811111,-121.8163889 ],
    [ u"us",u"East Hemet",13876,33.7400000,-116.9380556 ],
    [ u"us",u"East La Mirada",9764,33.9244444,-117.9880556 ],
    [ u"us",u"East Los Angeles",125157,34.0238889,-118.1711111 ],
    [ u"us",u"East Palo Alto",32906,37.4688889,-122.1400000 ],
    [ u"us",u"El Cajon",94807,32.7947222,-116.9616667 ],
    [ u"us",u"El Centro",38323,32.7919444,-115.5622222 ],
    [ u"us",u"El Cerrito",23192,37.9158333,-122.3105556 ],
    [ u"us",u"El Monte",125372,34.0686111,-118.0266667 ],
    [ u"us",u"El Segundo",16710,33.9191667,-118.4155556 ],
    [ u"us",u"El Sobrante",13790,37.9772222,-122.2941667 ],
    [ u"us",u"Elk Grove",94497,38.4088889,-121.3705556 ],
    [ u"us",u"Encinitas",61585,33.0369444,-117.2911111 ],
    [ u"us",u"Escondido",137119,33.1191667,-117.0855556 ],
    [ u"us",u"Eureka",25626,40.8022222,-124.1625000 ],
    [ u"us",u"Exeter",10078,36.2961111,-119.1411111 ],
    [ u"us",u"Fair Oaks",28989,38.6447222,-121.2711111 ],
    [ u"us",u"Fairfield",105741,38.2494444,-122.0388889 ],
    [ u"us",u"Fairview",9822,37.6786111,-122.0447222 ],
    [ u"us",u"Fallbrook",33617,33.3763889,-117.2502778 ],
    [ u"us",u"Farmersville",9743,36.2977778,-119.2058333 ],
    [ u"us",u"Fillmore",15386,34.3991667,-118.9172222 ],
    [ u"us",u"Florin",29808,38.4961111,-121.4077778 ],
    [ u"us",u"Folsom",67953,38.6780556,-121.1750000 ],
    [ u"us",u"Fontana",169160,34.0922222,-117.4341667 ],
    [ u"us",u"Foothill Farms",17828,38.6763889,-121.3352778 ],
    [ u"us",u"Fortuna",11162,40.5983333,-124.1561111 ],
    [ u"us",u"Foster City",28532,37.5586111,-122.2700000 ],
    [ u"us",u"Fountain Valley",56133,33.7091667,-117.9527778 ],
    [ u"us",u"Fremont",202615,37.5483333,-121.9875000 ],
    [ u"us",u"Fresno",465183,36.7477778,-119.7713889 ],
    [ u"us",u"Fullerton",135353,33.8702778,-117.9244444 ],
    [ u"us",u"Galt",23997,38.2547222,-121.2988889 ],
    [ u"us",u"Garden Acres",10523,37.9638889,-121.2283333 ],
    [ u"us",u"Garden Grove",167232,33.7738889,-117.9405556 ],
    [ u"us",u"Gardena",60915,33.8883333,-118.3080556 ],
    [ u"us",u"Gilroy",45309,37.0058333,-121.5672222 ],
    [ u"us",u"Glen Avon",16249,34.0116667,-117.4838889 ],
    [ u"us",u"Glendale",203201,34.1425000,-118.2541667 ],
    [ u"us",u"Glendora",51541,34.1361111,-117.8644444 ],
    [ u"us",u"Goleta",28351,34.4358333,-119.8266667 ],
    [ u"us",u"Gonzales",9054,36.5066667,-121.4433333 ],
    [ u"us",u"Grand Terrace",12518,34.0338889,-117.3127778 ],
    [ u"us",u"Grass Valley",12297,39.2191667,-121.0600000 ],
    [ u"us",u"Greenfield",13117,36.3208333,-121.2427778 ],
    [ u"us",u"Grover Beach",12974,35.1216667,-120.6202778 ],
    [ u"us",u"Hacienda Heights",54289,33.9930556,-117.9677778 ],
    [ u"us",u"Half Moon Bay",12423,37.4636111,-122.4275000 ],
    [ u"us",u"Hanford",47648,36.3275000,-119.6447222 ],
    [ u"us",u"Hawaiian Gardens",15652,33.8313889,-118.0719444 ],
    [ u"us",u"Hawthorne",87083,33.9163889,-118.3516667 ],
    [ u"us",u"Hayward",140494,37.6688889,-122.0797222 ],
    [ u"us",u"Healdsburg",11360,38.6105556,-122.8680556 ],
    [ u"us",u"Hemet",69039,33.7475000,-116.9711111 ],
    [ u"us",u"Hercules",23819,38.0172222,-122.2875000 ],
    [ u"us",u"Hermosa Beach",19825,33.8622222,-118.3986111 ],
    [ u"us",u"Hesperia",73640,34.4263889,-117.3000000 ],
    [ u"us",u"Highland",51312,34.1283333,-117.2077778 ],
    [ u"us",u"Hillsborough",10374,37.5741667,-122.3783333 ],
    [ u"us",u"Hollister",37485,36.8525000,-121.4005556 ],
    [ u"us",u"Huntington Beach",195968,33.6602778,-117.9983333 ],
    [ u"us",u"Huntington Park",63831,33.9816667,-118.2241667 ],
    [ u"us",u"Imperial",10268,32.8475000,-115.5686111 ],
    [ u"us",u"Imperial Beach",27091,32.5838889,-117.1122222 ],
    [ u"us",u"Indio",65955,33.7205556,-116.2147222 ],
    [ u"us",u"Inglewood",116158,33.9616667,-118.3522222 ],
    [ u"us",u"Irvine",189297,33.6694444,-117.8222222 ],
    [ u"us",u"Isla Vista",17716,34.4133333,-119.8600000 ],
    [ u"us",u"Kerman",10647,36.7236111,-120.0588889 ],
    [ u"us",u"King City",11431,36.2127778,-121.1250000 ],
    [ u"us",u"Kingsburg",11413,36.5138889,-119.5530556 ],
    [ u"us",u"La Canada Flintridge",21293,34.1991667,-118.1869444 ],
    [ u"us",u"La Habra",59654,33.9319444,-117.9452778 ],
    [ u"us",u"La Mesa",54087,32.7677778,-117.0222222 ],
    [ u"us",u"La Mirada",49963,33.9172222,-118.0111111 ],
    [ u"us",u"La Palma",16169,33.8463889,-118.0458333 ],
    [ u"us",u"La Presa",35119,32.7080556,-116.9963889 ],
    [ u"us",u"La Puente",42605,34.0200000,-117.9486111 ],
    [ u"us",u"La Quinta",37690,33.6633333,-116.3091667 ],
    [ u"us",u"La Riviera",10104,38.5669444,-121.3558333 ],
    [ u"us",u"La Verne",33698,34.1008333,-117.7669444 ],
    [ u"us",u"Lafayette",24780,37.8858333,-122.1169444 ],
    [ u"us",u"Laguna Beach",24181,33.5422222,-117.7822222 ],
    [ u"us",u"Laguna Hills",30843,33.6125000,-117.7119444 ],
    [ u"us",u"Laguna Niguel",66291,33.5225000,-117.7066667 ],
    [ u"us",u"Laguna Woods",19862,33.6102778,-117.7244444 ],
    [ u"us",u"Lake Elsinore",40630,33.6680556,-117.3263889 ],
    [ u"us",u"Lake Forest",76733,33.6469444,-117.6883333 ],
    [ u"us",u"Lakeside",19293,32.8572222,-116.9213889 ],
    [ u"us",u"Lakewood",82115,33.8536111,-118.1330556 ],
    [ u"us",u"Lamont",14438,35.2597222,-118.9133333 ],
    [ u"us",u"Lancaster",129548,34.6980556,-118.1358333 ],
    [ u"us",u"Larkspur",11667,37.9341667,-122.5341667 ],
    [ u"us",u"Lathrop",13250,37.8227778,-121.2755556 ],
    [ u"us",u"Lawndale",32841,33.8872222,-118.3516667 ],
    [ u"us",u"Lemon Grove",24802,32.7425000,-117.0305556 ],
    [ u"us",u"Lemoore",22763,36.3008333,-119.7819444 ],
    [ u"us",u"Lennox",23387,33.9380556,-118.3516667 ],
    [ u"us",u"Lincoln",33242,38.8916667,-121.2919444 ],
    [ u"us",u"Linda",13892,39.1277778,-121.5497222 ],
    [ u"us",u"Lindsay",10806,36.2030556,-119.0872222 ],
    [ u"us",u"Livermore",80347,37.6819444,-121.7669444 ],
    [ u"us",u"Livingston",12080,37.3869444,-120.7225000 ],
    [ u"us",u"Lodi",62778,38.1302778,-121.2713889 ],
    [ u"us",u"Loma Linda",20802,34.0483333,-117.2602778 ],
    [ u"us",u"Lomita",20751,33.7922222,-118.3141667 ],
    [ u"us",u"Lompoc",40957,34.6391667,-120.4569444 ],
    [ u"us",u"Long Beach",482618,33.7669444,-118.1883333 ],
    [ u"us",u"Los Alamitos",11718,33.8030556,-118.0716667 ],
    [ u"us",u"Los Altos",26871,37.3852778,-122.1130556 ],
    [ u"us",u"Los Altos Hills",8207,37.3797222,-122.1363889 ],
    [ u"us",u"Los Angeles",3877129,34.0522222,-118.2427778 ],
    [ u"us",u"Los Banos",33317,37.0583333,-120.8488889 ],
    [ u"us",u"Los Gatos",27551,37.2266667,-121.9736111 ],
    [ u"us",u"Lynwood",72397,33.9302778,-118.2105556 ],
    [ u"us",u"Madera",51451,36.9613889,-120.0597222 ],
    [ u"us",u"Magalia",11577,39.8122222,-121.5772222 ],
    [ u"us",u"Malibu",13769,34.0050000,-118.8091667 ],
    [ u"us",u"Manhattan Beach",37174,33.8847222,-118.4100000 ],
    [ u"us",u"Manteca",65820,37.7975000,-121.2150000 ],
    [ u"us",u"Marina",16957,36.6844444,-121.8011111 ],
    [ u"us",u"Martinez",36702,38.0194444,-122.1330556 ],
    [ u"us",u"Marysville",12530,39.1458333,-121.5902778 ],
    [ u"us",u"Maywood",28965,33.9866667,-118.1844444 ],
    [ u"us",u"Mendota",8872,36.7536111,-120.3805556 ],
    [ u"us",u"Menlo Park",29071,37.4538889,-122.1811111 ],
    [ u"us",u"Merced",72619,37.3022222,-120.4819444 ],
    [ u"us",u"Mill Valley",13219,37.9061111,-122.5438889 ],
    [ u"us",u"Millbrae",19557,37.5986111,-122.3861111 ],
    [ u"us",u"Milpitas",62636,37.4283333,-121.9055556 ],
    [ u"us",u"Mira Loma",18827,33.9925000,-117.5155556 ],
    [ u"us",u"Mission Viejo",96287,33.6000000,-117.6711111 ],
    [ u"us",u"Modesto",216008,37.6391667,-120.9958333 ],
    [ u"us",u"Monrovia",38439,34.1480556,-117.9980556 ],
    [ u"us",u"Montclair",35729,34.0775000,-117.6888889 ],
    [ u"us",u"Montebello",64327,34.0094444,-118.1044444 ],
    [ u"us",u"Monterey",30307,36.6002778,-121.8936111 ],
    [ u"us",u"Monterey Park",63193,34.0625000,-118.1219444 ],
    [ u"us",u"Moorpark",37010,34.2855556,-118.8811111 ],
    [ u"us",u"Moraga",16826,37.8350000,-122.1286111 ],
    [ u"us",u"Moreno Valley",168629,33.9375000,-117.2297222 ],
    [ u"us",u"Morgan Hill",34719,37.1305556,-121.6533333 ],
    [ u"us",u"Morro Bay",10242,35.3658333,-120.8488889 ],
    [ u"us",u"Mountain View",68268,37.3861111,-122.0827778 ],
    [ u"us",u"Murrieta",88714,33.5538889,-117.2130556 ],
    [ u"us",u"Napa",77015,38.2972222,-122.2844444 ],
    [ u"us",u"National City",62490,32.6780556,-117.0983333 ],
    [ u"us",u"Newark",42922,37.5297222,-122.0391667 ],
    [ u"us",u"Newport Beach",78702,33.6188889,-117.9280556 ],
    [ u"us",u"Norco",27346,33.9311111,-117.5477778 ],
    [ u"us",u"North Auburn",12841,38.9313889,-121.0808333 ],
    [ u"us",u"North Highlands",45878,38.6858333,-121.3711111 ],
    [ u"us",u"Norwalk",109111,33.9022222,-118.0808333 ],
    [ u"us",u"Novato",48817,38.1075000,-122.5686111 ],
    [ u"us",u"Oakdale",18668,37.7666667,-120.8461111 ],
    [ u"us",u"Oakland",394579,37.8044444,-122.2697222 ],
    [ u"us",u"Oakley",26774,37.9975000,-121.7113889 ],
    [ u"us",u"Oceanside",170340,33.1958333,-117.3786111 ],
    [ u"us",u"Oildale",28962,35.4197222,-119.0186111 ],
    [ u"us",u"Olivehurst",11919,39.0955556,-121.5511111 ],
    [ u"us",u"Ontario",172808,34.0633333,-117.6500000 ],
    [ u"us",u"Orange",133874,33.7877778,-117.8522222 ],
    [ u"us",u"Orange Cove",9768,36.6244444,-119.3127778 ],
    [ u"us",u"Orangevale",27318,38.6786111,-121.2247222 ],
    [ u"us",u"Orinda",18251,37.8772222,-122.1786111 ],
    [ u"us",u"Oroville",13197,39.5138889,-121.5552778 ],
    [ u"us",u"Oxnard",187235,34.1975000,-119.1761111 ],
    [ u"us",u"Pacific Grove",15196,36.6177778,-121.9155556 ],
    [ u"us",u"Pacifica",36472,37.6138889,-122.4858333 ],
    [ u"us",u"Palm Desert",48531,33.7222222,-116.3736111 ],
    [ u"us",u"Palm Springs",46680,33.8302778,-116.5444444 ],
    [ u"us",u"Palmdale",135294,34.5794444,-118.1155556 ],
    [ u"us",u"Palo Alto",56508,37.4419444,-122.1419444 ],
    [ u"us",u"Palos Verdes Estates",14036,33.8005556,-118.3891667 ],
    [ u"us",u"Paradise",26949,39.7597222,-121.6208333 ],
    [ u"us",u"Paramount",57275,33.8894444,-118.1588889 ],
    [ u"us",u"Parlier",12811,36.6116667,-119.5261111 ],
    [ u"us",u"Pasadena",144618,34.1477778,-118.1436111 ],
    [ u"us",u"Patterson",15957,37.4716667,-121.1286111 ],
    [ u"us",u"Pedley",12697,33.9752778,-117.4750000 ],
    [ u"us",u"Perris",46318,33.7825000,-117.2277778 ],
    [ u"us",u"Petaluma",55352,38.2325000,-122.6355556 ],
    [ u"us",u"Pico Rivera",66332,33.9830556,-118.0958333 ],
    [ u"us",u"Piedmont",10619,37.8244444,-122.2305556 ],
    [ u"us",u"Pinole",19540,38.0044444,-122.2977778 ],
    [ u"us",u"Pismo Beach",8477,35.1427778,-120.6402778 ],
    [ u"us",u"Pittsburg",62838,38.0280556,-121.8836111 ],
    [ u"us",u"Placentia",49160,33.8722222,-117.8694444 ],
    [ u"us",u"Placerville",10274,38.7297222,-120.7975000 ],
    [ u"us",u"Pleasant Hill",34477,37.9480556,-122.0597222 ],
    [ u"us",u"Pleasanton",66532,37.6625000,-121.8736111 ],
    [ u"us",u"Pomona",156183,34.0552778,-117.7513889 ],
    [ u"us",u"Port Hueneme",21417,34.1477778,-119.1941667 ],
    [ u"us",u"Porterville",44674,36.0652778,-119.0158333 ],
    [ u"us",u"Poway",49635,32.9627778,-117.0350000 ],
    [ u"us",u"Quartz Hill",10167,34.6452778,-118.2172222 ],
    [ u"us",u"Ramona",17373,33.0416667,-116.8672222 ],
    [ u"us",u"Rancho Cordova",59185,38.5891667,-121.3016667 ],
    [ u"us",u"Rancho Cucamonga",168557,34.1063889,-117.5922222 ],
    [ u"us",u"Rancho Mirage",16742,33.7397222,-116.4119444 ],
    [ u"us",u"Rancho Palos Verdes",42693,33.7444444,-118.3861111 ],
    [ u"us",u"Rancho San Diego",28267,32.7472222,-116.9344444 ],
    [ u"us",u"Rancho Santa Margarita",51344,33.6408333,-117.6022222 ],
    [ u"us",u"Red Bluff",14036,40.1786111,-122.2347222 ],
    [ u"us",u"Redding",91685,40.5866667,-122.3905556 ],
    [ u"us",u"Redlands",70287,34.0555556,-117.1816667 ],
    [ u"us",u"Redondo Beach",67791,33.8491667,-118.3875000 ],
    [ u"us",u"Redwood City",71969,37.4852778,-122.2352778 ],
    [ u"us",u"Reedley",22156,36.5963889,-119.4494444 ],
    [ u"us",u"Rialto",101523,34.1063889,-117.3694444 ],
    [ u"us",u"Richmond",103041,37.9358333,-122.3466667 ],
    [ u"us",u"Ridgecrest",26110,35.6225000,-117.6700000 ],
    [ u"us",u"Rio Linda",11128,38.6911111,-121.4475000 ],
    [ u"us",u"Ripon",13591,37.7416667,-121.1233333 ],
    [ u"us",u"Riverbank",18775,37.7361111,-120.9344444 ],
    [ u"us",u"Riverside",297554,33.9533333,-117.3952778 ],
    [ u"us",u"Rocklin",55007,38.7908333,-121.2347222 ],
    [ u"us",u"Rohnert Park",41314,38.3397222,-122.7000000 ],
    [ u"us",u"Roseland",5986,38.4222222,-122.7269444 ],
    [ u"us",u"Rosemead",56066,34.0805556,-118.0719444 ],
    [ u"us",u"Rosemont",23273,38.5519444,-121.3636111 ],
    [ u"us",u"Roseville",112647,38.7522222,-121.2869444 ],
    [ u"us",u"Rossmoor",10651,33.7855556,-118.0841667 ],
    [ u"us",u"Rowland Heights",52377,33.9761111,-117.9044444 ],
    [ u"us",u"Rubidoux",32235,33.9961111,-117.4047222 ],
    [ u"us",u"Sacramento",467898,38.5816667,-121.4933333 ],
    [ u"us",u"Salinas",148691,36.6777778,-121.6544444 ],
    [ u"us",u"San Anselmo",11936,37.9747222,-122.5605556 ],
    [ u"us",u"San Bernardino",202381,34.1083333,-117.2888889 ],
    [ u"us",u"San Bruno",39662,37.6305556,-122.4100000 ],
    [ u"us",u"San Carlos",26630,37.5072222,-122.2594444 ],
    [ u"us",u"San Clemente",62272,33.4269444,-117.6111111 ],
    [ u"us",u"San Diego",1287050,32.7152778,-117.1563889 ],
    [ u"us",u"San Dimas",36422,34.1066667,-117.8058333 ],
    [ u"us",u"San Fernando",24524,34.2819444,-118.4380556 ],
    [ u"us",u"San Francisco",732072,37.7750000,-122.4183333 ],
    [ u"us",u"San Gabriel",41535,34.0961111,-118.1050000 ],
    [ u"us",u"San Jacinto",29376,33.7838889,-116.9577778 ],
    [ u"us",u"San Jose",897460,37.3394444,-121.8938889 ],
    [ u"us",u"San Juan Capistrano",35301,33.5016667,-117.6616667 ],
    [ u"us",u"San Leandro",79904,37.7250000,-122.1550000 ],
    [ u"us",u"San Lorenzo",23201,37.6811111,-122.1233333 ],
    [ u"us",u"San Luis Obispo",44132,35.2827778,-120.6586111 ],
    [ u"us",u"San Marcos",69697,33.1433333,-117.1652778 ],
    [ u"us",u"San Marino",13314,34.1213889,-118.1055556 ],
    [ u"us",u"San Mateo",89982,37.5630556,-122.3244444 ],
    [ u"us",u"San Pablo",31351,37.9622222,-122.3444444 ],
    [ u"us",u"San Rafael",55270,37.9736111,-122.5300000 ],
    [ u"us",u"San Ramon",45993,37.7800000,-121.9769444 ],
    [ u"us",u"Sanger",20772,36.7080556,-119.5550000 ],
    [ u"us",u"Santa Ana",343054,33.7455556,-117.8669444 ],
    [ u"us",u"Santa Barbara",86681,34.4208333,-119.6972222 ],
    [ u"us",u"Santa Clara",102250,37.3541667,-121.9541667 ],
    [ u"us",u"Santa Clarita",168927,34.3916667,-118.5416667 ],
    [ u"us",u"Santa Cruz",54617,36.9741667,-122.0297222 ],
    [ u"us",u"Santa Fe Springs",16330,33.9472222,-118.0844444 ],
    [ u"us",u"Santa Maria",85480,34.9530556,-120.4347222 ],
    [ u"us",u"Santa Monica",88338,34.0194444,-118.4902778 ],
    [ u"us",u"Santa Paula",29015,34.3541667,-119.0583333 ],
    [ u"us",u"Santa Rosa",155118,38.4405556,-122.7133333 ],
    [ u"us",u"Santee",52600,32.8383333,-116.9730556 ],
    [ u"us",u"Saratoga",28956,37.2638889,-122.0219444 ],
    [ u"us",u"Scotts Valley",11120,37.0511111,-122.0136111 ],
    [ u"us",u"Seal Beach",24404,33.7413889,-118.1038889 ],
    [ u"us",u"Seaside",35762,36.6111111,-121.8505556 ],
    [ u"us",u"Selma",22426,36.5708333,-119.6111111 ],
    [ u"us",u"Shafter",14396,35.5005556,-119.2708333 ],
    [ u"us",u"Shasta Lake",10611,40.6805556,-122.3697222 ],
    [ u"us",u"Sierra Madre",11090,34.1616667,-118.0519444 ],
    [ u"us",u"Signal Hill",10576,33.8044444,-118.1669444 ],
    [ u"us",u"Simi Valley",119417,34.2694444,-118.7805556 ],
    [ u"us",u"Solana Beach",12909,32.9911111,-117.2702778 ],
    [ u"us",u"Soledad",28140,36.4247222,-121.3252778 ],
    [ u"us",u"Sonoma",9773,38.2919444,-122.4569444 ],
    [ u"us",u"Soquel",5096,36.9880556,-121.9555556 ],
    [ u"us",u"South El Monte",22049,34.0519444,-118.0458333 ],
    [ u"us",u"South Gate",99922,33.9547222,-118.2111111 ],
    [ u"us",u"South Lake Tahoe",23925,38.9333333,-119.9833333 ],
    [ u"us",u"South Pasadena",24994,34.1161111,-118.1494444 ],
    [ u"us",u"South San Francisco",58555,37.6547222,-122.4066667 ],
    [ u"us",u"South San Jose Hills",21779,34.0127778,-117.9038889 ],
    [ u"us",u"South Whittier",58952,33.9608333,-118.0408333 ],
    [ u"us",u"South Yuba City",15217,39.1166667,-121.6380556 ],
    [ u"us",u"Spring Valley",26180,32.7447222,-116.9980556 ],
    [ u"us",u"Stanford",12574,37.4241667,-122.1650000 ],
    [ u"us",u"Stanton",37914,33.8025000,-117.9922222 ],
    [ u"us",u"Stockton",289580,37.9577778,-121.2897222 ],
    [ u"us",u"Suisun City",27219,38.2383333,-122.0391667 ],
    [ u"us",u"Sun City",19579,33.7091667,-117.1963889 ],
    [ u"us",u"Sunnyvale",126499,37.3688889,-122.0352778 ],
    [ u"us",u"Susanville",17641,40.4163889,-120.6519444 ],
    [ u"us",u"Taft",9295,35.1425000,-119.4555556 ],
    [ u"us",u"Tehachapi",12009,35.1322222,-118.4480556 ],
    [ u"us",u"Temecula",85145,33.4936111,-117.1475000 ],
    [ u"us",u"Temple City",37973,34.1072222,-118.0569444 ],
    [ u"us",u"Thousand Oaks",127942,34.1705556,-118.8366667 ],
    [ u"us",u"Tiburon",8632,37.8736111,-122.4555556 ],
    [ u"us",u"Torrance",144963,33.8358333,-118.3397222 ],
    [ u"us",u"Tracy",83216,37.7397222,-121.4241667 ],
    [ u"us",u"Truckee",15771,39.3280556,-120.1822222 ],
    [ u"us",u"Tulare",50103,36.2077778,-119.3463889 ],
    [ u"us",u"Turlock",67940,37.4947222,-120.8455556 ],
    [ u"us",u"Tustin",68728,33.7458333,-117.8252778 ],
    [ u"us",u"Tustin Foothills",24257,33.7644444,-117.7930556 ],
    [ u"us",u"Twentynine Palms",22642,34.1355556,-116.0533333 ],
    [ u"us",u"Ukiah",15825,39.1502778,-123.2066667 ],
    [ u"us",u"Union City",69530,37.5958333,-122.0180556 ],
    [ u"us",u"Upland",74230,34.0975000,-117.6475000 ],
    [ u"us",u"Vacaville",96469,38.3566667,-121.9866667 ],
    [ u"us",u"Valinda",23721,34.0452778,-117.9427778 ],
    [ u"us",u"Vallejo",120446,38.1041667,-122.2555556 ],
    [ u"us",u"Victorville",83496,34.5361111,-117.2902778 ],
    [ u"us",u"Visalia",107431,36.3302778,-119.2911111 ],
    [ u"us",u"Vista",92707,33.2000000,-117.2416667 ],
    [ u"us",u"Walnut",31720,34.0202778,-117.8644444 ],
    [ u"us",u"Walnut Creek",65179,37.9063889,-122.0638889 ],
    [ u"us",u"Walnut Park",17168,33.9680556,-118.2241667 ],
    [ u"us",u"Wasco",22813,35.5941667,-119.3400000 ],
    [ u"us",u"Watsonville",45724,36.9102778,-121.7558333 ],
    [ u"us",u"West Athens",9355,33.9233333,-118.3025000 ],
    [ u"us",u"West Carson",21947,33.8216667,-118.2916667 ],
    [ u"us",u"West Covina",109756,34.0686111,-117.9380556 ],
    [ u"us",u"West Hollywood",37031,34.0900000,-118.3608333 ],
    [ u"us",u"West Puente Valley",24134,34.0516667,-117.9675000 ],
    [ u"us",u"West Sacramento",41446,38.5805556,-121.5291667 ],
    [ u"us",u"Westlake Village",8663,34.1458333,-118.8047222 ],
    [ u"us",u"Westminster",89868,33.7591667,-118.0058333 ],
    [ u"us",u"Westmont",32377,33.9413889,-118.3013889 ],
    [ u"us",u"Whittier",85778,33.9791667,-118.0319444 ],
    [ u"us",u"Wildomar",16442,33.5988889,-117.2791667 ],
    [ u"us",u"Willowbrook",35321,33.9169444,-118.2541667 ],
    [ u"us",u"Windsor",25262,38.5472222,-122.8152778 ],
    [ u"us",u"Woodland",51731,38.6786111,-121.7722222 ],
    [ u"us",u"Yorba Linda",64778,33.8886111,-117.8122222 ],
    [ u"us",u"Yuba City",52432,39.1405556,-121.6158333 ],
    [ u"us",u"Yucaipa",50392,34.0336111,-117.0422222 ],
    [ u"us",u"Yucca Valley",19344,34.1141667,-116.4313889 ],
    [ u"us",u"Alamosa",8771,37.4694444,-105.8694444 ],
    [ u"us",u"Applewood",7533,39.7472222,-105.1622222 ],
    [ u"us",u"Arvada",101732,39.8027778,-105.0869444 ],
    [ u"us",u"Aurora",299780,39.7294444,-104.8313889 ],
    [ u"us",u"Black Forest",16096,39.0130556,-104.7002778 ],
    [ u"us",u"Boulder",91521,40.0150000,-105.2700000 ],
    [ u"us",u"Brighton",29328,39.9852778,-104.8200000 ],
    [ u"us",u"Broomfield",44692,39.9205556,-105.0861111 ],
    [ u"us",u"Canon City",15972,38.4000000,-105.2166667 ],
    [ u"us",u"Castle Rock",38814,39.3722222,-104.8555556 ],
    [ u"us",u"Castlewood",25271,39.5847222,-104.9005556 ],
    [ u"us",u"Centennial",96930,39.5791667,-104.8763889 ],
    [ u"us",u"Cimarron Hills",16981,38.8586111,-104.6983333 ],
    [ u"us",u"Clifton",19435,39.0919444,-108.4483333 ],
    [ u"us",u"Colorado Springs",373072,38.8338889,-104.8208333 ],
    [ u"us",u"Columbine",23353,39.5877778,-105.0688889 ],
    [ u"us",u"Commerce City",30707,39.8083333,-104.9333333 ],
    [ u"us",u"Cortez",8285,37.3488889,-108.5852778 ],
    [ u"us",u"Craig",9391,40.5152778,-107.5458333 ],
    [ u"us",u"Denver",555981,39.7391667,-104.9841667 ],
    [ u"us",u"Durango",15022,37.2752778,-107.8794444 ],
    [ u"us",u"Englewood",32860,39.6477778,-104.9872222 ],
    [ u"us",u"Erie",10403,40.0502778,-105.0494444 ],
    [ u"us",u"Evans",19623,40.3763889,-104.6916667 ],
    [ u"us",u"Federal Heights",11551,39.8513889,-104.9980556 ],
    [ u"us",u"Fort Carson",10645,38.7375000,-104.7883333 ],
    [ u"us",u"Fort Collins",129252,40.5852778,-105.0838889 ],
    [ u"us",u"Fort Morgan",10969,40.2502778,-103.7994444 ],
    [ u"us",u"Fountain",15925,38.6822222,-104.7002778 ],
    [ u"us",u"Glenwood Springs",8540,39.5505556,-107.3241667 ],
    [ u"us",u"Golden",17887,39.7555556,-105.2205556 ],
    [ u"us",u"Grand Junction",45938,39.0638889,-108.5500000 ],
    [ u"us",u"Greeley",86875,40.4233333,-104.7086111 ],
    [ u"us",u"Greenwood Village",13338,39.6172222,-104.9502778 ],
    [ u"us",u"Highlands Ranch",101565,39.5538889,-104.9688889 ],
    [ u"us",u"Ken Caryl",33365,39.5758333,-105.1116667 ],
    [ u"us",u"Lafayette",23716,39.9936111,-105.0891667 ],
    [ u"us",u"Lakewood",140772,39.7047222,-105.0808333 ],
    [ u"us",u"Lamar",8514,38.0872222,-102.6202778 ],
    [ u"us",u"Littleton",40947,39.6133333,-105.0161111 ],
    [ u"us",u"Longmont",83291,40.1672222,-105.1013889 ],
    [ u"us",u"Louisville",17965,39.9777778,-105.1313889 ],
    [ u"us",u"Loveland",59618,40.3977778,-105.0744444 ],
    [ u"us",u"Montrose",15138,38.4783333,-107.8755556 ],
    [ u"us",u"Northglenn",32656,39.8855556,-104.9866667 ],
    [ u"us",u"Parker",41059,39.5186111,-104.7608333 ],
    [ u"us",u"Pueblo",104293,38.2544444,-104.6086111 ],
    [ u"us",u"Redlands",7877,39.0788889,-108.6350000 ],
    [ u"us",u"Sherrelwood",17556,39.8377778,-105.0008333 ],
    [ u"us",u"Southglenn",42268,39.5872222,-104.9522222 ],
    [ u"us",u"Steamboat Springs",9349,40.4850000,-106.8311111 ],
    [ u"us",u"Sterling",12682,40.6255556,-103.2072222 ],
    [ u"us",u"Superior",11186,39.9527778,-105.1680556 ],
    [ u"us",u"Thornton",104658,39.8680556,-104.9713889 ],
    [ u"us",u"Trinidad",9156,37.1694444,-104.5000000 ],
    [ u"us",u"Welby",14031,39.8366667,-104.9586111 ],
    [ u"us",u"Westminster",104037,39.8366667,-105.0366667 ],
    [ u"us",u"Wheat Ridge",30978,39.7661111,-105.0766667 ],
    [ u"us",u"Windsor",14904,40.4775000,-104.9008333 ],
    [ u"us",u"Ansonia",18959,41.3461111,-73.0794444 ],
    [ u"us",u"Branford",29438,41.2794444,-72.8155556 ],
    [ u"us",u"Bridgeport",139090,41.1669444,-73.2052778 ],
    [ u"us",u"Bristol",61033,41.6716667,-72.9497222 ],
    [ u"us",u"Cheshire",29443,41.4988889,-72.9011111 ],
    [ u"us",u"Clinton",14064,41.2786111,-72.5280556 ],
    [ u"us",u"Colchester",15502,41.5755556,-72.3325000 ],
    [ u"us",u"Coventry",12428,41.7700000,-72.3055556 ],
    [ u"us",u"Cromwell",13750,41.5950000,-72.6458333 ],
    [ u"us",u"Danbury",78565,41.3947222,-73.4544444 ],
    [ u"us",u"Darien",20753,41.0786111,-73.4697222 ],
    [ u"us",u"Derby",12717,41.3205556,-73.0894444 ],
    [ u"us",u"East Haddam",9042,41.4530556,-72.4616667 ],
    [ u"us",u"East Hampton",9540,41.5758333,-72.5030556 ],
    [ u"us",u"East Hartford",50160,41.7822222,-72.6125000 ],
    [ u"us",u"East Haven",29006,41.2761111,-72.8688889 ],
    [ u"us",u"Ellington",14693,41.9038889,-72.4702778 ],
    [ u"us",u"Fairfield",59052,41.1411111,-73.2641667 ],
    [ u"us",u"Greenwich",63652,41.0263889,-73.6288889 ],
    [ u"us",u"Groton",10363,41.3500000,-72.0788889 ],
    [ u"us",u"Guilford",22498,41.2888889,-72.6822222 ],
    [ u"us",u"Hamden",59847,41.3958333,-72.8972222 ],
    [ u"us",u"Hartford",124019,41.7636111,-72.6855556 ],
    [ u"us",u"Hebron",9298,41.6577778,-72.3663889 ],
    [ u"us",u"Litchfield",409,41.7472222,-73.1891667 ],
    [ u"us",u"Madison",19100,41.2794444,-72.5988889 ],
    [ u"us",u"Meriden",59395,41.5380556,-72.8075000 ],
    [ u"us",u"Middletown",50362,41.5622222,-72.6511111 ],
    [ u"us",u"Milford",51195,41.2222222,-73.0569444 ],
    [ u"us",u"Naugatuck",32161,41.4858333,-73.0511111 ],
    [ u"us",u"New Britain",71455,41.6611111,-72.7800000 ],
    [ u"us",u"New Haven",124922,41.3080556,-72.9286111 ],
    [ u"us",u"New London",26294,41.3555556,-72.1000000 ],
    [ u"us",u"New Milford",42421,41.5769444,-73.4088889 ],
    [ u"us",u"Newington",29945,41.6977778,-72.7241667 ],
    [ u"us",u"North Branford",14454,41.3275000,-72.7677778 ],
    [ u"us",u"North Haven",23960,41.3908333,-72.8600000 ],
    [ u"us",u"Norwalk",84530,41.1175000,-73.4083333 ],
    [ u"us",u"Norwich",36441,41.5241667,-72.0763889 ],
    [ u"us",u"Old Saybrook",10627,41.2916667,-72.3766667 ],
    [ u"us",u"Orange",13860,41.2783333,-73.0261111 ],
    [ u"us",u"Oxford",11345,41.4338889,-73.1172222 ],
    [ u"us",u"Plainfield",15498,41.6763889,-71.9155556 ],
    [ u"us",u"Plymouth",12284,41.6719444,-73.0533333 ],
    [ u"us",u"Portland",14510,41.5727778,-72.6411111 ],
    [ u"us",u"Prospect",9476,41.5022222,-72.9791667 ],
    [ u"us",u"Putnam",9111,41.9150000,-71.9094444 ],
    [ u"us",u"Seymour",16562,41.3966667,-73.0763889 ],
    [ u"us",u"Shelton",39695,41.3163889,-73.0936111 ],
    [ u"us",u"Somers",11291,41.9852778,-72.4466667 ],
    [ u"us",u"Southbury",19836,41.4813889,-73.2136111 ],
    [ u"us",u"Stafford",12029,41.9847222,-72.2894444 ],
    [ u"us",u"Stamford",121230,41.0533333,-73.5391667 ],
    [ u"us",u"Stonington",251,41.3358333,-71.9063889 ],
    [ u"us",u"Storrs",10684,41.8083333,-72.2500000 ],
    [ u"us",u"Stratford",51268,41.1844444,-73.1336111 ],
    [ u"us",u"Thompson",9358,41.9586111,-71.8630556 ],
    [ u"us",u"Tolland",14891,41.8713889,-72.3691667 ],
    [ u"us",u"Torrington",36000,41.8005556,-73.1216667 ],
    [ u"us",u"Trumbull",36065,41.2427778,-73.2011111 ],
    [ u"us",u"Vernon",30064,41.8186111,-72.4800000 ],
    [ u"us",u"Waterbury",108507,41.5580556,-73.0519444 ],
    [ u"us",u"Watertown",22391,41.6061111,-73.1186111 ],
    [ u"us",u"West Hartford",66610,41.7619444,-72.7425000 ],
    [ u"us",u"West Haven",53401,41.2705556,-72.9475000 ],
    [ u"us",u"Westport",26938,41.1413889,-73.3583333 ],
    [ u"us",u"Wethersfield",27104,41.7141667,-72.6530556 ],
    [ u"us",u"Willimantic",16686,41.7105556,-72.2086111 ],
    [ u"us",u"Windham",23072,41.6997222,-72.1575000 ],
    [ u"us",u"Windsor Locks",12138,41.9291667,-72.6277778 ],
    [ u"us",u"Wolcott",16639,41.6022222,-72.9872222 ],
    [ u"us",u"Woodbridge",9355,41.3525000,-73.0088889 ],
    [ u"us",u"Woodbury",9755,41.5444444,-73.2094444 ],
    [ u"us",u"Brookside",14519,39.6669444,-75.7272222 ],
    [ u"us",u"Claymont",8925,39.8005556,-75.4600000 ],
    [ u"us",u"Dover",33286,39.1580556,-75.5247222 ],
    [ u"us",u"Edgemoor",6036,39.7500000,-75.5000000 ],
    [ u"us",u"Elsmere",5713,39.7391667,-75.5983333 ],
    [ u"us",u"Georgetown",4932,38.6900000,-75.3858333 ],
    [ u"us",u"Middletown",6781,39.4494444,-75.7166667 ],
    [ u"us",u"Milford",7129,38.9125000,-75.4283333 ],
    [ u"us",u"New Castle",4718,39.6619444,-75.5666667 ],
    [ u"us",u"Newark",30238,39.6836111,-75.7500000 ],
    [ u"us",u"Pike Creek",25752,39.7308333,-75.7044444 ],
    [ u"us",u"Seaford",7121,38.6411111,-75.6113889 ],
    [ u"us",u"Smyrna",6691,39.2997222,-75.6050000 ],
    [ u"us",u"Wilmington",71356,39.7458333,-75.5469444 ],
    [ u"us",u"Wilmington Manor",8091,39.6866667,-75.5847222 ],
    [ u"us",u"Washington",552433,38.8950000,-77.0366667 ],
    [ u"us",u"Altamonte Springs",40819,28.6608333,-81.3658333 ],
    [ u"us",u"Apopka",33216,28.6802778,-81.5097222 ],
    [ u"us",u"Atlantic Beach",13644,30.3341667,-81.3988889 ],
    [ u"us",u"Auburndale",12405,28.0650000,-81.7888889 ],
    [ u"us",u"Aventura",27892,25.9561111,-80.1394444 ],
    [ u"us",u"Avon Park",8777,27.5955556,-81.5063889 ],
    [ u"us",u"Azalea Park",12347,28.5408333,-81.3008333 ],
    [ u"us",u"Bartow",15718,27.8961111,-81.8433333 ],
    [ u"us",u"Bayonet Point",24618,28.3263889,-82.6836111 ],
    [ u"us",u"Bayshore Gardens",17622,27.4250000,-82.5905556 ],
    [ u"us",u"Belle Glade",15269,26.6841667,-80.6677778 ],
    [ u"us",u"Bellview",22282,30.4613889,-87.3150000 ],
    [ u"us",u"Bloomingdale",23618,27.8933333,-82.2405556 ],
    [ u"us",u"Boca Raton",80689,26.3583333,-80.0833333 ],
    [ u"us",u"Bonita Springs",41840,26.3394444,-81.7788889 ],
    [ u"us",u"Boynton Beach",66442,26.5250000,-80.0666667 ],
    [ u"us",u"Bradenton",54608,27.4986111,-82.5750000 ],
    [ u"us",u"Brandon",90165,27.9375000,-82.2861111 ],
    [ u"us",u"Brent",22735,30.4686111,-87.2361111 ],
    [ u"us",u"Callaway",14913,30.1527778,-85.5700000 ],
    [ u"us",u"Cape Canaveral",10101,28.4055556,-80.6050000 ],
    [ u"us",u"Cape Coral",130807,26.5625000,-81.9497222 ],
    [ u"us",u"Carol City",63031,25.9402778,-80.2458333 ],
    [ u"us",u"Casselberry",23821,28.6775000,-81.3280556 ],
    [ u"us",u"Century Village",7839,26.7136111,-80.1291667 ],
    [ u"us",u"Citrus Park",22364,28.0780556,-82.5700000 ],
    [ u"us",u"Clearwater",108064,27.9655556,-82.8002778 ],
    [ u"us",u"Clermont",11473,28.5491667,-81.7730556 ],
    [ u"us",u"Cocoa",16433,28.3858333,-80.7422222 ],
    [ u"us",u"Cocoa Beach",12336,28.3197222,-80.6077778 ],
    [ u"us",u"Coconut Creek",50326,26.2513889,-80.1791667 ],
    [ u"us",u"Conway",15129,28.5025000,-81.3308333 ],
    [ u"us",u"Cooper City",29172,26.0569444,-80.2719444 ],
    [ u"us",u"Coral Gables",42485,25.7211111,-80.2686111 ],
    [ u"us",u"Coral Springs",131674,26.2708333,-80.2708333 ],
    [ u"us",u"Coral Terrace",25120,25.7455556,-80.3047222 ],
    [ u"us",u"Country Club",53746,25.9477778,-80.3172222 ],
    [ u"us",u"Crestview",16702,30.7619444,-86.5705556 ],
    [ u"us",u"Cutler",18117,25.6147222,-80.3108333 ],
    [ u"us",u"Cutler Ridge",26831,25.5802778,-80.3469444 ],
    [ u"us",u"Cypress Gardens",8755,27.9936111,-81.6902778 ],
    [ u"us",u"Cypress Lake",12994,26.5377778,-81.8994444 ],
    [ u"us",u"Dania Beach",28826,26.0519444,-80.1441667 ],
    [ u"us",u"Davie",82605,26.0625000,-80.2333333 ],
    [ u"us",u"Daytona Beach",64661,29.2105556,-81.0230556 ],
    [ u"us",u"De Land",22721,29.0280556,-81.3033333 ],
    [ u"us",u"Deerfield Beach",66239,26.3180556,-80.1000000 ],
    [ u"us",u"Delray Beach",65511,26.4611111,-80.0730556 ],
    [ u"us",u"Deltona",82008,28.9002778,-81.2638889 ],
    [ u"us",u"Destin",12115,30.3933333,-86.4958333 ],
    [ u"us",u"Doctor Phillips",10478,28.4491667,-81.4925000 ],
    [ u"us",u"Dunedin",37020,28.0194444,-82.7719444 ],
    [ u"us",u"East Lake",43892,28.1105556,-82.6950000 ],
    [ u"us",u"Edgewater",21209,28.9886111,-80.9025000 ],
    [ u"us",u"Egypt Lake-Leto",46140,28.0166667,-82.4955556 ],
    [ u"us",u"Elfers",13662,28.2163889,-82.7225000 ],
    [ u"us",u"Englewood",16907,26.9616667,-82.3527778 ],
    [ u"us",u"Ensley",20146,30.5186111,-87.2727778 ],
    [ u"us",u"Eustis",17071,28.8525000,-81.6855556 ],
    [ u"us",u"Fairview Shores",14353,28.5908333,-81.3944444 ],
    [ u"us",u"Fern Park",8394,28.6488889,-81.3513889 ],
    [ u"us",u"Fernandina Beach",11257,30.6694444,-81.4627778 ],
    [ u"us",u"Ferry Pass",27810,30.5100000,-87.2125000 ],
    [ u"us",u"Florida Ridge",16999,27.5800000,-80.3869444 ],
    [ u"us",u"Forest City",13767,28.6613889,-81.4191667 ],
    [ u"us",u"Fort Lauderdale",170510,26.1219444,-80.1436111 ],
    [ u"us",u"Fort Myers",53015,26.6402778,-81.8725000 ],
    [ u"us",u"Fort Myers Beach",6876,26.4516667,-81.9483333 ],
    [ u"us",u"Fort Pierce",37723,27.4463889,-80.3258333 ],
    [ u"us",u"Fort Walton Beach",19731,30.4055556,-86.6188889 ],
    [ u"us",u"Fruitville",14518,27.3294444,-82.4577778 ],
    [ u"us",u"Gainesville",125684,29.6513889,-82.3250000 ],
    [ u"us",u"Gladeview",14058,25.8388889,-80.2358333 ],
    [ u"us",u"Glenvar Heights",17087,25.7072222,-80.3258333 ],
    [ u"us",u"Golden Gate",25388,26.1875000,-81.6952778 ],
    [ u"us",u"Golden Glades",36924,25.9113889,-80.2005556 ],
    [ u"us",u"Goldenrod",13219,28.6100000,-81.2888889 ],
    [ u"us",u"Gulf Gate Estates",11749,27.2591667,-82.5069444 ],
    [ u"us",u"Gulfport",12612,27.7480556,-82.7036111 ],
    [ u"us",u"Haines City",14457,28.1138889,-81.6180556 ],
    [ u"us",u"Hallandale Beach",35761,25.9808333,-80.1486111 ],
    [ u"us",u"Hamptons at Boca Raton",11218,26.3822222,-80.1861111 ],
    [ u"us",u"Hialeah",224840,25.8572222,-80.2783333 ],
    [ u"us",u"Hialeah Gardens",20241,25.8647222,-80.3247222 ],
    [ u"us",u"Hobe Sound",11403,27.0591667,-80.1366667 ],
    [ u"us",u"Holiday",23391,28.1875000,-82.7397222 ],
    [ u"us",u"Holly Hill",12738,29.2433333,-81.0377778 ],
    [ u"us",u"Hollywood",144821,26.0108333,-80.1497222 ],
    [ u"us",u"Homestead",35379,25.4683333,-80.4777778 ],
    [ u"us",u"Immokalee",23322,26.4183333,-81.4175000 ],
    [ u"us",u"Indian Harbour Beach",8579,28.1486111,-80.5886111 ],
    [ u"us",u"Iona",13052,26.5200000,-81.9641667 ],
    [ u"us",u"Ives Estates",20043,25.9619444,-80.1769444 ],
    [ u"us",u"Jacksonville",797557,30.3319444,-81.6558333 ],
    [ u"us",u"Jacksonville Beach",21552,30.2944444,-81.3933333 ],
    [ u"us",u"Jasmine Estates",18887,28.2927778,-82.6902778 ],
    [ u"us",u"Jensen Beach",11812,27.2541667,-80.2300000 ],
    [ u"us",u"Jupiter",48974,26.9338889,-80.0944444 ],
    [ u"us",u"Kendale Lakes",61791,25.7077778,-80.4072222 ],
    [ u"us",u"Kendall",83026,25.6788889,-80.3175000 ],
    [ u"us",u"Key Biscayne",10122,25.6933333,-80.1630556 ],
    [ u"us",u"Key Largo",12247,25.0861111,-80.4475000 ],
    [ u"us",u"Key West",24646,24.5552778,-81.7827778 ],
    [ u"us",u"Kings Point",12201,26.4450000,-80.1400000 ],
    [ u"us",u"Kissimmee",63685,28.2916667,-81.4077778 ],
    [ u"us",u"Lady Lake",13262,28.9172222,-81.9230556 ],
    [ u"us",u"Lake City",10924,30.1894444,-82.6394444 ],
    [ u"us",u"Lake Lucerne",9044,25.9647222,-80.2416667 ],
    [ u"us",u"Lake Magdalene",38195,28.0738889,-82.4719444 ],
    [ u"us",u"Lake Mary",14599,28.7586111,-81.3180556 ],
    [ u"us",u"Lake Park",9656,26.8000000,-80.0666667 ],
    [ u"us",u"Lake Wales",12407,27.9011111,-81.5861111 ],
    [ u"us",u"Lake Worth",35817,26.6155556,-80.0572222 ],
    [ u"us",u"Lakeland",90761,28.0391667,-81.9500000 ],
    [ u"us",u"Lakeland Highlands",14100,27.9594444,-81.9502778 ],
    [ u"us",u"Lakeside",32051,30.1297222,-81.7683333 ],
    [ u"us",u"Lantana",9816,26.5863889,-80.0522222 ],
    [ u"us",u"Largo",71666,27.9091667,-82.7875000 ],
    [ u"us",u"Lauderdale Lakes",31589,26.1661111,-80.2086111 ],
    [ u"us",u"Lauderhill",59861,26.1400000,-80.2136111 ],
    [ u"us",u"Laurel",8529,27.1300000,-82.4533333 ],
    [ u"us",u"Leesburg",18284,28.8105556,-81.8780556 ],
    [ u"us",u"Lehigh Acres",48534,26.6250000,-81.6250000 ],
    [ u"us",u"Leisure City",23770,25.4950000,-80.4294444 ],
    [ u"us",u"Lighthouse Point",11237,26.2752778,-80.0875000 ],
    [ u"us",u"Lockhart",13713,28.6191667,-81.4427778 ],
    [ u"us",u"Longwood",13594,28.7027778,-81.3386111 ],
    [ u"us",u"Lutz",21583,28.1508333,-82.4616667 ],
    [ u"us",u"Lynn Haven",15945,30.2452778,-85.6483333 ],
    [ u"us",u"Maitland",11686,28.6275000,-81.3633333 ],
    [ u"us",u"Mango",8979,27.9794444,-82.3066667 ],
    [ u"us",u"Marathon",10060,24.7133333,-81.0905556 ],
    [ u"us",u"Margate",55510,26.2441667,-80.2066667 ],
    [ u"us",u"Melbourne",76326,28.0833333,-80.6083333 ],
    [ u"us",u"Merritt Island",37991,28.5388889,-80.6722222 ],
    [ u"us",u"Miami",382894,25.7738889,-80.1938889 ],
    [ u"us",u"Miami Beach",89326,25.7902778,-80.1302778 ],
    [ u"us",u"Miami Lakes",22582,25.9083333,-80.3088889 ],
    [ u"us",u"Miami Shores",10056,25.8627778,-80.1930556 ],
    [ u"us",u"Miami Springs",13383,25.8219444,-80.2897222 ],
    [ u"us",u"Micco",9944,27.8802778,-80.5005556 ],
    [ u"us",u"Mims",9095,28.6650000,-80.8450000 ],
    [ u"us",u"Miramar",112922,25.9869444,-80.2325000 ],
    [ u"us",u"Mount Dora",10924,28.8022222,-81.6447222 ],
    [ u"us",u"Myrtle Grove",17255,30.4208333,-87.3075000 ],
    [ u"us",u"Naples",21498,26.1416667,-81.7950000 ],
    [ u"us",u"Naples Park",6756,26.2613889,-81.8094444 ],
    [ u"us",u"New Port Richey",17154,28.2438889,-82.7194444 ],
    [ u"us",u"New Smyrna Beach",21234,29.0255556,-80.9272222 ],
    [ u"us",u"Niceville",12573,30.5166667,-86.4822222 ],
    [ u"us",u"Norland",23604,25.9486111,-80.2125000 ],
    [ u"us",u"North Andrews Gardens",10056,26.1911111,-80.1444444 ],
    [ u"us",u"North Fort Myers",46482,26.6669444,-81.8802778 ],
    [ u"us",u"North Lauderdale",34267,26.2169444,-80.2261111 ],
    [ u"us",u"North Miami",58472,25.8897222,-80.1869444 ],
    [ u"us",u"North Miami Beach",39735,25.9327778,-80.1627778 ],
    [ u"us",u"North Palm Beach",12863,26.8172222,-80.0822222 ],
    [ u"us",u"North Port",38054,27.0438889,-82.2361111 ],
    [ u"us",u"Oak Ridge",26836,28.4708333,-81.4247222 ],
    [ u"us",u"Oakland Park",31605,26.1719444,-80.1322222 ],
    [ u"us",u"Ocala",49558,29.1869444,-82.1402778 ],
    [ u"us",u"Ocoee",28570,28.5688889,-81.5441667 ],
    [ u"us",u"Ojus",17330,25.9480556,-80.1508333 ],
    [ u"us",u"Oldsmar",15172,28.0338889,-82.6652778 ],
    [ u"us",u"Olympia Heights",14874,25.7263889,-80.3555556 ],
    [ u"us",u"Opa-locka",14563,25.9019444,-80.2505556 ],
    [ u"us",u"Orange Park",9265,30.1658333,-81.7066667 ],
    [ u"us",u"Orlando",207970,28.5380556,-81.3794444 ],
    [ u"us",u"Ormond Beach",38455,29.2855556,-81.0561111 ],
    [ u"us",u"Oviedo",29056,28.6697222,-81.2083333 ],
    [ u"us",u"Palatka",10737,29.6483333,-81.6377778 ],
    [ u"us",u"Palm Bay",89093,28.0341667,-80.5888889 ],
    [ u"us",u"Palm Beach",9767,26.7052778,-80.0366667 ],
    [ u"us",u"Palm Beach Gardens",48140,26.8230556,-80.1388889 ],
    [ u"us",u"Palm City",28165,27.1675000,-80.2663889 ],
    [ u"us",u"Palm Coast",41483,29.5847222,-81.2080556 ],
    [ u"us",u"Palm Harbor",64502,28.0777778,-82.7638889 ],
    [ u"us",u"Palm Springs",14329,26.6355556,-80.0963889 ],
    [ u"us",u"Palm Valley",27680,30.1772222,-81.3877778 ],
    [ u"us",u"Palmetto",12806,27.5211111,-82.5725000 ],
    [ u"us",u"Palmetto Estates",14488,25.6211111,-80.3622222 ],
    [ u"us",u"Panama City",37633,30.1586111,-85.6602778 ],
    [ u"us",u"Parkland",24693,26.3097222,-80.2375000 ],
    [ u"us",u"Pembroke Pines",155862,26.0027778,-80.2241667 ],
    [ u"us",u"Pensacola",54104,30.4211111,-87.2169444 ],
    [ u"us",u"Pine Castle",9132,28.4716667,-81.3680556 ],
    [ u"us",u"Pine Hills",45530,28.5575000,-81.4536111 ],
    [ u"us",u"Pinecrest",19720,25.6666667,-80.3083333 ],
    [ u"us",u"Pinellas Park",46495,27.8425000,-82.6997222 ],
    [ u"us",u"Pinewood",17149,25.8686111,-80.2172222 ],
    [ u"us",u"Plant City",31675,28.0183333,-82.1130556 ],
    [ u"us",u"Plantation",85739,26.1272222,-80.2333333 ],
    [ u"us",u"Pompano Beach",89715,26.2375000,-80.1250000 ],
    [ u"us",u"Pompano Beach Highlands",7192,26.2825000,-80.1072222 ],
    [ u"us",u"Port Charlotte",49333,26.9758333,-82.0908333 ],
    [ u"us",u"Port Orange",54209,29.1380556,-80.9958333 ],
    [ u"us",u"Port Saint John",14082,28.4766667,-80.7888889 ],
    [ u"us",u"Port Saint Lucie",119371,27.2936111,-80.3505556 ],
    [ u"us",u"Punta Gorda",18306,26.9294444,-82.0455556 ],
    [ u"us",u"Richmond Heights",8496,25.6311111,-80.3691667 ],
    [ u"us",u"Richmond West",31541,25.6100000,-80.4297222 ],
    [ u"us",u"Riviera Beach",33678,26.7750000,-80.0583333 ],
    [ u"us",u"Rockledge",23511,28.3505556,-80.7255556 ],
    [ u"us",u"Royal Palm Beach",34750,26.7080556,-80.2308333 ],
    [ u"us",u"Safety Harbor",17528,27.9905556,-82.6933333 ],
    [ u"us",u"Saint Augustine",12097,29.8944444,-81.3147222 ],
    [ u"us",u"Saint Cloud",22947,28.2486111,-81.2813889 ],
    [ u"us",u"Saint Pete Beach",10065,27.7250000,-82.7413889 ],
    [ u"us",u"Saint Petersburg",246316,27.7705556,-82.6794444 ],
    [ u"us",u"San Carlos Park",19158,26.4669444,-81.8016667 ],
    [ u"us",u"Sandalfoot Cove",17964,26.3388889,-80.1877778 ],
    [ u"us",u"Sanford",45289,28.8002778,-81.2733333 ],
    [ u"us",u"Sarasota",53327,27.3361111,-82.5308333 ],
    [ u"us",u"Sarasota Springs",15898,27.3086111,-82.4797222 ],
    [ u"us",u"Satellite Beach",9321,28.1758333,-80.5902778 ],
    [ u"us",u"Scott Lake",14425,25.9411111,-80.2322222 ],
    [ u"us",u"Sebastian",18953,27.8161111,-80.4708333 ],
    [ u"us",u"Sebring",10030,27.4952778,-81.4411111 ],
    [ u"us",u"Seminole",16758,27.8394444,-82.7913889 ],
    [ u"us",u"South Bradenton",22340,27.4627778,-82.5819444 ],
    [ u"us",u"South Daytona",14451,29.1655556,-81.0047222 ],
    [ u"us",u"South Miami",12169,25.7072222,-80.2936111 ],
    [ u"us",u"South Miami Heights",35571,25.5972222,-80.3808333 ],
    [ u"us",u"South Patrick Shores",9031,28.2019444,-80.6097222 ],
    [ u"us",u"South Venice",14467,27.0527778,-82.4244444 ],
    [ u"us",u"Spring Hill",96767,28.5555556,-82.4505556 ],
    [ u"us",u"Springfield",9181,30.1530556,-85.6113889 ],
    [ u"us",u"Stuart",15112,27.1972222,-80.2530556 ],
    [ u"us",u"Sunrise",90993,26.1336111,-80.1133333 ],
    [ u"us",u"Sunset",17956,25.7055556,-80.3525000 ],
    [ u"us",u"Sweetwater",13937,25.7630556,-80.3733333 ],
    [ u"us",u"Tallahassee",153583,30.4380556,-84.2808333 ],
    [ u"us",u"Tamarac",59268,26.2125000,-80.2500000 ],
    [ u"us",u"Tamiami",69225,25.7583333,-80.3986111 ],
    [ u"us",u"Tampa",324465,27.9472222,-82.4586111 ],
    [ u"us",u"Tarpon Springs",22935,28.1458333,-82.7569444 ],
    [ u"us",u"Tavares",11684,28.8038889,-81.7258333 ],
    [ u"us",u"Temple Terrace",22036,28.0350000,-82.3894444 ],
    [ u"us",u"The Crossings",26047,25.6702778,-80.4013889 ],
    [ u"us",u"The Hammocks",69604,25.6711111,-80.4447222 ],
    [ u"us",u"Titusville",42700,28.6119444,-80.8077778 ],
    [ u"us",u"University Park",28168,28.5666667,-81.2083333 ],
    [ u"us",u"Venice",20457,27.0994444,-82.4544444 ],
    [ u"us",u"Vero Beach",17262,27.6383333,-80.3975000 ],
    [ u"us",u"Villas",12191,26.5500000,-81.8688889 ],
    [ u"us",u"Warrington",14946,30.3838889,-87.2750000 ],
    [ u"us",u"Wekiva Springs",23416,28.6983333,-81.4258333 ],
    [ u"us",u"Wellington",53164,26.6583333,-80.2416667 ],
    [ u"us",u"West Little River",32252,25.8566667,-80.2372222 ],
    [ u"us",u"West Melbourne",14159,28.0713889,-80.6536111 ],
    [ u"us",u"West Palm Beach",93620,26.7150000,-80.0536111 ],
    [ u"us",u"West Pensacola",22030,30.4263889,-87.2797222 ],
    [ u"us",u"Westchester",30690,25.7544444,-80.3275000 ],
    [ u"us",u"Weston",68254,26.1000000,-80.4000000 ],
    [ u"us",u"Westview",9779,25.8816667,-80.2422222 ],
    [ u"us",u"Wilton Manors",12888,26.1600000,-80.1391667 ],
    [ u"us",u"Winston",9050,28.0313889,-82.0150000 ],
    [ u"us",u"Winter Garden",24774,28.5650000,-81.5863889 ],
    [ u"us",u"Winter Haven",27938,28.0219444,-81.7330556 ],
    [ u"us",u"Winter Park",28530,28.5997222,-81.3394444 ],
    [ u"us",u"Winter Springs",32658,28.6986111,-81.3083333 ],
    [ u"us",u"Wright",23302,30.4555556,-86.6383333 ],
    [ u"us",u"Yeehaw Junction",24080,27.7000000,-80.9044444 ],
    [ u"us",u"Zephyrhills",12092,28.2333333,-82.1813889 ],
    [ u"us",u"Acworth",19852,34.0658333,-84.6769444 ],
    [ u"us",u"Albany",75794,31.5783333,-84.1558333 ],
    [ u"us",u"Alpharetta",34869,34.0752778,-84.2941667 ],
    [ u"us",u"Americus",16817,32.0722222,-84.2327778 ],
    [ u"us",u"Atlanta",422908,33.7488889,-84.3880556 ],
    [ u"us",u"Austell",6945,33.8125000,-84.6344444 ],
    [ u"us",u"Bainbridge",11714,30.9036111,-84.5755556 ],
    [ u"us",u"Belvedere Park",19149,33.7547222,-84.2675000 ],
    [ u"us",u"Brunswick",16486,31.1497222,-81.4916667 ],
    [ u"us",u"Buford",10860,34.1205556,-84.0044444 ],
    [ u"us",u"Cairo",9471,30.8772222,-84.2013889 ],
    [ u"us",u"Calhoun",13707,34.5025000,-84.9511111 ],
    [ u"us",u"Canton",17850,34.2366667,-84.4908333 ],
    [ u"us",u"Carrollton",21353,33.5800000,-85.0766667 ],
    [ u"us",u"Cartersville",17703,34.1650000,-84.8000000 ],
    [ u"us",u"Cedartown",9726,34.0536111,-85.2550000 ],
    [ u"us",u"Centerville",5795,32.6300000,-83.6897222 ],
    [ u"us",u"Chamblee",8887,33.8919444,-84.2988889 ],
    [ u"us",u"College Park",17957,33.6533333,-84.4494444 ],
    [ u"us",u"Columbus",185208,32.4608333,-84.9877778 ],
    [ u"us",u"Conyers",12528,33.6675000,-84.0177778 ],
    [ u"us",u"Cordele",11411,31.9633333,-83.7825000 ],
    [ u"us",u"Covington",14379,33.5966667,-83.8602778 ],
    [ u"us",u"Dallas",7995,33.9236111,-84.8408333 ],
    [ u"us",u"Dalton",31598,34.7697222,-84.9702778 ],
    [ u"us",u"Dawson",4991,31.7733333,-84.4466667 ],
    [ u"us",u"Decatur",17458,33.7747222,-84.2963889 ],
    [ u"us",u"Doraville",10065,33.8980556,-84.2833333 ],
    [ u"us",u"Douglas",10877,31.5086111,-82.8500000 ],
    [ u"us",u"Douglasville",31791,33.7513889,-84.7477778 ],
    [ u"us",u"Druid Hills",12874,33.7802778,-84.3361111 ],
    [ u"us",u"Dublin",15894,32.5402778,-82.9038889 ],
    [ u"us",u"Duluth",25213,34.0027778,-84.1447222 ],
    [ u"us",u"Dunwoody",35997,33.9461111,-84.3347222 ],
    [ u"us",u"East Point",35786,33.6794444,-84.4394444 ],
    [ u"us",u"Eatonton",6988,33.3266667,-83.3886111 ],
    [ u"us",u"Evans",19779,33.5336111,-82.1308333 ],
    [ u"us",u"Fairburn",8205,33.5669444,-84.5811111 ],
    [ u"us",u"Fayetteville",14878,33.4486111,-84.4550000 ],
    [ u"us",u"Forest Park",21153,33.6219444,-84.3691667 ],
    [ u"us",u"Fort Oglethorpe",8463,34.9488889,-85.2569444 ],
    [ u"us",u"Fort Stewart",10941,31.8625000,-81.5177778 ],
    [ u"us",u"Gainesville",33297,34.2977778,-83.8241667 ],
    [ u"us",u"Garden City",10738,32.1141667,-81.1541667 ],
    [ u"us",u"Gresham Park",9216,33.7033333,-84.3144444 ],
    [ u"us",u"Griffin",23820,33.2466667,-84.2641667 ],
    [ u"us",u"Hinesville",28066,31.8466667,-81.5961111 ],
    [ u"us",u"Jesup",9582,31.6072222,-81.8855556 ],
    [ u"us",u"Kennesaw",28439,34.0233333,-84.6155556 ],
    [ u"us",u"Kingsland",11410,30.7997222,-81.6900000 ],
    [ u"us",u"Lawrenceville",29368,33.9561111,-83.9880556 ],
    [ u"us",u"Lilburn",11347,33.8900000,-84.1430556 ],
    [ u"us",u"Lithia Springs",2012,33.7938889,-84.6605556 ],
    [ u"us",u"Loganville",9423,33.8388889,-83.9008333 ],
    [ u"us",u"Mableton",31476,33.8186111,-84.5825000 ],
    [ u"us",u"Macon",94273,32.8405556,-83.6325000 ],
    [ u"us",u"Marietta",61360,33.9525000,-84.5500000 ],
    [ u"us",u"Martinez",27195,33.5172222,-82.0758333 ],
    [ u"us",u"Milledgeville",19682,33.0800000,-83.2322222 ],
    [ u"us",u"Monroe",12189,33.7947222,-83.7133333 ],
    [ u"us",u"Moultrie",14644,31.1797222,-83.7891667 ],
    [ u"us",u"Mountain Park",496,34.0808333,-84.4113889 ],
    [ u"us",u"Newnan",23409,33.3805556,-84.7997222 ],
    [ u"us",u"Norcross",9717,33.9411111,-84.2136111 ],
    [ u"us",u"North Atlanta",44493,33.8650000,-84.3366667 ],
    [ u"us",u"North Decatur",15765,33.7902778,-84.3061111 ],
    [ u"us",u"North Druid Hills",21320,33.8166667,-84.3133333 ],
    [ u"us",u"Panthersville",12675,33.7072222,-84.2719444 ],
    [ u"us",u"Peachtree City",34215,33.3966667,-84.5958333 ],
    [ u"us",u"Perry",11234,32.4580556,-83.7316667 ],
    [ u"us",u"Pooler",10175,32.1152778,-81.2472222 ],
    [ u"us",u"Powder Springs",14616,33.8594444,-84.6838889 ],
    [ u"us",u"Redan",39044,33.7452778,-84.1316667 ],
    [ u"us",u"Richmond Hill",9414,31.9380556,-81.3036111 ],
    [ u"us",u"Rincon",6521,32.2958333,-81.2355556 ],
    [ u"us",u"Riverdale",16090,33.5725000,-84.4133333 ],
    [ u"us",u"Rome",35452,34.2569444,-85.1647222 ],
    [ u"us",u"Roswell",77218,34.0230556,-84.3616667 ],
    [ u"us",u"Saint Marys",17040,30.7302778,-81.5466667 ],
    [ u"us",u"Saint Simons",13915,31.1350000,-81.3902778 ],
    [ u"us",u"Sandy Springs",94717,33.9241667,-84.3786111 ],
    [ u"us",u"Savannah",126119,32.0833333,-81.1000000 ],
    [ u"us",u"Smyrna",46561,33.8838889,-84.5144444 ],
    [ u"us",u"Snellville",18687,33.8572222,-84.0200000 ],
    [ u"us",u"Statesboro",24558,32.4486111,-81.7833333 ],
    [ u"us",u"Stockbridge",12379,33.5441667,-84.2338889 ],
    [ u"us",u"Sugar Hill",15348,34.1063889,-84.0336111 ],
    [ u"us",u"Suwanee",11434,34.0513889,-84.0713889 ],
    [ u"us",u"Thomaston",9264,32.8880556,-84.3266667 ],
    [ u"us",u"Thomasville",18528,30.8363889,-83.9788889 ],
    [ u"us",u"Tifton",15902,31.4502778,-83.5086111 ],
    [ u"us",u"Toccoa",9178,34.5772222,-83.3325000 ],
    [ u"us",u"Tucker",26597,33.8544444,-84.2172222 ],
    [ u"us",u"Union City",14196,33.5869444,-84.5425000 ],
    [ u"us",u"Valdosta",45661,30.8325000,-83.2786111 ],
    [ u"us",u"Vidalia",10743,32.2175000,-82.4136111 ],
    [ u"us",u"Villa Rica",11328,33.7319444,-84.9191667 ],
    [ u"us",u"Warner Robins",57764,32.6208333,-83.6000000 ],
    [ u"us",u"Waycross",15067,31.2133333,-82.3541667 ],
    [ u"us",u"Wilmington Island",15702,32.0033333,-80.9738889 ],
    [ u"us",u"Winder",12643,33.9925000,-83.7202778 ],
    [ u"us",u"Woodstock",18902,34.1013889,-84.5194444 ],
    [ u"us",u"Ahuimanu",8731,21.4447222,-157.8377778 ],
    [ u"us",u"Aiea",9251,21.3822222,-157.9336111 ],
    [ u"us",u"Ewa Beach",15100,21.3155556,-158.0072222 ],
    [ u"us",u"Hilo",43050,19.7297222,-155.0900000 ],
    [ u"us",u"Honolulu",384241,21.3069444,-157.8583333 ],
    [ u"us",u"Kahului",22315,20.8947222,-156.4700000 ],
    [ u"us",u"Kailua",37079,21.4022222,-157.7394444 ],
    [ u"us",u"Kaneohe",35424,21.4180556,-157.8036111 ],
    [ u"us",u"Kapaa",10365,22.0783333,-159.3219444 ],
    [ u"us",u"Kihei",20707,20.7850000,-156.4655556 ],
    [ u"us",u"Lahaina",9319,20.8783333,-156.6825000 ],
    [ u"us",u"Makaha",7794,21.4694444,-158.2175000 ],
    [ u"us",u"Makakilo City",15383,21.3469444,-158.0858333 ],
    [ u"us",u"Mililani Town",28812,21.4500000,-158.0011111 ],
    [ u"us",u"Nanakuli",11675,21.3905556,-158.1547222 ],
    [ u"us",u"Pearl City",31572,21.3972222,-157.9733333 ],
    [ u"us",u"Wahiawa",15906,21.5027778,-158.0236111 ],
    [ u"us",u"Waianae",11668,21.4447222,-158.1900000 ],
    [ u"us",u"Wailuku",13391,20.8911111,-156.5047222 ],
    [ u"us",u"Waimalu",29662,21.4047222,-157.9433333 ],
    [ u"us",u"Waipahu",34588,21.3866667,-158.0091667 ],
    [ u"us",u"Ammon",10530,43.4697222,-111.9658333 ],
    [ u"us",u"Blackfoot",10810,43.1905556,-112.3441667 ],
    [ u"us",u"Burley",9247,42.5358333,-113.7919444 ],
    [ u"us",u"Caldwell",34330,43.6630556,-116.6863889 ],
    [ u"us",u"Chubbuck",10455,42.9208333,-112.4652778 ],
    [ u"us",u"Eagle",18351,43.6955556,-116.3530556 ],
    [ u"us",u"Emmett",6239,43.8736111,-116.4983333 ],
    [ u"us",u"Garden City",11366,43.6222222,-116.2372222 ],
    [ u"us",u"Hailey",7922,43.5197222,-114.3144444 ],
    [ u"us",u"Hayden",11481,47.7661111,-116.7855556 ],
    [ u"us",u"Idaho Falls",52175,43.4666667,-112.0333333 ],
    [ u"us",u"Jerome",8287,42.7241667,-114.5177778 ],
    [ u"us",u"Kuna",11410,43.4919444,-116.4191667 ],
    [ u"us",u"Lewiston",31422,46.4166667,-117.0166667 ],
    [ u"us",u"Meridian",45803,43.6122222,-116.3905556 ],
    [ u"us",u"Moscow",21865,46.7325000,-116.9991667 ],
    [ u"us",u"Mountain Home",11287,43.1330556,-115.6902778 ],
    [ u"us",u"Nampa",73064,43.5408333,-116.5625000 ],
    [ u"us",u"Payette",7525,44.0783333,-116.9327778 ],
    [ u"us",u"Pocatello",50656,42.8713889,-112.4447222 ],
    [ u"us",u"Post Falls",22287,47.7180556,-116.9505556 ],
    [ u"us",u"Preston",4957,42.0963889,-111.8758333 ],
    [ u"us",u"Rathdrum",5725,47.8125000,-116.8955556 ],
    [ u"us",u"Rexburg",29439,43.8261111,-111.7888889 ],
    [ u"us",u"Rupert",5216,42.6191667,-113.6763889 ],
    [ u"us",u"Sandpoint",7785,48.2766667,-116.5522222 ],
    [ u"us",u"Twin Falls",38602,42.5630556,-114.4600000 ],
    [ u"us",u"Weiser",5396,44.2511111,-116.9683333 ],
    [ u"us",u"Addison",37394,41.9316667,-87.9888889 ],
    [ u"us",u"Algonquin",30394,42.1655556,-88.2941667 ],
    [ u"us",u"Alsip",19302,41.6688889,-87.7386111 ],
    [ u"us",u"Alton",29251,38.8905556,-90.1841667 ],
    [ u"us",u"Antioch",11802,42.4772222,-88.0955556 ],
    [ u"us",u"Arlington Heights",74995,42.0883333,-87.9805556 ],
    [ u"us",u"Aurora",174276,41.7605556,-88.3200000 ],
    [ u"us",u"Barrington",10157,42.1538889,-88.1361111 ],
    [ u"us",u"Bartlett",38269,41.9950000,-88.1855556 ],
    [ u"us",u"Batavia",28175,41.8500000,-88.3125000 ],
    [ u"us",u"Beach Park",12382,42.4222222,-87.8572222 ],
    [ u"us",u"Belleville",40919,38.5200000,-89.9838889 ],
    [ u"us",u"Bellwood",19751,41.8813889,-87.8830556 ],
    [ u"us",u"Belvidere",24547,42.2638889,-88.8441667 ],
    [ u"us",u"Bensenville",20496,41.9550000,-87.9400000 ],
    [ u"us",u"Berwyn",51376,41.8505556,-87.7936111 ],
    [ u"us",u"Bethalto",9727,38.9091667,-90.0405556 ],
    [ u"us",u"Bloomingdale",21747,41.9575000,-88.0808333 ],
    [ u"us",u"Bloomington",70706,40.4841667,-88.9936111 ],
    [ u"us",u"Blue Island",22923,41.6572222,-87.6800000 ],
    [ u"us",u"Bolingbrook",73220,41.6986111,-88.0683333 ],
    [ u"us",u"Bourbonnais",16495,41.1416667,-87.8750000 ],
    [ u"us",u"Bradley",13748,41.1419444,-87.8611111 ],
    [ u"us",u"Bridgeview",15126,41.7500000,-87.8041667 ],
    [ u"us",u"Brookfield",18908,41.8238889,-87.8516667 ],
    [ u"us",u"Buffalo Grove",43281,42.1513889,-87.9597222 ],
    [ u"us",u"Burbank",28020,41.7338889,-87.7794444 ],
    [ u"us",u"Burr Ridge",10938,41.7488889,-87.9183333 ],
    [ u"us",u"Cahokia",15761,38.5708333,-90.1900000 ],
    [ u"us",u"Calumet City",38388,41.6155556,-87.5294444 ],
    [ u"us",u"Canton",14802,40.5580556,-90.0350000 ],
    [ u"us",u"Carbondale",24502,37.7272222,-89.2166667 ],
    [ u"us",u"Carol Stream",39839,41.9125000,-88.1347222 ],
    [ u"us",u"Carpentersville",36834,42.1211111,-88.2577778 ],
    [ u"us",u"Cary",20315,42.2119444,-88.2380556 ],
    [ u"us",u"Centralia",13426,38.5250000,-89.1333333 ],
    [ u"us",u"Champaign",75670,40.1163889,-88.2433333 ],
    [ u"us",u"Channahon",11994,41.4294444,-88.2286111 ],
    [ u"us",u"Charleston",19399,39.4961111,-88.1761111 ],
    [ u"us",u"Chatham",9837,39.6761111,-89.7044444 ],
    [ u"us",u"Chicago",2841952,41.8500000,-87.6500000 ],
    [ u"us",u"Chicago Heights",31806,41.5061111,-87.6355556 ],
    [ u"us",u"Chicago Ridge",13687,41.7013889,-87.7791667 ],
    [ u"us",u"Cicero",81184,41.8455556,-87.7538889 ],
    [ u"us",u"Collinsville",25491,38.6702778,-89.9844444 ],
    [ u"us",u"Country Club Hills",16350,41.5680556,-87.7202778 ],
    [ u"us",u"Crest Hill",16776,41.5547222,-88.0986111 ],
    [ u"us",u"Crestwood",11296,41.6611111,-87.7525000 ],
    [ u"us",u"Crystal Lake",41188,42.2411111,-88.3161111 ],
    [ u"us",u"Danville",32587,40.1244444,-87.6300000 ],
    [ u"us",u"Darien",22677,41.7519444,-87.9738889 ],
    [ u"us",u"DeKalb",43383,41.9294444,-88.7502778 ],
    [ u"us",u"Decatur",77868,39.8402778,-88.9547222 ],
    [ u"us",u"Deerfield",19618,42.1711111,-87.8444444 ],
    [ u"us",u"Des Plaines",54067,42.0333333,-87.8833333 ],
    [ u"us",u"Dixon",14869,41.8388889,-89.4794444 ],
    [ u"us",u"Dolton",24779,41.6388889,-87.6072222 ],
    [ u"us",u"Downers Grove",49504,41.8088889,-88.0111111 ],
    [ u"us",u"East Moline",21058,41.5008333,-90.4441667 ],
    [ u"us",u"East Peoria",22352,40.6661111,-89.5800000 ],
    [ u"us",u"East Saint Louis",29773,38.6244444,-90.1508333 ],
    [ u"us",u"Edwardsville",24551,38.8113889,-89.9530556 ],
    [ u"us",u"Effingham",12616,39.1200000,-88.5433333 ],
    [ u"us",u"Elgin",98586,42.0372222,-88.2811111 ],
    [ u"us",u"Elk Grove Village",34261,42.0038889,-87.9702778 ],
    [ u"us",u"Elmhurst",45060,41.8994444,-87.9402778 ],
    [ u"us",u"Elmwood Park",24418,41.9211111,-87.8091667 ],
    [ u"us",u"Evanston",75311,42.0411111,-87.6900000 ],
    [ u"us",u"Evergreen Park",20139,41.7205556,-87.7016667 ],
    [ u"us",u"Fairview Heights",15362,38.5888889,-89.9902778 ],
    [ u"us",u"Flossmoor",9462,41.5427778,-87.6847222 ],
    [ u"us",u"Forest Park",15171,41.8794444,-87.8136111 ],
    [ u"us",u"Fox Lake",10486,42.3966667,-88.1836111 ],
    [ u"us",u"Frankfort",15611,41.4958333,-87.8486111 ],
    [ u"us",u"Franklin Park",18728,41.9352778,-87.8655556 ],
    [ u"us",u"Freeport",25619,42.2966667,-89.6211111 ],
    [ u"us",u"Galesburg",32094,40.9477778,-90.3711111 ],
    [ u"us",u"Geneva",23974,41.8875000,-88.3052778 ],
    [ u"us",u"Glen Carbon",11567,38.7483333,-89.9830556 ],
    [ u"us",u"Glen Ellyn",27276,41.8775000,-88.0669444 ],
    [ u"us",u"Glendale Heights",33047,41.9102778,-88.0716667 ],
    [ u"us",u"Glenview",46539,42.0697222,-87.7877778 ],
    [ u"us",u"Godfrey",16844,38.9555556,-90.1866667 ],
    [ u"us",u"Goodings Grove",18569,41.6291667,-87.9308333 ],
    [ u"us",u"Granite City",30732,38.7013889,-90.1486111 ],
    [ u"us",u"Grayslake",22768,42.3444444,-88.0416667 ],
    [ u"us",u"Gurnee",31346,42.3702778,-87.9019444 ],
    [ u"us",u"Hanover Park",37083,41.9994444,-88.1450000 ],
    [ u"us",u"Harrisburg",9594,37.7383333,-88.5405556 ],
    [ u"us",u"Harvard",8996,42.4222222,-88.6136111 ],
    [ u"us",u"Harvey",28812,41.6100000,-87.6466667 ],
    [ u"us",u"Hazel Crest",14606,41.5716667,-87.6944444 ],
    [ u"us",u"Herrin",11472,37.8030556,-89.0275000 ],
    [ u"us",u"Hickory Hills",13601,41.7255556,-87.8250000 ],
    [ u"us",u"Highland Park",31403,42.1816667,-87.8002778 ],
    [ u"us",u"Hinsdale",18229,41.8008333,-87.9369444 ],
    [ u"us",u"Hoffman Estates",50541,42.0427778,-88.0797222 ],
    [ u"us",u"Homewood",19082,41.5572222,-87.6655556 ],
    [ u"us",u"Huntley",16700,42.1680556,-88.4280556 ],
    [ u"us",u"Jacksonville",19479,39.7338889,-90.2288889 ],
    [ u"us",u"Joliet",134957,41.5250000,-88.0816667 ],
    [ u"us",u"Justice",12691,41.7444444,-87.8377778 ],
    [ u"us",u"Kankakee",26623,41.1200000,-87.8611111 ],
    [ u"us",u"Kewanee",12574,41.2455556,-89.9247222 ],
    [ u"us",u"La Grange",15717,41.8050000,-87.8691667 ],
    [ u"us",u"La Grange Park",12840,41.8347222,-87.8616667 ],
    [ u"us",u"La Salle",9480,41.3333333,-89.0916667 ],
    [ u"us",u"Lake Forest",21014,42.2586111,-87.8405556 ],
    [ u"us",u"Lake Zurich",19903,42.1969444,-88.0933333 ],
    [ u"us",u"Lake in the Hills",28541,42.1816667,-88.3302778 ],
    [ u"us",u"Lansing",27667,41.5647222,-87.5388889 ],
    [ u"us",u"Lemont",15042,41.6736111,-88.0016667 ],
    [ u"us",u"Libertyville",21236,42.2830556,-87.9530556 ],
    [ u"us",u"Lincoln",14899,40.1483333,-89.3647222 ],
    [ u"us",u"Lincolnwood",12148,42.0044444,-87.7300000 ],
    [ u"us",u"Lindenhurst",15038,42.4105556,-88.0261111 ],
    [ u"us",u"Lisle",21665,41.8011111,-88.0747222 ],
    [ u"us",u"Lockport",22146,41.5894444,-88.0577778 ],
    [ u"us",u"Lombard",42836,41.8800000,-88.0077778 ],
    [ u"us",u"Loves Park",22650,42.3200000,-89.0580556 ],
    [ u"us",u"Lyons",10667,41.8133333,-87.8180556 ],
    [ u"us",u"Machesney Park",21494,42.3472222,-89.0388889 ],
    [ u"us",u"Macomb",19234,40.4591667,-90.6716667 ],
    [ u"us",u"Marion",17265,37.7305556,-88.9330556 ],
    [ u"us",u"Markham",12392,41.5936111,-87.6947222 ],
    [ u"us",u"Matteson",15209,41.5038889,-87.7130556 ],
    [ u"us",u"Mattoon",17711,39.4830556,-88.3727778 ],
    [ u"us",u"Maywood",25872,41.8791667,-87.8430556 ],
    [ u"us",u"Melrose Park",23054,41.9005556,-87.8566667 ],
    [ u"us",u"Midlothian",14125,41.6252778,-87.7175000 ],
    [ u"us",u"Mokena",19210,41.5261111,-87.8891667 ],
    [ u"us",u"Moline",42668,41.5066667,-90.5150000 ],
    [ u"us",u"Monmouth",9443,40.9113889,-90.6472222 ],
    [ u"us",u"Morris",12582,41.3572222,-88.4211111 ],
    [ u"us",u"Morton",15483,40.6127778,-89.4591667 ],
    [ u"us",u"Morton Grove",22968,42.0405556,-87.7825000 ],
    [ u"us",u"Mount Prospect",55303,42.0663889,-87.9372222 ],
    [ u"us",u"Mount Vernon",16505,38.3160000,-88.9106000 ],
    [ u"us",u"Mundelein",33012,42.2630556,-88.0038889 ],
    [ u"us",u"Naperville",143850,41.7858333,-88.1472222 ],
    [ u"us",u"New Lenox",24315,41.5119444,-87.9655556 ],
    [ u"us",u"Niles",29765,42.0188889,-87.8027778 ],
    [ u"us",u"Normal",51331,40.5141667,-88.9905556 ],
    [ u"us",u"Norridge",14157,41.9633333,-87.8272222 ],
    [ u"us",u"North Aurora",14447,41.8061111,-88.3272222 ],
    [ u"us",u"North Chicago",37301,42.3255556,-87.8411111 ],
    [ u"us",u"Northbrook",34322,42.1275000,-87.8288889 ],
    [ u"us",u"Northlake",11497,41.9172222,-87.8955556 ],
    [ u"us",u"Oak Forest",28122,41.6027778,-87.7438889 ],
    [ u"us",u"Oak Lawn",54767,41.7108333,-87.7580556 ],
    [ u"us",u"Oak Park",49509,41.8850000,-87.7844444 ],
    [ u"us",u"Orland Park",55741,41.6302778,-87.8538889 ],
    [ u"us",u"Oswego",21547,41.6827778,-88.3513889 ],
    [ u"us",u"Ottawa",18897,41.3455556,-88.8425000 ],
    [ u"us",u"Palatine",67828,42.1102778,-88.0341667 ],
    [ u"us",u"Palos Heights",12821,41.6680556,-87.7963889 ],
    [ u"us",u"Palos Hills",17501,41.6966667,-87.8169444 ],
    [ u"us",u"Park Forest",23401,41.4913889,-87.6744444 ],
    [ u"us",u"Park Ridge",37034,42.0111111,-87.8405556 ],
    [ u"us",u"Pekin",32743,40.5675000,-89.6405556 ],
    [ u"us",u"Peoria",113004,40.6936111,-89.5888889 ],
    [ u"us",u"Peru",9829,41.3275000,-89.1288889 ],
    [ u"us",u"Plainfield",26488,41.6269444,-88.2038889 ],
    [ u"us",u"Pontiac",10982,40.8808333,-88.6297222 ],
    [ u"us",u"Prospect Heights",16562,42.0952778,-87.9375000 ],
    [ u"us",u"Quincy",39731,39.9355556,-91.4097222 ],
    [ u"us",u"Rantoul",12991,40.3083333,-88.1558333 ],
    [ u"us",u"Richton Park",13049,41.4844444,-87.7033333 ],
    [ u"us",u"River Forest",11238,41.8977778,-87.8138889 ],
    [ u"us",u"River Grove",10278,41.9258333,-87.8358333 ],
    [ u"us",u"Riverdale",14493,41.6333333,-87.6330556 ],
    [ u"us",u"Rochelle",9686,41.9238889,-89.0686111 ],
    [ u"us",u"Rock Falls",9374,41.7797222,-89.6888889 ],
    [ u"us",u"Rock Island",38383,41.5094444,-90.5786111 ],
    [ u"us",u"Rockford",152765,42.2711111,-89.0938889 ],
    [ u"us",u"Rolling Meadows",24003,42.0841667,-88.0130556 ],
    [ u"us",u"Romeoville",41420,41.6475000,-88.0894444 ],
    [ u"us",u"Roselle",23119,41.9847222,-88.0797222 ],
    [ u"us",u"Round Lake Beach",29011,42.3716667,-88.0900000 ],
    [ u"us",u"Saint Charles",34485,41.9141667,-88.3086111 ],
    [ u"us",u"Sauk Village",10591,41.4883333,-87.5675000 ],
    [ u"us",u"Schaumburg",73451,42.0333333,-88.0833333 ],
    [ u"us",u"Schiller Park",11471,41.9558333,-87.8708333 ],
    [ u"us",u"Shiloh",10671,38.5613889,-89.8972222 ],
    [ u"us",u"Shorewood",11827,41.5200000,-88.2016667 ],
    [ u"us",u"Skokie",64227,42.0333333,-87.7333333 ],
    [ u"us",u"South Elgin",22341,41.9941667,-88.2922222 ],
    [ u"us",u"South Holland",21937,41.6008333,-87.6069444 ],
    [ u"us",u"Springfield",115975,39.8016667,-89.6436111 ],
    [ u"us",u"Steger",10209,41.4700000,-87.6363889 ],
    [ u"us",u"Sterling",15106,41.7886111,-89.6961111 ],
    [ u"us",u"Streamwood",37625,42.0255556,-88.1783333 ],
    [ u"us",u"Streator",13960,41.1208333,-88.8352778 ],
    [ u"us",u"Summit",10312,41.7880556,-87.8102778 ],
    [ u"us",u"Swansea",12058,38.5338889,-89.9888889 ],
    [ u"us",u"Sycamore",14145,41.9888889,-88.6866667 ],
    [ u"us",u"Taylorville",11197,39.5488889,-89.2944444 ],
    [ u"us",u"Tinley Park",57244,41.5733333,-87.7844444 ],
    [ u"us",u"Urbana",39511,40.1105556,-88.2072222 ],
    [ u"us",u"Vernon Hills",23510,42.2194444,-87.9794444 ],
    [ u"us",u"Villa Park",22868,41.8897222,-87.9888889 ],
    [ u"us",u"Warrenville",13179,41.8177778,-88.1733333 ],
    [ u"us",u"Washington",12294,40.7036111,-89.4072222 ],
    [ u"us",u"Waterloo",9315,38.3358333,-90.1497222 ],
    [ u"us",u"Wauconda",10269,42.2588889,-88.1391667 ],
    [ u"us",u"Waukegan",92695,42.3636111,-87.8447222 ],
    [ u"us",u"West Chicago",26014,41.8847222,-88.2038889 ],
    [ u"us",u"Westchester",16434,41.8505556,-87.8819444 ],
    [ u"us",u"Western Springs",12446,41.8097222,-87.9005556 ],
    [ u"us",u"Westmont",24552,41.7958333,-87.9755556 ],
    [ u"us",u"Wheaton",54545,41.8661111,-88.1069444 ],
    [ u"us",u"Wheeling",35815,42.1391667,-87.9288889 ],
    [ u"us",u"Wilmette",26871,42.0722222,-87.7227778 ],
    [ u"us",u"Winfield",9802,41.8616667,-88.1608333 ],
    [ u"us",u"Winnetka",12284,42.1080556,-87.7358333 ],
    [ u"us",u"Wood Dale",13316,41.9633333,-87.9788889 ],
    [ u"us",u"Wood River",10971,38.8611111,-90.0975000 ],
    [ u"us",u"Woodridge",34500,41.7469444,-88.0502778 ],
    [ u"us",u"Woodstock",21769,42.3147222,-88.4486111 ],
    [ u"us",u"Worth",10741,41.6897222,-87.7972222 ],
    [ u"us",u"Zion",24316,42.4461111,-87.8327778 ],
    [ u"us",u"Anderson",57496,40.1052778,-85.6802778 ],
    [ u"us",u"Angola",7932,41.6347222,-84.9994444 ],
    [ u"us",u"Auburn",12870,41.3669444,-85.0588889 ],
    [ u"us",u"Bedford",13289,38.8611111,-86.4872222 ],
    [ u"us",u"Beech Grove",14169,39.7219444,-86.0900000 ],
    [ u"us",u"Bloomington",71253,39.1652778,-86.5263889 ],
    [ u"us",u"Bluffton",9463,40.7386111,-85.1716667 ],
    [ u"us",u"Brownsburg",18528,39.8433333,-86.3977778 ],
    [ u"us",u"Carmel",47219,39.9783333,-86.1180556 ],
    [ u"us",u"Cedar Lake",9672,41.3647222,-87.4411111 ],
    [ u"us",u"Chesterton",11563,41.6105556,-87.0641667 ],
    [ u"us",u"Clarksville",21114,38.2966667,-85.7600000 ],
    [ u"us",u"Columbus",39395,39.2013889,-85.9213889 ],
    [ u"us",u"Connersville",14436,39.6411111,-85.1411111 ],
    [ u"us",u"Crawfordsville",15066,40.0411111,-86.8744444 ],
    [ u"us",u"Crown Point",21914,41.4169444,-87.3652778 ],
    [ u"us",u"Decatur",9444,40.8305556,-84.9291667 ],
    [ u"us",u"Dyer",15143,41.4941667,-87.5216667 ],
    [ u"us",u"East Chicago",30662,41.6391667,-87.4547222 ],
    [ u"us",u"Elkhart",51400,41.6819444,-85.9766667 ],
    [ u"us",u"Elwood",9051,40.2769444,-85.8419444 ],
    [ u"us",u"Evansville",115474,37.9747222,-87.5558333 ],
    [ u"us",u"Fishers",54829,39.9555556,-86.0138889 ],
    [ u"us",u"Fort Wayne",229715,41.1305556,-85.1288889 ],
    [ u"us",u"Frankfort",16315,40.2794444,-86.5108333 ],
    [ u"us",u"Franklin",21653,39.4805556,-86.0550000 ],
    [ u"us",u"Gary",97966,41.5933333,-87.3463889 ],
    [ u"us",u"Goshen",30045,41.5822222,-85.8344444 ],
    [ u"us",u"Granger",32749,41.7533333,-86.1108333 ],
    [ u"us",u"Greencastle",10092,39.6444444,-86.8647222 ],
    [ u"us",u"Greenfield",16257,39.7850000,-85.7694444 ],
    [ u"us",u"Greensburg",10601,39.3372222,-85.4836111 ],
    [ u"us",u"Greenwood",41244,39.6136111,-86.1066667 ],
    [ u"us",u"Griffith",16684,41.5283333,-87.4236111 ],
    [ u"us",u"Hammond",78883,41.5833333,-87.5000000 ],
    [ u"us",u"Hobart",28008,41.5322222,-87.2550000 ],
    [ u"us",u"Huntington",16932,40.8830556,-85.4975000 ],
    [ u"us",u"Indianapolis",773283,39.7683333,-86.1580556 ],
    [ u"us",u"Jasper",13850,38.3913889,-86.9311111 ],
    [ u"us",u"Jeffersonville",28465,38.2775000,-85.7372222 ],
    [ u"us",u"Kendallville",9629,41.4413889,-85.2650000 ],
    [ u"us",u"Kokomo",46227,40.4863889,-86.1336111 ],
    [ u"us",u"Lafayette",62231,40.4166667,-86.8752778 ],
    [ u"us",u"Lake Station",13667,41.5750000,-87.2388889 ],
    [ u"us",u"Lawrence",41821,39.8386111,-86.0252778 ],
    [ u"us",u"Lebanon",14583,40.0483333,-86.4691667 ],
    [ u"us",u"Logansport",19064,40.7544444,-86.3566667 ],
    [ u"us",u"Madison",12435,38.7358333,-85.3800000 ],
    [ u"us",u"Marion",30201,40.5583333,-85.6591667 ],
    [ u"us",u"Martinsville",11617,39.4277778,-86.4283333 ],
    [ u"us",u"Merrillville",31168,41.4827778,-87.3327778 ],
    [ u"us",u"Michigan City",31903,41.7075000,-86.8950000 ],
    [ u"us",u"Mishawaka",49055,41.6619444,-86.1586111 ],
    [ u"us",u"Mooresville",11417,39.6127778,-86.3741667 ],
    [ u"us",u"Muncie",65327,40.1933333,-85.3863889 ],
    [ u"us",u"Munster",22586,41.5644444,-87.5125000 ],
    [ u"us",u"New Albany",36138,38.2855556,-85.8241667 ],
    [ u"us",u"New Castle",18812,39.9288889,-85.3702778 ],
    [ u"us",u"New Haven",13843,41.0705556,-85.0144444 ],
    [ u"us",u"Noblesville",35840,40.0455556,-86.0086111 ],
    [ u"us",u"North Vernon",6324,39.0061111,-85.6236111 ],
    [ u"us",u"Peru",12841,40.7536111,-86.0688889 ],
    [ u"us",u"Plainfield",23135,39.7041667,-86.3994444 ],
    [ u"us",u"Plymouth",11024,41.3436111,-86.3097222 ],
    [ u"us",u"Portage",35787,41.5758333,-87.1761111 ],
    [ u"us",u"Richmond",37631,39.8288889,-84.8902778 ],
    [ u"us",u"Saint John",10391,41.4500000,-87.4700000 ],
    [ u"us",u"Schererville",27157,41.4788889,-87.4547222 ],
    [ u"us",u"Seymour",18730,38.9591667,-85.8902778 ],
    [ u"us",u"Shelbyville",17815,39.5213889,-85.7769444 ],
    [ u"us",u"South Bend",103760,41.6833333,-86.2500000 ],
    [ u"us",u"Speedway",12642,39.8022222,-86.2672222 ],
    [ u"us",u"Terre Haute",57063,39.4666667,-87.4138889 ],
    [ u"us",u"Valparaiso",28787,41.4730556,-87.0611111 ],
    [ u"us",u"Vincennes",18257,38.6772222,-87.5286111 ],
    [ u"us",u"Wabash",11124,40.7977778,-85.8205556 ],
    [ u"us",u"Warsaw",13003,41.2380556,-85.8530556 ],
    [ u"us",u"Washington",11271,38.6591667,-87.1727778 ],
    [ u"us",u"West Lafayette",30950,40.4258333,-86.9080556 ],
    [ u"us",u"Westfield",12570,40.0427778,-86.1275000 ],
    [ u"us",u"Zionsville",11170,39.9508333,-86.2619444 ],
    [ u"us",u"Altoona",12115,41.6441667,-93.4644444 ],
    [ u"us",u"Ames",56606,42.0347222,-93.6197222 ],
    [ u"us",u"Ankeny",33916,41.7297222,-93.6055556 ],
    [ u"us",u"Bettendorf",31421,41.5244444,-90.5155556 ],
    [ u"us",u"Boone",12802,42.0597222,-93.8800000 ],
    [ u"us",u"Burlington",25608,40.8075000,-91.1127778 ],
    [ u"us",u"Carroll",9941,42.0658333,-94.8666667 ],
    [ u"us",u"Cedar Falls",36258,42.5277778,-92.4452778 ],
    [ u"us",u"Cedar Rapids",122945,42.0083333,-91.6438889 ],
    [ u"us",u"Clinton",27294,41.8444444,-90.1886111 ],
    [ u"us",u"Clive",14092,41.6030556,-93.7238889 ],
    [ u"us",u"Coralville",17645,41.6763889,-91.5802778 ],
    [ u"us",u"Council Bluffs",58764,41.2619444,-95.8608333 ],
    [ u"us",u"Davenport",96930,41.5236111,-90.5775000 ],
    [ u"us",u"Des Moines",193180,41.6005556,-93.6088889 ],
    [ u"us",u"Dubuque",57185,42.5005556,-90.6644444 ],
    [ u"us",u"Fairfield",9442,41.0086111,-91.9625000 ],
    [ u"us",u"Fort Dodge",26879,42.4975000,-94.1677778 ],
    [ u"us",u"Fort Madison",10733,40.6297222,-91.3150000 ],
    [ u"us",u"Grinnell",9312,41.7430556,-92.7222222 ],
    [ u"us",u"Indianola",13353,41.3580556,-93.5572222 ],
    [ u"us",u"Iowa City",64170,41.6611111,-91.5300000 ],
    [ u"us",u"Johnston",12547,41.6730556,-93.6975000 ],
    [ u"us",u"Keokuk",10645,40.3972222,-91.3847222 ],
    [ u"us",u"Le Mars",9256,42.7941667,-96.1652778 ],
    [ u"us",u"Ledyard",15212,43.4216667,-94.1619444 ],
    [ u"us",u"Marion",30785,42.0341667,-91.5975000 ],
    [ u"us",u"Marshalltown",25554,42.0494444,-92.9077778 ],
    [ u"us",u"Mason City",27802,43.1536111,-93.2008333 ],
    [ u"us",u"Muscatine",22529,41.4244444,-91.0430556 ],
    [ u"us",u"Newton",16028,41.6997222,-93.0477778 ],
    [ u"us",u"Oskaloosa",11104,41.2963889,-92.6441667 ],
    [ u"us",u"Ottumwa",24593,41.0041667,-92.3736111 ],
    [ u"us",u"Pella",10058,41.4080556,-92.9161111 ],
    [ u"us",u"Sioux City",83248,42.5000000,-96.4000000 ],
    [ u"us",u"Spencer",11203,43.1413889,-95.1441667 ],
    [ u"us",u"Storm Lake",9835,42.6411111,-95.2094444 ],
    [ u"us",u"Urbandale",33528,41.6266667,-93.7119444 ],
    [ u"us",u"Waterloo",65836,42.4927778,-92.3427778 ],
    [ u"us",u"Waverly",9106,42.7258333,-92.4752778 ],
    [ u"us",u"West Des Moines",55279,41.5772222,-93.7111111 ],
    [ u"us",u"Andover",9201,37.7138889,-97.1361111 ],
    [ u"us",u"Arkansas City",11464,37.0619444,-97.0380556 ],
    [ u"us",u"Atchison",10068,39.5630556,-95.1213889 ],
    [ u"us",u"Chanute",8864,37.6791667,-95.4569444 ],
    [ u"us",u"Coffeyville",10150,37.0372222,-95.6161111 ],
    [ u"us",u"Derby",19843,37.5455556,-97.2686111 ],
    [ u"us",u"Dodge City",25932,37.7527778,-100.0166667 ],
    [ u"us",u"El Dorado",12669,37.8172222,-96.8619444 ],
    [ u"us",u"Emporia",26545,38.4038889,-96.1813889 ],
    [ u"us",u"Garden City",26425,37.9716667,-100.8722222 ],
    [ u"us",u"Gardner",13511,38.8108333,-94.9269444 ],
    [ u"us",u"Great Bend",14654,38.3644444,-98.7644444 ],
    [ u"us",u"Hays",19883,38.8791667,-99.3263889 ],
    [ u"us",u"Haysville",10012,37.5644444,-97.3519444 ],
    [ u"us",u"Hutchinson",40596,38.0608333,-97.9294444 ],
    [ u"us",u"Independence",9129,37.2241667,-95.7080556 ],
    [ u"us",u"Junction City",17215,39.0286111,-96.8311111 ],
    [ u"us",u"Kansas City",442028,39.1141667,-94.6272222 ],
    [ u"us",u"Lansing",10846,39.2486111,-94.9000000 ],
    [ u"us",u"Lawrence",83314,38.9716667,-95.2350000 ],
    [ u"us",u"Leavenworth",34880,39.3111111,-94.9222222 ],
    [ u"us",u"Leawood",29978,38.9666667,-94.6166667 ],
    [ u"us",u"Lenexa",43331,38.9536111,-94.7333333 ],
    [ u"us",u"Liberal",20182,37.0430556,-100.9205556 ],
    [ u"us",u"Manhattan",45629,39.1836111,-96.5713889 ],
    [ u"us",u"Merriam",10759,39.0236111,-94.6933333 ],
    [ u"us",u"Mission",9485,39.0277778,-94.6555556 ],
    [ u"us",u"Newton",18113,38.0466667,-97.3447222 ],
    [ u"us",u"Olathe",113647,38.8813889,-94.8188889 ],
    [ u"us",u"Ottawa",12118,38.6155556,-95.2675000 ],
    [ u"us",u"Overland Park",166010,38.9822222,-94.6705556 ],
    [ u"us",u"Parsons",11227,37.3402778,-95.2608333 ],
    [ u"us",u"Pittsburg",19476,37.4108333,-94.7047222 ],
    [ u"us",u"Prairie Village",21564,38.9916667,-94.6333333 ],
    [ u"us",u"Salina",45723,38.8402778,-97.6111111 ],
    [ u"us",u"Shawnee",57561,39.0416667,-94.7200000 ],
    [ u"us",u"Topeka",121570,39.0483333,-95.6777778 ],
    [ u"us",u"Wichita",355244,37.6922222,-97.3372222 ],
    [ u"us",u"Winfield",11754,37.2397222,-96.9952778 ],
    [ u"us",u"Ashland",21209,38.4783333,-82.6380556 ],
    [ u"us",u"Bardstown",10576,37.8091667,-85.4669444 ],
    [ u"us",u"Berea",12079,37.5686111,-84.2963889 ],
    [ u"us",u"Bowling Green",51558,36.9902778,-86.4436111 ],
    [ u"us",u"Campbellsville",10821,37.3433333,-85.3419444 ],
    [ u"us",u"Covington",42153,39.0836111,-84.5086111 ],
    [ u"us",u"Danville",15164,37.6455556,-84.7722222 ],
    [ u"us",u"Edgewood",9043,39.0186111,-84.5819444 ],
    [ u"us",u"Elizabethtown",23636,37.6938889,-85.8591667 ],
    [ u"us",u"Erlanger",16895,39.0166667,-84.6008333 ],
    [ u"us",u"Fern Creek",18409,38.1597222,-85.5877778 ],
    [ u"us",u"Florence",25487,38.9988889,-84.6266667 ],
    [ u"us",u"Fort Thomas",15654,39.0750000,-84.4472222 ],
    [ u"us",u"Frankfort",27051,38.2008333,-84.8733333 ],
    [ u"us",u"Georgetown",20347,38.2097222,-84.5588889 ],
    [ u"us",u"Glasgow",13972,36.9958333,-85.9119444 ],
    [ u"us",u"Henderson",27495,37.8361111,-87.5900000 ],
    [ u"us",u"Highview",15167,38.1427778,-85.6241667 ],
    [ u"us",u"Hopkinsville",27656,36.8655556,-87.4886111 ],
    [ u"us",u"Independence",18596,38.9430556,-84.5441667 ],
    [ u"us",u"Jeffersontown",26464,38.1941667,-85.5644444 ],
    [ u"us",u"Lawrenceburg",9437,38.0372222,-84.8966667 ],
    [ u"us",u"Lexington-Fayette",272079,38.0497222,-84.4586111 ],
    [ u"us",u"Louisville",243639,38.2541667,-85.7594444 ],
    [ u"us",u"Lyndon",10376,38.2566667,-85.6016667 ],
    [ u"us",u"Madisonville",19423,37.3280556,-87.4988889 ],
    [ u"us",u"Mayfield",10153,36.7416667,-88.6366667 ],
    [ u"us",u"Murray",15626,36.6102778,-88.3147222 ],
    [ u"us",u"Newburg",19967,38.1600000,-85.6597222 ],
    [ u"us",u"Newport",15674,39.0913889,-84.4958333 ],
    [ u"us",u"Nicholasville",24004,37.8805556,-84.5730556 ],
    [ u"us",u"Okolona",17134,38.1411111,-85.6877778 ],
    [ u"us",u"Owensboro",54478,37.7741667,-87.1133333 ],
    [ u"us",u"Paducah",25306,37.0833333,-88.6000000 ],
    [ u"us",u"Paris",9332,38.2097222,-84.2530556 ],
    [ u"us",u"Radcliff",21783,37.8402778,-85.9491667 ],
    [ u"us",u"Richmond",30697,37.7477778,-84.2947222 ],
    [ u"us",u"Saint Matthews",17503,38.2527778,-85.6558333 ],
    [ u"us",u"Shelbyville",10596,38.2119444,-85.2236111 ],
    [ u"us",u"Shively",15426,38.2000000,-85.8227778 ],
    [ u"us",u"Somerset",12142,37.0919444,-84.6041667 ],
    [ u"us",u"Valley Station",22756,38.1111111,-85.8702778 ],
    [ u"us",u"Winchester",16201,37.9900000,-84.1797222 ],
    [ u"us",u"Abbeville",11558,29.9744444,-92.1341667 ],
    [ u"us",u"Alexandria",45187,31.3111111,-92.4450000 ],
    [ u"us",u"Baker",13396,30.5880556,-91.1680556 ],
    [ u"us",u"Bastrop",12725,32.7561111,-91.8722222 ],
    [ u"us",u"Baton Rouge",223349,30.4505556,-91.1544444 ],
    [ u"us",u"Bogalusa",12695,30.7908333,-89.8486111 ],
    [ u"us",u"Bossier City",59580,32.5158333,-93.7319444 ],
    [ u"us",u"Chalmette",31698,29.9425000,-89.9633333 ],
    [ u"us",u"Crowley",13797,30.2138889,-92.3744444 ],
    [ u"us",u"Denham Springs",9405,30.4866667,-90.9561111 ],
    [ u"us",u"Estelle",16553,29.8455556,-90.1066667 ],
    [ u"us",u"Eunice",11788,30.4941667,-92.4175000 ],
    [ u"us",u"Gretna",17106,29.9144444,-90.0538889 ],
    [ u"us",u"Hammond",17812,30.5041667,-90.4611111 ],
    [ u"us",u"Harahan",9746,29.9402778,-90.2030556 ],
    [ u"us",u"Harvey",22383,29.9033333,-90.0772222 ],
    [ u"us",u"Houma",31800,29.5955556,-90.7194444 ],
    [ u"us",u"Jefferson",10604,29.9658333,-90.1530556 ],
    [ u"us",u"Jennings",10547,30.2222222,-92.6569444 ],
    [ u"us",u"Kenner",69721,29.9938889,-90.2416667 ],
    [ u"us",u"Lafayette",112197,30.2238889,-92.0197222 ],
    [ u"us",u"Lake Charles",70309,30.2263889,-93.2172222 ],
    [ u"us",u"Laplace",29064,30.0663889,-90.4800000 ],
    [ u"us",u"Mandeville",11906,30.3580556,-90.0655556 ],
    [ u"us",u"Marrero",35405,29.8991667,-90.1002778 ],
    [ u"us",u"Merrydale",10290,30.5011111,-91.1083333 ],
    [ u"us",u"Metairie",142489,29.9838889,-90.1527778 ],
    [ u"us",u"Minden",13376,32.6152778,-93.2866667 ],
    [ u"us",u"Monroe",51625,32.5091667,-92.1191667 ],
    [ u"us",u"Morgan City",12162,29.6991667,-91.2066667 ],
    [ u"us",u"Natchitoches",18598,31.7605556,-93.0861111 ],
    [ u"us",u"New Iberia",32430,30.0033333,-91.8186111 ],
    [ u"us",u"New Orleans",459336,29.9544444,-90.0750000 ],
    [ u"us",u"Opelousas",22835,30.5333333,-92.0813889 ],
    [ u"us",u"Pineville",13846,31.3222222,-92.4341667 ],
    [ u"us",u"River Ridge",14278,29.9600000,-90.2155556 ],
    [ u"us",u"Ruston",20686,32.5230556,-92.6377778 ],
    [ u"us",u"Shenandoah",18829,30.4011111,-91.0008333 ],
    [ u"us",u"Shreveport",196980,32.5250000,-93.7500000 ],
    [ u"us",u"Slidell",27799,30.2750000,-89.7811111 ],
    [ u"us",u"Sulphur",19570,30.2363889,-93.3772222 ],
    [ u"us",u"Terrytown",25858,29.9100000,-90.0325000 ],
    [ u"us",u"Thibodaux",14410,29.7955556,-90.8227778 ],
    [ u"us",u"Waggaman",9311,29.9183333,-90.2108333 ],
    [ u"us",u"West Monroe",12900,32.5183333,-92.1475000 ],
    [ u"us",u"Westwego",10386,29.9058333,-90.1422222 ],
    [ u"us",u"Zachary",12114,30.6483333,-91.1563889 ],
    [ u"us",u"Auburn",23488,44.0977778,-70.2316667 ],
    [ u"us",u"Augusta",18661,44.3105556,-69.7800000 ],
    [ u"us",u"Bangor",31534,44.8011111,-68.7783333 ],
    [ u"us",u"Bar Harbor",6090,44.3875000,-68.2044444 ],
    [ u"us",u"Bath",9363,43.9105556,-69.8211111 ],
    [ u"us",u"Belfast",7052,44.4258333,-69.0069444 ],
    [ u"us",u"Berwick",7851,43.2658333,-70.8650000 ],
    [ u"us",u"Biddeford",21885,43.4925000,-70.4538889 ],
    [ u"us",u"Brewer",9140,44.7966667,-68.7619444 ],
    [ u"us",u"Bridgton",6351,44.0547222,-70.7133333 ],
    [ u"us",u"Brunswick",24206,43.9144444,-69.9658333 ],
    [ u"us",u"Bucksport",5756,44.5736111,-68.7961111 ],
    [ u"us",u"Buxton",8136,43.6377778,-70.5194444 ],
    [ u"us",u"Camden",5858,44.2097222,-69.0652778 ],
    [ u"us",u"Cape Elizabeth",8999,43.5636111,-70.2005556 ],
    [ u"us",u"Caribou",8336,46.8605556,-68.0125000 ],
    [ u"us",u"Eliot",6528,43.1530556,-70.8005556 ],
    [ u"us",u"Ellsworth",7055,44.5433333,-68.4200000 ],
    [ u"us",u"Fairfield",8771,44.5883333,-69.5991667 ],
    [ u"us",u"Falmouth",10731,43.7294444,-70.2425000 ],
    [ u"us",u"Farmington",8849,44.6705556,-70.1516667 ],
    [ u"us",u"Freeport",12415,43.8569444,-70.1036111 ],
    [ u"us",u"Gardiner",6239,44.2300000,-69.7758333 ],
    [ u"us",u"Gorham",22308,43.6794444,-70.4447222 ],
    [ u"us",u"Gray",7396,43.8855556,-70.3322222 ],
    [ u"us",u"Hampden",7781,44.7444444,-68.8375000 ],
    [ u"us",u"Hermon",4909,44.8100000,-68.9138889 ],
    [ u"us",u"Houlton",6703,46.1261111,-67.8408333 ],
    [ u"us",u"Jay",4988,44.5038889,-70.2166667 ],
    [ u"us",u"Kennebunk",14651,43.3838889,-70.5452778 ],
    [ u"us",u"Kittery",13063,43.0880556,-70.7366667 ],
    [ u"us",u"Lebanon",5446,43.3944444,-70.8513889 ],
    [ u"us",u"Lewiston",36199,44.1002778,-70.2152778 ],
    [ u"us",u"Lincoln",6330,45.3622222,-68.5055556 ],
    [ u"us",u"Lisbon",9392,44.0313889,-70.1050000 ],
    [ u"us",u"Madawaska",4944,47.3552778,-68.3222222 ],
    [ u"us",u"Madison",5316,44.7975000,-69.8802778 ],
    [ u"us",u"Millinocket",5105,45.6572222,-68.7102778 ],
    [ u"us",u"New Gloucester",5389,43.9627778,-70.2830556 ],
    [ u"us",u"North Berwick",11436,43.3036111,-70.7338889 ],
    [ u"us",u"Norway",5731,44.2138889,-70.5452778 ],
    [ u"us",u"Oakland",7837,44.5402778,-69.7225000 ],
    [ u"us",u"Old Orchard Beach",9415,43.5172222,-70.3780556 ],
    [ u"us",u"Old Town",8134,44.9341667,-68.6458333 ],
    [ u"us",u"Orono",9423,44.8830556,-68.6725000 ],
    [ u"us",u"Paris",5073,44.2597222,-70.5011111 ],
    [ u"us",u"Poland",5314,44.0605556,-70.3941667 ],
    [ u"us",u"Portland",63142,43.6613889,-70.2558333 ],
    [ u"us",u"Presque Isle",9466,46.6811111,-68.0163889 ],
    [ u"us",u"Raymond",4649,43.9013889,-70.4708333 ],
    [ u"us",u"Rockland",7527,44.1036111,-69.1094444 ],
    [ u"us",u"Rumford",8339,44.5536111,-70.5513889 ],
    [ u"us",u"Sabattus",4694,44.1197222,-70.1080556 ],
    [ u"us",u"Saco",18447,43.5008333,-70.4433333 ],
    [ u"us",u"Sanford",27201,43.4391667,-70.7747222 ],
    [ u"us",u"Scarborough",27706,43.5780556,-70.3222222 ],
    [ u"us",u"Skowhegan",9531,44.7650000,-69.7197222 ],
    [ u"us",u"South Berwick",7480,43.2344444,-70.8100000 ],
    [ u"us",u"South Portland",23893,43.6413889,-70.2413889 ],
    [ u"us",u"Standish",9926,43.7358333,-70.5525000 ],
    [ u"us",u"Topsham",11100,43.9275000,-69.9763889 ],
    [ u"us",u"Turner",5470,44.2563889,-70.2566667 ],
    [ u"us",u"Waldoboro",7462,44.0952778,-69.3761111 ],
    [ u"us",u"Waterboro",7532,43.5355556,-70.7155556 ],
    [ u"us",u"Waterville",15906,44.5519444,-69.6322222 ],
    [ u"us",u"Wells",10162,43.3219444,-70.5813889 ],
    [ u"us",u"Westbrook",15956,43.6769444,-70.3716667 ],
    [ u"us",u"Winslow",8098,44.5469444,-69.6216667 ],
    [ u"us",u"Winthrop",8175,44.3050000,-69.9775000 ],
    [ u"us",u"Yarmouth",10630,43.8005556,-70.1872222 ],
    [ u"us",u"Aberdeen",14437,39.5094444,-76.1644444 ],
    [ u"us",u"Adelphi",15988,39.0030556,-76.9722222 ],
    [ u"us",u"Annapolis",36252,38.9783333,-76.4925000 ],
    [ u"us",u"Arbutus",20603,39.2544444,-76.7002778 ],
    [ u"us",u"Arnold",25460,39.0319444,-76.5030556 ],
    [ u"us",u"Aspen Hill",53430,39.0794444,-77.0733333 ],
    [ u"us",u"Baltimore",610892,39.2902778,-76.6125000 ],
    [ u"us",u"Beltsville",16546,39.0347222,-76.9077778 ],
    [ u"us",u"Bethesda",52801,38.9805556,-77.1005556 ],
    [ u"us",u"Bowie",56050,39.0066667,-76.7794444 ],
    [ u"us",u"Brooklyn Park",11083,39.2283333,-76.6166667 ],
    [ u"us",u"Calverton",13083,39.2894444,-76.6605556 ],
    [ u"us",u"Cambridge",10699,38.5630556,-76.0791667 ],
    [ u"us",u"Camp Springs",19049,38.8038889,-76.9069444 ],
    [ u"us",u"Carney",30078,39.3941667,-76.5238889 ],
    [ u"us",u"Catonsville",42827,39.2719444,-76.7322222 ],
    [ u"us",u"Chillum",36280,38.9636111,-76.9911111 ],
    [ u"us",u"Clinton",29982,38.7650000,-76.8986111 ],
    [ u"us",u"Cockeysville",20040,39.4811111,-76.6441667 ],
    [ u"us",u"Colesville",20606,39.0755556,-77.0022222 ],
    [ u"us",u"College Park",25539,38.9805556,-76.9372222 ],
    [ u"us",u"Columbia",96201,39.2402778,-76.8397222 ],
    [ u"us",u"Coral Hills",10740,38.8702778,-76.9213889 ],
    [ u"us",u"Crofton",25233,39.0016667,-76.6877778 ],
    [ u"us",u"Cumberland",20347,39.6527778,-78.7627778 ],
    [ u"us",u"Damascus",12466,39.2883333,-77.2041667 ],
    [ u"us",u"Dundalk",61659,39.2505556,-76.5208333 ],
    [ u"us",u"East Riverdale",15576,38.9619444,-76.9222222 ],
    [ u"us",u"Easton",13094,38.7741667,-76.0766667 ],
    [ u"us",u"Edgemere",9401,39.2419444,-76.4483333 ],
    [ u"us",u"Edgewood",23492,39.4186111,-76.2947222 ],
    [ u"us",u"Eldersburg",38366,39.4036111,-76.9505556 ],
    [ u"us",u"Elkridge",28734,39.2125000,-76.7138889 ],
    [ u"us",u"Elkton",14686,39.6066667,-75.8336111 ],
    [ u"us",u"Ellicott City",66215,39.2672222,-76.7986111 ],
    [ u"us",u"Essex",38851,39.3091667,-76.4752778 ],
    [ u"us",u"Fairland",23048,39.0761111,-76.9580556 ],
    [ u"us",u"Ferndale",16163,39.1830556,-76.6405556 ],
    [ u"us",u"Forestville",12058,38.8450000,-76.8752778 ],
    [ u"us",u"Fort Washington",24124,38.7072222,-77.0233333 ],
    [ u"us",u"Frederick",57297,39.4141667,-77.4108333 ],
    [ u"us",u"Friendly",12155,38.7516667,-76.9788889 ],
    [ u"us",u"Gaithersburg",60062,39.1433333,-77.2016667 ],
    [ u"us",u"Germantown",64720,39.1730556,-77.2719444 ],
    [ u"us",u"Glen Burnie",40317,39.1625000,-76.6250000 ],
    [ u"us",u"Glenn Dale",14491,38.9875000,-76.8208333 ],
    [ u"us",u"Green Haven",19326,39.1394444,-76.5480556 ],
    [ u"us",u"Green Valley",14091,39.3091667,-77.2975000 ],
    [ u"us",u"Greenbelt",22390,39.0044444,-76.8758333 ],
    [ u"us",u"Hagerstown",37313,39.6416667,-77.7202778 ],
    [ u"us",u"Havre de Grace",11505,39.5491667,-76.0919444 ],
    [ u"us",u"Hillandale",3239,39.0263889,-76.9744444 ],
    [ u"us",u"Hillcrest Heights",16253,39.1519444,-76.8922222 ],
    [ u"us",u"Hyattsville",15323,38.9558333,-76.9458333 ],
    [ u"us",u"Joppatowne",11716,39.4577778,-76.3555556 ],
    [ u"us",u"Kettering",11749,38.8844444,-76.8150000 ],
    [ u"us",u"La Plata",8284,38.5291667,-76.9755556 ],
    [ u"us",u"Lake Shore",13170,39.1069444,-76.4852778 ],
    [ u"us",u"Langley Park",15895,38.9886111,-76.9816667 ],
    [ u"us",u"Largo",8072,38.8975000,-76.8305556 ],
    [ u"us",u"Laurel",20860,39.0991667,-76.8486111 ],
    [ u"us",u"Lexington Park",11746,38.2666667,-76.4541667 ],
    [ u"us",u"Lochearn",25672,39.3405556,-76.7225000 ],
    [ u"us",u"Mays Chapel",12278,39.4330556,-76.6497222 ],
    [ u"us",u"Middle River",24019,39.3341667,-76.4397222 ],
    [ u"us",u"Milford Mill",29074,39.3477778,-76.7702778 ],
    [ u"us",u"Mitchellville",9135,38.9250000,-76.7430556 ],
    [ u"us",u"Montgomery Village",41721,39.1766667,-77.1955556 ],
    [ u"us",u"Mount Airy",8714,39.3761111,-77.1550000 ],
    [ u"us",u"Mount Rainier",8815,38.9413889,-76.9652778 ],
    [ u"us",u"New Carrollton",13233,38.9697222,-76.8802778 ],
    [ u"us",u"North Bethesda",44379,39.0444444,-77.1191667 ],
    [ u"us",u"North Laurel",24046,39.1388889,-76.8708333 ],
    [ u"us",u"North Potomac",25972,39.0827778,-77.2652778 ],
    [ u"us",u"Odenton",26005,39.0838889,-76.7005556 ],
    [ u"us",u"Olney",36957,39.1530556,-77.0672222 ],
    [ u"us",u"Overlea",12341,39.3633333,-76.5208333 ],
    [ u"us",u"Owings Mills",27415,39.4194444,-76.7805556 ],
    [ u"us",u"Parkville",31362,39.3772222,-76.5400000 ],
    [ u"us",u"Parole",16664,38.9794444,-76.5308333 ],
    [ u"us",u"Pasadena",13419,39.1072222,-76.5713889 ],
    [ u"us",u"Perry Hall",32530,39.4125000,-76.4638889 ],
    [ u"us",u"Pikesville",31882,39.3741667,-76.7227778 ],
    [ u"us",u"Potomac",45129,39.0180556,-77.2088889 ],
    [ u"us",u"Randallstown",33811,39.3672222,-76.7955556 ],
    [ u"us",u"Redland",17683,39.1452778,-77.1444444 ],
    [ u"us",u"Reisterstown",24447,39.4694444,-76.8297222 ],
    [ u"us",u"Riviera Beach",13573,39.1666667,-76.5083333 ],
    [ u"us",u"Rockville",60646,39.0838889,-77.1530556 ],
    [ u"us",u"Rosaryville",14521,38.7566667,-76.8100000 ],
    [ u"us",u"Rosedale",19736,39.3200000,-76.5158333 ],
    [ u"us",u"Rossville",12804,39.3383333,-76.4800000 ],
    [ u"us",u"Saint Charles",36376,38.6030556,-76.9388889 ],
    [ u"us",u"Salisbury",26352,38.3605556,-75.5997222 ],
    [ u"us",u"Severn",42157,39.1369444,-76.6986111 ],
    [ u"us",u"Severna Park",30292,39.0702778,-76.5455556 ],
    [ u"us",u"Silver Spring",77951,38.9905556,-77.0263889 ],
    [ u"us",u"South Gate",29658,39.1288889,-76.6261111 ],
    [ u"us",u"South Laurel",21762,39.0697222,-76.8505556 ],
    [ u"us",u"Takoma Park",17860,38.9777778,-77.0077778 ],
    [ u"us",u"Towson",53749,39.4013889,-76.6022222 ],
    [ u"us",u"Waldorf",27254,38.6244444,-76.9394444 ],
    [ u"us",u"Walker Mill",11364,38.8752778,-76.8886111 ],
    [ u"us",u"Westminster",17862,39.5752778,-76.9961111 ],
    [ u"us",u"White Oak",22492,39.0397222,-76.9933333 ],
    [ u"us",u"Abington",17374,42.1047222,-70.9458333 ],
    [ u"us",u"Acton",20897,42.4850000,-71.4333333 ],
    [ u"us",u"Acushnet",10850,41.6805556,-70.9083333 ],
    [ u"us",u"Agawam",28761,42.0694444,-72.6152778 ],
    [ u"us",u"Amesbury",18313,42.8583333,-70.9305556 ],
    [ u"us",u"Amherst Center",34618,42.3752778,-72.5197222 ],
    [ u"us",u"Andover",48286,42.6583333,-71.1375000 ],
    [ u"us",u"Arlington",41461,42.4152778,-71.1569444 ],
    [ u"us",u"Ashland",15802,42.2611111,-71.4638889 ],
    [ u"us",u"Athol",12871,42.5958333,-72.2272222 ],
    [ u"us",u"Attleboro",44271,41.9444444,-71.2861111 ],
    [ u"us",u"Bedford",12502,42.4905556,-71.2766667 ],
    [ u"us",u"Belchertown",22391,42.2769444,-72.4013889 ],
    [ u"us",u"Belmont",23546,42.3958333,-71.1791667 ],
    [ u"us",u"Beverly",40365,42.5583333,-70.8805556 ],
    [ u"us",u"Billerica",39904,42.5583333,-71.2694444 ],
    [ u"us",u"Blackstone",9163,42.0177778,-71.5416667 ],
    [ u"us",u"Boston",571281,42.3583333,-71.0602778 ],
    [ u"us",u"Bourne",34065,41.7411111,-70.5994444 ],
    [ u"us",u"Braintree",33509,42.2222222,-71.0000000 ],
    [ u"us",u"Brewster",37107,41.7600000,-70.0833333 ],
    [ u"us",u"Bridgewater",36525,41.9902778,-70.9755556 ],
    [ u"us",u"Brockton",94881,42.0833333,-71.0188889 ],
    [ u"us",u"Brookline",56079,42.3316667,-71.1216667 ],
    [ u"us",u"Burlington",22739,42.5047222,-71.1961111 ],
    [ u"us",u"Cambridge",101382,42.3750000,-71.1061111 ],
    [ u"us",u"Canton",21679,42.1583333,-71.1452778 ],
    [ u"us",u"Carver",11718,41.8833333,-70.7630556 ],
    [ u"us",u"Charlton",12764,42.1355556,-71.9705556 ],
    [ u"us",u"Chelmsford",33925,42.5997222,-71.3677778 ],
    [ u"us",u"Chelsea",33062,42.3916667,-71.0333333 ],
    [ u"us",u"Chicopee",55179,42.1486111,-72.6083333 ],
    [ u"us",u"Clinton",16317,42.4166667,-71.6833333 ],
    [ u"us",u"Concord",16810,42.4602778,-71.3494444 ],
    [ u"us",u"Danvers",25829,42.5750000,-70.9305556 ],
    [ u"us",u"Dedham",23019,42.2416667,-71.1666667 ],
    [ u"us",u"Dennis",26780,41.7352778,-70.1944444 ],
    [ u"us",u"Dracut",28831,42.6702778,-71.3025000 ],
    [ u"us",u"Dudley",11165,42.0450000,-71.9305556 ],
    [ u"us",u"Duxbury",27695,42.0416667,-70.6727778 ],
    [ u"us",u"East Bridgewater",14021,42.0333333,-70.9597222 ],
    [ u"us",u"East Longmeadow",15102,42.0644444,-72.5130556 ],
    [ u"us",u"Easthampton",16611,42.2666667,-72.6694444 ],
    [ u"us",u"Easton",23459,42.0244444,-71.1291667 ],
    [ u"us",u"Everett",37148,42.4083333,-71.0541667 ],
    [ u"us",u"Fairhaven",16453,41.6375000,-70.9041667 ],
    [ u"us",u"Fall River",93000,41.7013889,-71.1555556 ],
    [ u"us",u"Falmouth",59431,41.5513889,-70.6152778 ],
    [ u"us",u"Fitchburg",40363,42.5833333,-71.8027778 ],
    [ u"us",u"Foxborough",22733,42.0652778,-71.2483333 ],
    [ u"us",u"Framingham",65413,42.2791667,-71.4166667 ],
    [ u"us",u"Franklin",30636,42.0833333,-71.3972222 ],
    [ u"us",u"Gardner",21175,42.5750000,-71.9986111 ],
    [ u"us",u"Gloucester",30916,42.6158333,-70.6625000 ],
    [ u"us",u"Grafton",16583,42.2069444,-71.6861111 ],
    [ u"us",u"Greenfield",19753,42.5875000,-72.6000000 ],
    [ u"us",u"Groton",18772,42.6111111,-71.5750000 ],
    [ u"us",u"Hanover",16906,42.1130556,-70.8125000 ],
    [ u"us",u"Hanson",15315,42.0750000,-70.8805556 ],
    [ u"us",u"Harwich",13059,41.6861111,-70.0763889 ],
    [ u"us",u"Haverhill",61465,42.7761111,-71.0777778 ],
    [ u"us",u"Hingham",30151,42.2416667,-70.8902778 ],
    [ u"us",u"Holbrook",10876,42.1550000,-71.0091667 ],
    [ u"us",u"Holden",17016,42.3516667,-71.8638889 ],
    [ u"us",u"Holliston",14010,42.2000000,-71.4250000 ],
    [ u"us",u"Holyoke",40141,42.2041667,-72.6166667 ],
    [ u"us",u"Hopkinton",22601,42.2286111,-71.5230556 ],
    [ u"us",u"Hudson",19697,42.3916667,-71.5666667 ],
    [ u"us",u"Hull",11324,42.3019444,-70.9083333 ],
    [ u"us",u"Ipswich",18768,42.6791667,-70.8416667 ],
    [ u"us",u"Kingston",15658,41.9944444,-70.7250000 ],
    [ u"us",u"Lakeville",10787,41.8458333,-70.9500000 ],
    [ u"us",u"Lawrence",72609,42.7069444,-71.1636111 ],
    [ u"us",u"Leicester",11064,42.2458333,-71.9091667 ],
    [ u"us",u"Leominster",42301,42.5250000,-71.7602778 ],
    [ u"us",u"Lexington",30661,42.4472222,-71.2250000 ],
    [ u"us",u"Longmeadow",15699,42.0500000,-72.5833333 ],
    [ u"us",u"Lowell",103469,42.6333333,-71.3166667 ],
    [ u"us",u"Ludlow",22201,42.1600000,-72.4763889 ],
    [ u"us",u"Lunenburg",16520,42.5944444,-71.7250000 ],
    [ u"us",u"Lynn",89691,42.4666667,-70.9500000 ],
    [ u"us",u"Lynnfield",11748,42.5388889,-71.0486111 ],
    [ u"us",u"Malden",55290,42.4250000,-71.0666667 ],
    [ u"us",u"Mansfield",23380,42.0333333,-71.2194444 ],
    [ u"us",u"Marblehead",20424,42.5000000,-70.8583333 ],
    [ u"us",u"Marlborough",38334,42.3458333,-71.5527778 ],
    [ u"us",u"Marshfield",40849,42.0916667,-70.7061111 ],
    [ u"us",u"Mashpee",14834,41.6483333,-70.4816667 ],
    [ u"us",u"Maynard",10275,42.4333333,-71.4500000 ],
    [ u"us",u"Medfield",14846,42.1875000,-71.3069444 ],
    [ u"us",u"Medford",53963,42.4183333,-71.1066667 ],
    [ u"us",u"Medway",13042,42.1416667,-71.3972222 ],
    [ u"us",u"Melrose",26466,42.4583333,-71.0666667 ],
    [ u"us",u"Methuen",45372,42.7261111,-71.1913889 ],
    [ u"us",u"Middleton",9859,42.5950000,-71.0166667 ],
    [ u"us",u"Milford",28631,42.1397222,-71.5166667 ],
    [ u"us",u"Millbury",13606,42.1938889,-71.7605556 ],
    [ u"us",u"Milton",25586,42.2494444,-71.0666667 ],
    [ u"us",u"Nantucket",14775,41.2833333,-70.1000000 ],
    [ u"us",u"Natick",32276,42.2833333,-71.3500000 ],
    [ u"us",u"Needham",29125,42.2833333,-71.2333333 ],
    [ u"us",u"New Bedford",94083,41.6361111,-70.9347222 ],
    [ u"us",u"Newburyport",17575,42.8125000,-70.8777778 ],
    [ u"us",u"Newton",84851,42.3369444,-71.2097222 ],
    [ u"us",u"Norfolk",10386,42.1194444,-71.3255556 ],
    [ u"us",u"North Adams",14106,42.7008333,-73.1091667 ],
    [ u"us",u"North Andover",28222,42.6986111,-71.1355556 ],
    [ u"us",u"North Reading",14101,42.5750000,-71.0791667 ],
    [ u"us",u"Northampton",29665,42.3250000,-72.6416667 ],
    [ u"us",u"Northborough",18304,42.3194444,-71.6416667 ],
    [ u"us",u"Northbridge",14061,42.1513889,-71.6500000 ],
    [ u"us",u"Norton",19808,41.9666667,-71.1875000 ],
    [ u"us",u"Norwell",10581,42.1616667,-70.7944444 ],
    [ u"us",u"Norwood",28625,42.1944444,-71.2000000 ],
    [ u"us",u"Oxford",17746,42.1166667,-71.8652778 ],
    [ u"us",u"Palmer",18261,42.1583333,-72.3291667 ],
    [ u"us",u"Peabody",50293,42.5277778,-70.9291667 ],
    [ u"us",u"Pembroke",18041,42.0713889,-70.8097222 ],
    [ u"us",u"Pepperell",17453,42.6658333,-71.5888889 ],
    [ u"us",u"Pittsfield",44174,42.4500000,-73.2458333 ],
    [ u"us",u"Plymouth",90615,41.9583333,-70.6677778 ],
    [ u"us",u"Quincy",89168,42.2527778,-71.0027778 ],
    [ u"us",u"Randolph",30768,42.1625000,-71.0416667 ],
    [ u"us",u"Raynham",13153,41.9486111,-71.0736111 ],
    [ u"us",u"Reading",23441,42.5255556,-71.0958333 ],
    [ u"us",u"Rehoboth",11486,41.8402778,-71.2500000 ],
    [ u"us",u"Revere",46420,42.4083333,-71.0125000 ],
    [ u"us",u"Rockland",17982,42.1305556,-70.9166667 ],
    [ u"us",u"Salem",42455,42.5194444,-70.8972222 ],
    [ u"us",u"Sandwich",34886,41.7588889,-70.4944444 ],
    [ u"us",u"Saugus",26668,42.4647222,-71.0105556 ],
    [ u"us",u"Scituate",26400,42.1958333,-70.7263889 ],
    [ u"us",u"Seekonk",13966,41.8083333,-71.3375000 ],
    [ u"us",u"Sharon",24066,42.1236111,-71.1791667 ],
    [ u"us",u"Shrewsbury",33893,42.2958333,-71.7133333 ],
    [ u"us",u"Somerset",18943,41.7694444,-71.1291667 ],
    [ u"us",u"Somerville",75261,42.3875000,-71.1000000 ],
    [ u"us",u"South Hadley",17652,42.2583333,-72.5750000 ],
    [ u"us",u"South Yarmouth",12162,41.6666667,-70.1852778 ],
    [ u"us",u"Southborough",9686,42.3055556,-71.5250000 ],
    [ u"us",u"Southbridge",19030,42.0750000,-72.0338889 ],
    [ u"us",u"Southwick",9444,42.0547222,-72.7708333 ],
    [ u"us",u"Spencer",14814,42.2438889,-71.9927778 ],
    [ u"us",u"Springfield",152227,42.1013889,-72.5902778 ],
    [ u"us",u"Stoneham",21796,42.4800000,-71.1000000 ],
    [ u"us",u"Stoughton",26915,42.1250000,-71.1027778 ],
    [ u"us",u"Sudbury",17343,42.3833333,-71.4166667 ],
    [ u"us",u"Sutton",9215,42.1500000,-71.7633333 ],
    [ u"us",u"Swampscott",14447,42.4708333,-70.9180556 ],
    [ u"us",u"Swansea",16525,41.7480556,-71.1902778 ],
    [ u"us",u"Taunton",57160,41.9000000,-71.0902778 ],
    [ u"us",u"Tewksbury",29326,42.6105556,-71.2347222 ],
    [ u"us",u"Townsend",16933,42.6666667,-71.7055556 ],
    [ u"us",u"Uxbridge",12614,42.0772222,-71.6300000 ],
    [ u"us",u"Wakefield",24712,42.5063889,-71.0733333 ],
    [ u"us",u"Walpole",32670,42.1416667,-71.2500000 ],
    [ u"us",u"Waltham",58570,42.3763889,-71.2361111 ],
    [ u"us",u"Ware",11610,42.2597222,-72.2402778 ],
    [ u"us",u"Wareham",21478,41.7625000,-70.7222222 ],
    [ u"us",u"Watertown",32918,42.3708333,-71.1833333 ],
    [ u"us",u"Wayland",13155,42.3625000,-71.3619444 ],
    [ u"us",u"Webster",19028,42.0500000,-71.8805556 ],
    [ u"us",u"Wellesley",26446,42.2963889,-71.2930556 ],
    [ u"us",u"West Springfield",27912,42.1069444,-72.6208333 ],
    [ u"us",u"Westborough",29313,42.2694444,-71.6166667 ],
    [ u"us",u"Westfield",40932,42.1250000,-72.7500000 ],
    [ u"us",u"Westford",21587,42.5791667,-71.4383333 ],
    [ u"us",u"Weston",11682,42.3666667,-71.3036111 ],
    [ u"us",u"Westwood",14029,42.2138889,-71.2250000 ],
    [ u"us",u"Weymouth",54395,42.2208333,-70.9402778 ],
    [ u"us",u"Whitman",14495,42.0805556,-70.9361111 ],
    [ u"us",u"Wilbraham",20883,42.1236111,-72.4319444 ],
    [ u"us",u"Wilmington",21704,42.5463889,-71.1741667 ],
    [ u"us",u"Winchendon",12954,42.6861111,-72.0444444 ],
    [ u"us",u"Winchester",21366,42.4522222,-71.1375000 ],
    [ u"us",u"Winthrop",17618,42.3750000,-70.9833333 ],
    [ u"us",u"Woburn",37746,42.4791667,-71.1527778 ],
    [ u"us",u"Worcester",177216,42.2625000,-71.8027778 ],
    [ u"us",u"Wrentham",11251,42.0666667,-71.3286111 ],
    [ u"us",u"Yarmouth",25243,41.7055556,-70.2291667 ],
    [ u"us",u"Adrian",22704,41.8975000,-84.0372222 ],
    [ u"us",u"Albion",9154,42.2430556,-84.7530556 ],
    [ u"us",u"Allen Park",28157,42.2575000,-83.2111111 ],
    [ u"us",u"Alma",9373,43.3788889,-84.6597222 ],
    [ u"us",u"Alpena",10718,45.0616667,-83.4327778 ],
    [ u"us",u"Ann Arbor",113810,42.2708333,-83.7263889 ],
    [ u"us",u"Auburn Hills",20816,42.6875000,-83.2341667 ],
    [ u"us",u"Battle Creek",54088,42.3211111,-85.1797222 ],
    [ u"us",u"Bay City",34568,43.5944444,-83.8888889 ],
    [ u"us",u"Beecher",11971,43.0900000,-83.6944444 ],
    [ u"us",u"Benton Harbor",10893,42.1166667,-86.4541667 ],
    [ u"us",u"Berkley",14997,42.5030556,-83.1836111 ],
    [ u"us",u"Beverly Hills",10032,42.5238889,-83.2233333 ],
    [ u"us",u"Big Rapids",10731,43.6980556,-85.4836111 ],
    [ u"us",u"Birmingham",18977,42.5466667,-83.2113889 ],
    [ u"us",u"Burton",31587,42.9994444,-83.6163889 ],
    [ u"us",u"Cadillac",10258,44.2519444,-85.4011111 ],
    [ u"us",u"Canton",86825,42.3086111,-83.4822222 ],
    [ u"us",u"Clawson",12222,42.5333333,-83.1463889 ],
    [ u"us",u"Coldwater",10864,41.9402778,-85.0005556 ],
    [ u"us",u"Cutlerville",17231,42.8408333,-85.6636111 ],
    [ u"us",u"Dearborn",95170,42.3222222,-83.1763889 ],
    [ u"us",u"Dearborn Heights",56359,42.3369444,-83.2733333 ],
    [ u"us",u"Detroit",884941,42.3313889,-83.0458333 ],
    [ u"us",u"East Grand Rapids",10380,42.9411111,-85.6100000 ],
    [ u"us",u"East Lansing",48371,42.7369444,-84.4838889 ],
    [ u"us",u"Eastpointe",32682,42.4683333,-82.9555556 ],
    [ u"us",u"Ecorse",10773,42.2444444,-83.1458333 ],
    [ u"us",u"Escanaba",12622,45.7452778,-87.0644444 ],
    [ u"us",u"Farmington",9989,42.4644444,-83.3763889 ],
    [ u"us",u"Farmington Hills",79955,42.4852778,-83.3772222 ],
    [ u"us",u"Fenton",12236,42.7977778,-83.7050000 ],
    [ u"us",u"Ferndale",21361,42.4605556,-83.1347222 ],
    [ u"us",u"Flint",117258,43.0125000,-83.6875000 ],
    [ u"us",u"Forest Hills",23099,42.9594444,-85.4897222 ],
    [ u"us",u"Fraser",14878,42.5391667,-82.9494444 ],
    [ u"us",u"Garden City",29023,42.3255556,-83.3311111 ],
    [ u"us",u"Grand Haven",10644,43.0630556,-86.2283333 ],
    [ u"us",u"Grand Rapids",193852,42.9633333,-85.6680556 ],
    [ u"us",u"Grandville",16741,42.9097222,-85.7630556 ],
    [ u"us",u"Grosse Ile",11361,42.1291667,-83.1444444 ],
    [ u"us",u"Grosse Pointe Farms",9360,42.4091667,-82.8919444 ],
    [ u"us",u"Grosse Pointe Park",11937,42.3758333,-82.9375000 ],
    [ u"us",u"Grosse Pointe Woods",16364,42.4436111,-82.9069444 ],
    [ u"us",u"Hamtramck",21994,42.3927778,-83.0497222 ],
    [ u"us",u"Harper Woods",13665,42.4330556,-82.9241667 ],
    [ u"us",u"Haslett",11713,42.7469444,-84.4011111 ],
    [ u"us",u"Hazel Park",18261,42.4625000,-83.1041667 ],
    [ u"us",u"Highland Park",15568,42.4055556,-83.0969444 ],
    [ u"us",u"Holland",34544,42.7875000,-86.1088889 ],
    [ u"us",u"Holt",11023,42.6405556,-84.5152778 ],
    [ u"us",u"Howell",9860,42.6072222,-83.9294444 ],
    [ u"us",u"Inkster",28844,42.2941667,-83.3100000 ],
    [ u"us",u"Ionia",13647,42.9872222,-85.0711111 ],
    [ u"us",u"Jackson",34416,42.2458333,-84.4013889 ],
    [ u"us",u"Jenison",16758,42.9072222,-85.7919444 ],
    [ u"us",u"Kalamazoo",74138,42.2916667,-85.5872222 ],
    [ u"us",u"Kentwood",47059,42.8694444,-85.6447222 ],
    [ u"us",u"Lansing",117691,42.7325000,-84.5555556 ],
    [ u"us",u"Lapeer",9372,43.0513889,-83.3188889 ],
    [ u"us",u"Lincoln Park",38297,42.2505556,-83.1786111 ],
    [ u"us",u"Livonia",98218,42.3683333,-83.3527778 ],
    [ u"us",u"Madison Heights",30004,42.4858333,-83.1052778 ],
    [ u"us",u"Marquette",20831,46.5436111,-87.3952778 ],
    [ u"us",u"Marysville",9881,42.9125000,-82.4869444 ],
    [ u"us",u"Melvindale",10492,42.2825000,-83.1752778 ],
    [ u"us",u"Midland",42400,43.6155556,-84.2472222 ],
    [ u"us",u"Monroe",21076,41.9163889,-83.3977778 ],
    [ u"us",u"Mount Clemens",16776,42.5972222,-82.8780556 ],
    [ u"us",u"Mount Pleasant",25281,43.5977778,-84.7675000 ],
    [ u"us",u"Muskegon",40112,43.2341667,-86.2483333 ],
    [ u"us",u"Muskegon Heights",11689,43.2011111,-86.2388889 ],
    [ u"us",u"New Baltimore",11453,42.6811111,-82.7369444 ],
    [ u"us",u"Niles",11739,41.8297222,-86.2541667 ],
    [ u"us",u"Northview",15103,43.0455556,-85.6005556 ],
    [ u"us",u"Norton Shores",23486,43.1688889,-86.2638889 ],
    [ u"us",u"Novi",53754,42.4805556,-83.4755556 ],
    [ u"us",u"Oak Park",28644,42.4594444,-83.1827778 ],
    [ u"us",u"Okemos",23926,42.7222222,-84.4275000 ],
    [ u"us",u"Owosso",15373,42.9977778,-84.1766667 ],
    [ u"us",u"Pontiac",67994,42.6388889,-83.2911111 ],
    [ u"us",u"Port Huron",30978,42.9708333,-82.4250000 ],
    [ u"us",u"Portage",46403,42.2011111,-85.5800000 ],
    [ u"us",u"Redford",49936,42.3833333,-83.2966667 ],
    [ u"us",u"River Rouge",9117,42.2733333,-83.1344444 ],
    [ u"us",u"Riverview",12762,42.1741667,-83.1794444 ],
    [ u"us",u"Rochester",11485,42.6805556,-83.1338889 ],
    [ u"us",u"Rochester Hills",68895,42.6583333,-83.1500000 ],
    [ u"us",u"Romulus",24018,42.2222222,-83.3966667 ],
    [ u"us",u"Roseville",47372,42.4972222,-82.9372222 ],
    [ u"us",u"Royal Oak",57570,42.4894444,-83.1447222 ],
    [ u"us",u"Saginaw",57536,43.4194444,-83.9508333 ],
    [ u"us",u"South Lyon",11450,42.4605556,-83.6516667 ],
    [ u"us",u"Southfield",76828,42.4733333,-83.2219444 ],
    [ u"us",u"Southgate",29669,42.2138889,-83.1938889 ],
    [ u"us",u"Sterling Heights",126657,42.5802778,-83.0302778 ],
    [ u"us",u"Sturgis",11081,41.7991667,-85.4191667 ],
    [ u"us",u"Taylor",65088,42.2408333,-83.2697222 ],
    [ u"us",u"Traverse City",14425,44.7630556,-85.6205556 ],
    [ u"us",u"Trenton",19604,42.1394444,-83.1783333 ],
    [ u"us",u"Troy",81269,42.6055556,-83.1500000 ],
    [ u"us",u"Walker",23824,43.0013889,-85.7680556 ],
    [ u"us",u"Warren",133517,42.4775000,-83.0277778 ],
    [ u"us",u"Waterford",75737,42.7022222,-83.4027778 ],
    [ u"us",u"Waverly",16332,42.7391667,-84.6208333 ],
    [ u"us",u"Wayne",18785,42.2813889,-83.3863889 ],
    [ u"us",u"Westland",84801,42.3241667,-83.4002778 ],
    [ u"us",u"Wixom",13696,42.5247222,-83.5363889 ],
    [ u"us",u"Woodhaven",12917,42.1388889,-83.2416667 ],
    [ u"us",u"Wyandotte",26802,42.2141667,-83.1500000 ],
    [ u"us",u"Wyoming",70308,42.9133333,-85.7052778 ],
    [ u"us",u"Ypsilanti",22191,42.2411111,-83.6130556 ],
    [ u"us",u"Albert Lea",17605,43.6480556,-93.3680556 ],
    [ u"us",u"Alexandria",10226,45.8852778,-95.3772222 ],
    [ u"us",u"Andover",30209,45.2333333,-93.2911111 ],
    [ u"us",u"Anoka",17706,45.1977778,-93.3869444 ],
    [ u"us",u"Apple Valley",50540,44.7319444,-93.2175000 ],
    [ u"us",u"Austin",23451,43.6666667,-92.9744444 ],
    [ u"us",u"Bemidji",13331,47.4736111,-94.8800000 ],
    [ u"us",u"Blaine",54207,45.1608333,-93.2347222 ],
    [ u"us",u"Bloomington",81383,44.8408333,-93.2980556 ],
    [ u"us",u"Brainerd",14218,46.3580556,-94.2005556 ],
    [ u"us",u"Brooklyn Center",27718,45.0761111,-93.3325000 ],
    [ u"us",u"Brooklyn Park",67595,45.0941667,-93.3561111 ],
    [ u"us",u"Buffalo",14283,45.1719444,-93.8744444 ],
    [ u"us",u"Burnsville",59492,44.7677778,-93.2775000 ],
    [ u"us",u"Champlin",23364,45.1888889,-93.3972222 ],
    [ u"us",u"Chanhassen",23551,44.8622222,-93.5305556 ],
    [ u"us",u"Chaska",23176,44.7894444,-93.6019444 ],
    [ u"us",u"Cloquet",11548,46.7216667,-92.4591667 ],
    [ u"us",u"Columbia Heights",18235,45.0408333,-93.2627778 ],
    [ u"us",u"Coon Rapids",62528,45.1200000,-93.2875000 ],
    [ u"us",u"Cottage Grove",32975,44.8277778,-92.9436111 ],
    [ u"us",u"Crystal",21834,45.0327778,-93.3600000 ],
    [ u"us",u"Duluth",84800,46.7833333,-92.1063889 ],
    [ u"us",u"Eagan",64218,44.8041667,-93.1666667 ],
    [ u"us",u"East Bethel",11971,45.3194444,-93.2022222 ],
    [ u"us",u"Eden Prairie",63319,44.8547222,-93.4705556 ],
    [ u"us",u"Edina",45945,44.8897222,-93.3497222 ],
    [ u"us",u"Elk River",20377,45.3038889,-93.5669444 ],
    [ u"us",u"Fairmont",10576,43.6522222,-94.4608333 ],
    [ u"us",u"Faribault",22633,44.2950000,-93.2686111 ],
    [ u"us",u"Farmington",18954,44.6402778,-93.1433333 ],
    [ u"us",u"Fergus Falls",14364,46.2830556,-96.0772222 ],
    [ u"us",u"Forest Lake",17449,45.2788889,-92.9850000 ],
    [ u"us",u"Fridley",26834,45.0861111,-93.2630556 ],
    [ u"us",u"Golden Valley",20325,45.0097222,-93.3488889 ],
    [ u"us",u"Ham Lake",14954,45.2502778,-93.2497222 ],
    [ u"us",u"Hastings",20833,44.7433333,-92.8522222 ],
    [ u"us",u"Hibbing",16638,47.4272222,-92.9375000 ],
    [ u"us",u"Hopkins",17073,44.9250000,-93.4625000 ],
    [ u"us",u"Hugo",10125,45.1600000,-92.9930556 ],
    [ u"us",u"Hutchinson",13759,44.8877778,-94.3694444 ],
    [ u"us",u"Inver Grove Heights",32363,44.8480556,-93.0425000 ],
    [ u"us",u"Lakeville",50994,44.6497222,-93.2425000 ],
    [ u"us",u"Lino Lakes",20095,45.1602778,-93.0886111 ],
    [ u"us",u"Little Canada",9617,45.0269444,-93.0875000 ],
    [ u"us",u"Mahtomedi",8258,45.0697222,-92.9513889 ],
    [ u"us",u"Mankato",35138,44.1636111,-93.9991667 ],
    [ u"us",u"Maple Grove",59902,45.0725000,-93.4555556 ],
    [ u"us",u"Maplewood",36400,44.9530556,-92.9950000 ],
    [ u"us",u"Marshall",12348,44.4469444,-95.7880556 ],
    [ u"us",u"Mendota Heights",11195,44.8836111,-93.1380556 ],
    [ u"us",u"Minneapolis",367773,44.9800000,-93.2636111 ],
    [ u"us",u"Minnetonka",50117,44.9133333,-93.5030556 ],
    [ u"us",u"Monticello",10871,45.3055556,-93.7938889 ],
    [ u"us",u"Moorhead",33137,46.8738889,-96.7672222 ],
    [ u"us",u"Mound",9354,44.9366667,-93.6658333 ],
    [ u"us",u"Mounds View",12648,45.1050000,-93.2083333 ],
    [ u"us",u"New Brighton",21295,45.0655556,-93.2016667 ],
    [ u"us",u"New Hope",19851,45.0380556,-93.3863889 ],
    [ u"us",u"New Ulm",13273,44.3125000,-94.4602778 ],
    [ u"us",u"North Branch",10389,45.5113889,-92.9800000 ],
    [ u"us",u"North Mankato",12590,44.1733333,-94.0336111 ],
    [ u"us",u"North Saint Paul",11799,45.0125000,-92.9916667 ],
    [ u"us",u"Northfield",18900,44.4583333,-93.1613889 ],
    [ u"us",u"Oakdale",28143,44.9630556,-92.9647222 ],
    [ u"us",u"Owatonna",23955,44.0838889,-93.2258333 ],
    [ u"us",u"Plymouth",72239,45.0105556,-93.4552778 ],
    [ u"us",u"Prior Lake",23790,44.7133333,-93.4225000 ],
    [ u"us",u"Ramsey",20362,45.2461111,-93.4519444 ],
    [ u"us",u"Red Wing",15972,44.5625000,-92.5336111 ],
    [ u"us",u"Richfield",33349,44.8833333,-93.2827778 ],
    [ u"us",u"Robbinsdale",13314,45.0322222,-93.3383333 ],
    [ u"us",u"Rochester",96355,44.0216667,-92.4697222 ],
    [ u"us",u"Rosemount",18593,44.7394444,-93.1255556 ],
    [ u"us",u"Roseville",32563,45.0061111,-93.1563889 ],
    [ u"us",u"Saint Cloud",59154,45.5608333,-94.1622222 ],
    [ u"us",u"Saint Louis Park",44071,44.9483333,-93.3477778 ],
    [ u"us",u"Saint Michael",15516,45.2100000,-93.6647222 ],
    [ u"us",u"Saint Paul",274792,44.9444444,-93.0930556 ],
    [ u"us",u"Saint Peter",10584,44.3236111,-93.9577778 ],
    [ u"us",u"Sartell",13553,45.6216667,-94.2066667 ],
    [ u"us",u"Sauk Rapids",12321,45.5919444,-94.1658333 ],
    [ u"us",u"Savage",27096,44.7791667,-93.3361111 ],
    [ u"us",u"Shakopee",30384,44.7980556,-93.5266667 ],
    [ u"us",u"Shoreview",27622,45.0791667,-93.1469444 ],
    [ u"us",u"South Saint Paul",19338,44.8927778,-93.0347222 ],
    [ u"us",u"Stillwater",17746,45.0563889,-92.8058333 ],
    [ u"us",u"Vadnais Heights",13003,45.0575000,-93.0736111 ],
    [ u"us",u"Waconia",8808,44.8508333,-93.7866667 ],
    [ u"us",u"Waseca",9541,44.0777778,-93.5072222 ],
    [ u"us",u"West Fargo",17590,46.8766667,-96.8722222 ],
    [ u"us",u"West Saint Paul",19195,44.9161111,-93.1013889 ],
    [ u"us",u"White Bear Lake",24301,45.0847222,-93.0097222 ],
    [ u"us",u"Willmar",18473,45.1219444,-95.0430556 ],
    [ u"us",u"Winona",26618,44.0500000,-91.6391667 ],
    [ u"us",u"Woodbury",50955,44.9238889,-92.9591667 ],
    [ u"us",u"Worthington",11274,43.6200000,-95.5961111 ],
    [ u"us",u"Bay Saint Louis",8134,30.3086111,-89.3300000 ],
    [ u"us",u"Biloxi",47661,30.3958333,-88.8852778 ],
    [ u"us",u"Brandon",19239,32.2730556,-89.9858333 ],
    [ u"us",u"Brookhaven",9786,31.5788889,-90.4405556 ],
    [ u"us",u"Canton",12759,32.6125000,-90.0366667 ],
    [ u"us",u"Clarksdale",19143,34.2000000,-90.5708333 ],
    [ u"us",u"Cleveland",12763,33.7438889,-90.7247222 ],
    [ u"us",u"Clinton",24583,32.3413889,-90.3216667 ],
    [ u"us",u"Columbus",24386,33.4955556,-88.4272222 ],
    [ u"us",u"Corinth",14168,34.9341667,-88.5222222 ],
    [ u"us",u"Gautier",24891,30.3855556,-88.6116667 ],
    [ u"us",u"Greenville",38107,33.4100000,-91.0616667 ],
    [ u"us",u"Greenwood",17162,33.5161111,-90.1794444 ],
    [ u"us",u"Grenada",14558,33.7688889,-89.8083333 ],
    [ u"us",u"Gulfport",71329,30.3672222,-89.0927778 ],
    [ u"us",u"Hattiesburg",48123,31.3269444,-89.2902778 ],
    [ u"us",u"Horn Lake",16036,34.9552778,-90.0347222 ],
    [ u"us",u"Indianola",11201,33.4508333,-90.6550000 ],
    [ u"us",u"Jackson",176696,32.2986111,-90.1847222 ],
    [ u"us",u"Laurel",17891,31.6938889,-89.1305556 ],
    [ u"us",u"Long Beach",16763,30.3502778,-89.1527778 ],
    [ u"us",u"Madison",16786,32.4616667,-90.1152778 ],
    [ u"us",u"Meridian",39437,32.3641667,-88.7036111 ],
    [ u"us",u"Moss Point",14998,30.4113889,-88.5344444 ],
    [ u"us",u"Natchez",17118,31.5602778,-91.4030556 ],
    [ u"us",u"Ocean Springs",17659,30.4111111,-88.8277778 ],
    [ u"us",u"Olive Branch",27748,34.9616667,-89.8294444 ],
    [ u"us",u"Oxford",13348,34.3663889,-89.5191667 ],
    [ u"us",u"Pascagoula",25621,30.3655556,-88.5561111 ],
    [ u"us",u"Pearl",23272,32.2744444,-90.1319444 ],
    [ u"us",u"Picayune",10650,30.5252778,-89.6794444 ],
    [ u"us",u"Ridgeland",22714,32.4283333,-90.1322222 ],
    [ u"us",u"Southaven",38578,34.9888889,-90.0125000 ],
    [ u"us",u"Starkville",22820,33.4502778,-88.8183333 ],
    [ u"us",u"Tupelo",35956,34.2575000,-88.7033333 ],
    [ u"us",u"Vicksburg",25701,32.3525000,-90.8777778 ],
    [ u"us",u"West Point",11674,33.6075000,-88.6502778 ],
    [ u"us",u"Yazoo City",12081,32.8550000,-90.4055556 ],
    [ u"us",u"Affton",20092,38.5505556,-90.3330556 ],
    [ u"us",u"Arnold",20203,38.4327778,-90.3775000 ],
    [ u"us",u"Ballwin",30744,38.5950000,-90.5461111 ],
    [ u"us",u"Bellefontaine Neighbors",10668,38.7402778,-90.2263889 ],
    [ u"us",u"Belton",24522,38.8119444,-94.5316667 ],
    [ u"us",u"Berkeley",9688,38.7544444,-90.3311111 ],
    [ u"us",u"Blue Springs",49767,39.0169444,-94.2813889 ],
    [ u"us",u"Bolivar",9901,37.6144444,-93.4102778 ],
    [ u"us",u"Bridgeton",15421,38.7669444,-90.4113889 ],
    [ u"us",u"Cape Girardeau",35904,37.3058333,-89.5180556 ],
    [ u"us",u"Carthage",13047,37.1763889,-94.3100000 ],
    [ u"us",u"Chesterfield",47128,38.6630556,-90.5769444 ],
    [ u"us",u"Clayton",15915,38.6425000,-90.3236111 ],
    [ u"us",u"Clinton",9421,38.3686111,-93.7780556 ],
    [ u"us",u"Columbia",91415,38.9516667,-92.3338889 ],
    [ u"us",u"Crestwood",11771,38.5569444,-90.3816667 ],
    [ u"us",u"Creve Coeur",16695,38.6608333,-90.4225000 ],
    [ u"us",u"Ellisville",9362,38.5925000,-90.5869444 ],
    [ u"us",u"Excelsior Springs",11422,39.3391667,-94.2258333 ],
    [ u"us",u"Farmington",14739,37.7808333,-90.4216667 ],
    [ u"us",u"Ferguson",21519,38.7441667,-90.3052778 ],
    [ u"us",u"Festus",10205,38.2205556,-90.3958333 ],
    [ u"us",u"Florissant",51786,38.7891667,-90.3225000 ],
    [ u"us",u"Fulton",11936,38.8466667,-91.9477778 ],
    [ u"us",u"Gladstone",27601,39.2038889,-94.5544444 ],
    [ u"us",u"Grandview",24945,38.8858333,-94.5327778 ],
    [ u"us",u"Hannibal",17568,39.7083333,-91.3583333 ],
    [ u"us",u"Harrisonville",9722,38.6533333,-94.3486111 ],
    [ u"us",u"Hazelwood",25661,38.7713889,-90.3708333 ],
    [ u"us",u"Independence",110675,39.0911111,-94.4152778 ],
    [ u"us",u"Jackson",12835,37.3822222,-89.6661111 ],
    [ u"us",u"Jefferson City",35883,38.5766667,-92.1733333 ],
    [ u"us",u"Jennings",14895,38.7191667,-90.2602778 ],
    [ u"us",u"Joplin",46818,37.0841667,-94.5130556 ],
    [ u"us",u"Kansas City",442028,39.0997222,-94.5783333 ],
    [ u"us",u"Kennett",10926,36.2361111,-90.0555556 ],
    [ u"us",u"Kirksville",16973,40.1947222,-92.5830556 ],
    [ u"us",u"Kirkwood",27126,38.5833333,-90.4066667 ],
    [ u"us",u"Lake Saint Louis",14525,38.7975000,-90.7855556 ],
    [ u"us",u"Lebanon",13007,37.6805556,-92.6636111 ],
    [ u"us",u"Lemay",16706,38.5333333,-90.2791667 ],
    [ u"us",u"Liberty",29027,39.2461111,-94.4188889 ],
    [ u"us",u"Manchester",19235,38.5969444,-90.5091667 ],
    [ u"us",u"Maplewood",8775,38.6125000,-90.3244444 ],
    [ u"us",u"Marshall",11813,39.1230556,-93.1966667 ],
    [ u"us",u"Maryland Heights",25311,38.7130556,-90.4297222 ],
    [ u"us",u"Maryville",10670,40.3461111,-94.8722222 ],
    [ u"us",u"Mehlville",29175,38.5083333,-90.3227778 ],
    [ u"us",u"Mexico",10788,39.1697222,-91.8827778 ],
    [ u"us",u"Moberly",13849,39.4183333,-92.4380556 ],
    [ u"us",u"Murphy",8834,38.4902778,-90.4869444 ],
    [ u"us",u"Neosho",10890,36.8688889,-94.3677778 ],
    [ u"us",u"Nixa",14973,37.0433333,-93.2941667 ],
    [ u"us",u"Oakville",36787,38.4700000,-90.3044444 ],
    [ u"us",u"Overland",16130,38.7011111,-90.3622222 ],
    [ u"us",u"Ozark",15951,37.0208333,-93.2058333 ],
    [ u"us",u"Poplar Bluff",16488,36.7569444,-90.3927778 ],
    [ u"us",u"Raymore",14620,38.8019444,-94.4525000 ],
    [ u"us",u"Raytown",29219,39.0086111,-94.4633333 ],
    [ u"us",u"Republic",10423,37.1200000,-93.4800000 ],
    [ u"us",u"Richmond Heights",9312,38.6286111,-90.3194444 ],
    [ u"us",u"Rolla",17865,37.9513889,-91.7711111 ],
    [ u"us",u"Saint Ann",13205,38.7272222,-90.3830556 ],
    [ u"us",u"Saint Charles",62011,38.7838889,-90.4811111 ],
    [ u"us",u"Saint Joseph",71745,39.7686111,-94.8463889 ],
    [ u"us",u"Saint Louis",320916,38.6272222,-90.1977778 ],
    [ u"us",u"Saint Peters",53779,38.8002778,-90.6263889 ],
    [ u"us",u"Sappington",6426,38.5369444,-90.3797222 ],
    [ u"us",u"Sedalia",19772,38.7044444,-93.2280556 ],
    [ u"us",u"Sikeston",17026,36.8766667,-89.5877778 ],
    [ u"us",u"Spanish Lake",21637,38.7877778,-90.2158333 ],
    [ u"us",u"Springfield",150443,37.2152778,-93.2980556 ],
    [ u"us",u"Town and Country",10818,38.6122222,-90.4633333 ],
    [ u"us",u"University City",37634,38.6666667,-90.3208333 ],
    [ u"us",u"Warrensburg",17431,38.7627778,-93.7358333 ],
    [ u"us",u"Washington",13890,38.5580556,-91.0119444 ],
    [ u"us",u"Webb City",10503,37.1463889,-94.4627778 ],
    [ u"us",u"Webster Groves",22875,38.5925000,-90.3572222 ],
    [ u"us",u"Wentzville",17610,38.8113889,-90.8527778 ],
    [ u"us",u"West Plains",11050,36.7280556,-91.8522222 ],
    [ u"us",u"Wildwood",35007,38.5827778,-90.6627778 ],
    [ u"us",u"Anaconda",8693,46.1286111,-112.9413889 ],
    [ u"us",u"Belgrade",7452,45.7761111,-111.1761111 ],
    [ u"us",u"Billings",99751,45.7833333,-108.5000000 ],
    [ u"us",u"Bozeman",33178,45.6797222,-111.0377778 ],
    [ u"us",u"Butte",31056,46.0038889,-112.5338889 ],
    [ u"us",u"Dillon",3964,45.2163889,-112.6366667 ],
    [ u"us",u"Glendive",4699,47.1052778,-104.7119444 ],
    [ u"us",u"Great Falls",56075,47.5002778,-111.3000000 ],
    [ u"us",u"Hamilton",4528,46.2469444,-114.1594444 ],
    [ u"us",u"Havre",9379,48.5500000,-109.6833333 ],
    [ u"us",u"Helena",27340,46.5927778,-112.0352778 ],
    [ u"us",u"Kalispell",18018,48.1958333,-114.3119444 ],
    [ u"us",u"Laurel",6334,45.6691667,-108.7708333 ],
    [ u"us",u"Lewistown",5918,47.0625000,-109.4275000 ],
    [ u"us",u"Livingston",7155,45.6625000,-110.5602778 ],
    [ u"us",u"Miles City",8184,46.4083333,-105.8400000 ],
    [ u"us",u"Missoula",63164,46.8722222,-113.9930556 ],
    [ u"us",u"Orchard Homes",4897,46.8633333,-114.0475000 ],
    [ u"us",u"Polson",4832,47.6936111,-114.1622222 ],
    [ u"us",u"Sidney",4373,47.7166667,-104.1558333 ],
    [ u"us",u"Whitefish",6338,48.4111111,-114.3366667 ],
    [ u"us",u"Beatrice",13198,40.2680556,-96.7466667 ],
    [ u"us",u"Bellevue",48099,41.1366667,-95.8905556 ],
    [ u"us",u"Columbus",20823,41.4297222,-97.3680556 ],
    [ u"us",u"Fremont",25197,41.4333333,-96.4977778 ],
    [ u"us",u"Grand Island",44766,40.9250000,-98.3416667 ],
    [ u"us",u"Hastings",23001,40.5861111,-98.3880556 ],
    [ u"us",u"Kearney",28758,40.6994444,-99.0811111 ],
    [ u"us",u"La Vista",15695,41.1838889,-96.0308333 ],
    [ u"us",u"Lexington",10169,40.7808333,-99.7411111 ],
    [ u"us",u"Lincoln",242072,40.8000000,-96.6666667 ],
    [ u"us",u"Norfolk",24094,42.0283333,-97.4166667 ],
    [ u"us",u"North Platte",24172,41.1238889,-100.7650000 ],
    [ u"us",u"Omaha",413487,41.2586111,-95.9375000 ],
    [ u"us",u"Papillion",18755,41.1544444,-96.0419444 ],
    [ u"us",u"Scottsbluff",14869,41.8666667,-103.6666667 ],
    [ u"us",u"South Sioux City",12135,42.4738889,-96.4133333 ],
    [ u"us",u"Boulder City",15479,35.9786111,-114.8316667 ],
    [ u"us",u"Carson City",57341,39.1638889,-119.7663889 ],
    [ u"us",u"Elko",15822,40.8325000,-115.7622222 ],
    [ u"us",u"Fallon",8126,39.4736111,-118.7763889 ],
    [ u"us",u"Fernley",11974,39.6080556,-119.2508333 ],
    [ u"us",u"Henderson",239757,36.0397222,-114.9811111 ],
    [ u"us",u"Las Vegas",540111,36.1750000,-115.1363889 ],
    [ u"us",u"North Las Vegas",165416,36.1988889,-115.1166667 ],
    [ u"us",u"Pahrump",40349,36.2083333,-115.9830556 ],
    [ u"us",u"Paradise",215120,36.0972222,-115.1458333 ],
    [ u"us",u"Reno",202142,39.5297222,-119.8127778 ],
    [ u"us",u"Sparks",84662,39.5350000,-119.7516667 ],
    [ u"us",u"Spring Valley",165015,36.1080556,-115.2441667 ],
    [ u"us",u"Sun Valley",24009,39.5963889,-119.7750000 ],
    [ u"us",u"Sunrise Manor",188608,36.2111111,-115.0722222 ],
    [ u"us",u"West Wendover",4953,40.7391667,-114.0725000 ],
    [ u"us",u"Winchester",30743,36.1300000,-115.1180556 ],
    [ u"us",u"Winnemucca",6329,40.9730556,-117.7347222 ],
    [ u"us",u"Alton",5068,43.4522222,-71.2180556 ],
    [ u"us",u"Amherst",11723,42.8613889,-71.6258333 ],
    [ u"us",u"Atkinson",6782,42.8383333,-71.1475000 ],
    [ u"us",u"Auburn",5089,43.0044444,-71.3488889 ],
    [ u"us",u"Barnstead",4572,43.3338889,-71.2933333 ],
    [ u"us",u"Barrington",8417,43.2227778,-71.0475000 ],
    [ u"us",u"Bedford",21188,42.9463889,-71.5163889 ],
    [ u"us",u"Belmont",7516,43.4452778,-71.4783333 ],
    [ u"us",u"Berlin",9953,44.4686111,-71.1855556 ],
    [ u"us",u"Brookline",4650,42.7347222,-71.6586111 ],
    [ u"us",u"Candia",4405,43.0777778,-71.2772222 ],
    [ u"us",u"Charlestown",7726,43.2386111,-72.4250000 ],
    [ u"us",u"Chester",5236,42.9566667,-71.2577778 ],
    [ u"us",u"Claremont",13562,43.3766667,-72.3472222 ],
    [ u"us",u"Concord",42605,43.2080556,-71.5380556 ],
    [ u"us",u"Conway",9257,43.9791667,-71.1208333 ],
    [ u"us",u"Danville",4537,42.9125000,-71.1250000 ],
    [ u"us",u"Derry",34539,42.8805556,-71.3277778 ],
    [ u"us",u"Dover",29061,43.1977778,-70.8741667 ],
    [ u"us",u"Durham",13435,43.1338889,-70.9269444 ],
    [ u"us",u"Enfield",4969,43.6405556,-72.1444444 ],
    [ u"us",u"Epping",6251,43.0333333,-71.0747222 ],
    [ u"us",u"Epsom",4590,43.2227778,-71.3325000 ],
    [ u"us",u"Exeter",14750,42.9813889,-70.9483333 ],
    [ u"us",u"Farmington",6444,43.3897222,-71.0655556 ],
    [ u"us",u"Franklin",8729,43.4441667,-71.6477778 ],
    [ u"us",u"Gilford",7849,43.5475000,-71.4072222 ],
    [ u"us",u"Goffstown",17602,43.0202778,-71.6008333 ],
    [ u"us",u"Hampstead",8650,42.8744444,-71.1816667 ],
    [ u"us",u"Hampton",15514,42.9375000,-70.8394444 ],
    [ u"us",u"Hanover",11222,43.7022222,-72.2900000 ],
    [ u"us",u"Haverhill",4532,44.0344444,-72.0644444 ],
    [ u"us",u"Henniker",4961,43.1797222,-71.8227778 ],
    [ u"us",u"Hillsborough",5176,43.1141667,-71.8997222 ],
    [ u"us",u"Hollis",7711,42.7430556,-71.5922222 ],
    [ u"us",u"Hooksett",13575,43.0966667,-71.4655556 ],
    [ u"us",u"Hopkinton",5676,43.1913889,-71.6758333 ],
    [ u"us",u"Hudson",24474,42.7647222,-71.4402778 ],
    [ u"us",u"Jaffrey",5784,42.8138889,-72.0236111 ],
    [ u"us",u"Keene",22891,42.9336111,-72.2786111 ],
    [ u"us",u"Kingston",6225,42.9363889,-71.0538889 ],
    [ u"us",u"Laconia",17533,43.5277778,-71.4708333 ],
    [ u"us",u"Lebanon",12853,43.6422222,-72.2522222 ],
    [ u"us",u"Lee",4500,43.1230556,-71.0119444 ],
    [ u"us",u"Litchfield",8307,42.8441667,-71.4802778 ],
    [ u"us",u"Littleton",6296,44.3061111,-71.7705556 ],
    [ u"us",u"Londonderry",24474,42.8650000,-71.3744444 ],
    [ u"us",u"Loudon",5199,43.2855556,-71.4677778 ],
    [ u"us",u"Manchester",109877,42.9955556,-71.4552778 ],
    [ u"us",u"Meredith",6593,43.6575000,-71.5008333 ],
    [ u"us",u"Merrimack",26726,42.8650000,-71.4938889 ],
    [ u"us",u"Milford",14661,42.8352778,-71.6494444 ],
    [ u"us",u"Milton",4472,43.4097222,-70.9888889 ],
    [ u"us",u"Moultonborough",5034,43.7547222,-71.3972222 ],
    [ u"us",u"Nashua",87039,42.7652778,-71.4680556 ],
    [ u"us",u"New Boston",4934,42.9761111,-71.6944444 ],
    [ u"us",u"New Ipswich",5283,42.7480556,-71.8547222 ],
    [ u"us",u"New London",4369,43.4138889,-71.9855556 ],
    [ u"us",u"Newmarket",8931,43.0827778,-70.9355556 ],
    [ u"us",u"Newport",6593,43.3652778,-72.1738889 ],
    [ u"us",u"Newton",4513,42.8694444,-71.0350000 ],
    [ u"us",u"North Hampton",4721,42.9725000,-70.8302778 ],
    [ u"us",u"Northfield",5049,43.4330556,-71.5927778 ],
    [ u"us",u"Ossipee",4655,43.6852778,-71.1172222 ],
    [ u"us",u"Pelham",12676,42.7344444,-71.3250000 ],
    [ u"us",u"Pembroke",7461,43.1466667,-71.4580556 ],
    [ u"us",u"Peterborough",6021,42.8705556,-71.9522222 ],
    [ u"us",u"Pittsfield",4515,43.3058333,-71.3247222 ],
    [ u"us",u"Plaistow",7885,42.8363889,-71.0952778 ],
    [ u"us",u"Plymouth",6236,43.7569444,-71.6886111 ],
    [ u"us",u"Portsmouth",20954,43.0716667,-70.7630556 ],
    [ u"us",u"Raymond",10241,43.0361111,-71.1838889 ],
    [ u"us",u"Rindge",6049,42.7511111,-72.0102778 ],
    [ u"us",u"Rochester",30317,43.3044444,-70.9761111 ],
    [ u"us",u"Rye",5277,43.0133333,-70.7713889 ],
    [ u"us",u"Salem",29549,42.7883333,-71.2013889 ],
    [ u"us",u"Sandown",5827,42.9286111,-71.1875000 ],
    [ u"us",u"Seabrook",8679,42.8947222,-70.8716667 ],
    [ u"us",u"Somersworth",11897,43.2616667,-70.8658333 ],
    [ u"us",u"Stratham",6949,43.0238889,-70.9141667 ],
    [ u"us",u"Swanzey",7224,42.8697222,-72.2822222 ],
    [ u"us",u"Wakefield",4705,43.5680556,-71.0305556 ],
    [ u"us",u"Weare",8583,43.0947222,-71.7311111 ],
    [ u"us",u"Windham",13091,42.8005556,-71.3047222 ],
    [ u"us",u"Wolfeboro",6715,43.5838889,-71.2077778 ],
    [ u"us",u"Asbury Park",16507,40.2202778,-74.0125000 ],
    [ u"us",u"Atlantic City",40554,39.3641667,-74.4233333 ],
    [ u"us",u"Audubon",9069,39.8908333,-75.0733333 ],
    [ u"us",u"Avenel",18664,40.5802778,-74.2855556 ],
    [ u"us",u"Bayonne",59878,40.6686111,-74.1147222 ],
    [ u"us",u"Beachwood",10899,39.9388889,-74.1933333 ],
    [ u"us",u"Belleville",36878,40.7936111,-74.1505556 ],
    [ u"us",u"Bellmawr",11234,39.8675000,-75.0950000 ],
    [ u"us",u"Bergenfield",26120,40.9275000,-73.9977778 ],
    [ u"us",u"Berkeley Heights",14179,40.6833333,-74.4430556 ],
    [ u"us",u"Bloomfield",49120,40.8066667,-74.1858333 ],
    [ u"us",u"Bound Brook",10102,40.5683333,-74.5388889 ],
    [ u"us",u"Bridgeton",22945,39.4272222,-75.2344444 ],
    [ u"us",u"Brigantine",12670,39.4100000,-74.3650000 ],
    [ u"us",u"Burlington",9847,40.0711111,-74.8652778 ],
    [ u"us",u"Camden",80412,39.9258333,-75.1200000 ],
    [ u"us",u"Carteret",21944,40.5772222,-74.2286111 ],
    [ u"us",u"Cedar Grove",12457,40.8516667,-74.2294444 ],
    [ u"us",u"Cherry Hill",70475,39.9347222,-75.0311111 ],
    [ u"us",u"Cinnaminson",14646,39.9966667,-74.9930556 ],
    [ u"us",u"Clark",14628,40.6408333,-74.3111111 ],
    [ u"us",u"Cliffside Park",22801,40.8213889,-73.9880556 ],
    [ u"us",u"Clifton",80245,40.8583333,-74.1641667 ],
    [ u"us",u"Collingswood",14125,39.9180556,-75.0716667 ],
    [ u"us",u"Colonia",17669,40.5744444,-74.3025000 ],
    [ u"us",u"Cranford",22627,40.6583333,-74.3000000 ],
    [ u"us",u"Dover",18717,40.8838889,-74.5625000 ],
    [ u"us",u"Dumont",17505,40.9405556,-73.9972222 ],
    [ u"us",u"East Brunswick",48495,40.4277778,-74.4163889 ],
    [ u"us",u"East Hanover",12194,40.8200000,-74.3652778 ],
    [ u"us",u"East Orange",68390,40.7672222,-74.2052778 ],
    [ u"us",u"Eatontown",14185,40.2961111,-74.0513889 ],
    [ u"us",u"Edgewater",9875,40.8269444,-73.9761111 ],
    [ u"us",u"Edison",102548,40.5186111,-74.4125000 ],
    [ u"us",u"Elizabeth",123913,40.6638889,-74.2111111 ],
    [ u"us",u"Elmwood Park",18973,40.9038889,-74.1188889 ],
    [ u"us",u"Englewood",26012,40.8927778,-73.9730556 ],
    [ u"us",u"Ewing",36559,40.2697222,-74.8002778 ],
    [ u"us",u"Fair Lawn",31503,40.9402778,-74.1322222 ],
    [ u"us",u"Fairview",13446,40.8125000,-73.9994444 ],
    [ u"us",u"Florham Park",13534,40.7877778,-74.3886111 ],
    [ u"us",u"Fords",15391,40.5291667,-74.3163889 ],
    [ u"us",u"Fort Dix",6868,40.0297222,-74.6188889 ],
    [ u"us",u"Fort Lee",37839,40.8508333,-73.9705556 ],
    [ u"us",u"Franklin Lakes",11445,41.0166667,-74.2061111 ],
    [ u"us",u"Freehold",11558,40.2600000,-74.2741667 ],
    [ u"us",u"Garfield",29614,40.8813889,-74.1136111 ],
    [ u"us",u"Glassboro",19166,39.7027778,-75.1122222 ],
    [ u"us",u"Glen Rock",11459,40.9627778,-74.1333333 ],
    [ u"us",u"Gloucester City",11377,39.8916667,-75.1166667 ],
    [ u"us",u"Guttenberg",11086,40.7919444,-74.0041667 ],
    [ u"us",u"Hackensack",43716,40.8858333,-74.0438889 ],
    [ u"us",u"Hackettstown",8264,40.8538889,-74.8294444 ],
    [ u"us",u"Haddonfield",11568,39.8913889,-75.0380556 ],
    [ u"us",u"Hammonton",13261,39.6363889,-74.8027778 ],
    [ u"us",u"Harrison",14094,40.7463889,-74.1566667 ],
    [ u"us",u"Hasbrouck Heights",11608,40.8580556,-74.0811111 ],
    [ u"us",u"Hawthorne",18413,40.9491667,-74.1541667 ],
    [ u"us",u"Highland Park",14275,40.4958333,-74.4247222 ],
    [ u"us",u"Hillsdale",10075,41.0025000,-74.0408333 ],
    [ u"us",u"Hillside",22155,40.7011111,-74.2305556 ],
    [ u"us",u"Hoboken",39738,40.7438889,-74.0327778 ],
    [ u"us",u"Hopatcong",16267,40.9327778,-74.6597222 ],
    [ u"us",u"Irvington",61323,40.7322222,-74.2352778 ],
    [ u"us",u"Iselin",17019,40.5752778,-74.3227778 ],
    [ u"us",u"Jersey City",237681,40.7280556,-74.0780556 ],
    [ u"us",u"Keansburg",10631,40.4416667,-74.1302778 ],
    [ u"us",u"Kearny",39234,40.7683333,-74.1458333 ],
    [ u"us",u"Kinnelon",9536,41.0016667,-74.3675000 ],
    [ u"us",u"Lakewood",42120,40.0977778,-74.2180556 ],
    [ u"us",u"Lincoln Park",10845,40.9241667,-74.3025000 ],
    [ u"us",u"Linden",39878,40.6219444,-74.2450000 ],
    [ u"us",u"Lindenwold",17320,39.8241667,-74.9980556 ],
    [ u"us",u"Little Falls",10688,40.8688889,-74.2086111 ],
    [ u"us",u"Little Ferry",10790,40.8527778,-74.0425000 ],
    [ u"us",u"Livingston",27853,40.7958333,-74.3152778 ],
    [ u"us",u"Lodi",24278,40.8822222,-74.0836111 ],
    [ u"us",u"Long Branch",31524,40.3041667,-73.9927778 ],
    [ u"us",u"Lyndhurst",19996,40.8119444,-74.1247222 ],
    [ u"us",u"Madison",15299,40.7597222,-74.4175000 ],
    [ u"us",u"Manville",10357,40.5408333,-74.5880556 ],
    [ u"us",u"Maple Shade",19077,39.9525000,-74.9927778 ],
    [ u"us",u"Maplewood",25008,40.7738889,-74.2738889 ],
    [ u"us",u"Marlton",10307,39.8911111,-74.9222222 ],
    [ u"us",u"Maywood",9460,40.9025000,-74.0622222 ],
    [ u"us",u"Metuchen",13467,40.5430556,-74.3636111 ],
    [ u"us",u"Middlesex",14084,40.5725000,-74.4930556 ],
    [ u"us",u"Millburn",20386,40.7394444,-74.3044444 ],
    [ u"us",u"Millville",27390,39.4019444,-75.0397222 ],
    [ u"us",u"Montclair",39701,40.8258333,-74.2094444 ],
    [ u"us",u"Morristown",18886,40.7966667,-74.4819444 ],
    [ u"us",u"Mount Holly",10804,39.9927778,-74.7880556 ],
    [ u"us",u"New Brunswick",50633,40.4861111,-74.4522222 ],
    [ u"us",u"New Milford",16326,40.9350000,-74.0194444 ],
    [ u"us",u"New Providence",11935,40.6983333,-74.4019444 ],
    [ u"us",u"Newark",280123,40.7355556,-74.1727778 ],
    [ u"us",u"North Arlington",15205,40.7883333,-74.1336111 ],
    [ u"us",u"North Bergen",63484,40.8041667,-74.0125000 ],
    [ u"us",u"North Plainfield",20991,40.6300000,-74.4277778 ],
    [ u"us",u"Nutley",27572,40.8222222,-74.1602778 ],
    [ u"us",u"Oakland",14318,41.0130556,-74.2647222 ],
    [ u"us",u"Ocean City",15637,39.2775000,-74.5750000 ],
    [ u"us",u"Old Bridge",23233,40.4147222,-74.3658333 ],
    [ u"us",u"Orange",34457,40.7705556,-74.2330556 ],
    [ u"us",u"Palisades Park",18513,40.8480556,-73.9980556 ],
    [ u"us",u"Paramus",26947,40.9444444,-74.0758333 ],
    [ u"us",u"Passaic",68845,40.8566667,-74.1288889 ],
    [ u"us",u"Paterson",151205,40.9166667,-74.1722222 ],
    [ u"us",u"Pennsauken",36332,39.9561111,-75.0583333 ],
    [ u"us",u"Pennsville",11438,39.6533333,-75.5169444 ],
    [ u"us",u"Perth Amboy",49107,40.5066667,-74.2658333 ],
    [ u"us",u"Phillipsburg",15091,40.6936111,-75.1905556 ],
    [ u"us",u"Pine Hill",11306,39.7841667,-74.9925000 ],
    [ u"us",u"Pitman",9257,39.7327778,-75.1319444 ],
    [ u"us",u"Plainfield",47795,40.6336111,-74.4077778 ],
    [ u"us",u"Pleasantville",19039,39.3897222,-74.5244444 ],
    [ u"us",u"Point Pleasant",20156,40.0830556,-74.0686111 ],
    [ u"us",u"Pompton Lakes",11405,41.0052778,-74.2911111 ],
    [ u"us",u"Princeton",12945,40.3486111,-74.6594444 ],
    [ u"us",u"Rahway",26713,40.6080556,-74.2780556 ],
    [ u"us",u"Ramsey",14520,41.0572222,-74.1413889 ],
    [ u"us",u"Red Bank",11730,40.3469444,-74.0647222 ],
    [ u"us",u"Ridgefield",10932,40.8341667,-74.0091667 ],
    [ u"us",u"Ridgefield Park",12704,40.8569444,-74.0219444 ],
    [ u"us",u"Ridgewood",24738,40.9791667,-74.1169444 ],
    [ u"us",u"Ringwood",12862,41.1133333,-74.2458333 ],
    [ u"us",u"River Edge",10970,40.9286111,-74.0402778 ],
    [ u"us",u"Roselle",21337,40.6641667,-74.2636111 ],
    [ u"us",u"Roselle Park",13231,40.6644444,-74.2647222 ],
    [ u"us",u"Rutherford",17952,40.8263889,-74.1072222 ],
    [ u"us",u"Saddle Brook",13130,40.8988889,-74.0930556 ],
    [ u"us",u"Sayreville",42890,40.4591667,-74.3613889 ],
    [ u"us",u"Scotch Plains",23584,40.6552778,-74.3902778 ],
    [ u"us",u"Secaucus",15534,40.7894444,-74.0569444 ],
    [ u"us",u"Somers Point",11698,39.3175000,-74.5950000 ],
    [ u"us",u"Somerset",23584,40.4975000,-74.4888889 ],
    [ u"us",u"Somerville",12308,40.5741667,-74.6102778 ],
    [ u"us",u"South Orange",17295,40.7488889,-74.2616667 ],
    [ u"us",u"South Plainfield",23373,40.5791667,-74.4119444 ],
    [ u"us",u"South River",16480,40.4463889,-74.3863889 ],
    [ u"us",u"Springfield",14976,40.7230556,-74.3111111 ],
    [ u"us",u"Summit",21219,40.7413889,-74.3600000 ],
    [ u"us",u"Teaneck",40078,40.8975000,-74.0163889 ],
    [ u"us",u"Tenafly",14335,40.9252778,-73.9633333 ],
    [ u"us",u"Tinton Falls",16549,40.3041667,-74.1008333 ],
    [ u"us",u"Toms River",119088,39.9536111,-74.1983333 ],
    [ u"us",u"Totowa",10078,40.9050000,-74.2102778 ],
    [ u"us",u"Trenton",84833,40.2169444,-74.7433333 ],
    [ u"us",u"Union",56771,40.6975000,-74.2636111 ],
    [ u"us",u"Union City",66121,40.7794444,-74.0241667 ],
    [ u"us",u"Ventnor City",12699,39.3402778,-74.4777778 ],
    [ u"us",u"Verona",13545,40.8297222,-74.2405556 ],
    [ u"us",u"Vineland",58122,39.4861111,-75.0261111 ],
    [ u"us",u"Waldwick",9608,41.0105556,-74.1183333 ],
    [ u"us",u"Wallington",11469,40.8530556,-74.1141667 ],
    [ u"us",u"Wanaque",10512,41.0380556,-74.2944444 ],
    [ u"us",u"Wayne",57915,40.9252778,-74.2769444 ],
    [ u"us",u"Weehawken",14104,40.7694444,-74.0208333 ],
    [ u"us",u"West Caldwell",11672,40.8408333,-74.3022222 ],
    [ u"us",u"West Freehold",13219,40.2419444,-74.3016667 ],
    [ u"us",u"West Milford",26968,41.1311111,-74.3677778 ],
    [ u"us",u"West New York",46010,40.7877778,-74.0147222 ],
    [ u"us",u"West Orange",48131,40.7986111,-74.2394444 ],
    [ u"us",u"West Paterson",11380,40.8897222,-74.1952778 ],
    [ u"us",u"Westfield",29940,40.6588889,-74.3477778 ],
    [ u"us",u"Westwood",11002,40.9911111,-74.0330556 ],
    [ u"us",u"Williamstown",12310,39.6861111,-74.9955556 ],
    [ u"us",u"Willingboro",31668,40.0277778,-74.8694444 ],
    [ u"us",u"Woodbridge",18794,40.5575000,-74.2850000 ],
    [ u"us",u"Woodbury",10462,39.8380556,-75.1530556 ],
    [ u"us",u"Wyckoff",17124,41.0094444,-74.1733333 ],
    [ u"us",u"Alamogordo",36058,32.8994444,-105.9597222 ],
    [ u"us",u"Albuquerque",487378,35.0844444,-106.6505556 ],
    [ u"us",u"Artesia",10500,32.8422222,-104.4027778 ],
    [ u"us",u"Aztec",7001,36.8222222,-107.9922222 ],
    [ u"us",u"Belen",6893,34.6627778,-106.7758333 ],
    [ u"us",u"Bernalillo",7159,35.3000000,-106.5505556 ],
    [ u"us",u"Bloomfield",7469,36.7111111,-107.9838889 ],
    [ u"us",u"Carlsbad",25302,32.4205556,-104.2283333 ],
    [ u"us",u"Clovis",33163,34.4047222,-103.2047222 ],
    [ u"us",u"Corrales",7678,35.2377778,-106.6061111 ],
    [ u"us",u"Deming",14748,32.2686111,-107.7580556 ],
    [ u"us",u"Espanola",9729,35.9911111,-106.0800000 ],
    [ u"us",u"Farmington",43278,36.7280556,-108.2180556 ],
    [ u"us",u"Gallup",19454,35.5280556,-108.7419444 ],
    [ u"us",u"Grants",9067,35.1472222,-107.8508333 ],
    [ u"us",u"Hobbs",28013,32.7025000,-103.1355556 ],
    [ u"us",u"Las Cruces",80184,32.3122222,-106.7777778 ],
    [ u"us",u"Las Vegas",14044,35.5938889,-105.2233333 ],
    [ u"us",u"Los Alamos",11761,35.8880556,-106.3063889 ],
    [ u"us",u"Los Lunas",12115,34.8061111,-106.7327778 ],
    [ u"us",u"Los Ranchos de Albuquerque",5184,35.1619444,-106.6422222 ],
    [ u"us",u"Lovington",9417,32.9438889,-103.3480556 ],
    [ u"us",u"North Valley",11305,35.1733333,-106.6227778 ],
    [ u"us",u"Portales",11035,34.1861111,-103.3338889 ],
    [ u"us",u"Raton",7073,36.9033333,-104.4386111 ],
    [ u"us",u"Rio Rancho",64090,35.2333333,-106.6638889 ],
    [ u"us",u"Roswell",44069,33.3941667,-104.5225000 ],
    [ u"us",u"Ruidoso",8757,33.3316667,-105.6725000 ],
    [ u"us",u"Santa Fe",69205,35.6869444,-105.9372222 ],
    [ u"us",u"Silver City",9745,32.7700000,-108.2797222 ],
    [ u"us",u"Socorro",8668,34.0583333,-106.8908333 ],
    [ u"us",u"South Valley",39508,35.0100000,-106.6775000 ],
    [ u"us",u"Sunland Park",14251,31.7963889,-106.5794444 ],
    [ u"us",u"Taos",5197,36.4072222,-105.5725000 ],
    [ u"us",u"Truth or Consequences",7121,33.1283333,-107.2522222 ],
    [ u"us",u"Tucumcari",5313,35.1716667,-103.7244444 ],
    [ u"us",u"Albany",93794,42.6525000,-73.7566667 ],
    [ u"us",u"Amityville",9566,40.6788889,-73.4175000 ],
    [ u"us",u"Amsterdam",17735,42.9386111,-74.1886111 ],
    [ u"us",u"Arlington",12640,41.6958333,-73.8972222 ],
    [ u"us",u"Auburn",27873,42.9316667,-76.5663889 ],
    [ u"us",u"Babylon",12839,40.6955556,-73.3261111 ],
    [ u"us",u"Baldwin",23622,40.6563889,-73.6097222 ],
    [ u"us",u"Batavia",15831,42.9980556,-78.1877778 ],
    [ u"us",u"Bay Shore",24969,40.7250000,-73.2458333 ],
    [ u"us",u"Beacon",18644,41.5047222,-73.9700000 ],
    [ u"us",u"Bellmore",16313,40.6686111,-73.5275000 ],
    [ u"us",u"Bethpage",16791,40.7441667,-73.4825000 ],
    [ u"us",u"Binghamton",45480,42.0986111,-75.9183333 ],
    [ u"us",u"Bohemia",9944,40.7691667,-73.1155556 ],
    [ u"us",u"Brentwood",58107,40.7811111,-73.2466667 ],
    [ u"us",u"Brighton",35844,43.1475000,-77.5508333 ],
    [ u"us",u"Buffalo",279557,42.8863889,-78.8786111 ],
    [ u"us",u"Canandaigua",11655,42.8741667,-77.2883333 ],
    [ u"us",u"Centereach",27338,40.8583333,-73.1000000 ],
    [ u"us",u"Central Islip",34907,40.7905556,-73.2022222 ],
    [ u"us",u"Cheektowaga",77387,42.9033333,-78.7550000 ],
    [ u"us",u"Cohoes",15183,42.7741667,-73.7005556 ],
    [ u"us",u"Commack",36195,40.8427778,-73.2933333 ],
    [ u"us",u"Copiague",22309,40.6813889,-73.4002778 ],
    [ u"us",u"Coram",37150,40.8686111,-73.0019444 ],
    [ u"us",u"Corning",10451,42.1427778,-77.0550000 ],
    [ u"us",u"Cortland",18017,42.6011111,-76.1808333 ],
    [ u"us",u"Deer Park",27853,40.7616667,-73.3297222 ],
    [ u"us",u"Depew",15892,42.9038889,-78.6925000 ],
    [ u"us",u"Dix Hills",25902,40.8047222,-73.3366667 ],
    [ u"us",u"Dobbs Ferry",11249,41.0144444,-73.8730556 ],
    [ u"us",u"Dunkirk",12451,42.4794444,-79.3341667 ],
    [ u"us",u"East Islip",13854,40.7319444,-73.1861111 ],
    [ u"us",u"East Massapequa",19418,40.6733333,-73.4369444 ],
    [ u"us",u"East Meadow",37427,40.7138889,-73.5594444 ],
    [ u"us",u"East Northport",20887,40.8766667,-73.3250000 ],
    [ u"us",u"East Patchogue",20961,40.7669444,-72.9966667 ],
    [ u"us",u"East Rockaway",10268,40.6419444,-73.6700000 ],
    [ u"us",u"Eastchester",18431,40.8883333,-73.8286111 ],
    [ u"us",u"Elmira",30026,42.0897222,-76.8080556 ],
    [ u"us",u"Elmont",34479,40.7008333,-73.7133333 ],
    [ u"us",u"Elwood",10830,40.8452778,-73.3355556 ],
    [ u"us",u"Endicott",12802,42.0983333,-76.0497222 ],
    [ u"us",u"Endwell",11219,42.1127778,-76.0213889 ],
    [ u"us",u"Fairmount",10086,43.0472222,-76.2388889 ],
    [ u"us",u"Farmingville",17142,40.8311111,-73.0300000 ],
    [ u"us",u"Floral Park",15702,40.7236111,-73.7052778 ],
    [ u"us",u"Franklin Square",29658,40.7072222,-73.6763889 ],
    [ u"us",u"Fredonia",10440,42.4400000,-79.3319444 ],
    [ u"us",u"Freeport",43447,40.6575000,-73.5836111 ],
    [ u"us",u"Fulton",11513,43.3227778,-76.4175000 ],
    [ u"us",u"Garden City",21887,40.7266667,-73.6347222 ],
    [ u"us",u"Geneva",13429,42.8688889,-76.9780556 ],
    [ u"us",u"Glen Cove",26717,40.8622222,-73.6341667 ],
    [ u"us",u"Glens Falls",14169,43.3094444,-73.6444444 ],
    [ u"us",u"Gloversville",15120,43.0527778,-74.3441667 ],
    [ u"us",u"Great Neck",9628,40.8005556,-73.7288889 ],
    [ u"us",u"Greece",14048,43.2097222,-77.6933333 ],
    [ u"us",u"Hamburg",9656,42.7158333,-78.8297222 ],
    [ u"us",u"Harrison",25643,40.9688889,-73.7130556 ],
    [ u"us",u"Hartsdale",9868,41.0188889,-73.7986111 ],
    [ u"us",u"Hauppauge",20108,40.8255556,-73.2030556 ],
    [ u"us",u"Haverstraw",10114,41.1975000,-73.9650000 ],
    [ u"us",u"Hempstead",52837,40.7061111,-73.6191667 ],
    [ u"us",u"Hicksville",41453,40.7683333,-73.5255556 ],
    [ u"us",u"Holbrook",28407,40.8122222,-73.0788889 ],
    [ u"us",u"Holtsville",17914,40.8152778,-73.0455556 ],
    [ u"us",u"Huntington",18334,40.8680556,-73.4261111 ],
    [ u"us",u"Huntington Station",30484,40.8533333,-73.4119444 ],
    [ u"us",u"Irondequoit",51958,43.2133333,-77.5800000 ],
    [ u"us",u"Islip",21232,40.7297222,-73.2108333 ],
    [ u"us",u"Ithaca",31159,42.4405556,-76.4969444 ],
    [ u"us",u"Jamestown",30077,42.0969444,-79.2355556 ],
    [ u"us",u"Jericho",12898,40.7919444,-73.5402778 ],
    [ u"us",u"Johnson City",15006,42.1155556,-75.9591667 ],
    [ u"us",u"Kenmore",15603,42.9658333,-78.8702778 ],
    [ u"us",u"Kings Park",15313,40.8861111,-73.2577778 ],
    [ u"us",u"Kingston",23174,41.9269444,-73.9977778 ],
    [ u"us",u"Kiryas Joel",19382,41.3419444,-74.1683333 ],
    [ u"us",u"Lackawanna",18293,42.8255556,-78.8236111 ],
    [ u"us",u"Lake Grove",10715,40.8527778,-73.1155556 ],
    [ u"us",u"Lake Ronkonkoma",19884,40.8350000,-73.1316667 ],
    [ u"us",u"Lancaster",11846,42.9005556,-78.6705556 ],
    [ u"us",u"Levittown",52548,40.7258333,-73.5147222 ],
    [ u"us",u"Lindenhurst",29081,40.6866667,-73.3738889 ],
    [ u"us",u"Lockport",21191,43.1705556,-78.6905556 ],
    [ u"us",u"Long Beach",35203,40.5883333,-73.6583333 ],
    [ u"us",u"Lynbrook",19626,40.6547222,-73.6722222 ],
    [ u"us",u"Mamaroneck",18153,40.9486111,-73.7330556 ],
    [ u"us",u"Massapequa",22776,40.6805556,-73.4747222 ],
    [ u"us",u"Massapequa Park",17313,40.6802778,-73.4555556 ],
    [ u"us",u"Massena",10892,44.9280556,-74.8922222 ],
    [ u"us",u"Mastic",16155,40.8019444,-72.8413889 ],
    [ u"us",u"Mastic Beach",12086,40.7666667,-72.8525000 ],
    [ u"us",u"Medford",22152,40.8175000,-73.0005556 ],
    [ u"us",u"Melville",15428,40.7933333,-73.4155556 ],
    [ u"us",u"Merrick",22457,40.6627778,-73.5519444 ],
    [ u"us",u"Middletown",26096,41.4458333,-74.4233333 ],
    [ u"us",u"Mineola",19006,40.7491667,-73.6411111 ],
    [ u"us",u"Monsey",14638,41.1111111,-74.0688889 ],
    [ u"us",u"Mount Kisco",10019,41.2041667,-73.7275000 ],
    [ u"us",u"Mount Vernon",68137,40.9125000,-73.8375000 ],
    [ u"us",u"Nanuet",17973,41.0886111,-74.0138889 ],
    [ u"us",u"Nesconset",12546,40.8519444,-73.1544444 ],
    [ u"us",u"New Cassel",14907,40.7588889,-73.5700000 ],
    [ u"us",u"New City",33942,41.1475000,-73.9897222 ],
    [ u"us",u"New Hyde Park",9477,40.7350000,-73.6883333 ],
    [ u"us",u"New Rochelle",72786,40.9113889,-73.7827778 ],
    [ u"us",u"New York",8107916,40.7141667,-74.0063889 ],
    [ u"us",u"Newark",9365,43.0466667,-77.0955556 ],
    [ u"us",u"Newburgh",28476,41.5033333,-74.0108333 ],
    [ u"us",u"Niagara Falls",53054,43.0944444,-79.0569444 ],
    [ u"us",u"North Amityville",17890,40.6975000,-73.4255556 ],
    [ u"us",u"North Babylon",17642,40.7163889,-73.3222222 ],
    [ u"us",u"North Bay Shore",16023,40.7361111,-73.2630556 ],
    [ u"us",u"North Bellmore",20097,40.6913889,-73.5338889 ],
    [ u"us",u"North Lindenhurst",12282,40.7141667,-73.3819444 ],
    [ u"us",u"North Massapequa",18903,40.7008333,-73.4625000 ],
    [ u"us",u"North Merrick",11628,40.6911111,-73.5636111 ],
    [ u"us",u"North New Hyde Park",14514,40.7430556,-73.6936111 ],
    [ u"us",u"North Tonawanda",31825,43.0386111,-78.8644444 ],
    [ u"us",u"North Valley Stream",16266,40.6850000,-73.7022222 ],
    [ u"us",u"North Wantagh",12005,40.6933333,-73.5080556 ],
    [ u"us",u"Oceanside",32622,40.6386111,-73.6405556 ],
    [ u"us",u"Ogdensburg",11455,44.6941667,-75.4866667 ],
    [ u"us",u"Olean",14823,42.0775000,-78.4300000 ],
    [ u"us",u"Oneida",10945,43.0925000,-75.6516667 ],
    [ u"us",u"Oneonta",12328,42.4527778,-75.0641667 ],
    [ u"us",u"Ossining",24376,41.1627778,-73.8619444 ],
    [ u"us",u"Oswego",18434,43.4552778,-76.5108333 ],
    [ u"us",u"Patchogue",12030,40.7655556,-73.0155556 ],
    [ u"us",u"Pearl River",15544,41.0588889,-74.0222222 ],
    [ u"us",u"Peekskill",24117,41.2900000,-73.9208333 ],
    [ u"us",u"Plainview",25174,40.7763889,-73.4677778 ],
    [ u"us",u"Plattsburgh",19229,44.6994444,-73.4533333 ],
    [ u"us",u"Port Chester",27990,41.0016667,-73.6661111 ],
    [ u"us",u"Port Jervis",9159,41.3750000,-74.6930556 ],
    [ u"us",u"Port Washington",15016,40.8255556,-73.6986111 ],
    [ u"us",u"Potsdam",9666,44.6697222,-74.9816667 ],
    [ u"us",u"Poughkeepsie",30345,41.7002778,-73.9213889 ],
    [ u"us",u"Ridge",14120,40.8938889,-72.8963889 ],
    [ u"us",u"Rochester",211354,43.1547222,-77.6158333 ],
    [ u"us",u"Rome",34074,43.2127778,-75.4561111 ],
    [ u"us",u"Ronkonkoma",19705,40.8152778,-73.1127778 ],
    [ u"us",u"Roosevelt",16129,40.6786111,-73.5894444 ],
    [ u"us",u"Rotterdam",20060,42.7869444,-73.9713889 ],
    [ u"us",u"Rye",15056,40.9805556,-73.6841667 ],
    [ u"us",u"Rye Brook",9620,41.0191667,-73.6838889 ],
    [ u"us",u"Saint James",13436,40.8788889,-73.1572222 ],
    [ u"us",u"Saratoga Springs",27989,43.0830556,-73.7850000 ],
    [ u"us",u"Sayville",16691,40.7358333,-73.0825000 ],
    [ u"us",u"Scarsdale",17920,41.0050000,-73.7850000 ],
    [ u"us",u"Schenectady",60280,42.8141667,-73.9400000 ],
    [ u"us",u"Seaford",15758,40.6658333,-73.4886111 ],
    [ u"us",u"Selden",22300,40.8663889,-73.0361111 ],
    [ u"us",u"Shirley",26431,40.8013889,-72.8680556 ],
    [ u"us",u"Sleepy Hollow",9286,41.0855556,-73.8588889 ],
    [ u"us",u"Smithtown",27300,40.8558333,-73.2011111 ],
    [ u"us",u"South Farmingdale",14798,40.7205556,-73.4405556 ],
    [ u"us",u"South Huntington",9317,40.8236111,-73.3991667 ],
    [ u"us",u"Spring Valley",25469,41.1130556,-74.0441667 ],
    [ u"us",u"Stony Brook",13620,40.9255556,-73.1413889 ],
    [ u"us",u"Stony Point",12234,41.2294444,-73.9875000 ],
    [ u"us",u"Suffern",10972,41.1147222,-74.1500000 ],
    [ u"us",u"Syosset",18204,40.8261111,-73.5025000 ],
    [ u"us",u"Syracuse",141830,43.0480556,-76.1477778 ],
    [ u"us",u"Tarrytown",11460,41.0761111,-73.8591667 ],
    [ u"us",u"Terryville",10656,40.9088889,-73.0655556 ],
    [ u"us",u"Tonawanda",15401,43.0202778,-78.8805556 ],
    [ u"us",u"Troy",48232,42.7283333,-73.6922222 ],
    [ u"us",u"Uniondale",24201,40.7002778,-73.5933333 ],
    [ u"us",u"Utica",58590,43.1008333,-75.2330556 ],
    [ u"us",u"Valley Stream",35934,40.6641667,-73.7088889 ],
    [ u"us",u"Wantagh",19014,40.6836111,-73.5105556 ],
    [ u"us",u"Watertown",28055,43.9747222,-75.9111111 ],
    [ u"us",u"Watervliet",9967,42.7300000,-73.7016667 ],
    [ u"us",u"West Babylon",43606,40.7180556,-73.3547222 ],
    [ u"us",u"West Haverstraw",10356,41.2094444,-73.9858333 ],
    [ u"us",u"West Hempstead",19064,40.7047222,-73.6505556 ],
    [ u"us",u"West Islip",28911,40.7061111,-73.3066667 ],
    [ u"us",u"West Seneca",44712,42.8500000,-78.8000000 ],
    [ u"us",u"Westbury",14198,40.7555556,-73.5880556 ],
    [ u"us",u"White Plains",57260,41.0338889,-73.7633333 ],
    [ u"us",u"Woodmere",16740,40.6319444,-73.7130556 ],
    [ u"us",u"Yonkers",197818,40.9311111,-73.8991667 ],
    [ u"us",u"Albemarle",15281,35.3500000,-80.2002778 ],
    [ u"us",u"Apex",30873,35.7325000,-78.8505556 ],
    [ u"us",u"Archdale",9332,35.9144444,-79.9722222 ],
    [ u"us",u"Asheboro",23443,35.7077778,-79.8138889 ],
    [ u"us",u"Asheville",68795,35.6008333,-82.5541667 ],
    [ u"us",u"Boone",12921,36.2166667,-81.6747222 ],
    [ u"us",u"Burlington",46921,36.0955556,-79.4380556 ],
    [ u"us",u"Carrboro",16626,35.9100000,-79.0755556 ],
    [ u"us",u"Cary",103945,35.7913889,-78.7813889 ],
    [ u"us",u"Chapel Hill",47529,35.9130556,-79.0561111 ],
    [ u"us",u"Charlotte",598351,35.2269444,-80.8433333 ],
    [ u"us",u"Clayton",13177,35.6505556,-78.4566667 ],
    [ u"us",u"Clemmons",16319,36.0213889,-80.3822222 ],
    [ u"us",u"Concord",60592,35.4086111,-80.5797222 ],
    [ u"us",u"Cornelius",21284,35.4866667,-80.8602778 ],
    [ u"us",u"Dunn",10015,35.3061111,-78.6091667 ],
    [ u"us",u"Durham",204734,35.9938889,-78.8988889 ],
    [ u"us",u"Eden",15440,36.4883333,-79.7669444 ],
    [ u"us",u"Elizabeth City",18015,36.2944444,-76.2513889 ],
    [ u"us",u"Fayetteville",124775,35.0525000,-78.8786111 ],
    [ u"us",u"Fuquay-Varina",12127,35.5841667,-78.8002778 ],
    [ u"us",u"Garner",21959,35.7111111,-78.6144444 ],
    [ u"us",u"Gastonia",67869,35.2619444,-81.1875000 ],
    [ u"us",u"Goldsboro",38243,35.3847222,-77.9930556 ],
    [ u"us",u"Graham",13470,36.0688889,-79.4008333 ],
    [ u"us",u"Greensboro",231769,36.0725000,-79.7922222 ],
    [ u"us",u"Greenville",70757,35.6125000,-77.3666667 ],
    [ u"us",u"Havelock",22044,34.8788889,-76.9016667 ],
    [ u"us",u"Henderson",16134,36.3294444,-78.3994444 ],
    [ u"us",u"Hendersonville",11678,35.3186111,-82.4611111 ],
    [ u"us",u"Hickory",40334,35.7330556,-81.3413889 ],
    [ u"us",u"High Point",94281,35.9555556,-80.0055556 ],
    [ u"us",u"Holly Springs",14816,35.6511111,-78.8338889 ],
    [ u"us",u"Hope Mills",12232,34.9702778,-78.9455556 ],
    [ u"us",u"Huntersville",40342,35.4105556,-80.8430556 ],
    [ u"us",u"Indian Trail",15226,35.0766667,-80.6694444 ],
    [ u"us",u"Jacksonville",68015,34.7538889,-77.4305556 ],
    [ u"us",u"Kannapolis",38748,35.4872222,-80.6219444 ],
    [ u"us",u"Kernersville",21007,36.1197222,-80.0738889 ],
    [ u"us",u"Kings Mountain",10638,35.2450000,-81.3413889 ],
    [ u"us",u"Kinston",22475,35.2625000,-77.5819444 ],
    [ u"us",u"Laurinburg",15268,34.7738889,-79.4630556 ],
    [ u"us",u"Lenoir",17806,35.9138889,-81.5391667 ],
    [ u"us",u"Lewisville",9577,36.0969444,-80.4194444 ],
    [ u"us",u"Lexington",20784,35.8238889,-80.2536111 ],
    [ u"us",u"Lincolnton",10279,35.4736111,-81.2547222 ],
    [ u"us",u"Lumberton",21314,34.6180556,-79.0088889 ],
    [ u"us",u"Matthews",23716,35.1166667,-80.7238889 ],
    [ u"us",u"Mint Hill",15772,35.1794444,-80.6475000 ],
    [ u"us",u"Monroe",29681,34.9852778,-80.5497222 ],
    [ u"us",u"Mooresville",20223,35.5847222,-80.8102778 ],
    [ u"us",u"Morganton",17191,35.7452778,-81.6850000 ],
    [ u"us",u"Mount Holly",9512,35.2980556,-81.0161111 ],
    [ u"us",u"New Bern",23623,35.1083333,-77.0444444 ],
    [ u"us",u"Newton",12759,35.6697222,-81.2216667 ],
    [ u"us",u"Pinehurst",11523,35.1952778,-79.4697222 ],
    [ u"us",u"Piney Green",12932,34.7158333,-77.3205556 ],
    [ u"us",u"Raleigh",338759,35.7719444,-78.6388889 ],
    [ u"us",u"Reidsville",14768,36.3547222,-79.6647222 ],
    [ u"us",u"Roanoke Rapids",16299,36.4613889,-77.6544444 ],
    [ u"us",u"Rockingham",9053,34.9391667,-79.7741667 ],
    [ u"us",u"Rocky Mount",55997,35.9380556,-77.7908333 ],
    [ u"us",u"Salisbury",26693,35.6708333,-80.4744444 ],
    [ u"us",u"Sanford",23473,35.4797222,-79.1805556 ],
    [ u"us",u"Shelby",23235,35.2922222,-81.5358333 ],
    [ u"us",u"Smithfield",11208,35.5083333,-78.3397222 ],
    [ u"us",u"Southern Pines",11640,35.1738889,-79.3925000 ],
    [ u"us",u"Statesville",24709,35.7825000,-80.8875000 ],
    [ u"us",u"Tarboro",10601,35.8966667,-77.5361111 ],
    [ u"us",u"Thomasville",30857,35.8825000,-80.0822222 ],
    [ u"us",u"Wake Forest",18832,35.9797222,-78.5100000 ],
    [ u"us",u"Washington",9644,35.5463889,-77.0525000 ],
    [ u"us",u"Waynesville",9463,35.4886111,-82.9888889 ],
    [ u"us",u"Wilmington",92424,34.2255556,-77.9450000 ],
    [ u"us",u"Wilson",46748,35.7211111,-77.9158333 ],
    [ u"us",u"Winston-Salem",193300,36.0997222,-80.2444444 ],
    [ u"us",u"Bismarck",56706,46.8083333,-100.7833333 ],
    [ u"us",u"Devils Lake",6811,48.1127778,-98.8647222 ],
    [ u"us",u"Dickinson",15576,46.8791667,-102.7891667 ],
    [ u"us",u"Fargo",92103,46.8772222,-96.7894444 ],
    [ u"us",u"Grafton",4148,48.4122222,-97.4102778 ],
    [ u"us",u"Grand Forks",48426,47.9252778,-97.0325000 ],
    [ u"us",u"Jamestown",15081,46.9105556,-98.7080556 ],
    [ u"us",u"Mandan",16809,46.8266667,-100.8891667 ],
    [ u"us",u"Minot",34885,48.2325000,-101.2958333 ],
    [ u"us",u"Valley City",6193,46.9233333,-98.0027778 ],
    [ u"us",u"Wahpeton",8395,46.2652778,-96.6055556 ],
    [ u"us",u"West Fargo",17590,46.8750000,-96.9000000 ],
    [ u"us",u"Williston",11971,48.1333333,-103.6333333 ],
    [ u"us",u"Akron",208414,41.0813889,-81.5191667 ],
    [ u"us",u"Alliance",22676,40.9152778,-81.1061111 ],
    [ u"us",u"Amherst",11745,41.3977778,-82.2225000 ],
    [ u"us",u"Ashland",21827,40.8686111,-82.3183333 ],
    [ u"us",u"Ashtabula",20027,41.8650000,-80.7900000 ],
    [ u"us",u"Athens",23180,39.3291667,-82.1013889 ],
    [ u"us",u"Aurora",14549,41.3175000,-81.3455556 ],
    [ u"us",u"Austintown",30969,41.1016667,-80.7647222 ],
    [ u"us",u"Avon",15724,41.4516667,-82.0355556 ],
    [ u"us",u"Avon Lake",21004,41.5052778,-82.0283333 ],
    [ u"us",u"Barberton",27099,41.0127778,-81.6052778 ],
    [ u"us",u"Bay Village",15461,41.4847222,-81.9222222 ],
    [ u"us",u"Beachwood",11699,41.4644444,-81.5088889 ],
    [ u"us",u"Beavercreek",40788,39.7091667,-84.0633333 ],
    [ u"us",u"Bedford",13466,41.3930556,-81.5366667 ],
    [ u"us",u"Bedford Heights",11013,41.4169444,-81.5275000 ],
    [ u"us",u"Bellefontaine",12958,40.3611111,-83.7597222 ],
    [ u"us",u"Berea",18108,41.3661111,-81.8544444 ],
    [ u"us",u"Bexley",12244,39.9688889,-82.9377778 ],
    [ u"us",u"Blacklick Estates",9172,39.9050000,-82.8644444 ],
    [ u"us",u"Blue Ash",11744,39.2319444,-84.3783333 ],
    [ u"us",u"Boardman",36216,41.0241667,-80.6630556 ],
    [ u"us",u"Bowling Green",29215,41.3747222,-83.6513889 ],
    [ u"us",u"Brecksville",13427,41.3197222,-81.6269444 ],
    [ u"us",u"Broadview Heights",17374,41.3138889,-81.6852778 ],
    [ u"us",u"Brook Park",20232,41.3983333,-81.8047222 ],
    [ u"us",u"Brooklyn",11037,41.4397222,-81.7355556 ],
    [ u"us",u"Brunswick",34790,41.2380556,-81.8419444 ],
    [ u"us",u"Bucyrus",12768,40.8083333,-82.9755556 ],
    [ u"us",u"Cambridge",11699,40.0311111,-81.5886111 ],
    [ u"us",u"Campbell",8755,41.0783333,-80.5994444 ],
    [ u"us",u"Canton",78160,40.7988889,-81.3786111 ],
    [ u"us",u"Celina",10282,40.5488889,-84.5702778 ],
    [ u"us",u"Centerville",23222,39.6283333,-84.1594444 ],
    [ u"us",u"Chillicothe",22180,39.3330556,-82.9825000 ],
    [ u"us",u"Cincinnati",306382,39.1619444,-84.4569444 ],
    [ u"us",u"Circleville",13259,39.6005556,-82.9461111 ],
    [ u"us",u"Clayton",13133,39.8630556,-84.3605556 ],
    [ u"us",u"Cleveland",449514,41.4994444,-81.6955556 ],
    [ u"us",u"Cleveland Heights",47726,41.5200000,-81.5563889 ],
    [ u"us",u"Columbus",736836,39.9611111,-82.9988889 ],
    [ u"us",u"Conneaut",13064,41.9475000,-80.5544444 ],
    [ u"us",u"Coshocton",11687,40.2719444,-81.8597222 ],
    [ u"us",u"Cuyahoga Falls",51824,41.1338889,-81.4847222 ],
    [ u"us",u"Dayton",159134,39.7588889,-84.1916667 ],
    [ u"us",u"Defiance",15926,41.2844444,-84.3558333 ],
    [ u"us",u"Delaware",31457,40.2986111,-83.0680556 ],
    [ u"us",u"Dover",12450,40.5205556,-81.4741667 ],
    [ u"us",u"Dublin",35237,40.0991667,-83.1141667 ],
    [ u"us",u"East Cleveland",25513,41.5330556,-81.5791667 ],
    [ u"us",u"East Liverpool",12201,40.6186111,-80.5775000 ],
    [ u"us",u"Eastlake",19747,41.6538889,-81.4505556 ],
    [ u"us",u"Elyria",55873,41.3683333,-82.1077778 ],
    [ u"us",u"Englewood",12593,39.8775000,-84.3022222 ],
    [ u"us",u"Euclid",50123,41.5930556,-81.5269444 ],
    [ u"us",u"Fairborn",32586,39.8208333,-84.0194444 ],
    [ u"us",u"Fairfield",43121,39.3458333,-84.5605556 ],
    [ u"us",u"Fairview Park",16709,41.4413889,-81.8644444 ],
    [ u"us",u"Findlay",40354,41.0441667,-83.6500000 ],
    [ u"us",u"Finneytown",13545,39.2002778,-84.5205556 ],
    [ u"us",u"Forest Park",18106,39.2902778,-84.5041667 ],
    [ u"us",u"Fostoria",13673,41.1569444,-83.4169444 ],
    [ u"us",u"Franklin",12596,39.5588889,-84.3041667 ],
    [ u"us",u"Fremont",17280,41.3502778,-83.1219444 ],
    [ u"us",u"Gahanna",33127,40.0191667,-82.8794444 ],
    [ u"us",u"Galion",11349,40.7336111,-82.7900000 ],
    [ u"us",u"Garfield Heights",29218,41.4169444,-81.6061111 ],
    [ u"us",u"Girard",10456,41.1538889,-80.7016667 ],
    [ u"us",u"Green",23894,40.9458333,-81.4833333 ],
    [ u"us",u"Greenville",13250,40.1027778,-84.6330556 ],
    [ u"us",u"Grove City",30035,39.8813889,-83.0930556 ],
    [ u"us",u"Hamilton",61445,39.3994444,-84.5613889 ],
    [ u"us",u"Hilliard",26893,40.0333333,-83.1583333 ],
    [ u"us",u"Huber Heights",38391,39.8438889,-84.1247222 ],
    [ u"us",u"Hudson",23368,41.2400000,-81.4408333 ],
    [ u"us",u"Ironton",11209,38.5366667,-82.6830556 ],
    [ u"us",u"Kent",28387,41.1536111,-81.3580556 ],
    [ u"us",u"Kettering",55880,39.6894444,-84.1688889 ],
    [ u"us",u"Lakewood",52756,41.4819444,-81.7983333 ],
    [ u"us",u"Lancaster",35883,39.7136111,-82.5994444 ],
    [ u"us",u"Lebanon",20345,39.4352778,-84.2030556 ],
    [ u"us",u"Lima",39906,40.7425000,-84.1052778 ],
    [ u"us",u"Lincoln Village",9173,39.9547222,-83.1308333 ],
    [ u"us",u"Lorain",67920,41.4527778,-82.1825000 ],
    [ u"us",u"Louisville",9235,40.8372222,-81.2597222 ],
    [ u"us",u"Loveland",10993,39.2688889,-84.2638889 ],
    [ u"us",u"Lyndhurst",14558,41.5200000,-81.4888889 ],
    [ u"us",u"Macedonia",10606,41.3136111,-81.5086111 ],
    [ u"us",u"Mansfield",50310,40.7583333,-82.5155556 ],
    [ u"us",u"Maple Heights",24961,41.4152778,-81.5661111 ],
    [ u"us",u"Marietta",13795,39.4152778,-81.4550000 ],
    [ u"us",u"Marion",37482,40.5886111,-83.1286111 ],
    [ u"us",u"Marysville",16396,40.2363889,-83.3672222 ],
    [ u"us",u"Mason",30988,39.3600000,-84.3100000 ],
    [ u"us",u"Massillon",31526,40.7966667,-81.5216667 ],
    [ u"us",u"Maumee",14441,41.5627778,-83.6538889 ],
    [ u"us",u"Mayfield Heights",18567,41.5191667,-81.4580556 ],
    [ u"us",u"Medina",27358,41.1383333,-81.8638889 ],
    [ u"us",u"Mentor",49726,41.6661111,-81.3397222 ],
    [ u"us",u"Miamisburg",20031,39.6427778,-84.2866667 ],
    [ u"us",u"Middleburg Heights",15681,41.3613889,-81.8130556 ],
    [ u"us",u"Middletown",52834,39.5150000,-84.3983333 ],
    [ u"us",u"Montgomery",9431,39.2280556,-84.3541667 ],
    [ u"us",u"Mount Vernon",16965,40.3933333,-82.4858333 ],
    [ u"us",u"Napoleon",9198,41.3922222,-84.1252778 ],
    [ u"us",u"New Philadelphia",17472,40.4897222,-81.4458333 ],
    [ u"us",u"Newark",46812,40.0580556,-82.4013889 ],
    [ u"us",u"Niles",19902,41.1827778,-80.7655556 ],
    [ u"us",u"North Canton",16886,40.8758333,-81.4025000 ],
    [ u"us",u"North College Hill",9361,39.2183333,-84.5508333 ],
    [ u"us",u"North Olmsted",32958,41.4155556,-81.9236111 ],
    [ u"us",u"North Ridgeville",25851,41.3894444,-82.0191667 ],
    [ u"us",u"North Royalton",28920,41.3136111,-81.7247222 ],
    [ u"us",u"Northbrook",10786,39.2463889,-84.5836111 ],
    [ u"us",u"Norton",11733,41.0291667,-81.6383333 ],
    [ u"us",u"Norwalk",16396,41.2425000,-82.6158333 ],
    [ u"us",u"Norwood",20288,39.1555556,-84.4597222 ],
    [ u"us",u"Oregon",19408,41.6436111,-83.4869444 ],
    [ u"us",u"Oxford",20875,39.5069444,-84.7452778 ],
    [ u"us",u"Painesville",17251,41.7244444,-81.2458333 ],
    [ u"us",u"Parma",82565,41.4047222,-81.7230556 ],
    [ u"us",u"Parma Heights",20886,41.3900000,-81.7597222 ],
    [ u"us",u"Pataskala",13888,39.9955556,-82.6744444 ],
    [ u"us",u"Perrysburg",16793,41.5569444,-83.6272222 ],
    [ u"us",u"Pickerington",15408,39.8841667,-82.7536111 ],
    [ u"us",u"Piqua",20731,40.1447222,-84.2425000 ],
    [ u"us",u"Portage Lakes",8899,41.0072222,-81.5272222 ],
    [ u"us",u"Portsmouth",19083,38.7316667,-82.9977778 ],
    [ u"us",u"Ravenna",11327,41.1575000,-81.2422222 ],
    [ u"us",u"Reading",10317,39.2236111,-84.4422222 ],
    [ u"us",u"Reynoldsburg",33237,39.9547222,-82.8122222 ],
    [ u"us",u"Richmond Heights",10753,41.5527778,-81.5102778 ],
    [ u"us",u"Riverside",22518,39.7797222,-84.1241667 ],
    [ u"us",u"Rocky River",19774,41.4755556,-81.8394444 ],
    [ u"us",u"Salem",11779,40.9008333,-80.8569444 ],
    [ u"us",u"Sandusky",26428,41.4488889,-82.7080556 ],
    [ u"us",u"Seven Hills",12046,41.3952778,-81.6763889 ],
    [ u"us",u"Shaker Heights",27755,41.4738889,-81.5372222 ],
    [ u"us",u"Sharonville",13250,39.2680556,-84.4133333 ],
    [ u"us",u"Sheffield Lake",9139,41.4875000,-82.1016667 ],
    [ u"us",u"Shelby",9482,40.8813889,-82.6619444 ],
    [ u"us",u"Sidney",20161,40.2841667,-84.1555556 ],
    [ u"us",u"Solon",22451,41.3897222,-81.4413889 ],
    [ u"us",u"South Euclid",22350,41.5230556,-81.5186111 ],
    [ u"us",u"Springboro",16947,39.5522222,-84.2333333 ],
    [ u"us",u"Springdale",9785,39.2869444,-84.4852778 ],
    [ u"us",u"Springfield",64325,39.9241667,-83.8088889 ],
    [ u"us",u"Steubenville",19312,40.3697222,-80.6341667 ],
    [ u"us",u"Stow",35349,41.1594444,-81.4405556 ],
    [ u"us",u"Streetsboro",15787,41.2391667,-81.3461111 ],
    [ u"us",u"Strongsville",44863,41.3144444,-81.8358333 ],
    [ u"us",u"Struthers",11079,41.0525000,-80.6080556 ],
    [ u"us",u"Sylvania",19141,41.7188889,-83.7130556 ],
    [ u"us",u"Tallmadge",17537,41.1013889,-81.4419444 ],
    [ u"us",u"Tiffin",17013,41.1144444,-83.1780556 ],
    [ u"us",u"Tipp City",9380,39.9583333,-84.1722222 ],
    [ u"us",u"Toledo",306974,41.6638889,-83.5552778 ],
    [ u"us",u"Trenton",11000,39.4808333,-84.4577778 ],
    [ u"us",u"Trotwood",27197,39.7972222,-84.3113889 ],
    [ u"us",u"Troy",22336,40.0394444,-84.2033333 ],
    [ u"us",u"Twinsburg",17352,41.3125000,-81.4402778 ],
    [ u"us",u"University Heights",13374,41.4977778,-81.5375000 ],
    [ u"us",u"Upper Arlington",31474,39.9944444,-83.0625000 ],
    [ u"us",u"Urbana",11657,40.1083333,-83.7525000 ],
    [ u"us",u"Van Wert",10457,40.8694444,-84.5841667 ],
    [ u"us",u"Vandalia",14478,39.8905556,-84.1988889 ],
    [ u"us",u"Vermilion",11006,41.4219444,-82.3647222 ],
    [ u"us",u"Wadsworth",20187,41.0255556,-81.7300000 ],
    [ u"us",u"Wapakoneta",9524,40.5677778,-84.1936111 ],
    [ u"us",u"Warren",45475,41.2375000,-80.8186111 ],
    [ u"us",u"Warrensville Heights",14409,41.4350000,-81.5363889 ],
    [ u"us",u"West Carrollton City",13297,39.6722222,-84.2522222 ],
    [ u"us",u"Westerville",34226,40.1261111,-82.9291667 ],
    [ u"us",u"Westlake",31990,41.4552778,-81.9180556 ],
    [ u"us",u"White Oak",13557,39.2130556,-84.5994444 ],
    [ u"us",u"Whitehall",18173,39.9666667,-82.8855556 ],
    [ u"us",u"Wickliffe",13178,41.6052778,-81.4536111 ],
    [ u"us",u"Willoughby",22352,41.6397222,-81.4066667 ],
    [ u"us",u"Willowick",13850,41.6330556,-81.4688889 ],
    [ u"us",u"Wilmington",12312,39.4452778,-83.8286111 ],
    [ u"us",u"Wooster",25725,40.8050000,-81.9352778 ],
    [ u"us",u"Worthington",13199,40.0930556,-83.0180556 ],
    [ u"us",u"Xenia",23351,39.6847222,-83.9297222 ],
    [ u"us",u"Youngstown",77540,41.0997222,-80.6497222 ],
    [ u"us",u"Zanesville",24976,39.9402778,-82.0133333 ],
    [ u"us",u"Ada",16144,34.7744444,-96.6780556 ],
    [ u"us",u"Altus",20278,34.6380556,-99.3336111 ],
    [ u"us",u"Ardmore",23975,34.1741667,-97.1433333 ],
    [ u"us",u"Bartlesville",34610,36.7472222,-95.9805556 ],
    [ u"us",u"Bethany",19673,35.5186111,-97.6319444 ],
    [ u"us",u"Bixby",18949,35.9419444,-95.8830556 ],
    [ u"us",u"Broken Arrow",85535,36.0525000,-95.7905556 ],
    [ u"us",u"Chickasha",16772,35.0525000,-97.9361111 ],
    [ u"us",u"Choctaw",10530,35.4975000,-97.2686111 ],
    [ u"us",u"Claremore",17258,36.3125000,-95.6158333 ],
    [ u"us",u"Clinton",8153,35.5155556,-98.9669444 ],
    [ u"us",u"Del City",22135,35.4419444,-97.4405556 ],
    [ u"us",u"Duncan",21788,34.5022222,-97.9575000 ],
    [ u"us",u"Durant",15483,33.9938889,-96.3705556 ],
    [ u"us",u"Edmond",73915,35.6527778,-97.4777778 ],
    [ u"us",u"El Reno",15643,35.5322222,-97.9547222 ],
    [ u"us",u"Elk City",10522,35.4119444,-99.4038889 ],
    [ u"us",u"Enid",46138,36.3955556,-97.8780556 ],
    [ u"us",u"Guthrie",10277,35.8788889,-97.4250000 ],
    [ u"us",u"Guymon",10509,36.6827778,-101.4811111 ],
    [ u"us",u"Jenks",12921,36.0227778,-95.9680556 ],
    [ u"us",u"Lawton",91752,34.6086111,-98.3900000 ],
    [ u"us",u"Miami",13336,36.8744444,-94.8772222 ],
    [ u"us",u"Midwest City",54958,35.4494444,-97.3963889 ],
    [ u"us",u"Moore",47475,35.3394444,-97.4863889 ],
    [ u"us",u"Muskogee",38696,35.7477778,-95.3694444 ],
    [ u"us",u"Mustang",15612,35.3841667,-97.7241667 ],
    [ u"us",u"Norman",101742,35.2225000,-97.4391667 ],
    [ u"us",u"Oklahoma City",532950,35.4675000,-97.5161111 ],
    [ u"us",u"Okmulgee",12482,35.6233333,-95.9602778 ],
    [ u"us",u"Owasso",23923,36.2694444,-95.8544444 ],
    [ u"us",u"Ponca City",25273,36.7069444,-97.0852778 ],
    [ u"us",u"Sand Springs",17826,36.1397222,-96.1086111 ],
    [ u"us",u"Sapulpa",19825,35.9986111,-96.1138889 ],
    [ u"us",u"Shawnee",29721,35.3272222,-96.9250000 ],
    [ u"us",u"Stillwater",42757,36.1155556,-97.0580556 ],
    [ u"us",u"Tahlequah",16146,35.9152778,-94.9697222 ],
    [ u"us",u"The Village",9979,35.5608333,-97.5511111 ],
    [ u"us",u"Tulsa",382005,36.1538889,-95.9925000 ],
    [ u"us",u"Warr Acres",9594,35.5225000,-97.6186111 ],
    [ u"us",u"Weatherford",9262,35.5261111,-98.7072222 ],
    [ u"us",u"Woodward",11748,36.4336111,-99.3900000 ],
    [ u"us",u"Yukon",21196,35.5066667,-97.7622222 ],
    [ u"us",u"Albany",44757,44.6366667,-123.1047222 ],
    [ u"us",u"Aloha",44915,45.4944444,-122.8658333 ],
    [ u"us",u"Altamont",19716,42.2069444,-121.7361111 ],
    [ u"us",u"Ashland",20888,42.1947222,-122.7083333 ],
    [ u"us",u"Astoria",9535,46.1880556,-123.8300000 ],
    [ u"us",u"Baker City",9539,44.7750000,-117.8333333 ],
    [ u"us",u"Beaverton",82648,45.4872222,-122.8025000 ],
    [ u"us",u"Bend",65756,44.0583333,-121.3141667 ],
    [ u"us",u"Canby",15459,45.2630556,-122.6913889 ],
    [ u"us",u"Cedar Hills",8625,45.5050000,-122.7972222 ],
    [ u"us",u"Cedar Mill",13975,45.5250000,-122.8097222 ],
    [ u"us",u"Central Point",16270,42.3761111,-122.9152778 ],
    [ u"us",u"Coos Bay",15394,43.3666667,-124.2166667 ],
    [ u"us",u"Cornelius",10589,45.5200000,-123.0586111 ],
    [ u"us",u"Corvallis",50701,44.5647222,-123.2608333 ],
    [ u"us",u"Dallas",13852,44.9194444,-123.3158333 ],
    [ u"us",u"Eugene",145208,44.0522222,-123.0855556 ],
    [ u"us",u"Fairview",9445,45.5386111,-122.4327778 ],
    [ u"us",u"Forest Grove",19427,45.5200000,-123.1094444 ],
    [ u"us",u"Gladstone",12249,45.3808333,-122.5936111 ],
    [ u"us",u"Grants Pass",27191,42.4391667,-123.3272222 ],
    [ u"us",u"Gresham",98851,45.4983333,-122.4302778 ],
    [ u"us",u"Hayesville",20021,44.9861111,-122.9816667 ],
    [ u"us",u"Hermiston",14951,45.8405556,-119.2883333 ],
    [ u"us",u"Hillsboro",82320,45.5230556,-122.9886111 ],
    [ u"us",u"Keizer",35537,44.9902778,-123.0250000 ],
    [ u"us",u"Klamath Falls",19203,42.2250000,-121.7805556 ],
    [ u"us",u"La Grande",12288,45.3247222,-118.0866667 ],
    [ u"us",u"Lake Oswego",36597,45.4208333,-122.6694444 ],
    [ u"us",u"Lebanon",13487,44.5366667,-122.9058333 ],
    [ u"us",u"Medford",69638,42.3266667,-122.8744444 ],
    [ u"us",u"Milwaukie",20759,45.4463889,-122.6380556 ],
    [ u"us",u"Newberg",20790,45.3002778,-122.9719444 ],
    [ u"us",u"Newport",9515,44.6369444,-124.0522222 ],
    [ u"us",u"North Bend",9620,43.4066667,-124.2230556 ],
    [ u"us",u"Oak Grove",12674,45.4169444,-122.6388889 ],
    [ u"us",u"Ontario",10969,44.0266667,-116.9619444 ],
    [ u"us",u"Oregon City",29984,45.3575000,-122.6055556 ],
    [ u"us",u"Pendleton",16539,45.6722222,-118.7875000 ],
    [ u"us",u"Portland",540513,45.5236111,-122.6750000 ],
    [ u"us",u"Redmond",18807,44.2727778,-121.1727778 ],
    [ u"us",u"Roseburg",20430,43.2166667,-123.3405556 ],
    [ u"us",u"Saint Helens",12082,45.8641667,-122.8052778 ],
    [ u"us",u"Salem",146922,44.9430556,-123.0338889 ],
    [ u"us",u"Sherwood",15157,45.3566667,-122.8388889 ],
    [ u"us",u"Springfield",56032,44.0463889,-123.0208333 ],
    [ u"us",u"Tigard",47068,45.4313889,-122.7702778 ],
    [ u"us",u"Troutdale",15205,45.5394444,-122.3861111 ],
    [ u"us",u"Tualatin",26476,45.3841667,-122.7627778 ],
    [ u"us",u"West Linn",26067,45.3658333,-122.6111111 ],
    [ u"us",u"Wilsonville",16134,45.3000000,-122.7725000 ],
    [ u"us",u"Woodburn",22866,45.1438889,-122.8541667 ],
    [ u"us",u"Aliquippa",11074,40.6366667,-80.2402778 ],
    [ u"us",u"Allentown",105519,40.6083333,-75.4905556 ],
    [ u"us",u"Altoona",46962,40.5186111,-78.3950000 ],
    [ u"us",u"Ardmore",12554,40.0066667,-75.2858333 ],
    [ u"us",u"Back Mountain",26973,41.3358333,-75.9966667 ],
    [ u"us",u"Baldwin",18991,40.3380556,-79.9791667 ],
    [ u"us",u"Beaver Falls",9504,40.7519444,-80.3194444 ],
    [ u"us",u"Berwick",10373,41.0544444,-76.2336111 ],
    [ u"us",u"Bethel Park",32474,40.3275000,-80.0397222 ],
    [ u"us",u"Bethlehem",73710,40.6258333,-75.3708333 ],
    [ u"us",u"Bloomsburg",12943,41.0036111,-76.4552778 ],
    [ u"us",u"Bradford",8611,41.9558333,-78.6441667 ],
    [ u"us",u"Brentwood",9866,40.3705556,-79.9750000 ],
    [ u"us",u"Bristol",9854,40.1005556,-74.8522222 ],
    [ u"us",u"Broomall",11058,39.9813889,-75.3569444 ],
    [ u"us",u"Butler",14569,40.8611111,-79.8955556 ],
    [ u"us",u"Carbondale",9309,41.5736111,-75.5022222 ],
    [ u"us",u"Carlisle",18204,40.2013889,-77.1891667 ],
    [ u"us",u"Chambersburg",17884,39.9375000,-77.6613889 ],
    [ u"us",u"Chester",36938,39.8494444,-75.3561111 ],
    [ u"us",u"Coatesville",11430,39.9830556,-75.8241667 ],
    [ u"us",u"Colonial Park",12972,40.3005556,-76.8100000 ],
    [ u"us",u"Columbia",10121,40.0336111,-76.5047222 ],
    [ u"us",u"Croydon",9967,40.0872222,-74.9038889 ],
    [ u"us",u"Darby",10021,39.9183333,-75.2594444 ],
    [ u"us",u"Dormont",8716,40.3958333,-80.0333333 ],
    [ u"us",u"Drexel Hill",29075,39.9469444,-75.2925000 ],
    [ u"us",u"Dunmore",13563,41.4197222,-75.6327778 ],
    [ u"us",u"East Norriton",13108,40.1516667,-75.3369444 ],
    [ u"us",u"East Stroudsburg",10828,40.9994444,-75.1816667 ],
    [ u"us",u"Easton",26192,40.6883333,-75.2211111 ],
    [ u"us",u"Economy",9334,40.6000000,-80.2250000 ],
    [ u"us",u"Elizabethtown",11907,40.1527778,-76.6030556 ],
    [ u"us",u"Emmaus",11206,40.5394444,-75.4972222 ],
    [ u"us",u"Ephrata",13182,40.1797222,-76.1791667 ],
    [ u"us",u"Erie",99801,42.1291667,-80.0852778 ],
    [ u"us",u"Franklin Park",11737,40.5833333,-80.0880556 ],
    [ u"us",u"Fullerton",14781,40.6316667,-75.4736111 ],
    [ u"us",u"Greensburg",15309,40.3013889,-79.5391667 ],
    [ u"us",u"Hanover",15036,39.8005556,-76.9833333 ],
    [ u"us",u"Harrisburg",47840,40.2736111,-76.8847222 ],
    [ u"us",u"Hazleton",21961,40.9583333,-75.9750000 ],
    [ u"us",u"Hermitage",16784,41.2333333,-80.4488889 ],
    [ u"us",u"Hershey",13172,40.2858333,-76.6505556 ],
    [ u"us",u"Horsham",14597,40.1783333,-75.1288889 ],
    [ u"us",u"Indiana",14357,40.6213889,-79.1527778 ],
    [ u"us",u"Jeannette",10185,40.3280556,-79.6155556 ],
    [ u"us",u"Johnstown",22357,40.3266667,-78.9222222 ],
    [ u"us",u"King of Prussia",18489,40.0891667,-75.3963889 ],
    [ u"us",u"Kingston",13067,41.2616667,-75.8972222 ],
    [ u"us",u"Lancaster",54735,40.0377778,-76.3058333 ],
    [ u"us",u"Lansdale",16094,40.2413889,-75.2841667 ],
    [ u"us",u"Lansdowne",10736,39.9380556,-75.2722222 ],
    [ u"us",u"Lebanon",23581,40.3408333,-76.4116667 ],
    [ u"us",u"Levittown",53117,40.1550000,-74.8291667 ],
    [ u"us",u"Lock Haven",8777,41.1369444,-77.4472222 ],
    [ u"us",u"Lower Burrell",12476,40.5530556,-79.7575000 ],
    [ u"us",u"Meadville",13225,41.6413889,-80.1516667 ],
    [ u"us",u"Mount Lebanon",32730,40.3552778,-80.0497222 ],
    [ u"us",u"Munhall",11561,40.3922222,-79.9002778 ],
    [ u"us",u"Nanticoke",10265,41.2052778,-76.0052778 ],
    [ u"us",u"New Castle",24652,41.0036111,-80.3472222 ],
    [ u"us",u"New Kensington",14028,40.5697222,-79.7650000 ],
    [ u"us",u"Norristown",30735,40.1213889,-75.3402778 ],
    [ u"us",u"North Versailles",10571,40.3797222,-79.8097222 ],
    [ u"us",u"Northampton",9760,40.6861111,-75.4972222 ],
    [ u"us",u"Oil City",10891,41.4338889,-79.7066667 ],
    [ u"us",u"Philadelphia",1453268,39.9522222,-75.1641667 ],
    [ u"us",u"Phoenixville",14660,40.1302778,-75.5152778 ],
    [ u"us",u"Pittsburgh",319494,40.4405556,-79.9961111 ],
    [ u"us",u"Plum",26550,40.5002778,-79.7497222 ],
    [ u"us",u"Pottstown",21720,40.2452778,-75.6500000 ],
    [ u"us",u"Pottsville",14631,40.6855556,-76.1958333 ],
    [ u"us",u"Progress",9607,40.2850000,-76.8316667 ],
    [ u"us",u"Reading",79799,40.3355556,-75.9272222 ],
    [ u"us",u"Saint Marys",14026,41.4277778,-78.5611111 ],
    [ u"us",u"Scranton",73206,41.4088889,-75.6627778 ],
    [ u"us",u"Sharon",15415,41.2330556,-80.4936111 ],
    [ u"us",u"Springfield",23363,39.9305556,-75.3205556 ],
    [ u"us",u"State College",41835,40.7933333,-77.8602778 ],
    [ u"us",u"Sunbury",10084,40.8625000,-76.7947222 ],
    [ u"us",u"Swissvale",9069,40.4236111,-79.8830556 ],
    [ u"us",u"Uniontown",11878,39.9000000,-79.7166667 ],
    [ u"us",u"Warren",9569,41.8438889,-79.1452778 ],
    [ u"us",u"Washington",14637,40.1738889,-80.2463889 ],
    [ u"us",u"Waynesboro",9651,39.7558333,-77.5780556 ],
    [ u"us",u"West Chester",17545,39.9605556,-75.6058333 ],
    [ u"us",u"West Mifflin",21454,40.3633333,-79.8666667 ],
    [ u"us",u"West Norriton",14702,40.1294444,-75.3788889 ],
    [ u"us",u"Wilkes-Barre",40736,41.2458333,-75.8816667 ],
    [ u"us",u"Wilkinsburg",18036,40.4416667,-79.8822222 ],
    [ u"us",u"Williamsport",29377,41.2411111,-77.0013889 ],
    [ u"us",u"Willow Grove",16129,40.1438889,-75.1161111 ],
    [ u"us",u"Woodlyn",9944,39.8722222,-75.3375000 ],
    [ u"us",u"Yeadon",11469,39.9388889,-75.2558333 ],
    [ u"us",u"York",39587,39.9625000,-76.7280556 ],
    [ u"us",u"Adjuntas",5080,18.1647222,-66.7225000 ],
    [ u"us",u"Aguada",4040,18.3813889,-67.1886111 ],
    [ u"us",u"Aguadilla",16074,18.4294444,-67.1544444 ],
    [ u"us",u"Aguas Buenas",4576,18.2588889,-66.1033333 ],
    [ u"us",u"Aibonito",8947,18.1419444,-66.2663889 ],
    [ u"us",u"Anasco",6136,18.2847222,-67.1400000 ],
    [ u"us",u"Arecibo",49189,18.4744444,-66.7161111 ],
    [ u"us",u"Arroyo",7520,17.9677778,-66.0616667 ],
    [ u"us",u"Barceloneta",4494,18.4525000,-66.5388889 ],
    [ u"us",u"Barranquitas",3021,18.1886111,-66.3066667 ],
    [ u"us",u"Cabo Rojo",10840,18.0886111,-67.1461111 ],
    [ u"us",u"Caguas",86807,18.2361111,-66.0488889 ],
    [ u"us",u"Camuy",4240,18.4858333,-66.8452778 ],
    [ u"us",u"Candelaria",17632,18.4061111,-66.2091667 ],
    [ u"us",u"Canovanas",8437,18.3811111,-65.9016667 ],
    [ u"us",u"Carolina",170408,18.3827778,-65.9577778 ],
    [ u"us",u"Catano",28094,18.4433333,-66.1186111 ],
    [ u"us",u"Cayey",18495,18.1138889,-66.1663889 ],
    [ u"us",u"Ciales",3256,18.3380556,-66.4691667 ],
    [ u"us",u"Cidra",5067,18.1777778,-66.1616667 ],
    [ u"us",u"Coamo",11941,18.0819444,-66.3583333 ],
    [ u"us",u"Comerio",4649,18.2200000,-66.2263889 ],
    [ u"us",u"Corozal",11297,18.3430556,-66.3172222 ],
    [ u"us",u"Culebra",1486,18.3050000,-65.3013889 ],
    [ u"us",u"Dorado",13117,18.4608333,-66.2680556 ],
    [ u"us",u"Fajardo",34070,18.3277778,-65.6527778 ],
    [ u"us",u"Florida",5972,18.3652778,-66.5675000 ],
    [ u"us",u"Guanica",9224,17.9736111,-66.9083333 ],
    [ u"us",u"Guayama",21576,17.9861111,-66.1141667 ],
    [ u"us",u"Guayanilla",5213,18.0211111,-66.7922222 ],
    [ u"us",u"Guaynabo",81363,18.3594444,-66.1113889 ],
    [ u"us",u"Gurabo",8974,18.2563889,-65.9733333 ],
    [ u"us",u"Hatillo",5622,18.4883333,-66.8258333 ],
    [ u"us",u"Hormigueros",11935,18.1416667,-67.1277778 ],
    [ u"us",u"Humacao",20388,18.1516667,-65.8277778 ],
    [ u"us",u"Isabela",12505,18.5027778,-67.0247222 ],
    [ u"us",u"Jayuya",3587,18.2205556,-66.5919444 ],
    [ u"us",u"Juana Diaz",9427,18.0544444,-66.5069444 ],
    [ u"us",u"Juncos",8905,18.2294444,-65.9213889 ],
    [ u"us",u"Lajas",5255,18.0519444,-67.0597222 ],
    [ u"us",u"Lares",7184,18.2966667,-66.8775000 ],
    [ u"us",u"Las Piedras",6655,18.1850000,-65.8666667 ],
    [ u"us",u"Levittown",29786,18.4519444,-66.1819444 ],
    [ u"us",u"Loiza",4311,18.4333333,-65.8805556 ],
    [ u"us",u"Luquillo",8326,18.3744444,-65.7169444 ],
    [ u"us",u"Manati",16093,18.4294444,-66.4925000 ],
    [ u"us",u"Maricao",1172,18.1827778,-66.9802778 ],
    [ u"us",u"Maunabo",2154,18.0091667,-65.8997222 ],
    [ u"us",u"Mayaguez",76503,18.2030556,-67.1400000 ],
    [ u"us",u"Moca",4964,18.3966667,-67.1136111 ],
    [ u"us",u"Morovis",2414,18.3277778,-66.4069444 ],
    [ u"us",u"Naguabo",4643,18.2136111,-65.7352778 ],
    [ u"us",u"Naranjito",2005,18.3027778,-66.2452778 ],
    [ u"us",u"Orocovis",944,18.2288889,-66.3913889 ],
    [ u"us",u"Patillas",4247,18.0083333,-66.0161111 ],
    [ u"us",u"Penuelas",6847,18.0583333,-66.7219444 ],
    [ u"us",u"Ponce",152639,18.0130556,-66.6144444 ],
    [ u"us",u"Quebradillas",5620,18.4758333,-66.9388889 ],
    [ u"us",u"Rincon",1499,18.3422222,-67.2502778 ],
    [ u"us",u"Rio Grande",41218,18.3822222,-65.8316667 ],
    [ u"us",u"Sabana Grande",8961,18.0797222,-66.9608333 ],
    [ u"us",u"Salinas",6375,17.9794444,-66.2983333 ],
    [ u"us",u"San German",12055,18.0836111,-67.0452778 ],
    [ u"us",u"San Juan",418140,18.4683333,-66.1061111 ],
    [ u"us",u"San Lorenzo",9373,18.1913889,-65.9613889 ],
    [ u"us",u"San Sebastian",11591,18.3386111,-66.9905556 ],
    [ u"us",u"Santa Isabel",7260,17.9680556,-66.4052778 ],
    [ u"us",u"Toa Alta",4483,18.3902778,-66.2486111 ],
    [ u"us",u"Toa Baja",1889,18.4458333,-66.2600000 ],
    [ u"us",u"Trujillo Alto",54191,18.3566667,-66.0077778 ],
    [ u"us",u"Utuado",9844,18.2675000,-66.7008333 ],
    [ u"us",u"Vega Alta",12036,18.4141667,-66.3316667 ],
    [ u"us",u"Vega Baja",29326,18.4463889,-66.3880556 ],
    [ u"us",u"Vieques",4531,18.1494444,-65.4452778 ],
    [ u"us",u"Villalba",4555,18.1291667,-66.4925000 ],
    [ u"us",u"Yabucoa",6952,18.0525000,-65.8797222 ],
    [ u"us",u"Yauco",20296,18.0369444,-66.8502778 ],
    [ u"us",u"Barrington",16669,41.7405556,-71.3091667 ],
    [ u"us",u"Bristol",22795,41.6769444,-71.2666667 ],
    [ u"us",u"Central Falls",19509,41.8905556,-71.3927778 ],
    [ u"us",u"Charlestown",8421,41.3830556,-71.6422222 ],
    [ u"us",u"Coventry",35525,41.7000000,-71.6833333 ],
    [ u"us",u"Cranston",82926,41.7797222,-71.4377778 ],
    [ u"us",u"Cumberland",34843,41.9666667,-71.4333333 ],
    [ u"us",u"East Greenwich",13682,41.6602778,-71.4563889 ],
    [ u"us",u"East Providence",50453,41.8136111,-71.3705556 ],
    [ u"us",u"Exeter",6426,41.5775000,-71.5380556 ],
    [ u"us",u"Foster",4598,41.8536111,-71.7586111 ],
    [ u"us",u"Greenville",8964,41.8711111,-71.5525000 ],
    [ u"us",u"Hopkinton",8261,41.4611111,-71.7780556 ],
    [ u"us",u"Jamestown",5755,41.4969444,-71.3677778 ],
    [ u"us",u"Kingston",5113,41.4802778,-71.5230556 ],
    [ u"us",u"Middletown",17303,41.5455556,-71.2919444 ],
    [ u"us",u"Narragansett",17236,41.4500000,-71.4500000 ],
    [ u"us",u"Newport",25818,41.4900000,-71.3133333 ],
    [ u"us",u"North Providence",33835,41.8500000,-71.4666667 ],
    [ u"us",u"North Smithfield",11212,41.9666667,-71.5500000 ],
    [ u"us",u"Pascoag",4716,41.9555556,-71.7027778 ],
    [ u"us",u"Pawtucket",74965,41.8786111,-71.3830556 ],
    [ u"us",u"Portsmouth",17756,41.6022222,-71.2508333 ],
    [ u"us",u"Providence",177595,41.8238889,-71.4133333 ],
    [ u"us",u"Smithfield",21872,41.9219444,-71.5500000 ],
    [ u"us",u"Tiverton",19432,41.6258333,-71.2138889 ],
    [ u"us",u"Valley Falls",12048,41.9066667,-71.3911111 ],
    [ u"us",u"Warren",11280,41.7302778,-71.2830556 ],
    [ u"us",u"Warwick",88071,41.7000000,-71.4166667 ],
    [ u"us",u"West Warwick",30146,41.7061111,-71.5236111 ],
    [ u"us",u"Westerly",26048,41.3775000,-71.8277778 ],
    [ u"us",u"Woonsocket",45839,42.0027778,-71.5152778 ],
    [ u"us",u"Aiken",27237,33.5602778,-81.7197222 ],
    [ u"us",u"Anderson",25393,34.5033333,-82.6502778 ],
    [ u"us",u"Beaufort",12256,32.4313889,-80.6700000 ],
    [ u"us",u"Bennettsville",9253,34.6172222,-79.6850000 ],
    [ u"us",u"Berea",14331,34.8852778,-82.4561111 ],
    [ u"us",u"Cayce",12450,33.9655556,-81.0741667 ],
    [ u"us",u"Charleston",104782,32.7763889,-79.9311111 ],
    [ u"us",u"Clemson",11901,34.6833333,-82.8375000 ],
    [ u"us",u"Clinton",9368,34.4725000,-81.8808333 ],
    [ u"us",u"Columbia",117722,34.0005556,-81.0350000 ],
    [ u"us",u"Conway",13340,33.8358333,-79.0480556 ],
    [ u"us",u"Dentsville",13476,34.0638889,-80.9583333 ],
    [ u"us",u"Easley",18767,34.8297222,-82.6016667 ],
    [ u"us",u"Florence",30517,34.1952778,-79.7627778 ],
    [ u"us",u"Forest Acres",10236,34.0191667,-80.9900000 ],
    [ u"us",u"Gaffney",12791,35.0716667,-81.6500000 ],
    [ u"us",u"Gantt",13870,34.8000000,-82.4244444 ],
    [ u"us",u"Georgetown",8927,33.3766667,-79.2947222 ],
    [ u"us",u"Goose Creek",31399,32.9808333,-80.0327778 ],
    [ u"us",u"Greenville",55559,34.8525000,-82.3941667 ],
    [ u"us",u"Greenwood",22316,34.1952778,-82.1619444 ],
    [ u"us",u"Greer",20703,34.9386111,-82.2272222 ],
    [ u"us",u"Hanahan",13100,32.9183333,-80.0222222 ],
    [ u"us",u"Hilton Head Island",34457,32.2161111,-80.7527778 ],
    [ u"us",u"Irmo",11286,34.0858333,-81.1833333 ],
    [ u"us",u"Ladson",13019,32.9855556,-80.1100000 ],
    [ u"us",u"Lancaster",8349,34.7202778,-80.7711111 ],
    [ u"us",u"Laurens",9737,34.4988889,-82.0144444 ],
    [ u"us",u"Lexington",13991,33.9813889,-81.2363889 ],
    [ u"us",u"Mauldin",19513,34.7786111,-82.3102778 ],
    [ u"us",u"Mount Pleasant",59105,32.7938889,-79.8627778 ],
    [ u"us",u"Myrtle Beach",25310,33.6888889,-78.8869444 ],
    [ u"us",u"Newberry",10526,34.2744444,-81.6188889 ],
    [ u"us",u"North Augusta",19030,33.5016667,-81.9652778 ],
    [ u"us",u"North Charleston",82838,32.8544444,-79.9750000 ],
    [ u"us",u"North Myrtle Beach",13385,33.8158333,-78.6802778 ],
    [ u"us",u"Orangeburg",12913,33.4916667,-80.8558333 ],
    [ u"us",u"Parker",10521,34.8505556,-82.4536111 ],
    [ u"us",u"Rock Hill",59766,34.9247222,-81.0252778 ],
    [ u"us",u"Simpsonville",14988,34.7369444,-82.2544444 ],
    [ u"us",u"Socastee",16431,33.6833333,-78.9986111 ],
    [ u"us",u"Spartanburg",37992,34.9494444,-81.9322222 ],
    [ u"us",u"Summerville",34958,33.0183333,-80.1758333 ],
    [ u"us",u"Sumter",40079,33.9202778,-80.3416667 ],
    [ u"us",u"Taylors",20184,34.9202778,-82.2963889 ],
    [ u"us",u"Union",8175,34.7152778,-81.6238889 ],
    [ u"us",u"Wade Hampton",20484,34.9036111,-82.3333333 ],
    [ u"us",u"West Columbia",12861,33.9933333,-81.0741667 ],
    [ u"us",u"Aberdeen",23667,45.4647222,-98.4861111 ],
    [ u"us",u"Belle Fourche",4663,44.6713889,-103.8516667 ],
    [ u"us",u"Brandon",7155,43.5947222,-96.5716667 ],
    [ u"us",u"Brookings",18216,44.3113889,-96.7980556 ],
    [ u"us",u"Huron",11026,44.3633333,-98.2138889 ],
    [ u"us",u"Madison",6035,44.0061111,-97.1136111 ],
    [ u"us",u"Mitchell",14741,43.7094444,-98.0294444 ],
    [ u"us",u"Pierre",13879,44.3683333,-100.3505556 ],
    [ u"us",u"Rapid City",61888,44.0805556,-103.2305556 ],
    [ u"us",u"Rapid Valley",7494,44.0625000,-103.1458333 ],
    [ u"us",u"Sioux Falls",140336,43.5500000,-96.7000000 ],
    [ u"us",u"Spearfish",9173,44.4908333,-103.8588889 ],
    [ u"us",u"Sturgis",6362,44.4097222,-103.5086111 ],
    [ u"us",u"Vermillion",10009,42.7794444,-96.9288889 ],
    [ u"us",u"Watertown",20185,44.8994444,-97.1147222 ],
    [ u"us",u"Yankton",13410,42.8711111,-97.3969444 ],
    [ u"us",u"Alcoa",8354,35.7894444,-83.9738889 ],
    [ u"us",u"Athens",13900,35.4427778,-84.5930556 ],
    [ u"us",u"Atoka",5277,35.4411111,-89.7780556 ],
    [ u"us",u"Bartlett",43264,35.2044444,-89.8738889 ],
    [ u"us",u"Bloomingdale",9822,36.5844444,-82.4894444 ],
    [ u"us",u"Brentwood",31279,36.0330556,-86.7827778 ],
    [ u"us",u"Bristol",25110,36.5950000,-82.1888889 ],
    [ u"us",u"Brownsville",10735,35.5938889,-89.2622222 ],
    [ u"us",u"Chattanooga",154024,35.0455556,-85.3097222 ],
    [ u"us",u"Clarksville",111694,36.5297222,-87.3594444 ],
    [ u"us",u"Cleveland",37443,35.1594444,-84.8766667 ],
    [ u"us",u"Clinton",9281,36.1033333,-84.1319444 ],
    [ u"us",u"Collierville",37854,35.0419444,-89.6644444 ],
    [ u"us",u"Columbia",33641,35.6150000,-87.0352778 ],
    [ u"us",u"Cookeville",28668,36.1627778,-85.5016667 ],
    [ u"us",u"Covington",9632,35.5641667,-89.6463889 ],
    [ u"us",u"Crossville",10166,35.9488889,-85.0269444 ],
    [ u"us",u"Dickson",13234,36.0769444,-87.3877778 ],
    [ u"us",u"Dyersburg",17329,36.0344444,-89.3855556 ],
    [ u"us",u"East Brainerd",15114,34.9958333,-85.1502778 ],
    [ u"us",u"East Ridge",19588,35.0141667,-85.2519444 ],
    [ u"us",u"Elizabethton",14958,36.3486111,-82.2108333 ],
    [ u"us",u"Farragut",19312,35.8844444,-84.1536111 ],
    [ u"us",u"Franklin",49706,35.9250000,-86.8688889 ],
    [ u"us",u"Gallatin",26200,36.3883333,-86.4466667 ],
    [ u"us",u"Germantown",37361,35.0866667,-89.8100000 ],
    [ u"us",u"Goodlettsville",14516,36.3230556,-86.7133333 ],
    [ u"us",u"Greeneville",15207,36.1630556,-82.8311111 ],
    [ u"us",u"Hendersonville",44598,36.3047222,-86.6200000 ],
    [ u"us",u"Humboldt",9205,35.8197222,-88.9158333 ],
    [ u"us",u"Jackson",62080,35.6144444,-88.8138889 ],
    [ u"us",u"Johnson City",58603,36.3133333,-82.3536111 ],
    [ u"us",u"Kingsport",43952,36.5483333,-82.5619444 ],
    [ u"us",u"Knoxville",172474,35.9605556,-83.9208333 ],
    [ u"us",u"La Vergne",26412,36.0155556,-86.5819444 ],
    [ u"us",u"Lawrenceburg",10943,35.2422222,-87.3347222 ],
    [ u"us",u"Lebanon",22370,36.2080556,-86.2911111 ],
    [ u"us",u"Lenoir City",7548,35.7972222,-84.2561111 ],
    [ u"us",u"Lewisburg",10693,35.4491667,-86.7888889 ],
    [ u"us",u"Manchester",9218,35.4816667,-86.0886111 ],
    [ u"us",u"Martin",10209,36.3433333,-88.8502778 ],
    [ u"us",u"Maryville",26719,35.7563889,-83.9705556 ],
    [ u"us",u"Memphis",641608,35.1494444,-90.0488889 ],
    [ u"us",u"Middle Valley",11373,35.1958333,-85.1847222 ],
    [ u"us",u"Millington",10021,35.3413889,-89.8972222 ],
    [ u"us",u"Morristown",25204,36.2138889,-83.2950000 ],
    [ u"us",u"Mount Juliet",18586,36.2000000,-86.5186111 ],
    [ u"us",u"Murfreesboro",84700,35.8455556,-86.3902778 ],
    [ u"us",u"Nashville",530852,36.1658333,-86.7844444 ],
    [ u"us",u"Oak Ridge",27414,36.0102778,-84.2697222 ],
    [ u"us",u"Paris",9587,36.3019444,-88.3266667 ],
    [ u"us",u"Portland",10638,36.5816667,-86.5163889 ],
    [ u"us",u"Red Bank",11753,35.1122222,-85.2941667 ],
    [ u"us",u"Sevierville",15655,35.8680556,-83.5619444 ],
    [ u"us",u"Shelbyville",18317,35.4833333,-86.4602778 ],
    [ u"us",u"Smyrna",32963,35.9827778,-86.5186111 ],
    [ u"us",u"Soddy-Daisy",12219,35.2358333,-85.1908333 ],
    [ u"us",u"Spring Hill",15788,35.7511111,-86.9300000 ],
    [ u"us",u"Springfield",15509,36.5091667,-86.8850000 ],
    [ u"us",u"Tullahoma",18692,35.3619444,-86.2094444 ],
    [ u"us",u"Union City",10732,36.4241667,-89.0569444 ],
    [ u"us",u"Abilene",114247,32.4486111,-99.7327778 ],
    [ u"us",u"Addison",13628,32.9616667,-96.8288889 ],
    [ u"us",u"Alamo",16319,26.1833333,-98.1227778 ],
    [ u"us",u"Aldine",15596,29.9322222,-95.3800000 ],
    [ u"us",u"Alice",19589,27.7519444,-98.0694444 ],
    [ u"us",u"Allen",75868,33.1030556,-96.6702778 ],
    [ u"us",u"Alvin",22103,29.4236111,-95.2438889 ],
    [ u"us",u"Amarillo",181766,35.2219444,-101.8308333 ],
    [ u"us",u"Anderson Mill",8744,30.4547222,-97.8055556 ],
    [ u"us",u"Andrews",9384,32.3186111,-102.5452778 ],
    [ u"us",u"Angleton",18856,29.1691667,-95.4316667 ],
    [ u"us",u"Aransas Pass",9121,27.9091667,-97.1497222 ],
    [ u"us",u"Arlington",367535,32.7355556,-97.1077778 ],
    [ u"us",u"Atascocita",35102,29.9986111,-95.1763889 ],
    [ u"us",u"Athens",12387,32.2047222,-95.8552778 ],
    [ u"us",u"Austin",678368,30.2669444,-97.7427778 ],
    [ u"us",u"Azle",10504,32.8950000,-97.5455556 ],
    [ u"us",u"Balch Springs",19401,32.7286111,-96.6225000 ],
    [ u"us",u"Bay City",18663,28.9825000,-95.9691667 ],
    [ u"us",u"Baytown",67341,29.7352778,-94.9772222 ],
    [ u"us",u"Beaumont",111485,30.0858333,-94.1016667 ],
    [ u"us",u"Bedford",49185,32.8438889,-97.1427778 ],
    [ u"us",u"Beeville",13004,28.4005556,-97.7480556 ],
    [ u"us",u"Bellaire",17436,29.7055556,-95.4586111 ],
    [ u"us",u"Bellmead",9801,31.5938889,-97.1086111 ],
    [ u"us",u"Belton",15177,31.0558333,-97.4641667 ],
    [ u"us",u"Benbrook",21590,32.6730556,-97.4602778 ],
    [ u"us",u"Big Spring",24122,32.2502778,-101.4783333 ],
    [ u"us",u"Bonham",10782,33.5772222,-96.1780556 ],
    [ u"us",u"Borger",13408,35.6677778,-101.3969444 ],
    [ u"us",u"Brenham",14609,30.1666667,-96.3975000 ],
    [ u"us",u"Bridge City",8693,30.0205556,-93.8455556 ],
    [ u"us",u"Brownfield",8958,33.1811111,-102.2738889 ],
    [ u"us",u"Brownsville",168015,25.9013889,-97.4972222 ],
    [ u"us",u"Brownwood",19534,31.7091667,-98.9908333 ],
    [ u"us",u"Bryan",69621,30.6741667,-96.3697222 ],
    [ u"us",u"Burkburnett",10629,34.0977778,-98.5702778 ],
    [ u"us",u"Burleson",28534,32.5419444,-97.3205556 ],
    [ u"us",u"Canyon",13036,34.9802778,-101.9183333 ],
    [ u"us",u"Canyon Lake",21649,29.8750000,-98.2622222 ],
    [ u"us",u"Carrollton",120792,32.9536111,-96.8900000 ],
    [ u"us",u"Cedar Hill",44049,32.5883333,-96.9558333 ],
    [ u"us",u"Cedar Park",51695,30.5050000,-97.8200000 ],
    [ u"us",u"Channelview",31924,29.7758333,-95.1144444 ],
    [ u"us",u"Cleburne",28981,32.3475000,-97.3863889 ],
    [ u"us",u"Cloverleaf",26557,29.7780556,-95.1716667 ],
    [ u"us",u"Clute",10800,29.0244444,-95.3986111 ],
    [ u"us",u"College Station",78533,30.6277778,-96.3341667 ],
    [ u"us",u"Colleyville",22325,32.8808333,-97.1547222 ],
    [ u"us",u"Commerce",9735,33.2469444,-95.8997222 ],
    [ u"us",u"Conroe",41643,30.3116667,-95.4558333 ],
    [ u"us",u"Converse",12155,29.5177778,-98.3158333 ],
    [ u"us",u"Coppell",39574,32.9544444,-97.0147222 ],
    [ u"us",u"Copperas Cove",30546,31.1238889,-97.9027778 ],
    [ u"us",u"Corinth",19892,33.1538889,-97.0644444 ],
    [ u"us",u"Corpus Christi",280382,27.8002778,-97.3961111 ],
    [ u"us",u"Corsicana",26037,32.0952778,-96.4686111 ],
    [ u"us",u"Crowley",10034,32.5788889,-97.3622222 ],
    [ u"us",u"Dallas",1211704,32.7833333,-96.8000000 ],
    [ u"us",u"DeSoto",45541,32.5897222,-96.8566667 ],
    [ u"us",u"Deer Park",28772,29.7050000,-95.1236111 ],
    [ u"us",u"Del Rio",36068,29.3625000,-100.8963889 ],
    [ u"us",u"Denison",23680,33.7555556,-96.5363889 ],
    [ u"us",u"Denton",100975,33.2147222,-97.1327778 ],
    [ u"us",u"Dickinson",18348,29.4605556,-95.0511111 ],
    [ u"us",u"Donna",15879,26.1700000,-98.0516667 ],
    [ u"us",u"Dumas",13629,35.8655556,-101.9727778 ],
    [ u"us",u"Duncanville",34991,32.6516667,-96.9080556 ],
    [ u"us",u"Eagle Pass",26090,28.7088889,-100.4991667 ],
    [ u"us",u"Edinburg",60509,26.3013889,-98.1630556 ],
    [ u"us",u"El Campo",10760,29.1963889,-96.2694444 ],
    [ u"us",u"El Paso",597181,31.7586111,-106.4863889 ],
    [ u"us",u"Ennis",19518,32.3291667,-96.6250000 ],
    [ u"us",u"Euless",53221,32.8369444,-97.0816667 ],
    [ u"us",u"Farmers Branch",26468,32.9263889,-96.8958333 ],
    [ u"us",u"Flower Mound",66618,33.0144444,-97.0966667 ],
    [ u"us",u"Forest Hill",13406,32.6719444,-97.2688889 ],
    [ u"us",u"Fort Worth",618119,32.7252778,-97.3205556 ],
    [ u"us",u"Fredericksburg",10927,30.2750000,-98.8716667 ],
    [ u"us",u"Freeport",12632,28.9538889,-95.3594444 ],
    [ u"us",u"Friendswood",34622,29.5291667,-95.2008333 ],
    [ u"us",u"Frisco",71025,33.1505556,-96.8233333 ],
    [ u"us",u"Gainesville",16301,33.6258333,-97.1330556 ],
    [ u"us",u"Galena Park",10252,29.7333333,-95.2300000 ],
    [ u"us",u"Galveston",56420,29.3011111,-94.7975000 ],
    [ u"us",u"Garland",217219,32.9125000,-96.6386111 ],
    [ u"us",u"Gatesville",15489,31.4350000,-97.7436111 ],
    [ u"us",u"Georgetown",38895,30.6325000,-97.6769444 ],
    [ u"us",u"Glenn Heights",8569,32.5486111,-96.8563889 ],
    [ u"us",u"Graham",8636,33.1069444,-98.5891667 ],
    [ u"us",u"Grand Prairie",141122,32.7458333,-96.9975000 ],
    [ u"us",u"Grapevine",49666,32.9341667,-97.0777778 ],
    [ u"us",u"Greenville",25382,33.1383333,-96.1105556 ],
    [ u"us",u"Groves",15119,29.9480556,-93.9169444 ],
    [ u"us",u"Haltom City",41556,32.7994444,-97.2688889 ],
    [ u"us",u"Harker Heights",19049,31.0833333,-97.6594444 ],
    [ u"us",u"Harlingen",63159,26.1902778,-97.6958333 ],
    [ u"us",u"Henderson",10921,32.1530556,-94.7991667 ],
    [ u"us",u"Hereford",14372,34.8150000,-102.3972222 ],
    [ u"us",u"Hewitt",12981,31.4622222,-97.1955556 ],
    [ u"us",u"Hidalgo",10343,26.1000000,-98.2627778 ],
    [ u"us",u"Highland Park",8704,32.8333333,-96.7916667 ],
    [ u"us",u"Highland Village",15365,33.0916667,-97.0463889 ],
    [ u"us",u"Hillsboro",8936,32.0108333,-97.1297222 ],
    [ u"us",u"Hondo",8410,29.3472222,-99.1411111 ],
    [ u"us",u"Houston",2027712,29.7630556,-95.3630556 ],
    [ u"us",u"Humble",14723,29.9986111,-95.2619444 ],
    [ u"us",u"Huntsville",35590,30.7233333,-95.5505556 ],
    [ u"us",u"Hurst",37749,32.8233333,-97.1702778 ],
    [ u"us",u"Ingleside",9630,27.8775000,-97.2113889 ],
    [ u"us",u"Irving",193825,32.8138889,-96.9486111 ],
    [ u"us",u"Jacinto City",10121,29.7672222,-95.2336111 ],
    [ u"us",u"Jacksonville",13943,31.9636111,-95.2702778 ],
    [ u"us",u"Jollyville",16148,30.4425000,-97.7747222 ],
    [ u"us",u"Katy",13371,29.7855556,-95.8241667 ],
    [ u"us",u"Keller",37487,32.9344444,-97.2513889 ],
    [ u"us",u"Kerrville",21894,30.0472222,-99.1400000 ],
    [ u"us",u"Kilgore",11509,32.3861111,-94.8755556 ],
    [ u"us",u"Killeen",103009,31.1169444,-97.7275000 ],
    [ u"us",u"Kingsville",25264,27.5155556,-97.8558333 ],
    [ u"us",u"Kirby",8725,29.4630556,-98.3852778 ],
    [ u"us",u"Kyle",18035,29.9888889,-97.8769444 ],
    [ u"us",u"La Marque",13864,29.3683333,-94.9711111 ],
    [ u"us",u"La Porte",33740,29.6655556,-95.0191667 ],
    [ u"us",u"Lake Jackson",27127,29.0336111,-95.4341667 ],
    [ u"us",u"Lakeway",8235,30.3677778,-97.9913889 ],
    [ u"us",u"Lamesa",9157,32.7375000,-101.9505556 ],
    [ u"us",u"Lancaster",29201,32.5919444,-96.7558333 ],
    [ u"us",u"Laredo",210769,27.5061111,-99.5072222 ],
    [ u"us",u"League City",61894,29.5072222,-95.0947222 ],
    [ u"us",u"Leander",19321,30.5786111,-97.8527778 ],
    [ u"us",u"Leon Valley",9402,29.4950000,-98.6183333 ],
    [ u"us",u"Levelland",12865,33.5872222,-102.3775000 ],
    [ u"us",u"Lewisville",93907,33.0461111,-96.9938889 ],
    [ u"us",u"Liberty",8323,30.0577778,-94.7952778 ],
    [ u"us",u"Little Elm",19991,33.1625000,-96.9372222 ],
    [ u"us",u"Live Oak",10193,29.5650000,-98.3361111 ],
    [ u"us",u"Lockhart",13854,29.8847222,-97.6697222 ],
    [ u"us",u"Longview",75920,32.5005556,-94.7402778 ],
    [ u"us",u"Lubbock",211387,33.5777778,-101.8547222 ],
    [ u"us",u"Lufkin",33667,31.3380556,-94.7288889 ],
    [ u"us",u"Lumberton",9486,30.2655556,-94.1994444 ],
    [ u"us",u"Mansfield",36613,32.5630556,-97.1413889 ],
    [ u"us",u"Marshall",23882,32.5447222,-94.3672222 ],
    [ u"us",u"Mercedes",14227,26.1494444,-97.9133333 ],
    [ u"us",u"Mesquite",131337,32.7666667,-96.5988889 ],
    [ u"us",u"Midland",97782,31.9972222,-102.0775000 ],
    [ u"us",u"Midlothian",13676,32.4822222,-96.9941667 ],
    [ u"us",u"Mineral Wells",16993,32.8083333,-98.1125000 ],
    [ u"us",u"Mission",61486,26.2155556,-98.3250000 ],
    [ u"us",u"Mission Bend",34143,29.6936111,-95.6647222 ],
    [ u"us",u"Missouri City",69715,29.6183333,-95.5375000 ],
    [ u"us",u"Mount Pleasant",14403,33.1566667,-94.9680556 ],
    [ u"us",u"Nacogdoches",30691,31.6033333,-94.6552778 ],
    [ u"us",u"Nederland",16679,29.9741667,-93.9922222 ],
    [ u"us",u"New Braunfels",45840,29.7027778,-98.1241667 ],
    [ u"us",u"North Richland Hills",62821,32.8341667,-97.2286111 ],
    [ u"us",u"Odessa",91256,31.8455556,-102.3672222 ],
    [ u"us",u"Orange",17767,30.0927778,-93.7363889 ],
    [ u"us",u"Palestine",17930,31.7619444,-95.6305556 ],
    [ u"us",u"Pampa",16257,35.5361111,-100.9594444 ],
    [ u"us",u"Paris",27022,33.6608333,-95.5552778 ],
    [ u"us",u"Pasadena",144696,29.6908333,-95.2088889 ],
    [ u"us",u"Pearland",55233,29.5633333,-95.2858333 ],
    [ u"us",u"Pecan Grove",16050,29.6258333,-95.7313889 ],
    [ u"us",u"Pecos",8372,31.4227778,-103.4927778 ],
    [ u"us",u"Pflugerville",29541,30.4391667,-97.6197222 ],
    [ u"us",u"Pharr",60687,26.1944444,-98.1833333 ],
    [ u"us",u"Plainview",21723,34.1847222,-101.7063889 ],
    [ u"us",u"Plano",253372,33.0197222,-96.6986111 ],
    [ u"us",u"Pleasanton",9507,28.9669444,-98.4783333 ],
    [ u"us",u"Port Arthur",56945,29.8986111,-93.9286111 ],
    [ u"us",u"Port Lavaca",11743,28.6147222,-96.6258333 ],
    [ u"us",u"Port Neches",13101,29.9911111,-93.9583333 ],
    [ u"us",u"Portland",15772,27.8769444,-97.3236111 ],
    [ u"us",u"Raymondville",9331,26.4811111,-97.7827778 ],
    [ u"us",u"Richardson",104791,32.9480556,-96.7294444 ],
    [ u"us",u"Richland Hills",8173,32.8158333,-97.2277778 ],
    [ u"us",u"Richmond",14136,29.5819444,-95.7605556 ],
    [ u"us",u"Rio Grande City",13690,26.3794444,-98.8200000 ],
    [ u"us",u"Robinson",8741,31.4675000,-97.1144444 ],
    [ u"us",u"Robstown",12590,27.7900000,-97.6686111 ],
    [ u"us",u"Rockport",8972,28.0202778,-97.0541667 ],
    [ u"us",u"Rockwall",29930,32.9311111,-96.4594444 ],
    [ u"us",u"Rosenberg",29753,29.5569444,-95.8083333 ],
    [ u"us",u"Round Rock",88653,30.5080556,-97.6786111 ],
    [ u"us",u"Rowlett",54785,32.9027778,-96.5636111 ],
    [ u"us",u"Sachse",18239,32.9761111,-96.5950000 ],
    [ u"us",u"Saginaw",18317,32.8600000,-97.3636111 ],
    [ u"us",u"San Angelo",88256,31.4636111,-100.4366667 ],
    [ u"us",u"San Antonio",1256810,29.4238889,-98.4933333 ],
    [ u"us",u"San Benito",24506,26.1322222,-97.6308333 ],
    [ u"us",u"San Juan",30647,26.1888889,-98.1550000 ],
    [ u"us",u"San Marcos",46736,29.8830556,-97.9411111 ],
    [ u"us",u"Santa Fe",10716,29.3777778,-95.1055556 ],
    [ u"us",u"Schertz",28417,29.5519444,-98.2694444 ],
    [ u"us",u"Seabrook",12019,29.5638889,-95.0252778 ],
    [ u"us",u"Seagoville",11007,32.6394444,-96.5380556 ],
    [ u"us",u"Seguin",24000,29.5686111,-97.9644444 ],
    [ u"us",u"Sherman",37108,33.6355556,-96.6086111 ],
    [ u"us",u"Snyder",10600,32.7177778,-100.9172222 ],
    [ u"us",u"Socorro",28637,31.6544444,-106.3027778 ],
    [ u"us",u"South Houston",16041,29.6627778,-95.2352778 ],
    [ u"us",u"Southlake",25755,32.9411111,-97.1338889 ],
    [ u"us",u"Spring",38129,30.0797222,-95.4169444 ],
    [ u"us",u"Stafford",19625,29.6158333,-95.5575000 ],
    [ u"us",u"Stephenville",15637,32.2205556,-98.2019444 ],
    [ u"us",u"Sugar Land",75777,29.6194444,-95.6347222 ],
    [ u"us",u"Sulphur Springs",15029,33.1383333,-95.6008333 ],
    [ u"us",u"Sweetwater",10688,32.4708333,-100.4055556 ],
    [ u"us",u"Taylor",14551,30.5705556,-97.4091667 ],
    [ u"us",u"Temple",55703,31.0980556,-97.3425000 ],
    [ u"us",u"Terrell",17150,32.7358333,-96.2750000 ],
    [ u"us",u"Texarkana",35315,33.4250000,-94.0475000 ],
    [ u"us",u"Texas City",43879,29.3836111,-94.9025000 ],
    [ u"us",u"The Colony",41769,33.0888889,-96.8861111 ],
    [ u"us",u"The Woodlands",75527,30.1577778,-95.4891667 ],
    [ u"us",u"Tomball",10080,30.0969444,-95.6158333 ],
    [ u"us",u"Tyler",90878,32.3511111,-95.3008333 ],
    [ u"us",u"Universal City",15983,29.5477778,-98.2908333 ],
    [ u"us",u"University Park",23785,32.8500000,-96.8000000 ],
    [ u"us",u"Uvalde",17904,29.2094444,-99.7858333 ],
    [ u"us",u"Vernon",10541,34.1544444,-99.2647222 ],
    [ u"us",u"Victoria",62044,28.8050000,-97.0033333 ],
    [ u"us",u"Vidor",11213,30.1313889,-94.0152778 ],
    [ u"us",u"Waco",118967,31.5491667,-97.1463889 ],
    [ u"us",u"Watauga",24333,32.8577778,-97.2544444 ],
    [ u"us",u"Waxahachie",25612,32.3863889,-96.8480556 ],
    [ u"us",u"Weatherford",23051,32.7591667,-97.7969444 ],
    [ u"us",u"Webster",9038,29.5375000,-95.1180556 ],
    [ u"us",u"Weslaco",32732,26.1591667,-97.9905556 ],
    [ u"us",u"West Odessa",18455,31.8422222,-102.4983333 ],
    [ u"us",u"West University Place",15107,29.7177778,-95.4336111 ],
    [ u"us",u"Wharton",9310,29.3113889,-96.1025000 ],
    [ u"us",u"White Settlement",16174,32.7594444,-97.4580556 ],
    [ u"us",u"Wichita Falls",101212,33.9136111,-98.4930556 ],
    [ u"us",u"Woodway",8771,31.5058333,-97.2047222 ],
    [ u"us",u"Wylie",28505,33.0150000,-96.5386111 ],
    [ u"us",u"American Fork",23582,40.3769444,-111.7950000 ],
    [ u"us",u"Bountiful",41581,40.8894444,-111.8800000 ],
    [ u"us",u"Brigham City",17261,41.5102778,-112.0147222 ],
    [ u"us",u"Canyon Rim",10062,40.7066667,-111.8211111 ],
    [ u"us",u"Cedar City",23005,37.6775000,-113.0611111 ],
    [ u"us",u"Centerville",14879,40.9180556,-111.8713889 ],
    [ u"us",u"Clearfield",28424,41.1108333,-112.0252778 ],
    [ u"us",u"Clinton",17295,41.1397222,-112.0497222 ],
    [ u"us",u"Cottonwood Heights",28021,40.6197222,-111.8094444 ],
    [ u"us",u"Draper",35186,40.5247222,-111.8630556 ],
    [ u"us",u"East Millcreek",20816,40.7000000,-111.8097222 ],
    [ u"us",u"Farmington",14328,40.9805556,-111.8866667 ],
    [ u"us",u"Highland",10066,40.4500000,-111.7694444 ],
    [ u"us",u"Holladay",29737,40.6688889,-111.8238889 ],
    [ u"us",u"Hurricane",10275,37.1752778,-113.2891667 ],
    [ u"us",u"Kaysville",22211,41.0352778,-111.9377778 ],
    [ u"us",u"Kearns",35345,40.6600000,-111.9955556 ],
    [ u"us",u"Layton",62308,41.0602778,-111.9702778 ],
    [ u"us",u"Lehi",26401,40.3916667,-111.8500000 ],
    [ u"us",u"Lindon",8870,40.3433333,-111.7200000 ],
    [ u"us",u"Logan",44838,41.7355556,-111.8336111 ],
    [ u"us",u"Magna",24755,40.7091667,-112.1008333 ],
    [ u"us",u"Midvale",27264,40.6111111,-111.8991667 ],
    [ u"us",u"Millcreek",30696,40.6869444,-111.8747222 ],
    [ u"us",u"Murray",54991,40.6669444,-111.8872222 ],
    [ u"us",u"North Ogden",16717,41.3072222,-111.9594444 ],
    [ u"us",u"North Salt Lake",9667,40.8486111,-111.9061111 ],
    [ u"us",u"Ogden",78324,41.2230556,-111.9730556 ],
    [ u"us",u"Orem",93060,40.2969444,-111.6938889 ],
    [ u"us",u"Payson",15912,40.0444444,-111.7313889 ],
    [ u"us",u"Pleasant Grove",24449,40.3641667,-111.7377778 ],
    [ u"us",u"Price",8069,39.5994444,-110.8100000 ],
    [ u"us",u"Provo",105764,40.2338889,-111.6577778 ],
    [ u"us",u"Riverton",31855,40.5219444,-111.9383333 ],
    [ u"us",u"Roy",36265,41.1616667,-112.0255556 ],
    [ u"us",u"Saint George",61338,37.1041667,-113.5833333 ],
    [ u"us",u"Salt Lake City",178026,40.7608333,-111.8902778 ],
    [ u"us",u"South Jordan",37141,40.5622222,-111.9288889 ],
    [ u"us",u"South Ogden",15524,41.1919444,-111.9705556 ],
    [ u"us",u"South Salt Lake",21598,40.7188889,-111.8875000 ],
    [ u"us",u"Spanish Fork",24613,40.1150000,-111.6541667 ],
    [ u"us",u"Springville",22867,40.1652778,-111.6100000 ],
    [ u"us",u"Syracuse",18206,41.0894444,-112.0638889 ],
    [ u"us",u"Taylorsville",58284,40.6677778,-111.9380556 ],
    [ u"us",u"Tooele",29851,40.5308333,-112.2975000 ],
    [ u"us",u"Washington",12316,37.1305556,-113.5075000 ],
    [ u"us",u"Washington Terrace",8349,41.1727778,-111.9758333 ],
    [ u"us",u"West Jordan",101031,40.6097222,-111.9383333 ],
    [ u"us",u"West Valley City",113112,40.6916667,-112.0002778 ],
    [ u"us",u"Barre",9040,44.1969444,-72.5025000 ],
    [ u"us",u"Bennington",18272,42.8780556,-73.1972222 ],
    [ u"us",u"Brattleboro",13373,42.8508333,-72.5583333 ],
    [ u"us",u"Burlington",38601,44.4758333,-73.2125000 ],
    [ u"us",u"Colchester",17245,44.5438889,-73.1483333 ],
    [ u"us",u"Hartford",10834,43.6605556,-72.3388889 ],
    [ u"us",u"Hinesburg",4441,44.3291667,-73.1111111 ],
    [ u"us",u"Jericho",7286,44.5038889,-72.9980556 ],
    [ u"us",u"Lyndon",5496,44.5141667,-72.0113889 ],
    [ u"us",u"Manchester",216,43.1636111,-73.0727778 ],
    [ u"us",u"Middlebury",8862,44.0152778,-73.1677778 ],
    [ u"us",u"Milton",480,44.6397222,-73.1108333 ],
    [ u"us",u"Montpelier",7828,44.2600000,-72.5758333 ],
    [ u"us",u"Morristown",5653,44.5572222,-72.6241667 ],
    [ u"us",u"Newport",5167,44.9363889,-72.2055556 ],
    [ u"us",u"Northfield",1857,44.1511111,-72.6569444 ],
    [ u"us",u"Randolph",5141,43.9250000,-72.6663889 ],
    [ u"us",u"Rockingham",5198,43.1875000,-72.4894444 ],
    [ u"us",u"Rutland",17043,43.6105556,-72.9730556 ],
    [ u"us",u"Saint Albans",7450,44.8108333,-73.0836111 ],
    [ u"us",u"Saint Johnsbury",7762,44.4191667,-72.0155556 ],
    [ u"us",u"Shelburne",7004,44.3805556,-73.2280556 ],
    [ u"us",u"South Burlington",17185,44.4669444,-73.1713889 ],
    [ u"us",u"Springfield",11446,43.2983333,-72.4827778 ],
    [ u"us",u"Stowe",4846,44.4652778,-72.6850000 ],
    [ u"us",u"Swanton",1231,44.9180556,-73.1247222 ],
    [ u"us",u"Waterbury",719,44.3377778,-72.7566667 ],
    [ u"us",u"Williston",8314,44.4375000,-73.0686111 ],
    [ u"us",u"Winooski",6249,44.4913889,-73.1861111 ],
    [ u"us",u"Alexandria",127273,38.8047222,-77.0472222 ],
    [ u"us",u"Annandale",57512,38.8302778,-77.1966667 ],
    [ u"us",u"Arlington",185360,38.8902778,-77.0844444 ],
    [ u"us",u"Blacksburg",40183,37.2294444,-80.4141667 ],
    [ u"us",u"Bluefield",10945,37.2525000,-81.2713889 ],
    [ u"us",u"Bon Air",16268,37.5247222,-77.5580556 ],
    [ u"us",u"Bristol",25110,36.5963889,-82.1886111 ],
    [ u"us",u"Burke",58265,38.7933333,-77.2719444 ],
    [ u"us",u"Cave Spring",25602,37.2275000,-80.0130556 ],
    [ u"us",u"Centreville",65225,38.8402778,-77.4291667 ],
    [ u"us",u"Chantilly",48492,38.8941667,-77.4313889 ],
    [ u"us",u"Charlottesville",34703,38.0291667,-78.4769444 ],
    [ u"us",u"Chesapeake",219124,36.8188889,-76.2752778 ],
    [ u"us",u"Chester",19621,37.3566667,-77.4419444 ],
    [ u"us",u"Christiansburg",18223,37.1297222,-80.4091667 ],
    [ u"us",u"Colonial Heights",17626,37.2438889,-77.4105556 ],
    [ u"us",u"Culpeper",11009,38.4730556,-77.9969444 ],
    [ u"us",u"Dale City",61211,38.6369444,-77.3113889 ],
    [ u"us",u"Danville",45894,36.5858333,-79.3952778 ],
    [ u"us",u"East Highland Park",12917,37.5808333,-77.4072222 ],
    [ u"us",u"Fairfax",22162,38.8461111,-77.3066667 ],
    [ u"us",u"Falls Church",10340,38.8822222,-77.1713889 ],
    [ u"us",u"Fort Hunt",13011,38.7327778,-77.0583333 ],
    [ u"us",u"Franconia",40213,38.7819444,-77.1466667 ],
    [ u"us",u"Fredericksburg",20562,38.3030556,-77.4608333 ],
    [ u"us",u"Front Royal",14616,38.9180556,-78.1947222 ],
    [ u"us",u"Glen Allen",14820,37.6658333,-77.5066667 ],
    [ u"us",u"Groveton",22136,38.7672222,-77.0850000 ],
    [ u"us",u"Hampton",147993,37.0297222,-76.3455556 ],
    [ u"us",u"Harrisonburg",41725,38.4494444,-78.8691667 ],
    [ u"us",u"Herndon",21499,38.9694444,-77.3863889 ],
    [ u"us",u"Highland Springs",15942,37.5458333,-77.3280556 ],
    [ u"us",u"Hollins",14942,37.3411111,-79.9433333 ],
    [ u"us",u"Hopewell",22260,37.3041667,-77.2875000 ],
    [ u"us",u"Hybla Valley",17491,38.7475000,-77.0833333 ],
    [ u"us",u"Idylwood",16805,38.8950000,-77.2119444 ],
    [ u"us",u"Jefferson",28487,38.8644444,-77.1880556 ],
    [ u"us",u"Lake Ridge",34382,38.6877778,-77.2980556 ],
    [ u"us",u"Lakeside",10847,37.6075000,-77.4772222 ],
    [ u"us",u"Laurel",15986,37.6427778,-77.5091667 ],
    [ u"us",u"Leesburg",37053,39.1155556,-77.5638889 ],
    [ u"us",u"Lincolnia",17430,38.8183333,-77.1436111 ],
    [ u"us",u"Lorton",19215,38.7041667,-77.2280556 ],
    [ u"us",u"Lynchburg",65517,37.4136111,-79.1425000 ],
    [ u"us",u"Madison Heights",11636,37.4308333,-79.1233333 ],
    [ u"us",u"Manassas",37699,38.7508333,-77.4755556 ],
    [ u"us",u"Manassas Park",11323,38.7838889,-77.4700000 ],
    [ u"us",u"Martinsville",14874,36.6913889,-79.8727778 ],
    [ u"us",u"Mechanicsville",35803,37.6086111,-77.3736111 ],
    [ u"us",u"Montclair",18465,38.6108333,-77.3400000 ],
    [ u"us",u"Mount Vernon",29379,38.7077778,-77.0863889 ],
    [ u"us",u"Newington",20891,38.7383333,-77.1852778 ],
    [ u"us",u"Newport News",183444,36.9786111,-76.4283333 ],
    [ u"us",u"Norfolk",246216,36.8466667,-76.2855556 ],
    [ u"us",u"North Springfield",9342,38.8041667,-77.2050000 ],
    [ u"us",u"Oakton",32171,38.8808333,-77.3011111 ],
    [ u"us",u"Petersburg",32812,37.2277778,-77.4022222 ],
    [ u"us",u"Poquoson",12086,37.1222222,-76.3461111 ],
    [ u"us",u"Portsmouth",99049,36.8352778,-76.2986111 ],
    [ u"us",u"Pulaski",9016,37.0477778,-80.7800000 ],
    [ u"us",u"Radford",14117,37.1316667,-80.5766667 ],
    [ u"us",u"Reston",61076,38.9686111,-77.3413889 ],
    [ u"us",u"Richmond",190886,37.5536111,-77.4605556 ],
    [ u"us",u"Roanoke",91168,37.2708333,-79.9416667 ],
    [ u"us",u"Salem",24314,37.2933333,-80.0550000 ],
    [ u"us",u"Springfield",34510,38.7891667,-77.1875000 ],
    [ u"us",u"Staunton",24040,38.1494444,-79.0719444 ],
    [ u"us",u"Suffolk",80690,36.7280556,-76.5838889 ],
    [ u"us",u"Timberlake",10961,37.3205556,-79.2577778 ],
    [ u"us",u"Tuckahoe",43931,37.5900000,-77.5566667 ],
    [ u"us",u"Tysons Corner",22008,38.9186111,-77.2313889 ],
    [ u"us",u"Vienna",14986,38.9011111,-77.2655556 ],
    [ u"us",u"Virginia Beach",449386,36.8527778,-75.9783333 ],
    [ u"us",u"Waynesboro",20904,38.0683333,-78.8897222 ],
    [ u"us",u"West Springfield",28758,38.7725000,-77.2213889 ],
    [ u"us",u"Williamsburg",11400,37.2705556,-76.7077778 ],
    [ u"us",u"Winchester",24895,39.1855556,-78.1636111 ],
    [ u"us",u"Wolf Trap",14561,38.9397222,-77.2863889 ],
    [ u"us",u"Woodbridge",35252,38.6580556,-77.2500000 ],
    [ u"us",u"Aberdeen",16055,46.9755556,-123.8144444 ],
    [ u"us",u"Alderwood Manor",16875,47.8222222,-122.2808333 ],
    [ u"us",u"Anacortes",16061,48.5127778,-122.6113889 ],
    [ u"us",u"Auburn",45650,47.3075000,-122.2272222 ],
    [ u"us",u"Bellevue",111927,47.6105556,-122.1994444 ],
    [ u"us",u"Bellingham",73469,48.7597222,-122.4869444 ],
    [ u"us",u"Bonney Lake",14873,47.1772222,-122.1852778 ],
    [ u"us",u"Bothell",30615,47.7625000,-122.2041667 ],
    [ u"us",u"Bremerton",44053,47.5675000,-122.6313889 ],
    [ u"us",u"Burien",30611,47.4705556,-122.3455556 ],
    [ u"us",u"Burlington",8286,48.4758333,-122.3241667 ],
    [ u"us",u"Camas",17040,45.5872222,-122.3983333 ],
    [ u"us",u"Centralia",15107,46.7163889,-122.9530556 ],
    [ u"us",u"Cheney",10292,47.4875000,-117.5747222 ],
    [ u"us",u"College Place",8843,46.0494444,-118.3872222 ],
    [ u"us",u"Covington",16841,47.3483333,-122.1136111 ],
    [ u"us",u"Des Moines",28668,47.4019444,-122.3230556 ],
    [ u"us",u"East Renton Highlands",12991,47.4850000,-122.1111111 ],
    [ u"us",u"East Wenatchee",8856,47.4158333,-120.2919444 ],
    [ u"us",u"East Wenatchee Bench",13902,47.4258333,-120.2800000 ],
    [ u"us",u"Edgewood",9727,47.2502778,-122.2925000 ],
    [ u"us",u"Edmonds",39917,47.8108333,-122.3761111 ],
    [ u"us",u"Elk Plain",17279,47.0533333,-122.3963889 ],
    [ u"us",u"Ellensburg",17049,46.9966667,-120.5466667 ],
    [ u"us",u"Enumclaw",10857,47.2044444,-121.9902778 ],
    [ u"us",u"Esperance",3833,47.7891667,-122.3541667 ],
    [ u"us",u"Everett",96993,47.9791667,-122.2008333 ],
    [ u"us",u"Federal Way",80815,47.3225000,-122.3113889 ],
    [ u"us",u"Ferndale",10098,48.8466667,-122.5897222 ],
    [ u"us",u"Grandview",8620,46.2511111,-119.9005556 ],
    [ u"us",u"Hoquiam",8835,46.9811111,-123.8880556 ],
    [ u"us",u"Issaquah",16853,47.5302778,-122.0313889 ],
    [ u"us",u"Kelso",11648,46.1469444,-122.9072222 ],
    [ u"us",u"Kenmore",19284,47.7575000,-122.2427778 ],
    [ u"us",u"Kennewick",62158,46.2113889,-119.1361111 ],
    [ u"us",u"Kent",82276,47.3811111,-122.2336111 ],
    [ u"us",u"Kingsgate",11873,47.7272222,-122.1783333 ],
    [ u"us",u"Kirkland",45778,47.6816667,-122.2075000 ],
    [ u"us",u"Lacey",33755,47.0344444,-122.8219444 ],
    [ u"us",u"Lake Forest Park",12368,47.7569444,-122.2797222 ],
    [ u"us",u"Lakewood",58912,47.1719444,-122.5172222 ],
    [ u"us",u"Longview",36349,46.1383333,-122.9369444 ],
    [ u"us",u"Lynden",10816,48.9466667,-122.4508333 ],
    [ u"us",u"Lynnwood",33478,47.8211111,-122.3138889 ],
    [ u"us",u"Maple Valley",14100,47.4066667,-122.0375000 ],
    [ u"us",u"Martha Lake",13686,47.8511111,-122.2380556 ],
    [ u"us",u"Marysville",29824,48.0519444,-122.1758333 ],
    [ u"us",u"Mercer Island",22476,47.5708333,-122.2208333 ],
    [ u"us",u"Mill Creek",13466,47.8602778,-122.2030556 ],
    [ u"us",u"Minnehaha",7283,45.6591667,-122.6475000 ],
    [ u"us",u"Monroe",15554,47.8555556,-121.9697222 ],
    [ u"us",u"Moses Lake",16626,47.1302778,-119.2769444 ],
    [ u"us",u"Mount Vernon",29312,48.4213889,-122.3327778 ],
    [ u"us",u"Mountlake Terrace",20445,47.7883333,-122.3075000 ],
    [ u"us",u"Mukilteo",19927,47.9447222,-122.3033333 ],
    [ u"us",u"Newcastle",9333,47.5391667,-122.1544444 ],
    [ u"us",u"North Creek",26410,47.8197222,-122.1750000 ],
    [ u"us",u"North Marysville",21922,48.0994444,-122.1475000 ],
    [ u"us",u"Oak Harbor",22031,48.2933333,-122.6419444 ],
    [ u"us",u"Olympia",44916,47.0380556,-122.8994444 ],
    [ u"us",u"Opportunity",25877,47.6575000,-117.2388889 ],
    [ u"us",u"Parkland",25133,47.1555556,-122.4327778 ],
    [ u"us",u"Pasco",43390,46.2397222,-119.0994444 ],
    [ u"us",u"Port Angeles",18636,48.1183333,-123.4294444 ],
    [ u"us",u"Port Townsend",8970,48.1172222,-122.7591667 ],
    [ u"us",u"Pullman",25636,46.7313889,-117.1786111 ],
    [ u"us",u"Puyallup",36675,47.1855556,-122.2916667 ],
    [ u"us",u"Redmond",47264,47.6741667,-122.1202778 ],
    [ u"us",u"Renton",56141,47.4830556,-122.2158333 ],
    [ u"us",u"Richland",44869,46.2858333,-119.2833333 ],
    [ u"us",u"Salmon Creek",19192,45.7108333,-122.6477778 ],
    [ u"us",u"Sammamish",33929,47.6419444,-122.0791667 ],
    [ u"us",u"SeaTac",24663,47.4538889,-122.3205556 ],
    [ u"us",u"Seattle",569369,47.6063889,-122.3308333 ],
    [ u"us",u"Sedro-Woolley",10605,48.5038889,-122.2361111 ],
    [ u"us",u"Shelton",9032,47.2152778,-123.0994444 ],
    [ u"us",u"Shoreline",51657,47.7558333,-122.3402778 ],
    [ u"us",u"Snohomish",8708,47.9130556,-122.0969444 ],
    [ u"us",u"South Hill",44139,47.1413889,-122.2688889 ],
    [ u"us",u"Spanaway",25045,47.1041667,-122.4333333 ],
    [ u"us",u"Spokane",197262,47.6588889,-117.4250000 ],
    [ u"us",u"Sumner",9343,47.2033333,-122.2391667 ],
    [ u"us",u"Sunnyside",14208,46.3238889,-120.0075000 ],
    [ u"us",u"Tacoma",196957,47.2530556,-122.4430556 ],
    [ u"us",u"Toppenish",9186,46.3775000,-120.3075000 ],
    [ u"us",u"Tukwila",17022,47.4741667,-122.2597222 ],
    [ u"us",u"Tumwater",13374,47.0075000,-122.9080556 ],
    [ u"us",u"University Place",30873,47.2358333,-122.5491667 ],
    [ u"us",u"Vancouver",157517,45.6388889,-122.6602778 ],
    [ u"us",u"Walla Walla",30578,46.0647222,-118.3419444 ],
    [ u"us",u"Washougal",10234,45.5827778,-122.3522222 ],
    [ u"us",u"Wenatchee",29159,47.4236111,-120.3091667 ],
    [ u"us",u"West Lake Stevens",21047,47.9936111,-122.1005556 ],
    [ u"us",u"West Richland",9869,46.3044444,-119.3602778 ],
    [ u"us",u"White Center",20716,47.5175000,-122.3536111 ],
    [ u"us",u"Woodinville",10126,47.7544444,-122.1622222 ],
    [ u"us",u"Yakima",88405,46.6022222,-120.5047222 ],
    [ u"us",u"Beckley",16880,37.7780556,-81.1883333 ],
    [ u"us",u"Bluefield",10945,37.2697222,-81.2225000 ],
    [ u"us",u"Charleston",50427,38.3497222,-81.6327778 ],
    [ u"us",u"Clarksburg",16232,39.2805556,-80.3447222 ],
    [ u"us",u"Cross Lanes",10133,38.4202778,-81.7908333 ],
    [ u"us",u"Fairmont",18820,39.4850000,-80.1427778 ],
    [ u"us",u"Huntington",48518,38.4191667,-82.4452778 ],
    [ u"us",u"Martinsburg",15616,39.4561111,-77.9641667 ],
    [ u"us",u"Morgantown",28957,39.6294444,-79.9561111 ],
    [ u"us",u"Moundsville",9638,39.9202778,-80.7433333 ],
    [ u"us",u"Parkersburg",31564,39.2666667,-81.5616667 ],
    [ u"us",u"Saint Albans",10990,38.3855556,-81.8363889 ],
    [ u"us",u"South Charleston",12722,38.3683333,-81.6997222 ],
    [ u"us",u"Vienna",10909,39.3269444,-81.5486111 ],
    [ u"us",u"Weirton",19450,40.4188889,-80.5897222 ],
    [ u"us",u"Wheeling",29388,40.0638889,-80.7211111 ],
    [ u"us",u"Allouez",14990,44.4775000,-88.0161111 ],
    [ u"us",u"Appleton",70112,44.2619444,-88.4152778 ],
    [ u"us",u"Ashwaubenon",16842,44.4822222,-88.0700000 ],
    [ u"us",u"Baraboo",10907,43.4711111,-89.7441667 ],
    [ u"us",u"Beaver Dam",14856,43.4577778,-88.8372222 ],
    [ u"us",u"Bellevue",14394,44.4441667,-87.9200000 ],
    [ u"us",u"Beloit",35210,42.5083333,-89.0316667 ],
    [ u"us",u"Brookfield",40056,43.0605556,-88.1063889 ],
    [ u"us",u"Brown Deer",11911,43.1633333,-87.9644444 ],
    [ u"us",u"Burlington",11414,42.6780556,-88.2761111 ],
    [ u"us",u"Caledonia",24282,42.8077778,-87.9241667 ],
    [ u"us",u"Cedarburg",11220,43.2966667,-87.9875000 ],
    [ u"us",u"Chippewa Falls",12607,44.9369444,-91.3927778 ],
    [ u"us",u"Cudahy",18099,42.9597222,-87.8613889 ],
    [ u"us",u"De Pere",23419,44.4488889,-88.0602778 ],
    [ u"us",u"Eau Claire",62852,44.8113889,-91.4983333 ],
    [ u"us",u"Fitchburg",22586,42.9608333,-89.4697222 ],
    [ u"us",u"Fond du Lac",41860,43.7730556,-88.4469444 ],
    [ u"us",u"Fort Atkinson",11791,42.9288889,-88.8369444 ],
    [ u"us",u"Franklin",33272,42.8886111,-88.0383333 ],
    [ u"us",u"Germantown",19465,43.2286111,-88.1102778 ],
    [ u"us",u"Glendale",12974,43.1352778,-87.9355556 ],
    [ u"us",u"Grafton",11833,43.3197222,-87.9533333 ],
    [ u"us",u"Green Bay",101012,44.5191667,-88.0197222 ],
    [ u"us",u"Greendale",13990,42.9405556,-87.9958333 ],
    [ u"us",u"Greenfield",36493,42.9613889,-88.0125000 ],
    [ u"us",u"Hartford",12525,43.3177778,-88.3788889 ],
    [ u"us",u"Hartland",8786,43.1050000,-88.3419444 ],
    [ u"us",u"Howard",16379,44.5436111,-88.0880556 ],
    [ u"us",u"Hudson",11288,44.9747222,-92.7566667 ],
    [ u"us",u"Janesville",61675,42.6827778,-89.0186111 ],
    [ u"us",u"Kaukauna",14788,44.2780556,-88.2719444 ],
    [ u"us",u"Kenosha",93982,42.5847222,-87.8211111 ],
    [ u"us",u"La Crosse",50470,43.8013889,-91.2394444 ],
    [ u"us",u"Little Chute",10698,44.2800000,-88.3183333 ],
    [ u"us",u"Madison",224625,43.0730556,-89.4011111 ],
    [ u"us",u"Manitowoc",33939,44.0886111,-87.6575000 ],
    [ u"us",u"Marinette",11171,45.1000000,-87.6305556 ],
    [ u"us",u"Marshfield",18670,44.6688889,-90.1716667 ],
    [ u"us",u"Menasha",16621,44.2022222,-88.4463889 ],
    [ u"us",u"Menomonee Falls",34515,43.1788889,-88.1172222 ],
    [ u"us",u"Menomonie",15361,44.8755556,-91.9191667 ],
    [ u"us",u"Mequon",23902,43.2363889,-87.9844444 ],
    [ u"us",u"Merrill",10184,45.1805556,-89.6833333 ],
    [ u"us",u"Middleton",16288,43.0972222,-89.5041667 ],
    [ u"us",u"Milwaukee",579180,43.0388889,-87.9063889 ],
    [ u"us",u"Monroe",10608,42.6011111,-89.6383333 ],
    [ u"us",u"Muskego",22889,42.9058333,-88.1388889 ],
    [ u"us",u"Neenah",24810,44.1858333,-88.4625000 ],
    [ u"us",u"New Berlin",38735,42.9763889,-88.1083333 ],
    [ u"us",u"Oak Creek",34755,42.8858333,-87.8630556 ],
    [ u"us",u"Oconomowoc",13757,43.1116667,-88.4991667 ],
    [ u"us",u"Onalaska",15924,43.8844444,-91.2350000 ],
    [ u"us",u"Oshkosh",63017,44.0247222,-88.5425000 ],
    [ u"us",u"Pewaukee",13332,43.0805556,-88.2611111 ],
    [ u"us",u"Platteville",9786,42.7341667,-90.4783333 ],
    [ u"us",u"Pleasant Prairie",19458,42.5530556,-87.9333333 ],
    [ u"us",u"Plover",11464,44.4563889,-89.5438889 ],
    [ u"us",u"Port Washington",11030,43.3872222,-87.8755556 ],
    [ u"us",u"Portage",10098,43.5391667,-89.4625000 ],
    [ u"us",u"Racine",79263,42.7261111,-87.7827778 ],
    [ u"us",u"Richfield",10892,43.2561111,-88.1938889 ],
    [ u"us",u"River Falls",13435,44.8613889,-92.6236111 ],
    [ u"us",u"Salem",11416,42.5547222,-88.1108333 ],
    [ u"us",u"Sheboygan",48591,43.7508333,-87.7144444 ],
    [ u"us",u"Shorewood",13192,43.0891667,-87.8875000 ],
    [ u"us",u"Somers",9454,42.6402778,-87.9102778 ],
    [ u"us",u"South Milwaukee",21059,42.9105556,-87.8605556 ],
    [ u"us",u"Stevens Point",24408,44.5236111,-89.5744444 ],
    [ u"us",u"Stoughton",12735,42.9169444,-89.2177778 ],
    [ u"us",u"Sturgeon Bay",9492,44.8341667,-87.3769444 ],
    [ u"us",u"Suamico",10297,44.6319444,-88.0391667 ],
    [ u"us",u"Sun Prairie",25561,43.1836111,-89.2136111 ],
    [ u"us",u"Superior",27130,46.7208333,-92.1038889 ],
    [ u"us",u"Sussex",10152,43.1338889,-88.2219444 ],
    [ u"us",u"Two Rivers",11985,44.1538889,-87.5691667 ],
    [ u"us",u"Verona",10649,42.9908333,-89.5330556 ],
    [ u"us",u"Watertown",23323,43.1947222,-88.7288889 ],
    [ u"us",u"Waukesha",68112,43.0116667,-88.2313889 ],
    [ u"us",u"Waunakee",10366,43.1919444,-89.4555556 ],
    [ u"us",u"Waupun",10480,43.6333333,-88.7294444 ],
    [ u"us",u"Wausau",36779,44.9591667,-89.6300000 ],
    [ u"us",u"Wauwatosa",45453,43.0494444,-88.0075000 ],
    [ u"us",u"West Allis",59363,43.0166667,-88.0069444 ],
    [ u"us",u"West Bend",29431,43.4252778,-88.1833333 ],
    [ u"us",u"Weston",13080,44.8908333,-89.5475000 ],
    [ u"us",u"Whitefish Bay",13611,43.1133333,-87.9000000 ],
    [ u"us",u"Whitewater",14536,42.8336111,-88.7322222 ],
    [ u"us",u"Wisconsin Rapids",17724,44.3836111,-89.8172222 ],
    [ u"us",u"Casper",51507,42.8666667,-106.3125000 ],
    [ u"us",u"Cheyenne",55443,41.1400000,-104.8197222 ],
    [ u"us",u"Cody",9161,44.5263889,-109.0558333 ],
    [ u"us",u"Douglas",5378,42.7597222,-105.3816667 ],
    [ u"us",u"Evanston",11258,41.2683333,-110.9625000 ],
    [ u"us",u"Gillette",23101,44.2911111,-105.5016667 ],
    [ u"us",u"Green River",11358,41.5286111,-109.4655556 ],
    [ u"us",u"Jackson",8989,43.4800000,-110.7616667 ],
    [ u"us",u"Lander",6821,42.8330556,-108.7300000 ],
    [ u"us",u"Laramie",26934,41.3113889,-105.5905556 ],
    [ u"us",u"Powell",5213,44.7538889,-108.7566667 ],
    [ u"us",u"Rawlins",8533,41.7911111,-107.2380556 ],
    [ u"us",u"Riverton",9192,43.0250000,-108.3794444 ],
    [ u"us",u"Rock Springs",18226,41.5875000,-109.2022222 ],
    [ u"us",u"Sheridan",16154,44.7972222,-106.9555556 ],
    [ u"us",u"Torrington",5483,42.0650000,-104.1811111 ],
    [ u"us",u"Worland",4729,44.0169444,-107.9547222 ],
    [ u"uy",u"Artigas",44564,-30.4,-56.4666667 ],
    [ u"uy",u"Bella Unión",14639,-30.25,-57.5833333 ],
    [ u"uy",u"Canelones",21081,-34.5227778,-56.2777778 ],
    [ u"uy",u"Carmelo",18713,-33.9891667,-58.2855556 ],
    [ u"uy",u"Chuy",11287,-33.6833333,-53.45 ],
    [ u"uy",u"Colonia",24870,-34.4666667,-57.85 ],
    [ u"uy",u"Delta del Tigre",17952,-34.7633333,-56.3852778 ],
    [ u"uy",u"Dolores",16205,-33.5441667,-58.1972222 ],
    [ u"uy",u"Durazno",32782,-33.4130556,-56.5005556 ],
    [ u"uy",u"Florida",34002,-34.0955556,-56.2141667 ],
    [ u"uy",u"Fray Bentos",23566,-33.1325,-58.2955556 ],
    [ u"uy",u"Juan Lacaze",13263,-34.4333333,-57.4166667 ],
    [ u"uy",u"La Paz",22804,-34.7616667,-56.2236111 ],
    [ u"uy",u"Las Piedras",72965,-34.7263889,-56.22 ],
    [ u"uy",u"Maldonado",67188,-34.9,-54.95 ],
    [ u"uy",u"Melo",50833,-32.3666667,-54.1833333 ],
    [ u"uy",u"Mercedes",41075,-33.2558333,-58.0191667 ],
    [ u"uy",u"Minas",39123,-34.37,-55.225 ],
    [ u"uy",u"Montevideo",1305865,-34.8580556,-56.1708333 ],
    [ u"uy",u"Nueva Helvecia",10305,-34.3166667,-57.2166667 ],
    [ u"uy",u"Pando",28775,-34.7166667,-55.95 ],
    [ u"uy",u"Paso de Carrasco",13846,-34.8602778,-56.0522222 ],
    [ u"uy",u"Paso de los Toros",13599,-32.8166667,-56.5166667 ],
    [ u"uy",u"Paysandú",78902,-32.3213889,-58.0755556 ],
    [ u"uy",u"Progreso",17715,-34.665,-56.2194444 ],
    [ u"uy",u"Río Branco",17405,-32.5666667,-53.4166667 ],
    [ u"uy",u"Rivera",68020,-30.9,-55.5166667 ],
    [ u"uy",u"Rocha",27695,-34.4833333,-54.3333333 ],
    [ u"uy",u"Salto",104667,-31.3833333,-57.9666667 ],
    [ u"uy",u"San Carlos",27613,-34.8,-54.9166667 ],
    [ u"uy",u"San José",37606,-34.3375,-56.7136111 ],
    [ u"uy",u"Santa Lucía",18022,-34.4533333,-56.3905556 ],
    [ u"uy",u"Tacuarembó",50575,-31.7333333,-55.9833333 ],
    [ u"uy",u"Treinta y Tres",27433,-33.2333333,-54.3833333 ],
    [ u"uy",u"Trinidad",21110,-33.5333333,-56.9 ],
    [ u"uy",u"Young",16600,-32.6833333,-57.6333333 ],
    [ u"uz",u"Aktash",38307,39.9166667,65.9666667 ],
    [ u"uz",u"Almazar",24781,40.9833333,68.9 ],
    [ u"uz",u"Andijon",318439,40.6541667,72.3575 ],
    [ u"uz",u"Angren",126962,41.0166667,70.1436111 ],
    [ u"uz",u"Asaka",56736,40.6413889,72.2372222 ],
    [ u"uz",u"Bekobod",86266,40.2208333,69.2697222 ],
    [ u"uz",u"Bektemir",26380,41.2097222,69.3341667 ],
    [ u"uz",u"Beruni",50929,41.6911111,60.7525 ],
    [ u"uz",u"Boysun",25050,38.2061111,67.1986111 ],
    [ u"uz",u"Boz",23750,40.6872222,71.9233333 ],
    [ u"uz",u"Buka",19642,40.8108333,69.1986111 ],
    [ u"uz",u"Denau",69094,38.2666667,67.9 ],
    [ u"uz",u"Druzhba",17226,41.2222222,61.3066667 ],
    [ u"uz",u"Dustlik",16524,40.5247222,68.0358333 ],
    [ u"uz",u"Gagarin",24856,40.6619444,68.1722222 ],
    [ u"uz",u"Gazalkent",24610,41.5580556,69.7708333 ],
    [ u"uz",u"Gazli",11446,40.1333333,63.45 ],
    [ u"uz",u"Guliston",53418,40.4897222,68.7841667 ],
    [ u"uz",u"Gurlan",27506,41.8447222,60.3919444 ],
    [ u"uz",u"Hamza",13470,40.4263889,71.4955556 ],
    [ u"uz",u"Hazorasp",17643,41.3194444,61.0741667 ],
    [ u"uz",u"Iskandar",27636,41.5538889,69.7008333 ],
    [ u"uz",u"Karauzyak",27081,43.0275,60.0125 ],
    [ u"uz",u"Karmana",23007,40.1413889,65.365 ],
    [ u"uz",u"Kegayli",14147,42.7766667,59.6077778 ],
    [ u"uz",u"Kibray",27750,41.3897222,69.465 ],
    [ u"uz",u"Kitob",41938,39.1180556,66.8755556 ],
    [ u"uz",u"Kogon",62696,39.7227778,64.5516667 ],
    [ u"uz",u"Koson",59681,39.0375,65.585 ],
    [ u"uz",u"Kosonsoy",43684,41.2561111,71.5508333 ],
    [ u"uz",u"Krasnogorskiy",11762,41.1494444,69.6711111 ],
    [ u"uz",u"Kuva",33167,40.5236111,72.0616667 ],
    [ u"uz",u"Kuybyshevo",30117,40.3566667,71.2847222 ],
    [ u"uz",u"Mangit",30854,42.1155556,60.0597222 ],
    [ u"uz",u"Maymanak",17010,39.0561111,65.4211111 ],
    [ u"uz",u"Muborak",29180,39.2552778,65.1527778 ],
    [ u"uz",u"Namangan",432479,40.9952778,71.6725 ],
    [ u"uz",u"Navoi",129734,40.0844444,65.3791667 ],
    [ u"uz",u"Nukus",230020,42.4530556,59.6102778 ],
    [ u"uz",u"Nurobod",9960,39.6086111,66.2866667 ],
    [ u"uz",u"Nurota",29403,40.5613889,65.6886111 ],
    [ u"uz",u"Ohangaron",35516,40.9063889,69.6383333 ],
    [ u"uz",u"Olot",11984,39.415,63.8033333 ],
    [ u"uz",u"Parkent",35972,41.2944444,69.6763889 ],
    [ u"uz",u"Paytug",25597,40.8941667,72.2436111 ],
    [ u"uz",u"Pop",22122,40.8736111,71.1088889 ],
    [ u"uz",u"Pskent",27864,40.8972222,69.3505556 ],
    [ u"uz",u"Romitan",12927,39.9294444,64.3794444 ],
    [ u"uz",u"Salar",26494,41.3722222,69.3816667 ],
    [ u"uz",u"Samarkand",319404,39.6541667,66.9597222 ],
    [ u"uz",u"Soldatskiy",14161,40.8636111,68.9347222 ],
    [ u"uz",u"Stantsiya Gorchakovo",14114,40.4272222,71.7188889 ],
    [ u"uz",u"Tashkent",1978078,41.3166667,69.25 ],
    [ u"uz",u"Termiz",140404,37.2241667,67.2783333 ],
    [ u"uz",u"Turtkul",48908,41.5544444,61.0011111 ],
    [ u"uz",u"Tuytepa",19985,41.0427778,69.3572222 ],
    [ u"uz",u"Urgut",47373,39.4022222,67.2430556 ],
    [ u"uz",u"Urtaaul",14046,41.1866667,69.1452778 ],
    [ u"uz",u"Yaypan",20332,40.3758333,70.8155556 ],
    [ u"uz",u"Zomin",27078,39.9605556,68.3958333 ],
    [ u"vc",u"Barroualie",1902,13.2333333,-61.2666667 ],
    [ u"vc",u"Biabou",1050,13.2,-61.1333333 ],
    [ u"vc",u"Chateaubelair",735,13.2833333,-61.25 ],
    [ u"vc",u"Dovers",525,12.8833333,-61.1833333 ],
    [ u"vc",u"Georgetown",1708,13.2666667,-61.1166667 ],
    [ u"vc",u"Kingstown",17995,13.1333333,-61.2166667 ],
    [ u"vc",u"Layou",1609,13.2,-61.2666667 ],
    [ u"vc",u"Port Elizabeth",839,13.0166667,-61.2333333 ],
    [ u"ve",u"Acarigua",143739,9.5597222,-69.2019444 ],
    [ u"ve",u"Altagracia de Orituco",40058,9.8622222,-66.3805556 ],
    [ u"ve",u"Anaco",117605,9.4375,-64.4730556 ],
    [ u"ve",u"Araure",73074,9.5666667,-69.2166667 ],
    [ u"ve",u"Bachaquero",30869,9.9683333,-71.1161111 ],
    [ u"ve",u"Barcelona",424819,10.1333333,-64.7 ],
    [ u"ve",u"Barinas",284305,8.6291667,-70.2072222 ],
    [ u"ve",u"Barinitas",34397,8.7622222,-70.4111111 ],
    [ u"ve",u"Barquisimeto",809564,10.0738889,-69.3227778 ],
    [ u"ve",u"Baruta",244216,10.4333333,-66.8833333 ],
    [ u"ve",u"Cabimas",200859,10.4019444,-71.4461111 ],
    [ u"ve",u"Cabudare",131013,10.0288889,-69.0894444 ],
    [ u"ve",u"Cagua",119052,10.1833333,-67.45 ],
    [ u"ve",u"Calabozo",117148,8.9344444,-67.4266667 ],
    [ u"ve",u"Cantaura",33042,9.3105556,-64.3594444 ],
    [ u"ve",u"Caraballeda",37831,10.6166667,-66.8333333 ],
    [ u"ve",u"Caracas",1815681,10.5,-66.9166667 ],
    [ u"ve",u"Carora",93803,10.1777778,-70.0805556 ],
    [ u"ve",u"Carrizal",40618,10.35,-66.9833333 ],
    [ u"ve",u"Carúpano",112102,10.6697222,-63.2491667 ],
    [ u"ve",u"Catia La Mar",106850,10.6,-67.0333333 ],
    [ u"ve",u"Caucaguita",52555,10.3611111,-66.8083333 ],
    [ u"ve",u"Chacao",64755,10.5,-66.85 ],
    [ u"ve",u"Charallave",129213,10.2483333,-66.8566667 ],
    [ u"ve",u"Chivacoa",45912,10.1602778,-68.895 ],
    [ u"ve",u"Ciudad Bolívar",291170,8.1222222,-63.5497222 ],
    [ u"ve",u"Ciudad Guayana",746606,8.3533333,-62.6527778 ],
    [ u"ve",u"Ciudad Ojeda",73931,10.2033333,-71.31 ],
    [ u"ve",u"Coro",195246,11.4091667,-69.6672222 ],
    [ u"ve",u"Cúa",182925,10.1622222,-66.8852778 ],
    [ u"ve",u"Cumaná",257821,10.4666667,-64.1666667 ],
    [ u"ve",u"Ejido",107056,8.5513889,-71.2375 ],
    [ u"ve",u"El Cafetal",80029,10.4666667,-66.8277778 ],
    [ u"ve",u"El Hatillo",57591,10.4333333,-66.8166667 ],
    [ u"ve",u"El Limón",148270,10.3091667,-67.6325 ],
    [ u"ve",u"El Tigre",151011,8.8925,-64.2527778 ],
    [ u"ve",u"El Tocuyo",53108,9.7861111,-69.7894444 ],
    [ u"ve",u"El Vigía",59102,8.6219444,-71.6505556 ],
    [ u"ve",u"Goaigoaza",49767,10.4491667,-68.0605556 ],
    [ u"ve",u"Guacara",151788,10.2297222,-67.8738889 ],
    [ u"ve",u"Guanare",112315,9.05,-69.75 ],
    [ u"ve",u"Guarenas",181657,10.4666667,-66.6166667 ],
    [ u"ve",u"Guasdualito",30860,7.2472222,-70.7294444 ],
    [ u"ve",u"Guatire",192291,10.4666667,-66.5333333 ],
    [ u"ve",u"Güigüe",71548,10.0852778,-67.7791667 ],
    [ u"ve",u"La Asunción",35089,11.0333333,-63.8627778 ],
    [ u"ve",u"La Dolorita",56846,10.4905556,-66.7833333 ],
    [ u"ve",u"La Fría",27077,8.2188889,-72.2483333 ],
    [ u"ve",u"La Guaira",25264,10.6,-66.9333333 ],
    [ u"ve",u"Lagunillas",44257,10.1408333,-71.2613889 ],
    [ u"ve",u"La Victoria",87060,10.2333333,-67.3333333 ],
    [ u"ve",u"Los Dos Caminos",58300,10.2372222,-66.6833333 ],
    [ u"ve",u"Los Rastrojos",34636,10.0227778,-69.2444444 ],
    [ u"ve",u"Los Teques",173749,10.35,-67.0333333 ],
    [ u"ve",u"Machiques",62982,10.0644444,-72.545 ],
    [ u"ve",u"Maiquetía",52573,10.6,-66.95 ],
    [ u"ve",u"Maracaibo",1948269,10.6316667,-71.6405556 ],
    [ u"ve",u"Maracay",395412,10.2469444,-67.5958333 ],
    [ u"ve",u"Mariara",105511,10.2983333,-67.7161111 ],
    [ u"ve",u"Maturín",410967,9.75,-63.1766667 ],
    [ u"ve",u"Morón",44319,10.4888889,-68.2002778 ],
    [ u"ve",u"Nirgua",30188,10.155,-68.5630556 ],
    [ u"ve",u"Ocumare del Tuy",166112,10.1216667,-66.7716667 ],
    [ u"ve",u"Palo Negro",128895,10.1738889,-67.5419444 ],
    [ u"ve",u"Petare",365959,10.4833333,-66.8166667 ],
    [ u"ve",u"Porlamar",87131,10.95,-63.85 ],
    [ u"ve",u"Puerto Ayacucho",52528,5.6638889,-67.6236111 ],
    [ u"ve",u"Puerto Cabello",163886,10.4730556,-68.0125 ],
    [ u"ve",u"Punta Cardón",58933,11.6580556,-70.215 ],
    [ u"ve",u"Punto Fijo",131797,11.6997222,-70.1991667 ],
    [ u"ve",u"Quíbor",41533,9.9255556,-69.6202778 ],
    [ u"ve",u"Rubio",51577,7.7072222,-72.3538889 ],
    [ u"ve",u"San Antonio del Táchira",32465,7.8177778,-72.4425 ],
    [ u"ve",u"San Carlos del Zulia",56595,9.0041667,-71.9163889 ],
    [ u"ve",u"San Carlos",77204,9.6666667,-68.6 ],
    [ u"ve",u"San Cristóbal",246620,7.7669444,-72.225 ],
    [ u"ve",u"San Felipe",76779,10.3405556,-68.7372222 ],
    [ u"ve",u"San Joaquín",41630,10.2625,-67.7922222 ],
    [ u"ve",u"San José de Guanipa",62133,8.8933333,-64.1591667 ],
    [ u"ve",u"San Juan de Colón",38240,8.0377778,-72.2519444 ],
    [ u"ve",u"San Juan de los Morros",87752,9.9111111,-67.3583333 ],
    [ u"ve",u"San Mateo",50409,10.2166667,-67.4166667 ],
    [ u"ve",u"Santa Rita",31817,10.5333333,-71.5166667 ],
    [ u"ve",u"Santa Teresa",279424,10.2313889,-66.6636111 ],
    [ u"ve",u"Tacarigua",39215,10.09,-67.9197222 ],
    [ u"ve",u"Táriba",27432,7.8236111,-72.2213889 ],
    [ u"ve",u"Tinaquillo",82157,9.9186111,-68.3047222 ],
    [ u"ve",u"Trujillo",38114,9.3666667,-70.4333333 ],
    [ u"ve",u"Tucupita",51547,9.0686111,-62.0491667 ],
    [ u"ve",u"Turmero",344746,10.2333333,-67.4833333 ],
    [ u"ve",u"Upata",53697,8.0086111,-62.3988889 ],
    [ u"ve",u"Valencia",1385202,10.1805556,-68.0038889 ],
    [ u"ve",u"Valera",93764,9.3177778,-70.6036111 ],
    [ u"ve",u"Villa Bruzual",28001,9.3327778,-69.1208333 ],
    [ u"ve",u"Villa de Cura",76627,10.0333333,-67.4833333 ],
    [ u"ve",u"Villa del Rosario",65025,10.3166667,-72.3166667 ],
    [ u"ve",u"Yaritagua",89677,10.08,-69.1261111 ],
    [ u"ve",u"Zaraza",41490,9.35,-65.3166667 ],
    [ u"vg",u"Little Harbour",84,18.4333333,-64.7166667 ],
    [ u"vg",u"Road Town",8449,18.4166667,-64.6166667 ],
    [ u"vg",u"Spanish Town",355,18.45,-64.4333333 ],
    [ u"vn",u"Bac Can",21837,22.133333,105.833333 ],
    [ u"vn",u"Bac Giang",53732,21.266667,106.2 ],
    [ u"vn",u"Bac Lieu",107920,9.285,105.724444 ],
    [ u"vn",u"Bac Ninh",43564,21.183333,106.05 ],
    [ u"vn",u"Ben Tre",59449,10.233333,106.383333 ],
    [ u"vn",u"Biên Hòa",407224,10.95,106.816667 ],
    [ u"vn",u"Buon Me Thuot",146986,12.666667,108.05 ],
    [ u"vn",u"Cà Mau",111903,9.176944,105.15 ],
    [ u"vn",u"Cam Pha",135487,21.016667,107.316667 ],
    [ u"vn",u"Cam Ranh",146771,11.9,109.15 ],
    [ u"vn",u"Can Tho",259608,10.033333,105.783333 ],
    [ u"vn",u"Cao Bang",41117,22.666667,106.25 ],
    [ u"vn",u"Chau Doc",58039,10.7,105.116667 ],
    [ u"vn",u"Da Lat",131382,11.933333,108.416667 ],
    [ u"vn",u"Da Nang",472255,16.067778,108.220833 ],
    [ u"vn",u"Dien Bien",40292,21.383333,103.016667 ],
    [ u"vn",u"Dong Hoi",31044,17.5,106.633333 ],
    [ u"vn",u"Dong Hoi",31044,17.483333,106.6 ],
    [ u"vn",u"Dong Xoai",23978,11.533333,106.916667 ],
    [ u"vn",u"Hà Giang",32690,22.833333,104.983333 ],
    [ u"vn",u"Hai Duong",58035,20.933333,106.316667 ],
    [ u"vn",u"Hai Phong",602718,20.856111,106.682222 ],
    [ u"vn",u"Hanoi",1431377,21.033333,105.85 ],
    [ u"vn",u"Ha Noi",1431377,21.033333,105.85 ],
    [ u"vn",u"Ha Tinh",26547,18.333333,105.9 ],
    [ u"vn",u"Hòa Bình",105268,20.813333,105.338333 ],
    [ u"vn",u"Ho Chi Minh City",3467426,10.75,106.666667 ],
    [ u"vn",u"Hoi An",32757,15.879444,108.335 ],
    [ u"vn",u"Hong Gai",148072,20.951111,107.08 ],
    [ u"vn",u"Hue",287228,16.466667,107.6 ],
    [ u"vn",u"Kon Tum",47414,14.366667,107.95 ],
    [ u"vn",u"Kon Tum",47414,14.35,108 ],
    [ u"vn",u"Lang Son",34964,21.833333,106.733333 ],
    [ u"vn",u"Lào Cai",36502,22.483333,103.95 ],
    [ u"vn",u"Long Xuyên",158159,10.383333,105.416667 ],
    [ u"vn",u"My Tho",122315,10.35,106.35 ],
    [ u"vn",u"Nam Dinh",193507,20.416667,106.166667 ],
    [ u"vn",u"Nha Trang",283452,12.25,109.183333 ],
    [ u"vn",u"Ninh Bình",36868,20.253889,105.975 ],
    [ u"vn",u"Phan Rang",91520,11.566667,108.983333 ],
    [ u"vn",u"Phan Thiet",160665,10.933333,108.1 ],
    [ u"vn",u"Phu Ly",31818,20.541111,105.913889 ],
    [ u"vn",u"Plây Cu",114234,13.983333,108 ],
    [ u"vn",u"Quang Ngai",32995,15.116667,108.8 ],
    [ u"vn",u"Qui Nhon",210346,13.766667,109.233333 ],
    [ u"vn",u"Rach Gia",228365,10.016667,105.083333 ],
    [ u"vn",u"Soc Trang",114462,9.603333,105.98 ],
    [ u"vn",u"Son La",19054,21.316667,103.9 ],
    [ u"vn",u"Son Tay",40636,21.137778,105.505 ],
    [ u"vn",u"Tam Ky",59000,15.566667,108.483333 ],
    [ u"vn",u"Tân An",64806,10.533333,106.416667 ],
    [ u"vn",u"Tây Ninh",47971,11.3,106.1 ],
    [ u"vn",u"Thái Bình",53095,20.45,106.333333 ],
    [ u"vn",u"Thái Nguyên",133882,21.592778,105.844167 ],
    [ u"vn",u"Thanh Hóa",112482,19.8,105.766667 ],
    [ u"vn",u"Trà Vinh",57413,9.934722,106.345278 ],
    [ u"vn",u"Tuyên Quang",36435,21.823333,105.218056 ],
    [ u"vn",u"Tuy Hòa",69602,13.083333,109.3 ],
    [ u"vn",u"Uông Bí",63829,21.033333,106.783333 ],
    [ u"vn",u"Viet Tri",71462,21.306542,105.418847 ],
    [ u"vn",u"Vinh Long",103323,10.25,105.966667 ],
    [ u"vn",u"Vinh",107130,18.666667,105.666667 ],
    [ u"vn",u"Vinh Yen",17876,21.31,105.596667 ],
    [ u"vn",u"Vung Tau",209699,10.35,107.066667 ],
    [ u"vn",u"Yên Bái",96548,21.7,104.866667 ],
    [ u"vu",u"Isangel",1437,-19.55,169.2666667 ],
    [ u"vu",u"Lakatoro",705,-16.1166667,167.4166667 ],
    [ u"vu",u"Luganville",13398,-15.5333333,167.1666667 ],
    [ u"vu",u"Norsup",2998,-16.0666667,167.3833333 ],
    [ u"vu",u"Sola",1171,-13.8833333,167.55 ],
    [ u"vu",u"Vila",35903,-17.7333333,168.3166667 ],
    [ u"wf",u"Ahoa",495,-13.2833333,-176.2 ],
    [ u"wf",u"Alele",901,-13.2333333,-176.15 ],
    [ u"wf",u"Falaleu",659,-13.3,-176.15 ],
    [ u"wf",u"Gahi",280,-13.3333333,-176.15 ],
    [ u"wf",u"Haatofo",236,-13.3333333,-176.15 ],
    [ u"wf",u"Halalo",635,-13.35,-176.1833333 ],
    [ u"wf",u"Kolia",437,-14.3166667,-178.0833333 ],
    [ u"wf",u"Kolopopo",171,-13.35,-176.1666667 ],
    [ u"wf",u"Leava",480,-14.3,-178.1666667 ],
    [ u"wf",u"Liku",696,-13.2666667,-176.1333333 ],
    [ u"wf",u"Teesi",284,-13.35,-176.1666667 ],
    [ u"wf",u"Tepa",244,-13.3166667,-176.15 ],
    [ u"wf",u"Vailala",451,-13.2166667,-176.15 ],
    [ u"wf",u"Vaitupu",601,-13.2333333,-176.15 ],
    [ u"wf",u"Velé",309,-14.3166667,-178.0666667 ],
    [ u"ws",u"Afega",1895,-13.8,-171.8166667 ],
    [ u"ws",u"Amaile",221,-13.95,-171.3833333 ],
    [ u"ws",u"Aopo",390,-13.4833333,-172.5 ],
    [ u"ws",u"Apia",40407,-13.8333333,-171.7333333 ],
    [ u"ws",u"Asaga",337,-13.5833333,-172.1333333 ],
    [ u"ws",u"Auala",574,-13.4666667,-172.6 ],
    [ u"ws",u"Aufaga",459,-14.0166667,-171.4666667 ],
    [ u"ws",u"Avao",276,-13.45,-172.3666667 ],
    [ u"ws",u"Avata",302,-13.4833333,-172.7833333 ],
    [ u"ws",u"Eva",266,-13.8666667,-171.5833333 ],
    [ u"ws",u"Fagafau",273,-13.5833333,-172.65 ],
    [ u"ws",u"Fagamalo",294,-13.4166667,-172.35 ],
    [ u"ws",u"Faiaai",421,-13.6333333,-172.6333333 ],
    [ u"ws",u"Falealupo",518,-13.5,-172.8 ],
    [ u"ws",u"Faleapuna",584,-13.8666667,-171.5666667 ],
    [ u"ws",u"Faleatiu",847,-13.8166667,-171.9333333 ],
    [ u"ws",u"Falefa",1346,-13.8833333,-171.55 ],
    [ u"ws",u"Falelima",416,-13.5333333,-172.6833333 ],
    [ u"ws",u"Faleolo",16,-13.8166667,-171.9833333 ],
    [ u"ws",u"Faleula",2592,-13.8,-171.8 ],
    [ u"ws",u"Falevai",202,-13.9166667,-171.9833333 ],
    [ u"ws",u"Falevao",552,-13.9,-171.5333333 ],
    [ u"ws",u"Fasitoouta",2098,-13.8166667,-171.9166667 ],
    [ u"ws",u"Fatuvalu",170,-13.4666667,-172.4166667 ],
    [ u"ws",u"Fausaga",303,-14.0166667,-171.8 ],
    [ u"ws",u"Fogasavaii",380,-13.6333333,-172.6 ],
    [ u"ws",u"Fogatuli",273,-13.6166667,-172.6166667 ],
    [ u"ws",u"Fusi",447,-14.0,-171.8 ],
    [ u"ws",u"Gataivai",1141,-13.75,-172.3833333 ],
    [ u"ws",u"Gautavai",171,-13.75,-172.3666667 ],
    [ u"ws",u"Iliili",30,-14.0166667,-171.7 ],
    [ u"ws",u"Lalomalava",399,-13.7,-172.1333333 ],
    [ u"ws",u"Lalomanu",704,-14.0,-171.4 ],
    [ u"ws",u"Lalomauga",406,-13.9,-171.5666667 ],
    [ u"ws",u"Lalovi",322,-13.85,-172.0333333 ],
    [ u"ws",u"Lano",706,-13.6,-172.1333333 ],
    [ u"ws",u"Leagiagi",124,-13.45,-172.4 ],
    [ u"ws",u"Lelepa",213,-13.45,-172.3333333 ],
    [ u"ws",u"Lepa",172,-14.0,-171.45 ],
    [ u"ws",u"Letogo",533,-13.8333333,-171.7 ],
    [ u"ws",u"Letui",273,-13.4666667,-172.4666667 ],
    [ u"ws",u"Leulumoega",1458,-13.8166667,-171.9166667 ],
    [ u"ws",u"Leusoalii",371,-13.85,-171.6666667 ],
    [ u"ws",u"Levi",125,-13.8,-171.85 ],
    [ u"ws",u"Lona",218,-13.9166667,-171.4666667 ],
    [ u"ws",u"Lotofaga",1126,-13.9833333,-171.8333333 ],
    [ u"ws",u"Lufilufi",1074,-13.85,-171.5833333 ],
    [ u"ws",u"Maasina",160,-13.9166667,-171.5 ],
    [ u"ws",u"Malie",2189,-13.8,-171.8166667 ],
    [ u"ws",u"Malua",371,-13.8,-171.8833333 ],
    [ u"ws",u"Manase",158,-13.4333333,-172.3666667 ],
    [ u"ws",u"Maninoa",366,-14.0166667,-171.7833333 ],
    [ u"ws",u"Manunu",284,-13.9,-171.5666667 ],
    [ u"ws",u"Matanofo",80,-13.9166667,-171.9833333 ],
    [ u"ws",u"Matatufu",397,-14.0166667,-171.5333333 ],
    [ u"ws",u"Matautu",203,-13.8166667,-171.7333333 ],
    [ u"ws",u"Mulivai",449,-14.0166667,-171.8 ],
    [ u"ws",u"Musumusu",75,-13.8833333,-171.5 ],
    [ u"ws",u"Mutiatele",283,-13.9833333,-171.3666667 ],
    [ u"ws",u"Nefunefu",141,-13.9166667,-172.0 ],
    [ u"ws",u"Niusuatia",331,-13.9666667,-171.8 ],
    [ u"ws",u"Nofoalii",1828,-13.8166667,-171.9166667 ],
    [ u"ws",u"Paia",308,-13.4666667,-172.4 ],
    [ u"ws",u"Papa",284,-13.4666667,-172.7 ],
    [ u"ws",u"Patamea",597,-13.4833333,-172.2666667 ],
    [ u"ws",u"Pata",549,-13.9166667,-171.9833333 ],
    [ u"ws",u"Piu",69,-14.0,-171.5666667 ],
    [ u"ws",u"Poutasi",378,-14.0166667,-171.6833333 ],
    [ u"ws",u"Puleia",262,-13.75,-172.35 ],
    [ u"ws",u"Saaga",490,-14.0166667,-171.7833333 ],
    [ u"ws",u"Saasaai",520,-13.6166667,-172.1333333 ],
    [ u"ws",u"Safotu",1207,-13.45,-172.4 ],
    [ u"ws",u"Sagone",776,-13.65,-172.5833333 ],
    [ u"ws",u"Saina",230,-13.8166667,-171.7833333 ],
    [ u"ws",u"Saipipi",705,-13.6166667,-172.1333333 ],
    [ u"ws",u"Salani",524,-14.0,-171.55 ],
    [ u"ws",u"Saleaaumua",544,-13.9666667,-171.3666667 ],
    [ u"ws",u"Saleaula",597,-13.4333333,-172.3333333 ],
    [ u"ws",u"Saleia",275,-13.45,-172.3666667 ],
    [ u"ws",u"Saleilua",604,-14.0166667,-171.7 ],
    [ u"ws",u"Salelesi",411,-13.8666667,-171.5833333 ],
    [ u"ws",u"Salesatele",330,-14.0,-171.5666667 ],
    [ u"ws",u"Saletele",160,-13.8833333,-171.5166667 ],
    [ u"ws",u"Salimu",250,-13.65,-172.1166667 ],
    [ u"ws",u"Samalaeulu",789,-13.4666667,-172.2666667 ],
    [ u"ws",u"Samamea",89,-13.9,-171.4666667 ],
    [ u"ws",u"Samatau",939,-13.9,-172.0333333 ],
    [ u"ws",u"Samauga",289,-13.9166667,-171.5666667 ],
    [ u"ws",u"Samea",150,-13.8333333,-172.0166667 ],
    [ u"ws",u"Samusu",686,-13.9666667,-171.3666667 ],
    [ u"ws",u"Sapapalii",877,-13.6833333,-172.1166667 ],
    [ u"ws",u"Sapulu",957,-13.8,-171.8833333 ],
    [ u"ws",u"Sapunaoa",408,-14.0,-171.5666667 ],
    [ u"ws",u"Sasina",566,-13.45,-172.4333333 ],
    [ u"ws",u"Satalo",356,-14.0166667,-171.5833333 ],
    [ u"ws",u"Satapuala",1412,-13.8333333,-171.9666667 ],
    [ u"ws",u"Sataua",771,-13.4666667,-172.6666667 ],
    [ u"ws",u"Satitoa",522,-13.9833333,-171.3666667 ],
    [ u"ws",u"Satoalepai",235,-13.45,-172.3333333 ],
    [ u"ws",u"Satuiatua",304,-13.6833333,-172.55 ],
    [ u"ws",u"Sauniatu",81,-13.9166667,-171.5666667 ],
    [ u"ws",u"Savaia",395,-13.9333333,-171.9333333 ],
    [ u"ws",u"Sili",868,-13.7166667,-172.35 ],
    [ u"ws",u"Siuniu",104,-14.0,-171.55 ],
    [ u"ws",u"Siupapa",53,-14.0166667,-171.45 ],
    [ u"ws",u"Siusega",2226,-13.8333333,-171.8166667 ],
    [ u"ws",u"Siutu",648,-13.6833333,-172.55 ],
    [ u"ws",u"Solosolo",1487,-13.85,-171.6 ],
    [ u"ws",u"Taelefaga",183,-13.9166667,-171.5166667 ],
    [ u"ws",u"Tafagamanu",314,-13.95,-171.9166667 ],
    [ u"ws",u"Tafatafa",224,-14.0166667,-171.65 ],
    [ u"ws",u"Tafitoala",393,-14.0166667,-171.8 ],
    [ u"ws",u"Tafua",403,-13.7833333,-172.2166667 ],
    [ u"ws",u"Taga",680,-13.7666667,-172.4666667 ],
    [ u"ws",u"Tapueleele",228,-13.6333333,-172.1666667 ],
    [ u"ws",u"Toamua",778,-13.8,-171.7833333 ],
    [ u"ws",u"Tuasivi",365,-13.6666667,-172.1166667 ],
    [ u"ws",u"Tufulele",905,-13.8,-171.8833333 ],
    [ u"ws",u"Tufutafoe",330,-13.4833333,-172.7666667 ],
    [ u"ws",u"Uafato",301,-13.9333333,-171.4333333 ],
    [ u"ws",u"Ulutogia",195,-14.0,-171.3833333 ],
    [ u"ws",u"Utufaalalafa",89,-13.9666667,-171.3666667 ],
    [ u"ws",u"Utulaelae",166,-14.0166667,-171.55 ],
    [ u"ws",u"Utuloa",34,-13.4666667,-172.5833333 ],
    [ u"ws",u"Vaiala",221,-13.8166667,-171.7166667 ],
    [ u"ws",u"Vaiee",497,-14.0,-171.8166667 ],
    [ u"ws",u"Vaigaga",760,-13.8166667,-171.8 ],
    [ u"ws",u"Vaigalu",97,-14.0166667,-171.45 ],
    [ u"ws",u"Vailoa",336,-14.0,-171.3833333 ],
    [ u"ws",u"Vaipouli",171,-13.45,-172.35 ],
    [ u"ws",u"Vaipua",417,-13.6333333,-172.6166667 ],
    [ u"ws",u"Vaisala",599,-13.4666667,-172.6166667 ],
    [ u"ws",u"Vaitele",5631,-13.8166667,-171.7833333 ],
    [ u"ws",u"Vaiusu",2043,-13.8166667,-171.7666667 ],
    [ u"ws",u"Vaotupua",183,-13.5,-172.8 ],
    [ u"ws",u"Vaovai",577,-14.0166667,-171.65 ],
    [ u"ws",u"Vavau",383,-14.0166667,-171.4833333 ],
    [ u"ye",u"Aden",550744,12.7794444,45.0366667 ],
    [ u"ye",u"Bajil",48217,15.0666667,43.2833333 ],
    [ u"ye",u"Ibb",234992,13.9666667,44.1833333 ],
    [ u"ye",u"Jiblah",9627,13.9166667,44.15 ],
    [ u"ye",u"Lahij",23377,13.0566667,44.8819444 ],
    [ u"ye",u"Sayyan",69402,15.1663889,44.3280556 ],
    [ u"ye",u"Yarim",33049,14.2972222,44.3802778 ],
    [ u"ye",u"Zabid",52589,14.1947222,43.3155556 ],
    [ u"yt",u"Acoua",5350,-12.7225,45.0563889 ],
    [ u"yt",u"Bandraboua",7882,-12.7016667,45.1205556 ],
    [ u"yt",u"Bandrélé",6352,-12.9066667,45.1913889 ],
    [ u"yt",u"Bouéni",5335,-12.9025,45.0761111 ],
    [ u"yt",u"Chiconi",7205,-12.8333333,45.1105556 ],
    [ u"yt",u"Chirongui",6174,-12.9319444,45.1483333 ],
    [ u"yt",u"Dzaoudzi",14144,-12.7794444,45.2536111 ],
    [ u"yt",u"Koungou",18121,-12.7336111,45.2041667 ],
    [ u"yt",u"Mamoudzou",54837,-12.7794444,45.2272222 ],
    [ u"yt",u"Mtsamboro",7725,-12.6966667,45.0666667 ],
    [ u"yt",u"Ouangani",7273,-12.8463889,45.1361111 ],
    [ u"yt",u"Sada",9834,-12.8480556,45.0975 ],
    [ u"yt",u"Tsingoni",7603,-12.7872222,45.1027778 ],
    [ u"za",u"Adelaide",12212,-32.707468,26.295638 ],
    [ u"za",u"Alberton",202503,-26.265207,28.140595 ],
    [ u"za",u"Alice",9788,-32.787493,26.834396 ],
    [ u"za",u"Aliwal North",44475,-30.693664,26.711407 ],
    [ u"za",u"Allanridge",31718,-27.754306,26.643825 ],
    [ u"za",u"Atlantis",60269,-33.56668,18.483348 ],
    [ u"za",u"Balfour",46039,-26.663308,28.590159 ],
    [ u"za",u"Ballitoville",17218,-29.538969,31.214386 ],
    [ u"za",u"Barberton",67971,-25.788422,31.053194 ],
    [ u"za",u"Barkly West",11621,-28.535366,24.521506 ],
    [ u"za",u"Belfast",11916,-25.689911,30.035043 ],
    [ u"za",u"Benoni",605363,-26.190851,28.311338 ],
    [ u"za",u"Bethal",101986,-26.426373,29.468704 ],
    [ u"za",u"Bethlehem",83658,-28.230779,28.307071 ],
    [ u"za",u"Bisho",137288,-32.847212,27.442179 ],
    [ u"za",u"Bloemfontein",463084,-29.121065,26.214003 ],
    [ u"za",u"Bloemhof",17122,-27.646855,25.606973 ],
    [ u"za",u"Boksburg",445182,-26.214953,28.254732 ],
    [ u"za",u"Botshabelo",309810,-29.123036,26.773654 ],
    [ u"za",u"Brakpan",305702,-26.236561,28.369378 ],
    [ u"za",u"Brandfort",12091,-28.700083,26.459684 ],
    [ u"za",u"Bredasdorp",14936,-34.532154,20.040308 ],
    [ u"za",u"Breyten",12550,-26.301761,29.986961 ],
    [ u"za",u"Brits",122576,-25.634731,27.780224 ],
    [ u"za",u"Bronkhorstspruit",27343,-25.810153,28.742483 ],
    [ u"za",u"Burgersdorp",12548,-30.997659,26.328623 ],
    [ u"za",u"Butterworth",34353,-32.330833,28.149808 ],
    [ u"za",u"Caledon",4687,-34.229974,19.426502 ],
    [ u"za",u"Calvinia",8146,-31.470688,19.776008 ],
    [ u"za",u"Cape Town",3433504,-33.925839,18.423218 ],
    [ u"za",u"Carnarvon",5785,-30.968266,22.133026 ],
    [ u"za",u"Ceres",41598,-33.368892,19.310955 ],
    [ u"za",u"Christiana",17523,-27.914023,25.161111 ],
    [ u"za",u"Clocolan",12318,-28.913669,27.565555 ],
    [ u"za",u"Colesberg",12424,-30.719994,25.097185 ],
    [ u"za",u"Cradock",32900,-32.164221,25.619176 ],
    [ u"za",u"Cullinan",25490,-25.670885,28.523645 ],
    [ u"za",u"Daniëlskuil",10123,-28.18873,23.539508 ],
    [ u"za",u"De Aar",32322,-30.649657,24.012295 ],
    [ u"za",u"Delmas",92181,-26.146601,28.683222 ],
    [ u"za",u"Deneysville",12397,-26.890798,28.097067 ],
    [ u"za",u"Dordrecht",9123,-31.371997,27.048779 ],
    [ u"za",u"Duiwelskloof",24572,-23.693394,30.140016 ],
    [ u"za",u"Dundee",84430,-28.166784,30.233707 ],
    [ u"za",u"Durban",3120340,-29.857896,31.029198 ],
    [ u"za",u"East London",421562,-33.011051,27.910049 ],
    [ u"za",u"Ekangala",37650,-25.696193,28.749183 ],
    [ u"za",u"Ekuvukeni",14331,-28.467523,30.155126 ],
    [ u"za",u"Elliot",11836,-31.333333,27.85 ],
    [ u"za",u"Ellisras",15360,-23.6649,27.744263 ],
    [ u"za",u"Empangeni",28094,-28.761974,31.893293 ],
    [ u"za",u"Ermelo",41201,-26.533333,29.983333 ],
    [ u"za",u"Eshowe",14786,-28.886485,31.469903 ],
    [ u"za",u"Fochville",62528,-26.488624,27.493869 ],
    [ u"za",u"Fort Beaufort",58469,-32.774769,26.633756 ],
    [ u"za",u"Frankfort",38055,-27.266667,28.483333 ],
    [ u"za",u"George",174591,-33.963,22.461727 ],
    [ u"za",u"Giyani",37047,-23.30246,30.718682 ],
    [ u"za",u"Glencoe",13547,-28.178269,30.147024 ],
    [ u"za",u"Graaff-Reinet",62921,-32.25,24.55 ],
    [ u"za",u"Grabouw",29897,-34.151519,19.015091 ],
    [ u"za",u"Grahamstown",91552,-33.304216,26.53276 ],
    [ u"za",u"Greytown",13912,-29.064155,30.592786 ],
    [ u"za",u"Harrismith",35108,-28.272758,29.129462 ],
    [ u"za",u"Heidelberg",64201,-26.504759,28.359214 ],
    [ u"za",u"Heilbron",55237,-27.281154,27.970901 ],
    [ u"za",u"Hendrina",15871,-26.158806,29.715284 ],
    [ u"za",u"Hennenman",22847,-27.976539,27.024227 ],
    [ u"za",u"Hermanus",25153,-34.418696,19.234464 ],
    [ u"za",u"Hoopstad",12663,-27.832735,25.908326 ],
    [ u"za",u"Howick",28726,-29.477947,30.230571 ],
    [ u"za",u"Ilinge",10899,-31.976764,27.042674 ],
    [ u"za",u"Jan Kempdorp",13485,-27.922456,24.830515 ],
    [ u"za",u"Johannesburg",2026466,-26.205171,28.049815 ],
    [ u"za",u"Kathu",9219,-27.695692,23.049289 ],
    [ u"za",u"Kimberley",142105,-28.732262,24.762315 ],
    [ u"za",u"Kirkwood",10148,-33.398287,25.442785 ],
    [ u"za",u"Klerksdorp",178928,-26.852128,26.666719 ],
    [ u"za",u"Knysna",63110,-34.036643,23.049704 ],
    [ u"za",u"Kokstad",25373,-30.547231,29.42412 ],
    [ u"za",u"Komatipoort",20523,-25.433205,31.954777 ],
    [ u"za",u"Koppies",11445,-27.241789,27.574222 ],
    [ u"za",u"Koster",12126,-25.863009,26.897561 ],
    [ u"za",u"Kriel",15055,-26.27391,29.225301 ],
    [ u"za",u"Kroonstad",103997,-27.65036,27.234879 ],
    [ u"za",u"Krugersdorp",378833,-26.092835,27.790701 ],
    [ u"za",u"Kruisfontein",18991,-34.003333,24.731417 ],
    [ u"za",u"Kuruman",9093,-27.452402,23.432456 ],
    [ u"za",u"Ladybrand",17228,-29.194483,27.45739 ],
    [ u"za",u"Lady Frere",25041,-31.703118,27.232904 ],
    [ u"za",u"Lebowakgomo",33329,-24.2,29.5 ],
    [ u"za",u"Lichtenburg",65863,-26.152004,26.159679 ],
    [ u"za",u"Louis Trichardt",86854,-23.043853,29.90319 ],
    [ u"za",u"Lydenburg",21695,-25.097803,30.459672 ],
    [ u"za",u"Mabopane",97417,-25.497677,28.100654 ],
    [ u"za",u"Malmesbury",34993,-33.460657,18.728704 ],
    [ u"za",u"Margate",34407,-30.863595,30.370522 ],
    [ u"za",u"Marquard",10839,-28.664489,27.430481 ],
    [ u"za",u"Messina",20191,-22.351308,30.039597 ],
    [ u"za",u"Middelburg",18164,-31.492849,25.00633 ],
    [ u"za",u"Middelburg",154720,-25.775071,29.464821 ],
    [ u"za",u"Midrand",173009,-25.963611,28.137778 ],
    [ u"za",u"Mmabatho",76897,-25.85,25.633333 ],
    [ u"za",u"Mogwase",11601,-25.185052,27.266543 ],
    [ u"za",u"Molteno",10078,-31.396755,26.362457 ],
    [ u"za",u"Mondlo",44924,-27.982991,30.717694 ],
    [ u"za",u"Mooi River",10132,-29.208242,29.994598 ],
    [ u"za",u"Mpophomeni",26230,-29.568219,30.186182 ],
    [ u"za",u"Nelspruit",110170,-25.474482,30.970333 ],
    [ u"za",u"Newcastle",404849,-27.757956,29.931803 ],
    [ u"za",u"Nigel",140649,-26.431376,28.477132 ],
    [ u"za",u"Nkowakowa",30157,-23.887823,30.287081 ],
    [ u"za",u"Nylstroom",20527,-24.7,28.4 ],
    [ u"za",u"Orkney",145843,-26.980232,26.672717 ],
    [ u"za",u"Oudtshoorn",76713,-33.592343,22.205482 ],
    [ u"za",u"Paarl",187875,-33.733781,18.975228 ],
    [ u"za",u"Pampierstad",21800,-27.783235,24.687685 ],
    [ u"za",u"Parys",71373,-26.903296,27.457268 ],
    [ u"za",u"Phalaborwa",109468,-23.942987,31.141073 ],
    [ u"za",u"Phuthaditjhaba",84286,-28.52423,28.81582 ],
    [ u"za",u"Pietermaritzburg",750864,-29.616785,30.39278 ],
    [ u"za",u"Pietersburg",123754,-23.904485,29.468851 ],
    [ u"za",u"Piet Retief",84403,-27.007063,30.813231 ],
    [ u"za",u"Plettenberg Bay",19445,-34.052742,23.3716 ],
    [ u"za",u"Port Alfred",17959,-33.590572,26.891037 ],
    [ u"za",u"Port Elizabeth",967722,-33.917988,25.570066 ],
    [ u"za",u"Port Shepstone",52804,-30.741369,30.454992 ],
    [ u"za",u"Potchefstroom",123674,-26.716667,27.1 ],
    [ u"za",u"Potgietersrus",101090,-24.201369,28.986761 ],
    [ u"za",u"Pretoria",1619485,-25.706944,28.229444 ],
    [ u"za",u"Prieska",11236,-29.664088,22.747421 ],
    [ u"za",u"Queenstown",105315,-31.897563,26.875329 ],
    [ u"za",u"Randfontein",133659,-26.178429,27.690266 ],
    [ u"za",u"Reitz",16637,-27.801383,28.427264 ],
    [ u"za",u"Richards Bay",253156,-28.775417,32.054005 ],
    [ u"za",u"Richmond",32445,-29.871962,30.272352 ],
    [ u"za",u"Ritchie",9960,-29.038006,24.60278 ],
    [ u"za",u"Robertson",25217,-33.803418,19.885374 ],
    [ u"za",u"Rustenburg",124064,-25.667562,27.242079 ],
    [ u"za",u"Saldanha",68288,-33.01167,17.944202 ],
    [ u"za",u"Sasolburg",77016,-26.815934,27.829707 ],
    [ u"za",u"Scottsburgh",23949,-30.286656,30.753161 ],
    [ u"za",u"Secunda",20452,-26.55,29.166667 ],
    [ u"za",u"Senekal",39614,-28.319708,27.620816 ],
    [ u"za",u"Siyabuswa",26239,-25.113194,29.044538 ],
    [ u"za",u"Somerset East",16155,-32.721727,25.588041 ],
    [ u"za",u"Somerset West",183503,-34.079375,18.85699 ],
    [ u"za",u"Soweto",1695094,-26.267812,27.858492 ],
    [ u"za",u"Springbok",10438,-29.664336,17.886495 ],
    [ u"za",u"Springs",186400,-26.25,28.4 ],
    [ u"za",u"Standerton",74028,-26.933655,29.241518 ],
    [ u"za",u"Stanger",59901,-29.328164,31.289537 ],
    [ u"za",u"Stellenbosch",94268,-33.934621,18.866762 ],
    [ u"za",u"Stilfontein",93138,-26.844926,26.768294 ],
    [ u"za",u"Stutterheim",35524,-32.57076,27.423961 ],
    [ u"za",u"Sundumbili",12455,-29.133711,31.397521 ],
    [ u"za",u"Swellendam",13675,-34.022624,20.441706 ],
    [ u"za",u"Temba",47983,-25.381708,28.264376 ],
    [ u"za",u"Tembisa",511671,-25.996363,28.226802 ],
    [ u"za",u"Thaba Nchu",38616,-29.209325,26.838982 ],
    [ u"za",u"Thabazimbi",10365,-24.59165,27.411551 ],
    [ u"za",u"Theunissen",34745,-28.410979,26.701068 ],
    [ u"za",u"Thohoyandou",44046,-22.945642,30.484972 ],
    [ u"za",u"Tzaneen",16954,-23.833222,30.163506 ],
    [ u"za",u"Uitenhage",228924,-33.75757,25.397099 ],
    [ u"za",u"Ulundi",20763,-28.335233,31.416172 ],
    [ u"za",u"Umkomaas",20410,-30.206742,30.797759 ],
    [ u"za",u"Umtata",78663,-31.588926,28.784431 ],
    [ u"za",u"Umzimvubu",5939,-31.622911,29.544772 ],
    [ u"za",u"Upington",71381,-28.447758,21.256121 ],
    [ u"za",u"Utrecht",3575,-27.658623,30.32166 ],
    [ u"za",u"Vanderbijlpark",246821,-26.711711,27.837949 ],
    [ u"za",u"Ventersburg",10698,-28.085614,27.138143 ],
    [ u"za",u"Vereeniging",474680,-26.673133,27.926147 ],
    [ u"za",u"Verwoerdburg",233394,-25.840795,28.176102 ],
    [ u"za",u"Viljoenskroon",55025,-27.208406,26.948553 ],
    [ u"za",u"Villiers",11240,-27.030256,28.600612 ],
    [ u"za",u"Virginia",122542,-28.10391,26.86593 ],
    [ u"za",u"Volksrust",43382,-27.365415,29.881752 ],
    [ u"za",u"Vredefort",10649,-27.008048,27.364601 ],
    [ u"za",u"Vredendal",14806,-31.668329,18.501192 ],
    [ u"za",u"Vrede",14622,-27.425734,29.165854 ],
    [ u"za",u"Vryburg",49590,-26.956588,24.728403 ],
    [ u"za",u"Vryheid",150079,-27.76952,30.791653 ],
    [ u"za",u"Warmbad",90300,-24.883333,28.283333 ],
    [ u"za",u"Warrenton",17946,-28.113955,24.847526 ],
    [ u"za",u"Welkom",432070,-27.986442,26.706612 ],
    [ u"za",u"Wesselsbron",42599,-27.854904,26.365827 ],
    [ u"za",u"Westonaria",156831,-26.319055,27.648605 ],
    [ u"za",u"Whittlesea",12080,-32.175877,26.824372 ],
    [ u"za",u"Willowmore",7100,-33.292647,23.489537 ],
    [ u"za",u"Winburg",11072,-28.518046,27.009331 ],
    [ u"za",u"Witbank",262514,-25.871331,29.233234 ],
    [ u"za",u"Witrivier",15954,-25.319558,31.019234 ],
    [ u"za",u"Wolmaranstad",49436,-27.197395,25.983106 ],
    [ u"za",u"Worcester",127604,-33.64651,19.448523 ],
    [ u"za",u"Zastron",12449,-30.302249,27.083951 ],
    [ u"za",u"Zeerust",17708,-25.536951,26.075117 ],
    [ u"zm",u"Chadiza",3690,-14.0666667,32.4333333 ],
    [ u"zm",u"Chama",4061,-11.2,33.1666667 ],
    [ u"zm",u"Chambishi",11073,-12.65,28.0833333 ],
    [ u"zm",u"Chibombo",4477,-14.65,28.0666667 ],
    [ u"zm",u"Chililabombwe",57335,-12.3666667,27.8333333 ],
    [ u"zm",u"Chingola",148583,-12.5333333,27.85 ],
    [ u"zm",u"Chinsali",14016,-10.55,32.0666667 ],
    [ u"zm",u"Chipata",85973,-13.6333333,32.65 ],
    [ u"zm",u"Choma",46751,-16.8166667,26.9833333 ],
    [ u"zm",u"Chongwe",6057,-15.35,28.7 ],
    [ u"zm",u"Gwembe",2052,-16.5,27.6166667 ],
    [ u"zm",u"Isoka",13123,-10.1333333,32.6333333 ],
    [ u"zm",u"Kabompo",6592,-13.6,24.2 ],
    [ u"zm",u"Kabwe",189006,-14.4333333,28.45 ],
    [ u"zm",u"Kafue",47558,-15.7666667,28.1833333 ],
    [ u"zm",u"Kalabo",7732,-14.9666667,22.6833333 ],
    [ u"zm",u"Kalengwa",7574,-13.4666667,25.0 ],
    [ u"zm",u"Kalomo",12485,-17.05,26.5 ],
    [ u"zm",u"Kalulushi",66583,-12.8333333,28.0833333 ],
    [ u"zm",u"Kansanshi",40711,-12.1,26.4333333 ],
    [ u"zm",u"Kaoma",14214,-14.7833333,24.8 ],
    [ u"zm",u"Kapiri Mposhi",37948,-13.9666667,28.6833333 ],
    [ u"zm",u"Kaputa",2683,-8.4666667,29.6666667 ],
    [ u"zm",u"Kasama",91063,-10.2,31.2 ],
    [ u"zm",u"Kasempa",5622,-13.45,25.8333333 ],
    [ u"zm",u"Katete",12507,-14.05,32.0833333 ],
    [ u"zm",u"Kawambwa",20589,-9.7833333,29.0833333 ],
    [ u"zm",u"Kitwe",400955,-12.8166667,28.2 ],
    [ u"zm",u"Limulunga",7461,-15.1,23.15 ],
    [ u"zm",u"Livingstone",109218,-17.85,25.8666667 ],
    [ u"zm",u"Luangwa",3065,-15.6166667,30.4166667 ],
    [ u"zm",u"Luanshya",113379,-13.1333333,28.4 ],
    [ u"zm",u"Lukulu",3349,-14.3833333,23.25 ],
    [ u"zm",u"Lundazi",11637,-12.3,33.1833333 ],
    [ u"zm",u"Lusaka",1267458,-15.4166667,28.2833333 ],
    [ u"zm",u"Luwingu",6161,-10.2666667,29.9 ],
    [ u"zm",u"Maamba",12251,-17.3666667,27.15 ],
    [ u"zm",u"Mansa",42280,-11.2,28.8833333 ],
    [ u"zm",u"Mazabuka",64014,-15.8666667,27.7666667 ],
    [ u"zm",u"Mbala",20572,-8.8333333,31.3833333 ],
    [ u"zm",u"Mkushi",12308,-13.6166667,29.4 ],
    [ u"zm",u"Mongu",52539,-15.25,23.1333333 ],
    [ u"zm",u"Monze",30261,-16.2833333,27.4833333 ],
    [ u"zm",u"Mpika",28448,-11.8333333,31.45 ],
    [ u"zm",u"Mpongwe",8997,-13.5333333,28.15 ],
    [ u"zm",u"Mporokoso",3401,-9.3833333,30.1333333 ],
    [ u"zm",u"Mpulungu",8547,-8.7666667,31.1333333 ],
    [ u"zm",u"Mufulira",120516,-12.55,28.2333333 ],
    [ u"zm",u"Mufumbwe",6155,-13.6833333,24.8 ],
    [ u"zm",u"Mumbwa",19090,-14.9833333,27.0666667 ],
    [ u"zm",u"Mungwi",6821,-10.1666667,31.3833333 ],
    [ u"zm",u"Mwense",4378,-10.3833333,28.6833333 ],
    [ u"zm",u"Mwinilunga",13800,-11.7333333,24.4333333 ],
    [ u"zm",u"Nakambala",10425,-15.8333333,27.7666667 ],
    [ u"zm",u"Nakonde",10652,-9.3333333,32.7666667 ],
    [ u"zm",u"Namwala",4450,-15.75,26.45 ],
    [ u"zm",u"Nchelenge",23695,-9.35,28.7333333 ],
    [ u"zm",u"Ndola",394559,-12.9666667,28.6333333 ],
    [ u"zm",u"Nyimba",1336,-14.55,30.8333333 ],
    [ u"zm",u"Petauke",19299,-14.25,31.3333333 ],
    [ u"zm",u"Samfya",20472,-11.35,29.55 ],
    [ u"zm",u"Senanga",10006,-16.1166667,23.2666667 ],
    [ u"zm",u"Serenje",8780,-13.2333333,30.2333333 ],
    [ u"zm",u"Sesheke",20162,-17.4666667,24.3 ],
    [ u"zm",u"Siavonga",18651,-16.5333333,28.7166667 ],
    [ u"zm",u"Sinazongwe",11528,-17.25,27.4666667 ],
    [ u"zm",u"Solwezi",4846,-12.1833333,26.4 ],
    [ u"zm",u"Zambezi",7075,-13.55,23.1166667 ],
    [ u"zw",u"Beitbridge",11865,-22.2166667,30.0 ],
    [ u"zw",u"Bindura",22497,-17.2963889,31.3297222 ],
    [ u"zw",u"Bulawayo",897249,-20.15,28.5833333 ],
    [ u"zw",u"Chegutu",45538,-18.1333333,30.15 ],
    [ u"zw",u"Chinhoyi",77007,-17.3666667,30.2 ],
    [ u"zw",u"Chipinge",11278,-20.2,32.6166667 ],
    [ u"zw",u"Chiredzi",13030,-21.05,31.6666667 ],
    [ u"zw",u"Chitungwiza",456206,-17.9938889,31.0480556 ],
    [ u"zw",u"Gwanda",20731,-20.9333333,29.0 ],
    [ u"zw",u"Gweru",201879,-19.45,29.8166667 ],
    [ u"zw",u"Harare",2213701,-17.8177778,31.0447222 ],
    [ u"zw",u"Hwange",41632,-18.3666667,26.4833333 ],
    [ u"zw",u"Kadoma",100276,-18.35,29.9166667 ],
    [ u"zw",u"Kariba",34797,-16.5166667,28.8 ],
    [ u"zw",u"Karoi",24981,-16.8166667,29.6833333 ],
    [ u"zw",u"Kwekwe",116332,-18.9166667,29.8166667 ],
    [ u"zw",u"Marondera",82294,-18.1833333,31.55 ],
    [ u"zw",u"Masvingo",86772,-20.0833333,30.8333333 ],
    [ u"zw",u"Mount Darwin",11963,-16.7833333,31.5833333 ],
    [ u"zw",u"Mutare",253449,-18.9666667,32.6666667 ],
    [ u"zw",u"Mutoko",11380,-17.4,32.2166667 ],
    [ u"zw",u"Mvuma",6498,-19.2833333,30.5333333 ],
    [ u"zw",u"Norton",19519,-17.8833333,30.7 ],
    [ u"zw",u"Redcliffe",38231,-19.0333333,29.7833333 ],
    [ u"zw",u"Rusape",23761,-18.5333333,32.1166667 ],
    [ u"zw",u"Shurugwi",17107,-19.6666667,30.0 ],
    [ u"zw",u"Victoria Falls",36702,-17.9333333,25.8333333 ],
    [ u"zw",u"Zvishavane",79876,-20.3333333,30.0333333 ]
]
